import { __decorate, __metadata, __param } from 'tslib';
import { Injectable, ViewContainerRef, Directive, ElementRef, ChangeDetectorRef, Component, EventEmitter, ComponentFactoryResolver, Input, Output, ViewChild, ViewEncapsulation, Pipe, HostListener, ApplicationRef, Injector, TemplateRef, Renderer2, forwardRef, KeyValueDiffers, Inject, ChangeDetectionStrategy, ContentChildren, QueryList, ContentChild, NgModule, CUSTOM_ELEMENTS_SCHEMA } from '@angular/core';
import { NG_VALIDATORS, NG_VALUE_ACCESSOR, NgControl, NgModel, FormsModule } from '@angular/forms';
import { DatePipe, AsyncPipe, CommonModule } from '@angular/common';
import { RouterModule } from '@angular/router';
import { Subject } from 'rxjs';
import { isDate } from 'rxjs/internal/util/isDate';
import { isNullOrUndefined } from 'util';
import { of, timer, Subject as Subject$1 } from 'rxjs/index';
import { repeatWhen, flatMap, takeWhile, map } from 'rxjs/internal/operators';
import { trigger, transition, style, animate, state } from '@angular/animations';

var UiElement_1;
let UiElement = UiElement_1 = class UiElement {
    static disableScroll() {
        if (window.addEventListener) { // older FF
            window.addEventListener('DOMMouseScroll', preventDefault, false);
        }
        window.onwheel = preventDefault; // modern standard
        // window.onmousewheel = document.onmousewheel = preventDefault; // older browsers, IE
        window.ontouchmove = preventDefault; // mobile
        document.onkeydown = preventDefaultForScrollKeys;
    }
    static enableScroll() {
        if (window.removeEventListener) {
            window.removeEventListener('DOMMouseScroll', preventDefault, false);
        }
        // window.onmousewheel = document.onmousewheel = null;
        window.onwheel = null;
        window.ontouchmove = null;
        document.onkeydown = null;
    }
    static closest(el, selector) {
        /* Source: http://stackoverflow.com/questions/18663941/finding-closest-element-without-jquery */
        let matchesFn = null;
        // find vendor prefix
        ['matches', 'webkitMatchesSelector', 'mozMatchesSelector', 'msMatchesSelector', 'oMatchesSelector'].some(function (fn) {
            if (typeof document.body[fn] === 'function') {
                matchesFn = fn;
                return true;
            }
            return false;
        });
        let parent;
        // traverse parents
        while (el) {
            parent = el.parentElement;
            if (parent && parent[matchesFn](selector)) {
                return parent;
            }
            el = parent;
        }
        return null;
    }
    static index(el) {
        const nodes = el.parentNode.childNodes;
        let node;
        let count;
        let i = count = 0;
        while ((node = nodes.item(i++)) && node !== el) {
            if (node.nodeType === 1) {
                count++;
            }
        }
        return count;
    }
    static trigger(el, eventToTrigger) {
        const event = document.createEvent('HTMLEvents');
        event.initEvent(eventToTrigger, true, false);
        el.dispatchEvent(event);
    }
    static on(el, events, listener) {
        let elements;
        if (el.constructor === NodeList) {
            elements = el;
        }
        else {
            elements = [el];
        }
        events = events.split(' ');
        Array.prototype.forEach.call(elements, el2 => {
            events.forEach(event => el2.addEventListener(event, listener, false));
        });
    }
    static off(el, events, listener) {
        events = events.split(' ');
        const iLen = events.length;
        for (let i = 0; i < iLen; i++) {
            if (events[i]) {
                el.removeEventListener(events[i], listener, false);
            }
        }
    }
    static is(el, selector) {
        const matches = el.matches || el.matchesSelector || el.msMatchesSelector || el.mozMatchesSelector || el.webkitMatchesSelector || el.oMatchesSelector;
        if (matches) {
            return (matches).call(el, selector);
        }
        else {
            return null;
        }
    }
    static position(el, withoutScroll) {
        /* http://javascript.info/tutorial/coordinates */
        if (el.getBoundingClientRect) {
            return getOffsetRect(el);
        }
        else { // old browser
            return getOffsetSum(el);
        }
        function getOffsetSum(elem) {
            /* Source: http://javascript.info/tutorial/coordinates */
            let top = 0, left = 0;
            while (elem) {
                top = top + parseInt(elem.offsetTop, 10);
                left = left + parseInt(elem.offsetLeft, 10);
                elem = elem.offsetParent;
            }
            return { top: top, left: left };
        }
        function getOffsetRect(elem) {
            /* http://javascript.info/tutorial/coordinates */
            const box = elem.getBoundingClientRect();
            const body = document.body;
            const docElem = document.documentElement;
            let scrollTop = 0;
            let scrollLeft = 0;
            if (!withoutScroll) {
                scrollTop = window.pageYOffset || docElem.scrollTop || body.scrollTop;
                scrollLeft = window.pageXOffset || docElem.scrollLeft || body.scrollLeft;
            }
            const clientTop = docElem.clientTop || body.clientTop || 0;
            const clientLeft = docElem.clientLeft || body.clientLeft || 0;
            const top = box.top + scrollTop - clientTop;
            const left = box.left + scrollLeft - clientLeft;
            return { top: Math.round(top), left: Math.round(left) };
        }
    }
    static offset(el) {
        const top = el.offsetTop;
        const left = el.offsetLeft;
        return { top: Math.round(top), left: Math.round(left) };
    }
    static animate(object, property, start_value, end_value, time, end, tick) {
        const propWithPx = ['width', 'height', 'left', 'top', 'border-radius', 'border-spacing', 'margin-left', 'margin-top'];
        const frame_rate = 0.06; // 60 FPS
        let frame = 0;
        const delta = (end_value - start_value) / time / frame_rate;
        const handle = setInterval(() => {
            frame++;
            const value = start_value + delta * frame;
            if (tick) {
                tick(value);
            }
            const hasPx = propWithPx.indexOf(property) > -1;
            object.style[property] = value + (hasPx ? 'px' : '');
            if ((start_value > end_value ? value.toFixed(2) <= end_value : value.toFixed(2) >= end_value)) {
                clearInterval(handle);
                if (end) {
                    end();
                }
            }
        }, 1 / frame_rate);
    }
    static css(el, styleProp, newValue) {
        if (typeof newValue !== 'undefined') {
            styleProp = styleProp.replace(/-([a-z])/g, function (g) {
                return g[1].toUpperCase();
            });
            el.style[styleProp] = newValue;
        }
        else {
            let value;
            const defaultView = (el.ownerDocument || document).defaultView;
            // W3C standard way:
            if (defaultView && defaultView.getComputedStyle) {
                // sanitize property name to css notation
                // (hyphen separated words eg. font-Size)
                styleProp = styleProp.replace(/([A-Z])/g, '-$1').toLowerCase();
                return defaultView.getComputedStyle(el, null).getPropertyValue(styleProp);
            }
            else if (el.currentStyle) { // IE
                // sanitize property name to camelCase
                styleProp = styleProp.replace(/-(\w)/g, function (str, letter) {
                    return letter.toUpperCase();
                });
                value = el.currentStyle[styleProp];
                // convert other units to pixels on IE
                if (/^\d+(em|pt|%|ex)?$/i.test(value)) {
                    return (function (value2) {
                        const oldLeft = el.style.left;
                        const oldRsLeft = el.runtimeStyle.left;
                        el.runtimeStyle.left = el.currentStyle.left;
                        el.style.left = value2 || 0;
                        value2 = el.style.pixelLeft + 'px';
                        el.style.left = oldLeft;
                        el.runtimeStyle.left = oldRsLeft;
                        return value2;
                    })(value);
                }
                return value;
            }
        }
    }
    static isInViewport(el) {
        const rect = el.getBoundingClientRect();
        return (rect.top >= 0 &&
            rect.left >= 0 &&
            rect.top <= (window.innerHeight || document.documentElement.clientHeight) &&
            rect.left <= (window.innerWidth || document.documentElement.clientWidth));
    }
    static focus(el) {
        el.focus();
        const headerSpace = document.querySelector('ui-toolbar header').clientHeight + 16;
        const elTop = UiElement_1.position(el, true).top;
        if (elTop < headerSpace) {
            window.scrollTo(0, UiElement_1.position(el).top - headerSpace);
        }
        return;
    }
    static isMobile() {
        let isMobile = false;
        (function (a) {
            if (/(android|bb\d+|meego).+mobile|avantgo|bada\/|blackberry|blazer|compal|elaine|fennec|hiptop|iemobile|ip(hone|od)|iris|kindle|lge |maemo|midp|mmp|mobile.+firefox|netfront|opera m(ob|in)i|palm( os)?|phone|p(ixi|re)\/|plucker|pocket|psp|series(4|6)0|symbian|treo|up\.(browser|link)|vodafone|wap|windows ce|xda|xiino/i.test(a) || /1207|6310|6590|3gso|4thp|50[1-6]i|770s|802s|a wa|abac|ac(er|oo|s\-)|ai(ko|rn)|al(av|ca|co)|amoi|an(ex|ny|yw)|aptu|ar(ch|go)|as(te|us)|attw|au(di|\-m|r |s )|avan|be(ck|ll|nq)|bi(lb|rd)|bl(ac|az)|br(e|v)w|bumb|bw\-(n|u)|c55\/|capi|ccwa|cdm\-|cell|chtm|cldc|cmd\-|co(mp|nd)|craw|da(it|ll|ng)|dbte|dc\-s|devi|dica|dmob|do(c|p)o|ds(12|\-d)|el(49|ai)|em(l2|ul)|er(ic|k0)|esl8|ez([4-7]0|os|wa|ze)|fetc|fly(\-|_)|g1 u|g560|gene|gf\-5|g\-mo|go(\.w|od)|gr(ad|un)|haie|hcit|hd\-(m|p|t)|hei\-|hi(pt|ta)|hp( i|ip)|hs\-c|ht(c(\-| |_|a|g|p|s|t)|tp)|hu(aw|tc)|i\-(20|go|ma)|i230|iac( |\-|\/)|ibro|idea|ig01|ikom|im1k|inno|ipaq|iris|ja(t|v)a|jbro|jemu|jigs|kddi|keji|kgt( |\/)|klon|kpt |kwc\-|kyo(c|k)|le(no|xi)|lg( g|\/(k|l|u)|50|54|\-[a-w])|libw|lynx|m1\-w|m3ga|m50\/|ma(te|ui|xo)|mc(01|21|ca)|m\-cr|me(rc|ri)|mi(o8|oa|ts)|mmef|mo(01|02|bi|de|do|t(\-| |o|v)|zz)|mt(50|p1|v )|mwbp|mywa|n10[0-2]|n20[2-3]|n30(0|2)|n50(0|2|5)|n7(0(0|1)|10)|ne((c|m)\-|on|tf|wf|wg|wt)|nok(6|i)|nzph|o2im|op(ti|wv)|oran|owg1|p800|pan(a|d|t)|pdxg|pg(13|\-([1-8]|c))|phil|pire|pl(ay|uc)|pn\-2|po(ck|rt|se)|prox|psio|pt\-g|qa\-a|qc(07|12|21|32|60|\-[2-7]|i\-)|qtek|r380|r600|raks|rim9|ro(ve|zo)|s55\/|sa(ge|ma|mm|ms|ny|va)|sc(01|h\-|oo|p\-)|sdk\/|se(c(\-|0|1)|47|mc|nd|ri)|sgh\-|shar|sie(\-|m)|sk\-0|sl(45|id)|sm(al|ar|b3|it|t5)|so(ft|ny)|sp(01|h\-|v\-|v )|sy(01|mb)|t2(18|50)|t6(00|10|18)|ta(gt|lk)|tcl\-|tdg\-|tel(i|m)|tim\-|t\-mo|to(pl|sh)|ts(70|m\-|m3|m5)|tx\-9|up(\.b|g1|si)|utst|v400|v750|veri|vi(rg|te)|vk(40|5[0-3]|\-v)|vm40|voda|vulc|vx(52|53|60|61|70|80|81|83|85|98)|w3c(\-| )|webc|whit|wi(g |nc|nw)|wmlb|wonu|x700|yas\-|your|zeto|zte\-/i.test(a.substr(0, 4))) {
                isMobile = true;
            }
        })(navigator.userAgent || navigator.vendor || window.opera);
        return isMobile;
    }
};
UiElement.caretPosition = {
    get: getCaretPosition,
    set: setCaretPosition
};
UiElement.classList = {
    remove: removeClass,
    add: addClass,
    contains: containsClass
};
UiElement = UiElement_1 = __decorate([
    Injectable()
], UiElement);
// left: 37, up: 38, right: 39, down: 40,
// spacebar: 32, pageup: 33, pagedown: 34, end: 35, home: 36
// const keys = {37: 1, 38: 1, 39: 1, 40: 1};
const keys = { 38: 1, 40: 1 };
function preventDefault(e) {
    e = e || window.event;
    if (e.preventDefault) {
        e.preventDefault();
    }
    e.returnValue = false;
}
function preventDefaultForScrollKeys(e) {
    if (keys[e.keyCode]) {
        preventDefault(e);
        return false;
    }
}
function getCaretPosition(el) {
    const documentt = {
        selection: undefined
    };
    Object.assign(documentt, document);
    let caretPos = 0;
    if (documentt.selection) { // IE Support
        el.focus();
        const select = documentt.selection.createRange();
        select.moveStart('character', -el.value.length);
        caretPos = select.text.length;
    }
    else if (el.selectionStart || el.selectionStart === '0') { // Firefox support
        caretPos = el.selectionStart;
    }
    return caretPos;
}
function setCaretPosition(el, beforeSelIndex, afterSelIndex, symbolsPositions) {
    // https://javascriptexamples.info/snippet/getset-cursor-in-html-textarea
    let futureSelIndex;
    symbolsPositions = symbolsPositions || [];
    if (el.selectionStart || el.selectionStart === '0') {
        futureSelIndex = afterSelIndex;
        for (let i = 0; i < symbolsPositions.length; i++) {
            if (beforeSelIndex === symbolsPositions[i] && afterSelIndex === symbolsPositions[i] + 1) {
                futureSelIndex = symbolsPositions[i] + 2;
                break;
            }
        }
        setTimeout(() => {
            setCaret();
        });
    }
    function setCaret() {
        if (el.setSelectionRange) {
            if (el.selectionStart) {
                el.focus();
                el.setSelectionRange(futureSelIndex, futureSelIndex);
            }
            else {
                el.focus();
            }
        }
        else if (el.createTextRange) {
            const range = el.createTextRange();
            range.collapse(true);
            range.move('character', futureSelIndex);
            range.moveEnd('character', futureSelIndex);
            range.moveStart('character', futureSelIndex);
            range.select();
        }
    }
}
function removeClass(el, className) {
    return el.classList.remove(className);
}
function addClass(el, className) {
    return el.classList.add(className);
}
function containsClass(el, className) {
    return el.classList.contains(className);
}

UiElement.on(window, 'scroll resize', (e) => {
    const fabContainers = document.querySelectorAll('.ui-fab-container');
    const len = fabContainers.length;
    if (len) {
        const scroll = (window.scrollY || window.pageYOffset);
        for (let i = 0; i < len; i++) {
            const fabContainer = fabContainers[i];
            if (scroll > 1) {
                fabContainer.classList.add('scrolled');
            }
            else {
                fabContainer.classList.remove('scrolled');
            }
        }
    }
});

function debounce(func, wait, immediate) {
    let timeout;
    return function () {
        const context = this;
        const args = arguments;
        const later = function () {
            timeout = null;
            if (!immediate) {
                func.apply(context, args);
            }
        };
        const callNow = immediate && !timeout;
        clearTimeout(timeout);
        timeout = setTimeout(later, wait);
        if (callNow) {
            func.apply(context, args);
        }
    };
}

/*
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

   http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/
const defaultDiacriticsRemovalMap = [
    {
        'base': 'A',
        'letters': '\u0041\u24B6\uFF21\u00C0\u00C1\u00C2\u1EA6\u1EA4\u1EAA\u1EA8\u00C3\u0100\u0102\u1EB0\u1EAE\u1EB4\u1EB2\u0226\u01E0\u00C4\u01DE\u1EA2\u00C5\u01FA\u01CD\u0200\u0202\u1EA0\u1EAC\u1EB6\u1E00\u0104\u023A\u2C6F'
    },
    { 'base': 'AA', 'letters': '\uA732' },
    { 'base': 'AE', 'letters': '\u00C6\u01FC\u01E2' },
    { 'base': 'AO', 'letters': '\uA734' },
    { 'base': 'AU', 'letters': '\uA736' },
    { 'base': 'AV', 'letters': '\uA738\uA73A' },
    { 'base': 'AY', 'letters': '\uA73C' },
    { 'base': 'B', 'letters': '\u0042\u24B7\uFF22\u1E02\u1E04\u1E06\u0243\u0182\u0181' },
    { 'base': 'C', 'letters': '\u0043\u24B8\uFF23\u0106\u0108\u010A\u010C\u00C7\u1E08\u0187\u023B\uA73E' },
    {
        'base': 'D',
        'letters': '\u0044\u24B9\uFF24\u1E0A\u010E\u1E0C\u1E10\u1E12\u1E0E\u0110\u018B\u018A\u0189\uA779\u00D0'
    },
    { 'base': 'DZ', 'letters': '\u01F1\u01C4' },
    { 'base': 'Dz', 'letters': '\u01F2\u01C5' },
    {
        'base': 'E',
        'letters': '\u0045\u24BA\uFF25\u00C8\u00C9\u00CA\u1EC0\u1EBE\u1EC4\u1EC2\u1EBC\u0112\u1E14\u1E16\u0114\u0116\u00CB\u1EBA\u011A\u0204\u0206\u1EB8\u1EC6\u0228\u1E1C\u0118\u1E18\u1E1A\u0190\u018E'
    },
    { 'base': 'F', 'letters': '\u0046\u24BB\uFF26\u1E1E\u0191\uA77B' },
    {
        'base': 'G',
        'letters': '\u0047\u24BC\uFF27\u01F4\u011C\u1E20\u011E\u0120\u01E6\u0122\u01E4\u0193\uA7A0\uA77D\uA77E'
    },
    {
        'base': 'H',
        'letters': '\u0048\u24BD\uFF28\u0124\u1E22\u1E26\u021E\u1E24\u1E28\u1E2A\u0126\u2C67\u2C75\uA78D'
    },
    {
        'base': 'I',
        'letters': '\u0049\u24BE\uFF29\u00CC\u00CD\u00CE\u0128\u012A\u012C\u0130\u00CF\u1E2E\u1EC8\u01CF\u0208\u020A\u1ECA\u012E\u1E2C\u0197'
    },
    { 'base': 'J', 'letters': '\u004A\u24BF\uFF2A\u0134\u0248' },
    {
        'base': 'K',
        'letters': '\u004B\u24C0\uFF2B\u1E30\u01E8\u1E32\u0136\u1E34\u0198\u2C69\uA740\uA742\uA744\uA7A2'
    },
    {
        'base': 'L',
        'letters': '\u004C\u24C1\uFF2C\u013F\u0139\u013D\u1E36\u1E38\u013B\u1E3C\u1E3A\u0141\u023D\u2C62\u2C60\uA748\uA746\uA780'
    },
    { 'base': 'LJ', 'letters': '\u01C7' },
    { 'base': 'Lj', 'letters': '\u01C8' },
    { 'base': 'M', 'letters': '\u004D\u24C2\uFF2D\u1E3E\u1E40\u1E42\u2C6E\u019C' },
    {
        'base': 'N',
        'letters': '\u004E\u24C3\uFF2E\u01F8\u0143\u00D1\u1E44\u0147\u1E46\u0145\u1E4A\u1E48\u0220\u019D\uA790\uA7A4'
    },
    { 'base': 'NJ', 'letters': '\u01CA' },
    { 'base': 'Nj', 'letters': '\u01CB' },
    {
        'base': 'O',
        'letters': '\u004F\u24C4\uFF2F\u00D2\u00D3\u00D4\u1ED2\u1ED0\u1ED6\u1ED4\u00D5\u1E4C\u022C\u1E4E\u014C\u1E50\u1E52\u014E\u022E\u0230\u00D6\u022A\u1ECE\u0150\u01D1\u020C\u020E\u01A0\u1EDC\u1EDA\u1EE0\u1EDE\u1EE2\u1ECC\u1ED8\u01EA\u01EC\u00D8\u01FE\u0186\u019F\uA74A\uA74C'
    },
    { 'base': 'OI', 'letters': '\u01A2' },
    { 'base': 'OO', 'letters': '\uA74E' },
    { 'base': 'OU', 'letters': '\u0222' },
    { 'base': 'OE', 'letters': '\u008C\u0152' },
    { 'base': 'oe', 'letters': '\u009C\u0153' },
    { 'base': 'P', 'letters': '\u0050\u24C5\uFF30\u1E54\u1E56\u01A4\u2C63\uA750\uA752\uA754' },
    { 'base': 'Q', 'letters': '\u0051\u24C6\uFF31\uA756\uA758\u024A' },
    {
        'base': 'R',
        'letters': '\u0052\u24C7\uFF32\u0154\u1E58\u0158\u0210\u0212\u1E5A\u1E5C\u0156\u1E5E\u024C\u2C64\uA75A\uA7A6\uA782'
    },
    {
        'base': 'S',
        'letters': '\u0053\u24C8\uFF33\u1E9E\u015A\u1E64\u015C\u1E60\u0160\u1E66\u1E62\u1E68\u0218\u015E\u2C7E\uA7A8\uA784'
    },
    {
        'base': 'T',
        'letters': '\u0054\u24C9\uFF34\u1E6A\u0164\u1E6C\u021A\u0162\u1E70\u1E6E\u0166\u01AC\u01AE\u023E\uA786'
    },
    { 'base': 'TZ', 'letters': '\uA728' },
    {
        'base': 'U',
        'letters': '\u0055\u24CA\uFF35\u00D9\u00DA\u00DB\u0168\u1E78\u016A\u1E7A\u016C\u00DC\u01DB\u01D7\u01D5\u01D9\u1EE6\u016E\u0170\u01D3\u0214\u0216\u01AF\u1EEA\u1EE8\u1EEE\u1EEC\u1EF0\u1EE4\u1E72\u0172\u1E76\u1E74\u0244'
    },
    { 'base': 'V', 'letters': '\u0056\u24CB\uFF36\u1E7C\u1E7E\u01B2\uA75E\u0245' },
    { 'base': 'VY', 'letters': '\uA760' },
    { 'base': 'W', 'letters': '\u0057\u24CC\uFF37\u1E80\u1E82\u0174\u1E86\u1E84\u1E88\u2C72' },
    { 'base': 'X', 'letters': '\u0058\u24CD\uFF38\u1E8A\u1E8C' },
    {
        'base': 'Y',
        'letters': '\u0059\u24CE\uFF39\u1EF2\u00DD\u0176\u1EF8\u0232\u1E8E\u0178\u1EF6\u1EF4\u01B3\u024E\u1EFE'
    },
    {
        'base': 'Z',
        'letters': '\u005A\u24CF\uFF3A\u0179\u1E90\u017B\u017D\u1E92\u1E94\u01B5\u0224\u2C7F\u2C6B\uA762'
    },
    {
        'base': 'a',
        'letters': '\u0061\u24D0\uFF41\u1E9A\u00E0\u00E1\u00E2\u1EA7\u1EA5\u1EAB\u1EA9\u00E3\u0101\u0103\u1EB1\u1EAF\u1EB5\u1EB3\u0227\u01E1\u00E4\u01DF\u1EA3\u00E5\u01FB\u01CE\u0201\u0203\u1EA1\u1EAD\u1EB7\u1E01\u0105\u2C65\u0250'
    },
    { 'base': 'aa', 'letters': '\uA733' },
    { 'base': 'ae', 'letters': '\u00E6\u01FD\u01E3' },
    { 'base': 'ao', 'letters': '\uA735' },
    { 'base': 'au', 'letters': '\uA737' },
    { 'base': 'av', 'letters': '\uA739\uA73B' },
    { 'base': 'ay', 'letters': '\uA73D' },
    { 'base': 'b', 'letters': '\u0062\u24D1\uFF42\u1E03\u1E05\u1E07\u0180\u0183\u0253' },
    { 'base': 'c', 'letters': '\u0063\u24D2\uFF43\u0107\u0109\u010B\u010D\u00E7\u1E09\u0188\u023C\uA73F\u2184' },
    {
        'base': 'd',
        'letters': '\u0064\u24D3\uFF44\u1E0B\u010F\u1E0D\u1E11\u1E13\u1E0F\u0111\u018C\u0256\u0257\uA77A'
    },
    { 'base': 'dz', 'letters': '\u01F3\u01C6' },
    {
        'base': 'e',
        'letters': '\u0065\u24D4\uFF45\u00E8\u00E9\u00EA\u1EC1\u1EBF\u1EC5\u1EC3\u1EBD\u0113\u1E15\u1E17\u0115\u0117\u00EB\u1EBB\u011B\u0205\u0207\u1EB9\u1EC7\u0229\u1E1D\u0119\u1E19\u1E1B\u0247\u025B\u01DD'
    },
    { 'base': 'f', 'letters': '\u0066\u24D5\uFF46\u1E1F\u0192\uA77C' },
    {
        'base': 'g',
        'letters': '\u0067\u24D6\uFF47\u01F5\u011D\u1E21\u011F\u0121\u01E7\u0123\u01E5\u0260\uA7A1\u1D79\uA77F'
    },
    {
        'base': 'h',
        'letters': '\u0068\u24D7\uFF48\u0125\u1E23\u1E27\u021F\u1E25\u1E29\u1E2B\u1E96\u0127\u2C68\u2C76\u0265'
    },
    { 'base': 'hv', 'letters': '\u0195' },
    {
        'base': 'i',
        'letters': '\u0069\u24D8\uFF49\u00EC\u00ED\u00EE\u0129\u012B\u012D\u00EF\u1E2F\u1EC9\u01D0\u0209\u020B\u1ECB\u012F\u1E2D\u0268\u0131'
    },
    { 'base': 'j', 'letters': '\u006A\u24D9\uFF4A\u0135\u01F0\u0249' },
    {
        'base': 'k',
        'letters': '\u006B\u24DA\uFF4B\u1E31\u01E9\u1E33\u0137\u1E35\u0199\u2C6A\uA741\uA743\uA745\uA7A3'
    },
    {
        'base': 'l',
        'letters': '\u006C\u24DB\uFF4C\u0140\u013A\u013E\u1E37\u1E39\u013C\u1E3D\u1E3B\u017F\u0142\u019A\u026B\u2C61\uA749\uA781\uA747'
    },
    { 'base': 'lj', 'letters': '\u01C9' },
    { 'base': 'm', 'letters': '\u006D\u24DC\uFF4D\u1E3F\u1E41\u1E43\u0271\u026F' },
    {
        'base': 'n',
        'letters': '\u006E\u24DD\uFF4E\u01F9\u0144\u00F1\u1E45\u0148\u1E47\u0146\u1E4B\u1E49\u019E\u0272\u0149\uA791\uA7A5'
    },
    { 'base': 'nj', 'letters': '\u01CC' },
    {
        'base': 'o',
        'letters': '\u006F\u24DE\uFF4F\u00F2\u00F3\u00F4\u1ED3\u1ED1\u1ED7\u1ED5\u00F5\u1E4D\u022D\u1E4F\u014D\u1E51\u1E53\u014F\u022F\u0231\u00F6\u022B\u1ECF\u0151\u01D2\u020D\u020F\u01A1\u1EDD\u1EDB\u1EE1\u1EDF\u1EE3\u1ECD\u1ED9\u01EB\u01ED\u00F8\u01FF\u0254\uA74B\uA74D\u0275'
    },
    { 'base': 'oi', 'letters': '\u01A3' },
    { 'base': 'ou', 'letters': '\u0223' },
    { 'base': 'oo', 'letters': '\uA74F' },
    { 'base': 'p', 'letters': '\u0070\u24DF\uFF50\u1E55\u1E57\u01A5\u1D7D\uA751\uA753\uA755' },
    { 'base': 'q', 'letters': '\u0071\u24E0\uFF51\u024B\uA757\uA759' },
    {
        'base': 'r',
        'letters': '\u0072\u24E1\uFF52\u0155\u1E59\u0159\u0211\u0213\u1E5B\u1E5D\u0157\u1E5F\u024D\u027D\uA75B\uA7A7\uA783'
    },
    {
        'base': 's',
        'letters': '\u0073\u24E2\uFF53\u00DF\u015B\u1E65\u015D\u1E61\u0161\u1E67\u1E63\u1E69\u0219\u015F\u023F\uA7A9\uA785\u1E9B'
    },
    {
        'base': 't',
        'letters': '\u0074\u24E3\uFF54\u1E6B\u1E97\u0165\u1E6D\u021B\u0163\u1E71\u1E6F\u0167\u01AD\u0288\u2C66\uA787'
    },
    { 'base': 'tz', 'letters': '\uA729' },
    {
        'base': 'u',
        'letters': '\u0075\u24E4\uFF55\u00F9\u00FA\u00FB\u0169\u1E79\u016B\u1E7B\u016D\u00FC\u01DC\u01D8\u01D6\u01DA\u1EE7\u016F\u0171\u01D4\u0215\u0217\u01B0\u1EEB\u1EE9\u1EEF\u1EED\u1EF1\u1EE5\u1E73\u0173\u1E77\u1E75\u0289'
    },
    { 'base': 'v', 'letters': '\u0076\u24E5\uFF56\u1E7D\u1E7F\u028B\uA75F\u028C' },
    { 'base': 'vy', 'letters': '\uA761' },
    { 'base': 'w', 'letters': '\u0077\u24E6\uFF57\u1E81\u1E83\u0175\u1E87\u1E85\u1E98\u1E89\u2C73' },
    { 'base': 'x', 'letters': '\u0078\u24E7\uFF58\u1E8B\u1E8D' },
    {
        'base': 'y',
        'letters': '\u0079\u24E8\uFF59\u1EF3\u00FD\u0177\u1EF9\u0233\u1E8F\u00FF\u1EF7\u1E99\u1EF5\u01B4\u024F\u1EFF'
    },
    {
        'base': 'z',
        'letters': '\u007A\u24E9\uFF5A\u017A\u1E91\u017C\u017E\u1E93\u1E95\u01B6\u0225\u0240\u2C6C\uA763'
    }
];
const diacriticsMap = {};
for (let i = 0; i < defaultDiacriticsRemovalMap.length; i++) {
    const letters = defaultDiacriticsRemovalMap[i].letters;
    for (let j = 0; j < letters.length; j++) {
        diacriticsMap[letters[j]] = defaultDiacriticsRemovalMap[i].base;
    }
}
// "what?" version ... http://jsperf.com/diacritics/12
function unaccent(str) {
    return str.replace(/[^\u0000-\u007E]/g, function (a) {
        return diacriticsMap[a] || a;
    });
}

let UiAddCalendarDirective = class UiAddCalendarDirective {
    constructor(viewContainerRef) {
        this.viewContainerRef = viewContainerRef;
    }
};
UiAddCalendarDirective.ctorParameters = () => [
    { type: ViewContainerRef }
];
UiAddCalendarDirective = __decorate([
    Directive({
        selector: '[addCalendar]'
    }),
    __metadata("design:paramtypes", [ViewContainerRef])
], UiAddCalendarDirective);

let UiDatetimeService = class UiDatetimeService {
    constructor() {
        this.days = ['domingo', 'segunda-feira', 'terça-feira', 'quarta-feira', 'quinta-feira', 'sexta-feira', 'sábado'];
        this.shortDays = ['dom', 'seg', 'ter', 'qua', 'qui', 'sex', 'sáb'];
        this.months = ['janeiro', 'fevereiro', 'março', 'abril', 'maio', 'junho', 'julho', 'agosto', 'setembro', 'outubro', 'novembro', 'dezembro'];
        this.shortMonths = ['jan', 'fev', 'mar', 'abr', 'mai', 'jun', 'jul', 'ago', 'set', 'out', 'nov', 'dez'];
    }
};
UiDatetimeService = __decorate([
    Injectable(),
    __metadata("design:paramtypes", [])
], UiDatetimeService);

let UiColor = class UiColor {
    static isBright(hex, minDarkPerc) {
        return _isBright(hex, minDarkPerc);
    }
    static hexToRgb(hex) {
        return _hexToRgb(hex);
    }
    constructor() {
    }
};
UiColor = __decorate([
    Injectable(),
    __metadata("design:paramtypes", [])
], UiColor);
function _isBright(hex, minDarkPerc) {
    const color = _hexToRgb(hex);
    if (!color) {
        return false;
    }
    const luminosityPerc = 1 - (0.299 * color.r + 0.587 * color.g + 0.114 * color.b) / 255;
    return (luminosityPerc < (minDarkPerc || 0.3));
}
function _hexToRgb(hex) {
    const result = /^#?([a-f\d]{2})([a-f\d]{2})([a-f\d]{2})$/i.exec(hex);
    return result ? {
        r: parseInt(result[1], 16),
        g: parseInt(result[2], 16),
        b: parseInt(result[3], 16)
    } : null;
}

let UiCalendarContentComponent = class UiCalendarContentComponent {
    constructor(datetimeService, elementRef, changeDetectorRef) {
        this.datetimeService = datetimeService;
        this.elementRef = elementRef;
        this.changeDetectorRef = changeDetectorRef;
        this.chosen = new Subject();
        this.days = datetimeService.days;
        this.months = datetimeService.months;
    }
    ngAfterViewInit() {
        if (this.events && this.events.length) {
            this.verifyEventDates();
            this.changeDetectorRef.detectChanges();
        }
        this.elementRef.nativeElement.querySelectorAll('.days button').forEach(item => {
            item.addEventListener('keydown', e => {
                const target = UiElement.closest(e.target, '.day');
                const index = UiElement.index(target);
                let toFocus;
                let toFocusIndex = 0;
                let toFocusAlt;
                setTimeout(() => {
                    switch (e.keyCode) {
                        // Seta para esquerda
                        case 37:
                            toFocus = this.getSibling(index - 1);
                            if (!toFocus.length) {
                                toFocus = this.elementRef.nativeElement.querySelectorAll('.days button:not([disabled])');
                                toFocusIndex = toFocus.length - 1;
                            }
                            toFocus[toFocusIndex].focus();
                            break;
                        // Seta para cima
                        case 38:
                            toFocus = this.getSibling(index - 7);
                            toFocusAlt = this.elementRef.nativeElement.querySelectorAll('.days button:not([disabled])')[0];
                            if (toFocus.length && index > UiElement.index(toFocus[0])) {
                                toFocus[0].focus();
                            }
                            else {
                                toFocusAlt.focus();
                            }
                            break;
                        // Seta para direita
                        case 39:
                            toFocus = this.getSibling(index + 1);
                            if (!toFocus.length) {
                                this.elementRef.nativeElement.querySelectorAll('.days button:not([disabled])')[0].focus();
                            }
                            else {
                                toFocus[0].focus();
                            }
                            break;
                        // // Seta para baixo
                        case 40:
                            toFocus = this.getSibling(index + 7);
                            toFocusAlt = this.elementRef.nativeElement.querySelectorAll('.days button:not([disabled])');
                            toFocusAlt = toFocusAlt[toFocusAlt.length - 1];
                            if (toFocus.length && index < UiElement.index(toFocus[0].parentNode)) {
                                toFocus[0].focus();
                            }
                            else {
                                toFocusAlt.focus();
                            }
                            break;
                    }
                });
            });
        });
        this.elementRef.nativeElement.addEventListener('keydown', e => {
            if ([37, 38, 39, 40].indexOf(e.keyCode) > -1) {
                e.preventDefault();
                return false;
            }
        });
    }
    getSibling(index) {
        if (index < 0 || !this.elementRef.nativeElement.querySelectorAll('.day')[index]) {
            return [];
        }
        return this.elementRef.nativeElement.querySelectorAll('.day')[index].querySelectorAll('button:not([disabled])');
    }
    isDay(value) {
        const dateToCheck = this.chosenDate;
        if (!dateToCheck) {
            return;
        }
        return (dateToCheck.getDate() === value.getDate() &&
            dateToCheck.getMonth() === value.getMonth() &&
            dateToCheck.getFullYear() === value.getFullYear());
    }
    chooseDate(value) {
        if (value) {
            this.chosenDate = value;
            if (!this.confirmSelection) {
                this.ngModel = value;
            }
            const newValue = {
                value,
                confirmSelection: this.confirmSelection
            };
            this.chosen.next(newValue);
        }
    }
    isDisabled(value) {
        const minDate = this.minDate ? new Date(this.minDate).getTime() : null;
        const maxDate = this.maxDate ? new Date(this.maxDate).getTime() : null;
        const date = value.getTime();
        return (typeof minDate === 'number' && !isNaN(minDate) && date < minDate) || (typeof maxDate === 'number' && !isNaN(maxDate) && date > maxDate);
    }
    verifyEventDates() {
        this.calendar.days.map(day => {
            this.events.map(event => {
                const date = new Date(event.date);
                if ((date.getTime() + (day.value.getTimezoneOffset() * 60000)) === day.value.getTime()) {
                    day.hasEvent = true;
                    day.eventColor = event.color;
                    day.blocked = event.blocked;
                }
            });
        });
    }
    isBright(color) {
        return UiColor.isBright(color);
    }
};
UiCalendarContentComponent.ctorParameters = () => [
    { type: UiDatetimeService },
    { type: ElementRef },
    { type: ChangeDetectorRef }
];
UiCalendarContentComponent = __decorate([
    Component({
        selector: 'ui-calendar-content',
        template: "<div class=\"label\">\r\n    <button class=\"month-label\">\r\n        <span>{{months[calendar.month] + ' de ' + calendar.year | uiCapitalize}}</span>\r\n    </button>\r\n</div>\r\n<div class=\"week-header\">\r\n    <div class=\"week-day\" *ngFor=\"let day of days\">{{day.charAt(0).toUpperCase()}}</div>\r\n</div>\r\n<div class=\"days\">\r\n    <div class=\"day\" *ngFor=\"let day of calendar.days\">\r\n        <button type=\"button\"\r\n                class=\"ui-button icon\"\r\n                [style.backgroundColor]=\"day.eventColor\"\r\n                (click)=\"!isDisabled(day.value) && chooseDate(day.value)\"\r\n                [disabled]=\"isDisabled(day.value) || day.blocked\"\r\n                [ngClass]=\"{'primary': isDay(day.value) || day.today && !day.hasEvent, 'flat': !isDay(day.value),\r\n                'dark-text': isBright(day.color), 'light-text': !isBright(day.color) && !isDisabled(day.value)}\"\r\n                *ngIf=\"day.month === calendar.month\">\r\n            {{day.date}}\r\n        </button>\r\n    </div>\r\n</div>\r\n",
        styles: [":host{width:296px;display:block;padding:8px 0}:host .label{height:36px}:host .month-label{background-color:transparent;width:100%;height:36px;display:flex;align-items:center;justify-content:center;border-radius:2px;font-size:14px}:host .week-header{display:flex;font-weight:700;padding:0 8px}:host .days{display:flex;flex-wrap:wrap;padding:0 8px}:host .day,:host .week-day{display:flex;align-items:center;justify-content:center;width:14.28%;height:40px;font-size:12px}:host .dark-text{color:rgba(0,0,0,.84)}:host .light-text{color:#fff}"]
    }),
    __metadata("design:paramtypes", [UiDatetimeService, ElementRef, ChangeDetectorRef])
], UiCalendarContentComponent);

let UiCalendarComponent = class UiCalendarComponent {
    constructor(componentFactoryResolver, datetimeService) {
        this.componentFactoryResolver = componentFactoryResolver;
        this.datetimeService = datetimeService;
        this.select = new EventEmitter();
        this.selectDateChange = new EventEmitter();
        this.cancel = new EventEmitter();
        this.ngModelChange = new EventEmitter();
        this.updateMonth = new EventEmitter();
        this.chosen = new Subject();
        this.days = datetimeService.days;
        this.shortDays = datetimeService.shortDays;
        this.months = datetimeService.months;
    }
    ngOnInit() {
        this.minDate = this.minDate && isDate(new Date(this.minDate)) ? new Date(this.minDate) : this.minDate;
        this.maxDate = this.maxDate && isDate(new Date(this.maxDate)) ? new Date(this.maxDate) : this.maxDate;
        this.chosenDate = this.ngModel && isDate(new Date(this.ngModel)) ? new Date(this.ngModel) : null;
        this.ngModel = this.ngModel && isDate(new Date(this.ngModel)) ? new Date(this.ngModel) : this.ngModel;
        this.viewDate = isDate(this.ngModel) ? this.ngModel : this.initOnSelected || new Date();
        this.renderCalendar(this.viewDate);
    }
    ngOnChanges(value) {
        if (value.ngModel && !value.ngModel.firstChange && !isNaN(value.ngModel.currentValue)) {
            const ngModel = value.ngModel.currentValue = value.ngModel.currentValue && isDate(new Date(value.ngModel.currentValue)) ? new Date(value.ngModel.currentValue) : value.ngModel.currentValue;
            this.ngModel = this.chosenDate = this.componentRef.instance.chosenDate = this.componentRef.instance.ngModel = ngModel;
        }
        if (value.maxDate && !value.maxDate.firstChange) {
            const maxDate = value.maxDate.currentValue = value.maxDate.currentValue && isDate(new Date(value.maxDate.currentValue)) ? new Date(value.maxDate.currentValue) : value.maxDate.currentValue;
            this.componentRef.instance.maxDate = this.maxDate = maxDate;
        }
        if (value.minDate && !value.minDate.firstChange) {
            const minDate = value.minDate.currentValue = value.minDate.currentValue && isDate(new Date(value.minDate.currentValue)) ? new Date(value.minDate.currentValue) : value.minDate.currentValue;
            this.componentRef.instance.minDate = this.minDate = minDate;
        }
        if (value.confirmSelection) {
            this.confirmSelection = value.confirmSelection.currentValue;
        }
    }
    prevMonth() {
        this.viewDate.setMonth(this.viewDate.getMonth() - 1);
        this.updateMonth.emit();
        this.renderCalendar(this.viewDate);
    }
    nextMonth() {
        this.viewDate.setMonth(this.viewDate.getMonth() + 1);
        this.updateMonth.emit();
        this.renderCalendar(this.viewDate);
    }
    selectDate(value) {
        this.ngModel = this.componentRef.instance.ngModel = value;
        this.ngModelChange.emit(this.ngModel);
        this.select.emit(this.ngModel);
        this.selectDateChange.emit(this.ngModel);
        this.chosen.next(this.ngModel);
    }
    cancelDate() {
        this.ngModel = this.chosenDate = this.componentRef.instance.ngModel = this.componentRef.instance.chosenDate = null;
        this.cancel.emit();
        this.ngModelChange.emit(this.ngModel);
    }
    renderCalendar(dateTarget) {
        let date = dateTarget;
        date.setHours(0, 0, 0, 0);
        date.setDate(1);
        date.setMonth(date.getMonth() + 1);
        date.setDate(0);
        this.viewDate = date;
        const calendar = {
            year: date.getFullYear(),
            month: date.getMonth(),
            monthDays: date.getDate(),
            lastDayWeek: date.getDay(),
            lastDayWeekName: this.days[date.getDay()]
        };
        date.setDate(1);
        calendar.firstDayWeek = date.getDay();
        calendar.firstDayWeekName = this.days[date.getDay()];
        calendar.totalDays = calendar.monthDays + calendar.firstDayWeek + (6 - calendar.lastDayWeek);
        calendar.days = [];
        const firstDate = -calendar.firstDayWeek + 1;
        const lastDate = calendar.monthDays + (7 - calendar.lastDayWeek);
        for (let i = firstDate; i < lastDate; i++) {
            date = new Date(calendar.year, calendar.month, i);
            let today = new Date();
            today = date.getFullYear() === today.getFullYear() && date.getMonth() === today.getMonth() && date.getDate() === today.getDate();
            calendar.days.push({
                month: date.getMonth(),
                date: date.getDate(),
                value: date,
                time: date.getTime(),
                today: today
            });
        }
        this.calendar = calendar;
        const keysComponent = ['calendar', 'ngModel', 'minDate', 'maxDate', 'chosenDate', 'confirmSelection', 'events'];
        const componentFactory = this.componentFactoryResolver.resolveComponentFactory(UiCalendarContentComponent);
        const viewContainerRef = this.addCalendar.viewContainerRef;
        viewContainerRef.clear();
        this.componentRef = viewContainerRef.createComponent(componentFactory);
        keysComponent.map(key => this.componentRef.instance[key] = this[key]);
        this.componentRef.instance.chosen.subscribe(newValue => {
            if (newValue) {
                this.chosenDate = newValue.value;
                if (!newValue.confirmSelection) {
                    this.selectDate(newValue.value);
                }
            }
        });
    }
};
UiCalendarComponent.ctorParameters = () => [
    { type: ComponentFactoryResolver },
    { type: UiDatetimeService }
];
__decorate([
    Input(),
    __metadata("design:type", Object)
], UiCalendarComponent.prototype, "ngModel", void 0);
__decorate([
    Input(),
    __metadata("design:type", Date)
], UiCalendarComponent.prototype, "maxDate", void 0);
__decorate([
    Input(),
    __metadata("design:type", Date)
], UiCalendarComponent.prototype, "minDate", void 0);
__decorate([
    Input(),
    __metadata("design:type", Boolean)
], UiCalendarComponent.prototype, "hideHeader", void 0);
__decorate([
    Input(),
    __metadata("design:type", Date)
], UiCalendarComponent.prototype, "initOnSelected", void 0);
__decorate([
    Input(),
    __metadata("design:type", Boolean)
], UiCalendarComponent.prototype, "confirmSelection", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], UiCalendarComponent.prototype, "select", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], UiCalendarComponent.prototype, "selectDateChange", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], UiCalendarComponent.prototype, "cancel", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], UiCalendarComponent.prototype, "ngModelChange", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], UiCalendarComponent.prototype, "updateMonth", void 0);
__decorate([
    ViewChild(UiAddCalendarDirective, { static: true }),
    __metadata("design:type", UiAddCalendarDirective)
], UiCalendarComponent.prototype, "addCalendar", void 0);
UiCalendarComponent = __decorate([
    Component({
        selector: 'ui-calendar',
        template: "<header *ngIf=\"!hideHeader\">\r\n    <div>\r\n        <div class=\"year\" >{{chosenDate && chosenDate.getFullYear()}}</div>\r\n        <span class=\"date-empty\" *ngIf=\"!chosenDate\">Selecione uma data</span>\r\n        <div class=\"date\" *ngIf=\"chosenDate\">\r\n            <span class=\"week-day\">{{shortDays[chosenDate.getDay()] | uiCapitalize}},</span> {{chosenDate.getDate()}} de {{months[chosenDate.getMonth()] | uiCapitalize}}\r\n        </div>\r\n    </div>\r\n</header>\r\n<div>\r\n    <div class=\"content\">\r\n        <div class=\"controls\">\r\n            <button class=\"prev ui-button icon flat\"\r\n                    (click)=\"prevMonth()\"\r\n                    [hidden]=\"!(!minDate || (calendar && calendar.days[0].time > minDate.getTime()))\"\r\n                    tabindex=\"0\"><i class=\"material-icons\">keyboard_arrow_left</i></button>\r\n            <button class=\"next ui-button icon flat\"\r\n                    (click)=\"nextMonth()\"\r\n                    [hidden]=\"!(!maxDate || (calendar && calendar.days[calendar.days.length - 1].time < maxDate.getTime()))\"\r\n                    tabindex=\"2\"><i class=\"material-icons\">keyboard_arrow_right</i></button>\r\n        </div>\r\n        <div class=\"calendar-cover\">\r\n            <div addCalendar></div>\r\n        </div>\r\n    </div>\r\n    <div class=\"actions ui-button-container align-right\" *ngIf=\"confirmSelection\">\r\n        <button class=\"ui-button flat primary\" (click)=\"cancelDate()\">Cancelar</button>\r\n        <button class=\"ui-button flat primary\" (click)=\"selectDate(chosenDate)\">Ok</button>\r\n    </div>\r\n</div>\r\n",
        encapsulation: ViewEncapsulation.None,
        styles: ["@-webkit-keyframes open{0%{transform:scale(0)}100%{transform:scale(1)}}@keyframes open{0%{transform:scale(0)}100%{transform:scale(1)}}ui-calendar{display:inline-flex;flex-direction:column;overflow:hidden;border-radius:2px;position:relative;z-index:0}ui-calendar header{padding:16px;min-height:72px;display:flex;justify-content:center;flex-direction:column}ui-calendar header .year{font-size:14px;opacity:.8;font-weight:400}ui-calendar header .date-empty{font-size:18px;font-weight:500}ui-calendar header .date{margin-top:8px;font-size:26px;font-weight:500}ui-calendar .actions{padding:8px;text-align:right;cursor:default}ui-calendar .content{position:relative}ui-calendar .content .calendar-cover{position:relative;overflow:hidden;transition:.3s ease-in-out}ui-calendar .content .controls{position:absolute;top:0;left:0;right:0;z-index:1}ui-calendar .content .controls button{position:absolute;top:0;margin:8px}ui-calendar .content .controls .prev{left:0}ui-calendar .content .controls .next{right:0}@media (min-width:600px),(min-width:496px) and (orientation:landscape){ui-calendar:not(.portrait-only){flex-direction:row}ui-calendar:not(.portrait-only) header{justify-content:flex-start;width:192px}ui-calendar:not(.portrait-only) header .week-day{display:block}}"]
    }),
    __metadata("design:paramtypes", [ComponentFactoryResolver, UiDatetimeService])
], UiCalendarComponent);

let UiCapitalizePipe = class UiCapitalizePipe {
    transform(value, args) {
        return value && value.length > 0 ? value[0].toUpperCase() + value.substr(1).toLowerCase() : value;
    }
};
UiCapitalizePipe = __decorate([
    Pipe({
        name: 'uiCapitalize'
    })
], UiCapitalizePipe);

// @dynamic
let UiCookie = class UiCookie {
    static get(name) {
        const ca = document.cookie.split(';');
        const caLen = ca.length;
        const cookieName = `${name}=`;
        let c;
        for (let i = 0; i < caLen; i += 1) {
            c = ca[i].replace(/^\s+/g, '');
            if (c.indexOf(cookieName) === 0) {
                return c.substring(cookieName.length, c.length);
            }
        }
        return '';
    }
    static has(name) {
        return !!this.get(name);
    }
    static delete(name, domain) {
        this.set(name, '', -1, null, domain);
    }
    static set(name, value, expireDays = 365, path = '/', domain) {
        const d = new Date();
        d.setTime(d.getTime() + expireDays * 24 * 60 * 60 * 1000);
        const expires = 'expires=' + d.toUTCString();
        if (domain)
            domain = '; domain=' + domain;
        document.cookie = name + '=' + value + '; ' + expires + '; path=' + path + domain;
    }
};
UiCookie = __decorate([
    Injectable()
], UiCookie);

let UiDataTableOrderByDirective = class UiDataTableOrderByDirective {
    constructor(element) {
        this.element = element;
    }
    ngAfterViewInit() {
        const icon = document.createElement('i');
        icon.classList.add('material-icons');
        icon.innerHTML = 'arrow_downward';
        if (this.element.nativeElement.classList.contains('align-right')) {
            this.element.nativeElement.insertBefore(icon.cloneNode(true), this.element.nativeElement.firstChild);
        }
        else {
            this.element.nativeElement.appendChild(icon.cloneNode(true));
        }
    }
    ngOnChanges(changes) {
        if (changes.uiDataTableOrderBy && !changes.uiDataTableOrderBy.firstChange) {
            this.uiDataTableOrderBy = changes.uiDataTableOrderBy.currentValue;
            this.orderByCondition();
        }
    }
    orderByClick() {
        if (this.element.nativeElement.classList.contains('order_desc')
            || this.element.nativeElement.classList.contains('order_asc')) {
            if (this.element.nativeElement.classList.contains('order_asc')) {
                this.element.nativeElement.classList.add('order_desc');
                this.element.nativeElement.classList.remove('order_asc');
            }
            else if (this.element.nativeElement.classList.contains('order_desc')) {
                this.element.nativeElement.classList.remove('order_desc');
                this.element.nativeElement.classList.remove('order_asc');
            }
        }
        else {
            this.element.nativeElement.classList.add('order_asc');
        }
    }
    orderByCondition() {
        switch (this.uiDataTableOrderBy) {
            case 'ASC':
                this.element.nativeElement.classList.add('order_asc');
                this.element.nativeElement.classList.remove('order_desc');
                break;
            case 'DESC':
                this.element.nativeElement.classList.add('order_desc');
                this.element.nativeElement.classList.remove('order_asc');
                break;
            default:
                this.element.nativeElement.classList.remove('order_asc', 'order_desc');
                break;
        }
    }
    onClick() {
        if (this.withCondition) {
            return;
        }
        this.orderByClick();
    }
};
UiDataTableOrderByDirective.ctorParameters = () => [
    { type: ElementRef }
];
__decorate([
    Input('withCondition'),
    __metadata("design:type", Boolean)
], UiDataTableOrderByDirective.prototype, "withCondition", void 0);
__decorate([
    Input('uiDataTableOrderBy'),
    __metadata("design:type", String)
], UiDataTableOrderByDirective.prototype, "uiDataTableOrderBy", void 0);
__decorate([
    HostListener('click'),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", void 0)
], UiDataTableOrderByDirective.prototype, "onClick", null);
UiDataTableOrderByDirective = __decorate([
    Directive({ selector: 'th[uiDataTableOrderBy]' }),
    __metadata("design:paramtypes", [ElementRef])
], UiDataTableOrderByDirective);

let UiReferencesService = class UiReferencesService {
    constructor() {
        this.datePickers = {};
    }
    add(name, component) {
        if (this.datePickers && this.datePickers[name]) {
            return;
        }
        this.datePickers[name] = component;
    }
    get(name) {
        return this.datePickers[name];
    }
    remove(name) {
        delete this.datePickers[name];
    }
    closeAll() {
        UiElement.trigger(window, 'click');
    }
    getAll() {
        return this.datePickers;
    }
    updateModel(name, value) {
        this.datePickers[name].ngModel = value;
        this.datePickers[name].ngModelChange.emit(value);
    }
};
UiReferencesService = __decorate([
    Injectable(),
    __metadata("design:paramtypes", [])
], UiReferencesService);

let UiDatePickerCallerDirective = class UiDatePickerCallerDirective {
    constructor(componentFactoryResolver, applicationRef, injector, referencesService, elementRef) {
        this.componentFactoryResolver = componentFactoryResolver;
        this.applicationRef = applicationRef;
        this.injector = injector;
        this.referencesService = referencesService;
        this.elementRef = elementRef;
    }
    ngAfterViewInit() {
        this.datePicker = this.referencesService.get(this.datePickerCaller);
        UiElement.on(this.elementRef.nativeElement, this.pickerEvent || 'click', (e) => {
            this.inputElement = document.querySelector(`[date-picker-name="${this.datePickerCaller}"]`);
            this.referencesService.closeAll();
            if (!this.pickerOpen) {
                this.renderDatePicker(this.datePicker);
                e.stopPropagation(); // Parando propagação do evento para os eventos do window
            }
        });
        UiElement.on(window, 'click resize scroll', (e) => {
            if (this.pickerOpen) {
                if ((!(UiElement.is(e.target, '.wrap-date-picker') || UiElement.closest(e.target, '.wrap-date-picker'))
                    && !(document.body.clientWidth <= 600 && e.type === 'scroll')) || UiElement.is(e.target, '.overlay')) {
                    this.closePicker();
                }
            }
        });
    }
    getComponentAsElement(componentRef) {
        return componentRef.hostView.rootNodes[0];
    }
    setInstances(component, componentRef) {
        const keysComponent = ['ngModel', 'maxDate', 'minDate', 'initOnSelected', 'confirmSelection', 'select', 'selectDateChange', 'events'];
        keysComponent.map(key => componentRef.instance[key] = component[key]);
        componentRef.instance.cancel.subscribe(() => this.closePicker());
        componentRef.instance.updateMonth.subscribe(() => this.setCoordinate(this.componentElement));
        component.chosen.subscribe(value => componentRef.instance.ngOnChanges(value));
        componentRef.instance.chosen.subscribe(value => {
            this.referencesService.updateModel(this.datePickerCaller, value);
            if (this.pickerOpen) {
                this.inputElement.focus();
                this.closePicker();
            }
        });
    }
    renderViewCalendar(element, themeClass) {
        this.wrapDatePicker = document.createElement('div');
        this.wrapDatePicker.classList.add('wrap-date-picker');
        const overlay = document.createElement('div');
        overlay.classList.add('overlay');
        if (themeClass) {
            this.wrapDatePicker.classList.add(themeClass);
        }
        this.wrapDatePicker.style.transform = 'scale(0)';
        element.classList.add('portrait-only');
        this.wrapDatePicker.appendChild(overlay);
        this.wrapDatePicker.appendChild(element);
        document.body.appendChild(this.wrapDatePicker);
        this.setCoordinate(element);
    }
    renderDatePicker(component) {
        const componentFactory = this.componentFactoryResolver.resolveComponentFactory(UiCalendarComponent);
        this.componentRef = componentFactory.create(this.injector);
        this.componentElement = this.getComponentAsElement(this.componentRef);
        this.setInstances(component, this.componentRef);
        this.applicationRef.attachView(this.componentRef.hostView);
        this.renderViewCalendar(this.componentElement, component.themeClass);
        this.pickerOpen = true;
    }
    closePicker() {
        this.wrapDatePicker.classList.remove('open');
        setTimeout(() => {
            this.pickerOpen = false;
            this.applicationRef.detachView(this.componentRef.hostView);
            document.body.style.overflowY = '';
            try {
                document.body.removeChild(this.wrapDatePicker);
            }
            catch (e) {
            }
        }, 280);
    }
    setCoordinate(element) {
        const position = UiElement.position(this.inputElement);
        const coordinate = {
            x: position.left,
            y: this.inputElement.offsetHeight + position.top
        };
        setTimeout(() => {
            const pickerHorizontalCoveringArea = coordinate.x + element.clientWidth;
            const pickerVerticalCoveringArea = coordinate.y + element.clientHeight;
            const windowWidth = window.innerWidth + (document.body.scrollLeft || window.scrollX || window.pageXOffset);
            const windowHeight = window.innerHeight + (document.body.scrollTop || window.scrollY || window.pageYOffset);
            if (pickerHorizontalCoveringArea > windowWidth) {
                coordinate.x = windowWidth - (element.clientWidth + 8);
            }
            if (pickerVerticalCoveringArea > windowHeight) {
                coordinate.y = windowHeight - (element.clientHeight + 8);
            }
            this.wrapDatePicker.style.transform = '';
            element.style.position = 'absolute';
            element.style.top = coordinate.y + 'px';
            element.style.left = coordinate.x + 'px';
            this.wrapDatePicker.classList.add('open');
            if (document.body.clientWidth <= 600) {
                document.body.style.overflowY = 'hidden';
            }
        });
    }
};
UiDatePickerCallerDirective.ctorParameters = () => [
    { type: ComponentFactoryResolver },
    { type: ApplicationRef },
    { type: Injector },
    { type: UiReferencesService },
    { type: ElementRef }
];
__decorate([
    Input(),
    __metadata("design:type", String)
], UiDatePickerCallerDirective.prototype, "pickerEvent", void 0);
__decorate([
    Input('uiDatePickerCaller'),
    __metadata("design:type", String)
], UiDatePickerCallerDirective.prototype, "datePickerCaller", void 0);
UiDatePickerCallerDirective = __decorate([
    Directive({
        selector: '[uiDatePickerCaller]'
    }),
    __metadata("design:paramtypes", [ComponentFactoryResolver,
        ApplicationRef,
        Injector,
        UiReferencesService,
        ElementRef])
], UiDatePickerCallerDirective);

let UiDatePickerDirective = class UiDatePickerDirective {
    constructor(referencesService, element, changeDetectorRef) {
        this.referencesService = referencesService;
        this.element = element;
        this.changeDetectorRef = changeDetectorRef;
        this.select = new EventEmitter();
        this.selectDateChange = new EventEmitter();
        this.ngModelChange = new EventEmitter();
        this.chosen = new Subject();
        this.minDate = this.minDate && isDate(new Date(this.minDate)) ? new Date(this.minDate) : this.minDate;
        this.maxDate = this.maxDate && isDate(new Date(this.maxDate)) ? new Date(this.maxDate) : this.maxDate;
    }
    ngOnInit() {
        this.referencesService.add(this.datePicker, this);
    }
    ngAfterViewInit() {
        this.element.nativeElement.setAttribute('date-picker-name', this.datePicker);
    }
    ngOnChanges(value) {
        this.chosen.next(value);
        if (value.ngModel && value.ngModel.currentValue === '') {
            this.ngModelChange.emit(null);
            this.changeDetectorRef.detectChanges();
        }
    }
    ngOnDestroy() {
        this.referencesService.remove(this.datePicker);
    }
};
UiDatePickerDirective.ctorParameters = () => [
    { type: UiReferencesService },
    { type: ElementRef },
    { type: ChangeDetectorRef }
];
__decorate([
    Input(),
    __metadata("design:type", Object)
], UiDatePickerDirective.prototype, "ngModel", void 0);
__decorate([
    Input(),
    __metadata("design:type", Date)
], UiDatePickerDirective.prototype, "maxDate", void 0);
__decorate([
    Input(),
    __metadata("design:type", Date)
], UiDatePickerDirective.prototype, "minDate", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], UiDatePickerDirective.prototype, "events", void 0);
__decorate([
    Input(),
    __metadata("design:type", Date)
], UiDatePickerDirective.prototype, "initOnSelected", void 0);
__decorate([
    Input(),
    __metadata("design:type", Boolean)
], UiDatePickerDirective.prototype, "confirmSelection", void 0);
__decorate([
    Input('theme-class'),
    __metadata("design:type", String)
], UiDatePickerDirective.prototype, "themeClass", void 0);
__decorate([
    Input('uiDatePicker'),
    __metadata("design:type", String)
], UiDatePickerDirective.prototype, "datePicker", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], UiDatePickerDirective.prototype, "select", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], UiDatePickerDirective.prototype, "selectDateChange", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], UiDatePickerDirective.prototype, "ngModelChange", void 0);
UiDatePickerDirective = __decorate([
    Directive({
        selector: '[uiDatePicker]'
    }),
    __metadata("design:paramtypes", [UiReferencesService, ElementRef, ChangeDetectorRef])
], UiDatePickerDirective);

class UiElementRef {
    constructor(element) {
        this.nativeElement = element;
        if (element) {
            if (element.length) {
                this.length = element.length;
                if (element === window) {
                    this[0] = new UiElementRef(element);
                }
                else {
                    for (let i = 0; i < element.length; i++) {
                        this[i] = new UiElementRef(element[i]);
                    }
                }
            }
            else {
                this.length = 1;
                this[0] = element;
            }
        }
        this.classList = {
            remove: function removeClass(className) {
                return UiElement.classList.remove(element, className);
            },
            add: function addClass(className) {
                return UiElement.classList.add(element, className);
            },
            contains: function addClass(className) {
                return UiElement.classList.contains(element, className);
            }
        };
    }
    closest(selector) {
        return new UiElementRef(UiElement.closest(this.nativeElement, selector));
    }
    index() {
        return UiElement.index(this.nativeElement);
    }
    trigger(eventToTrigger) {
        return UiElement.trigger(this.nativeElement, eventToTrigger);
    }
    on(events, listener) {
        return UiElement.on(this.nativeElement, events, listener);
    }
    off(events, listener) {
        return UiElement.off(this.nativeElement, events, listener);
    }
    is(selector) {
        return UiElement.is(this.nativeElement, selector);
    }
    position(withoutScroll) {
        return UiElement.position(this.nativeElement, withoutScroll);
    }
    offset() {
        return UiElement.offset(this.nativeElement);
    }
    animate(property, start_value, end_value, time, end, tick) {
        return UiElement.animate(this.nativeElement, property, start_value, end_value, time, end, tick);
    }
    querySelector(selector) {
        let selected = this.nativeElement.querySelectorAll(selector);
        if (selected.length) {
            selected = selected.length === 1 ? selected[0] : selected;
            return new UiElementRef(selected);
        }
        return new UiElementRef(null);
    }
    forEach(callback) {
        return Array.prototype.forEach.call(this, callback);
    }
    filter(callback) {
        return Array.prototype.filter.call(this, callback);
    }
    indexOf(element) {
        return Array.prototype.indexOf.call(this, element);
    }
    css(styleProp, newValue) {
        return UiElement.css(this.nativeElement, styleProp, newValue);
    }
    isInViewport() {
        return UiElement.isInViewport(this.nativeElement);
    }
    attribute(name, value) {
        if (typeof value !== 'undefined') {
            return this.nativeElement.setAttribute(name, value);
        }
        else {
            return this.nativeElement.getAttribute(name);
        }
    }
    height(newHeight) {
        if (typeof newHeight !== 'undefined') {
            UiElement.css(this.nativeElement, 'height', newHeight);
        }
        return this.nativeElement.clientHeight;
    }
    parent() {
        return new UiElementRef(this.nativeElement.parentNode);
    }
    focus() {
        if (this.nativeElement && this.nativeElement.focus) {
            this.nativeElement.focus();
        }
    }
}

let UiDialogComponent = class UiDialogComponent {
    constructor(elementRef) {
        this.elementRef = elementRef;
        this.closeChange = new EventEmitter();
    }
    close() {
        this.opened = false;
        this.closeChange.emit();
        if (this.viewRef) {
            const fabs = new UiElementRef(document).querySelector('.ui-fab-container');
            if (fabs.length) {
                fabs.classList.remove('hide');
            }
            this.viewRef.rootNodes.forEach(rootNode => {
                if (rootNode.classList) {
                    rootNode.classList.remove('open');
                }
            });
            if (this.viewRef) {
                setTimeout(() => {
                    this.viewRef.rootNodes.forEach(rootNode => {
                        if (rootNode.remove) {
                            rootNode.remove();
                        }
                        else {
                            rootNode.parentNode.removeChild(rootNode);
                        }
                    });
                    this.viewRef.destroy();
                    this.viewRef = null;
                }, 280);
            }
            document.body.style.overflowY = '';
        }
    }
    show(config) {
        if (!this.viewRef) {
            const dialog = this;
            this.close();
            config = config || {};
            if (config.clickOverlayToClose === undefined) {
                config.clickOverlayToClose = true;
            }
            else if (config.clickOverlayToClose) {
                config.clickOverlayToClose = JSON.parse(config.clickOverlayToClose);
            }
            this.viewRef = dialog.templateRef.createEmbeddedView(dialog.templateRef);
            this.viewRef.detectChanges();
            this.viewRef.rootNodes.forEach(rootNode => {
                document.body.appendChild(rootNode);
                if (rootNode.clientWidth) {
                    this.open(rootNode, config);
                }
            });
        }
    }
    open(element, config) {
        this.opened = true;
        setTimeout(() => {
            const fabs = new UiElementRef(document).querySelector('.ui-fab-container');
            if (config.darkClass) {
                element.classList.add(config.darkClass);
            }
            if (config.themeClass) {
                element.classList.add(config.themeClass);
            }
            if (config.transparentOverlay) {
                element.classList.add('transparent-overlay');
            }
            if (config.cardSize || this.cardSize) {
                element.querySelector('ui-card').style.maxWidth = (config.cardSize || this.cardSize) + 'px';
                element.querySelector('ui-card').style.width = '100%';
            }
            if (!config.transparentOverlay && fabs.length) {
                fabs.classList.add('hide');
            }
            if (config.clickOverlayToClose) {
                element.querySelector('.overlay').addEventListener('click', () => {
                    this.close();
                });
            }
            element.style.transform = '';
            element.classList.add('open');
            document.body.style.overflowY = 'hidden';
        });
    }
};
UiDialogComponent.ctorParameters = () => [
    { type: ElementRef }
];
__decorate([
    Input('card-size'),
    __metadata("design:type", Number)
], UiDialogComponent.prototype, "cardSize", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], UiDialogComponent.prototype, "closeChange", void 0);
__decorate([
    ViewChild(TemplateRef, { static: true }),
    __metadata("design:type", TemplateRef)
], UiDialogComponent.prototype, "templateRef", void 0);
UiDialogComponent = __decorate([
    Component({
        selector: 'ui-dialog',
        template: "<ng-template>\r\n    <div class=\"wrap-dialog\">\r\n        <div class=\"overlay\"></div>\r\n        <ui-card>\r\n            <ng-content>\r\n            </ng-content>\r\n        </ui-card>\r\n    </div>\r\n</ng-template>\r\n",
        encapsulation: ViewEncapsulation.None,
        styles: [".wrap-dialog{position:fixed;z-index:5;left:0;top:0;width:100%;height:100%;display:flex;align-items:center;justify-content:center;padding:16px}.wrap-dialog ui-card{transform-origin:bottom;transition:transform 225ms cubic-bezier(.4,0,1,1),opacity 195ms cubic-bezier(.4,0,1,1);transform:scale(.8) translateY(16px);box-shadow:0 24px 38px 3px rgba(0,0,0,.14),0 9px 49px 8px rgba(0,0,0,.12),0 11px 15px 0 rgba(0,0,0,.2);opacity:0;max-width:100%;max-height:100%;overflow-y:auto}.wrap-dialog .overlay{transition:opacity 280ms;left:0;top:0;position:absolute;width:100%;height:100%;opacity:0}.wrap-dialog.open ui-card{transition:transform 225ms cubic-bezier(0,0,.2,1),opacity 195ms cubic-bezier(0,0,.2,1);transform:scale(1) translateY(0);opacity:1}.wrap-dialog.open .overlay{transition:opacity 280ms cubic-bezier(0,0,.2,1);opacity:1}"]
    }),
    __metadata("design:paramtypes", [ElementRef])
], UiDialogComponent);

let UiDialogTriggerDirective = class UiDialogTriggerDirective {
    constructor(viewContainerRef, elementRef) {
        this.viewContainerRef = viewContainerRef;
        this.elementRef = elementRef;
    }
    ngAfterViewInit() {
        this.dialog.closeChange.subscribe(() => {
            this.close();
        });
        UiElement.on(this.elementRef.nativeElement, this.triggerEvents || 'click', () => {
            this.render();
        });
        this.clickOverlayToClose = this.clickOverlayToClose !== undefined ? this.clickOverlayToClose : true;
    }
    render() {
        this.viewRef = this.viewContainerRef.createEmbeddedView(this.dialog.templateRef);
        this.viewRef.detectChanges();
        this.viewRef.rootNodes.forEach(rootNode => {
            document.body.appendChild(rootNode);
            if (rootNode.clientWidth) {
                this.open(rootNode);
            }
        });
    }
    open(element) {
        this.opened = true;
        setTimeout(() => {
            const fabs = document.querySelectorAll('.ui-fab-container');
            if (this.darkClass) {
                element.classList.add(this.darkClass);
            }
            if (this.themeClass) {
                element.classList.add(this.themeClass);
            }
            if (this.transparentOverlay) {
                element.classList.add('transparent-overlay');
            }
            if (this.dialog.cardSize) {
                element.querySelectorAll('ui-card')[0].style.maxWidth = this.dialog.cardSize + 'px';
                element.querySelectorAll('ui-card')[0].style.width = '100%';
            }
            if (!this.transparentOverlay && fabs.length) {
                Array.prototype.forEach.call(fabs, fab => {
                    fab.classList.add('hide');
                });
            }
            if (this.clickOverlayToClose) {
                element.querySelectorAll('.overlay')[0].addEventListener('click', () => {
                    this.close();
                });
            }
            element.style.transform = '';
            element.classList.add('open');
            document.body.style.overflowY = 'hidden';
        });
    }
    close() {
        this.opened = false;
        if (this.viewContainerRef.length) {
            const viewRef = this.viewRef; // Salvando a referência para achar o index deste componente
            const fabs = document.querySelectorAll('.ui-fab-container');
            if (fabs.length) {
                Array.prototype.forEach.call(fabs, fab => {
                    fab.classList.remove('hide');
                });
            }
            viewRef.rootNodes.forEach(rootNode => {
                if (rootNode.classList) {
                    rootNode.classList.remove('open');
                }
            });
            setTimeout(() => this.viewContainerRef.remove(this.viewContainerRef.indexOf(viewRef)), 280);
            document.body.style.overflowY = '';
        }
    }
};
UiDialogTriggerDirective.ctorParameters = () => [
    { type: ViewContainerRef },
    { type: ElementRef }
];
__decorate([
    Input('trigger-events'),
    __metadata("design:type", String)
], UiDialogTriggerDirective.prototype, "triggerEvents", void 0);
__decorate([
    Input('dark-class'),
    __metadata("design:type", String)
], UiDialogTriggerDirective.prototype, "darkClass", void 0);
__decorate([
    Input('theme-class'),
    __metadata("design:type", String)
], UiDialogTriggerDirective.prototype, "themeClass", void 0);
__decorate([
    Input('transparent-overlay'),
    __metadata("design:type", Boolean)
], UiDialogTriggerDirective.prototype, "transparentOverlay", void 0);
__decorate([
    Input('uiDialogTrigger'),
    __metadata("design:type", Object)
], UiDialogTriggerDirective.prototype, "dialog", void 0);
__decorate([
    Input('click-overlay-to-close'),
    __metadata("design:type", Object)
], UiDialogTriggerDirective.prototype, "clickOverlayToClose", void 0);
UiDialogTriggerDirective = __decorate([
    Directive({
        selector: '[uiDialogTrigger]'
    }),
    __metadata("design:paramtypes", [ViewContainerRef, ElementRef])
], UiDialogTriggerDirective);

let UiInputContainerComponent = class UiInputContainerComponent {
    constructor(element) {
        this.element = element;
    }
    ngAfterViewInit() {
        const nativeElement = this.element.nativeElement;
        const inputWrap = nativeElement.getElementsByClassName('ui-input-wrap')[0];
        const icon = nativeElement.getElementsByClassName('icon')[0];
        const line = document.createElement('div');
        line.className = 'line';
        inputWrap.appendChild(line);
        if (icon) {
            const methodInsertIcon = icon === inputWrap.firstElementChild ? 'insertBefore' : 'appendChild';
            inputWrap.removeChild(icon);
            nativeElement[methodInsertIcon](icon, nativeElement.firstChild);
        }
    }
};
UiInputContainerComponent.ctorParameters = () => [
    { type: ElementRef }
];
__decorate([
    Input(),
    __metadata("design:type", Object)
], UiInputContainerComponent.prototype, "loading", void 0);
UiInputContainerComponent = __decorate([
    Component({
        selector: 'ui-input-container',
        template: `
    <div class="ui-input-wrap">
      <ng-content></ng-content>
        
        <div *ngIf="loading" class="ui-progress input">
            <div class="indeterminate"></div>
        </div>
    </div>
  `,
        // styleUrls: ['input.component.scss'],
        encapsulation: ViewEncapsulation.None
    }),
    __metadata("design:paramtypes", [ElementRef])
], UiInputContainerComponent);

let UiInputDirective = class UiInputDirective {
    constructor(element, renderer) {
        this.element = element;
        this.renderer = renderer;
        this.ngModelChange = new EventEmitter();
        this.placeholder = element.nativeElement.placeholder;
    }
    ngAfterViewInit() {
        this.renderer.addClass(this.element.nativeElement, 'ui-control');
        this.setPlaceholder();
    }
    ngOnChanges() {
        this.isEmpty(this.ngModel);
    }
    onBlur() {
        this.isEmpty(this.ngModel);
    }
    onFocus() {
        this.isEmpty(this.ngModel);
        this.setPlaceholder(this.placeholder);
    }
    onFocusout() {
        this.setPlaceholder();
    }
    isEmpty(value) {
        // TODO: Try model e view value
        const self = this;
        function isEmpty() {
            let action = isNullOrUndefined(value) && !self.element.nativeElement.value ? 'addClass' : 'removeClass';
            if (!isNullOrUndefined(self.ngModel) && self.ngModel.trim && !self.ngModel.trim()) {
                action = 'addClass';
            }
            self.renderer[action](self.element.nativeElement, 'ui-empty');
        }
        isEmpty();
        setTimeout(isEmpty);
    }
    setPlaceholder(value) {
        value = this.persistPlaceholder ? this.placeholder : value || '';
        this.renderer.setProperty(this.element.nativeElement, 'placeholder', value);
    }
};
UiInputDirective.ctorParameters = () => [
    { type: ElementRef },
    { type: Renderer2 }
];
__decorate([
    Input(),
    __metadata("design:type", Object)
], UiInputDirective.prototype, "ngModel", void 0);
__decorate([
    Input(),
    __metadata("design:type", Boolean)
], UiInputDirective.prototype, "persistPlaceholder", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], UiInputDirective.prototype, "ngModelChange", void 0);
__decorate([
    HostListener('blur'),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", void 0)
], UiInputDirective.prototype, "onBlur", null);
__decorate([
    HostListener('focus'),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", void 0)
], UiInputDirective.prototype, "onFocus", null);
__decorate([
    HostListener('focusout'),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", void 0)
], UiInputDirective.prototype, "onFocusout", null);
UiInputDirective = __decorate([
    Directive({
        selector: '[uiInput]'
    }),
    __metadata("design:paramtypes", [ElementRef, Renderer2])
], UiInputDirective);

var UiMaxlengthDirective_1;
let UiMaxlengthDirective = UiMaxlengthDirective_1 = class UiMaxlengthDirective {
    constructor() { }
    validate(control) {
        const value = control.value ? control.value.toString() : control.value;
        if (value && value.length > this.maxLength) {
            return {
                uiMaxlength: true
            };
        }
        return null;
    }
};
__decorate([
    Input('uiMaxlength'),
    __metadata("design:type", Object)
], UiMaxlengthDirective.prototype, "maxLength", void 0);
UiMaxlengthDirective = UiMaxlengthDirective_1 = __decorate([
    Directive({
        selector: '[uiMaxlength][ngModel]',
        providers: [
            { provide: NG_VALIDATORS, useExisting: forwardRef(() => UiMaxlengthDirective_1), multi: true }
        ]
    }),
    __metadata("design:paramtypes", [])
], UiMaxlengthDirective);

let UiMenuComponent = class UiMenuComponent {
    constructor(viewContainerRef, elementRef) {
        this.viewContainerRef = viewContainerRef;
        this.elementRef = elementRef;
        this.closeChange = new EventEmitter(); // OLD VERSION
    }
    ngOnDestroy() {
        this.close();
    }
    show(event, config) {
        if (config) {
            this.element = config.element || null;
            this.themeClass = config.class || null;
            this.menuAlign = config.align || null;
            this.persistentMenu = config.persistent || null;
        }
        this.createListener();
        let coordinate = {
            x: event.clientX,
            y: event.clientY + window.pageYOffset
        };
        if (this.element) {
            const position = UiElement.position(this.element);
            coordinate = {
                x: position.left,
                y: position.top
            };
        }
        this.render(coordinate);
    }
    render(coordinate) {
        this.viewRef = this.viewContainerRef.createEmbeddedView(this.templateRef);
        this.viewRef.detectChanges();
        this.viewRef.rootNodes.forEach(rootNode => {
            document.body.appendChild(rootNode);
            if (rootNode.clientWidth) {
                this.open(rootNode, coordinate);
            }
        });
    }
    open(element, coordinate) {
        setTimeout(() => {
            let horizontalCoveringArea = coordinate.x + element.clientWidth;
            const verticalCoveringArea = coordinate.y + element.clientHeight;
            const windowWidth = window.innerWidth + document.body.scrollLeft;
            const windowHeight = document.body.clientHeight + (document.body.scrollTop || window.scrollY || window.pageYOffset);
            if (this.menuAlign === 'right') {
                coordinate.x -= element.clientWidth - (this.element ? this.element.clientWidth : 0);
                horizontalCoveringArea = coordinate.x;
            }
            if (horizontalCoveringArea > windowWidth) {
                element.classList.add('right');
                coordinate.x = windowWidth - (element.clientWidth + 8);
            }
            if (coordinate.x <= 8) {
                coordinate.x = 8;
            }
            if (verticalCoveringArea > windowHeight) {
                coordinate.y = windowHeight - (element.clientHeight + 8);
            }
            if (coordinate.y <= 0) {
                coordinate.y = 0;
            }
            if (this.themeClass) {
                element.classList.add(this.themeClass);
            }
            if (this.menuAlign) {
                element.classList.add(this.menuAlign);
            }
            element.style.transform = '';
            element.querySelector('ui-card').style.maxHeight = window.innerHeight + 'px';
            element.style.top = coordinate.y + 'px';
            element.style.left = coordinate.x + 'px';
            element.classList.add('open');
        });
    }
    close() {
        this.closeChange.emit(); // OLD VERSION
        if (this.viewContainerRef.length) {
            const viewRef = this.viewRef; // Salvando a referência para achar o index deste componente
            viewRef.rootNodes.forEach(rootNode => {
                if (rootNode.classList) {
                    rootNode.classList.remove('open');
                }
            });
            setTimeout(() => this.viewContainerRef.remove(this.viewContainerRef.indexOf(viewRef)), 280);
        }
    }
    createListener() {
        if (!this.listenerExists) {
            this.listenerExists = true;
            UiElement.on(window, 'mouseup resize scroll touchend', (e) => {
                if (this.elementRef.nativeElement !== e.target) {
                    if (!this.persistentMenu) {
                        this.close();
                    }
                }
            });
        }
    }
};
UiMenuComponent.ctorParameters = () => [
    { type: ViewContainerRef },
    { type: ElementRef }
];
__decorate([
    ViewChild(TemplateRef),
    __metadata("design:type", TemplateRef)
], UiMenuComponent.prototype, "templateRef", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], UiMenuComponent.prototype, "closeChange", void 0);
UiMenuComponent = __decorate([
    Component({
        selector: 'ui-menu',
        template: "<ng-template>\r\n    <div class=\"wrap-menu-overlay\" *ngIf=\"overlay\" (click)=\"close()\"></div>\r\n    <div class=\"wrap-menu\">\r\n        <ui-card>\r\n            <ng-content>\r\n            </ng-content>\r\n        </ui-card>\r\n    </div>\r\n</ng-template>\r\n\r\n",
        encapsulation: ViewEncapsulation.None,
        styles: [".wrap-menu-overlay{position:fixed;top:0;left:0;right:0;bottom:0}.wrap-menu{position:absolute;transition:transform 280ms,opacity 280ms;transform-origin:top left;transform:scale(0);opacity:0;z-index:5}.wrap-menu.right{transform-origin:top right}.wrap-menu.top{transform-origin:top}.wrap-menu.open{transition:transform 280ms cubic-bezier(0,0,.2,1),opacity 280ms cubic-bezier(0,0,.2,1);transform:scale(1);opacity:1}.wrap-menu ui-card{box-shadow:0 8px 10px 1px rgba(0,0,0,.14),0 3px 14px 3px rgba(0,0,0,.12),0 4px 15px 0 rgba(0,0,0,.2);overflow-y:auto}.wrap-menu .ui-menu-title{font-size:14px;font-weight:500;padding:8px 24px}.wrap-menu .ui-menu-content{padding:8px 0;min-width:56px}.wrap-menu .ui-menu-content.size-2x{min-width:112px}.wrap-menu .ui-menu-content.size-3x{min-width:168px}.wrap-menu .ui-menu-content.size-4x{min-width:224px}.wrap-menu .ui-menu-content.size-5x{min-width:280px}.wrap-menu .ui-menu-content.size-6x{min-width:336px}.wrap-menu .ui-menu-content.size-7x{min-width:392px}.wrap-menu .ui-menu-item{height:48px;line-height:48px;padding:0 16px;white-space:nowrap;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;display:flex;align-items:center;color:inherit;text-decoration:none;transition:280ms cubic-bezier(0,0,.2,1)}.wrap-menu .ui-menu-item:not(a){cursor:default}.wrap-menu .ui-menu-item .icon{margin-right:14px;margin-left:-4px}.wrap-menu ui-subheader{color:inherit;padding:0 16px}@media only screen and (min-width:376px) and (min-width:764px){.wrap-menu .ui-menu-content.size-2x{min-width:128px}.wrap-menu .ui-menu-content.size-3x{min-width:192px}.wrap-menu .ui-menu-content.size-4x{min-width:256px}.wrap-menu .ui-menu-content.size-5x{min-width:320px}.wrap-menu .ui-menu-content.size-6x{min-width:384px}.wrap-menu .ui-menu-content.size-7x{min-width:448px}.wrap-menu .ui-menu-item{height:32px;line-height:32px;font-size:15px;padding:0 24px}.wrap-menu ui-subheader{min-height:32px;padding:0 24px}}body.ui-nav-drawer-persistent .wrap-menu{z-index:6}"]
    }),
    __metadata("design:paramtypes", [ViewContainerRef, ElementRef])
], UiMenuComponent);

let UiMenuTriggerDirective = class UiMenuTriggerDirective {
    constructor(viewContainerRef, elementRef) {
        this.viewContainerRef = viewContainerRef;
        this.elementRef = elementRef;
    }
    ngAfterViewInit() {
        this.menu.closeChange.subscribe(() => {
            this.close();
        });
        UiElement.on(this.elementRef.nativeElement, this.triggerEvents || 'click', event => {
            this.menu.overlay = this.overlay;
            if (!this.persistentMenu) {
                this.close();
            }
            if (this.contextmenu) {
                return;
            }
            setTimeout(() => {
                const position = UiElement.position(this.elementRef.nativeElement);
                const coordinate = {
                    x: position.left,
                    y: position.top
                };
                this.render(coordinate);
            });
        });
        UiElement.on(window, 'mouseup resize scroll touchend', (e) => {
            if (this.fixed && (e.type === 'scroll' || e.type === 'resize')) {
                return;
            }
            if (this.clickOverlayToClose) {
                switch (e.type) {
                    case 'mouseup':
                    case 'touchend':
                        if (!UiElement.closest(e.target, '.wrap-menu')) {
                            this.close();
                        }
                        return;
                    default:
                        this.close();
                        return;
                }
            }
            if (this.elementRef.nativeElement !== e.target) {
                if (!this.persistentMenu) {
                    this.close();
                }
            }
        });
        UiElement.on(window, 'mouseup touchend', e => {
            if (this.clickOverlayToClose && !UiElement.closest(e.target, '.wrap-menu')) {
                this.close();
                return;
            }
        });
    }
    onContextmenu() {
        if (!this.contextmenu) {
            return true;
        }
        const position = UiElement.position(this.elementRef.nativeElement);
        const coordinate = {
            x: position.left,
            y: position.top
        };
        this.render(coordinate);
        return false;
    }
    render(coordinate) {
        this.viewRef = this.viewContainerRef.createEmbeddedView(this.menu.templateRef);
        this.viewRef.detectChanges();
        this.viewRef.rootNodes.forEach(rootNode => {
            document.body.appendChild(rootNode);
            if (rootNode.clientWidth && !rootNode.classList.contains('wrap-menu-overlay')) {
                this.open(rootNode, coordinate);
            }
        });
    }
    open(element, coordinate) {
        setTimeout(() => {
            let horizontalCoveringArea = coordinate.x + element.clientWidth;
            const verticalCoveringArea = coordinate.y + element.clientHeight;
            const windowWidth = window.innerWidth + document.body.scrollLeft;
            const windowHeight = document.body.clientHeight + (document.body.scrollTop || window.scrollY || window.pageYOffset);
            if (this.align === 'right' || this.menuAlign === 'right') {
                coordinate.x -= element.clientWidth - this.elementRef.nativeElement.clientWidth;
                horizontalCoveringArea = coordinate.x;
            }
            if (horizontalCoveringArea > windowWidth) {
                coordinate.x = windowWidth - (element.clientWidth + 8);
            }
            if (coordinate.x <= 8) {
                coordinate.x = 8;
            }
            if (verticalCoveringArea > windowHeight) {
                coordinate.y = windowHeight - (element.clientHeight + 8);
            }
            if (coordinate.y <= 0) {
                coordinate.y = 0;
            }
            if (this.themeClass) {
                element.classList.add(this.themeClass);
            }
            if (this.align || this.menuAlign) {
                element.classList.add(this.align || this.menuAlign);
            }
            element.style.transform = '';
            element.querySelector('ui-card').style.maxHeight = window.innerHeight + 'px';
            element.querySelector('ui-card').style.maxWidth = (window.innerWidth - 16) + 'px';
            element.style.top = coordinate.y + 'px';
            element.style.left = coordinate.x + 'px';
            element.classList.add('open');
        });
    }
    close() {
        if (this.viewContainerRef.length) {
            const viewRef = this.viewRef; // Salvando a referência para achar o index deste componente
            viewRef.rootNodes.forEach(rootNode => {
                if (rootNode.classList) {
                    rootNode.classList.remove('open');
                }
            });
            setTimeout(() => this.viewContainerRef.remove(this.viewContainerRef.indexOf(viewRef)), 280);
        }
    }
};
UiMenuTriggerDirective.ctorParameters = () => [
    { type: ViewContainerRef },
    { type: ElementRef }
];
__decorate([
    Input('trigger-events'),
    __metadata("design:type", Object)
], UiMenuTriggerDirective.prototype, "triggerEvents", void 0);
__decorate([
    Input('theme-class'),
    __metadata("design:type", Object)
], UiMenuTriggerDirective.prototype, "themeClass", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], UiMenuTriggerDirective.prototype, "align", void 0);
__decorate([
    Input('menu-align'),
    __metadata("design:type", Object)
], UiMenuTriggerDirective.prototype, "menuAlign", void 0);
__decorate([
    Input('uiMenuTrigger'),
    __metadata("design:type", Object)
], UiMenuTriggerDirective.prototype, "menu", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], UiMenuTriggerDirective.prototype, "persistentMenu", void 0);
__decorate([
    Input('click-overlay-to-close'),
    __metadata("design:type", Object)
], UiMenuTriggerDirective.prototype, "clickOverlayToClose", void 0);
__decorate([
    Input(),
    __metadata("design:type", Boolean)
], UiMenuTriggerDirective.prototype, "contextmenu", void 0);
__decorate([
    Input(),
    __metadata("design:type", Boolean)
], UiMenuTriggerDirective.prototype, "overlay", void 0);
__decorate([
    Input(),
    __metadata("design:type", Boolean)
], UiMenuTriggerDirective.prototype, "fixed", void 0);
__decorate([
    HostListener('contextmenu'),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", void 0)
], UiMenuTriggerDirective.prototype, "onContextmenu", null);
UiMenuTriggerDirective = __decorate([
    Directive({
        selector: '[uiMenuTrigger]'
    }),
    __metadata("design:paramtypes", [ViewContainerRef, ElementRef])
], UiMenuTriggerDirective);

let UiNavDrawerComponent = class UiNavDrawerComponent {
    constructor(element) {
        this.element = element;
        this.openChange = new EventEmitter();
        this.openNav = () => {
            if (document.body.clientWidth <= 375 || (!this.element.nativeElement.classList.contains('persistent') && (window.scrollY || window.pageYOffset) > 1)) {
                const fabContainer = document.querySelectorAll('.ui-fab-container')[0];
                if (fabContainer) {
                    fabContainer.classList.add('hide');
                }
            }
            this.element.nativeElement.classList.add('open');
            if (!this.element.nativeElement.classList.contains('persistent')) {
                document.body.style.overflowY = 'hidden';
            }
            else {
                document.body.style.overflowY = '';
            }
        };
        this.closeNav = () => {
            const fabContainer = document.querySelectorAll('.ui-fab-container')[0];
            if (fabContainer) {
                fabContainer.classList.remove('hide');
            }
            this.element.nativeElement.classList.remove('open');
            document.body.style.overflowY = '';
        };
    }
    ngAfterViewInit() {
        const body = UiElement.closest(this.element.nativeElement, 'body');
        body.classList.add('notransition');
        setTimeout(() => {
            body.classList.remove('notransition');
            this.element.nativeElement.querySelectorAll('.ui-nav-drawer-overlay')[0].style.visibility = 'visible';
        }, 300);
        const isPersistent = this.element.nativeElement.classList.contains('persistent');
        const isOpen = this.element.nativeElement.classList.contains('open');
        if (isPersistent && isOpen) {
            if (document.body.clientWidth > 375) {
                body.classList.add('ui-nav-drawer-persistent');
            }
        }
        else {
            body.classList.remove('ui-nav-drawer-persistent');
        }
        this.element.nativeElement.addEventListener('click', (e) => {
            if (!(isPersistent && window.innerWidth > 763) && UiElement.is(e.srcElement, 'a')) {
                this.open = false;
                this.openChange.emit(this.open);
            }
        });
        if (this.open) {
            this.openNav();
        }
        else {
            this.closeNav();
        }
        const navDrawer = this.element.nativeElement.querySelector('nav');
        let navDrawerTouch;
        let mouseX;
        let mouseXMovement;
        this.onTouchStart = (e) => {
            if (this.element.nativeElement.classList.contains('.right')) {
                return;
            }
            mouseX = e.touches[0].pageX;
            navDrawerTouch = (mouseX > 0 && mouseX < 40) ? 'open' : navDrawerTouch;
            navDrawerTouch = (mouseX > 320 && mouseX < 360) ? 'close' : navDrawerTouch;
        };
        this.onTouchMove = (e) => {
            if (navDrawerTouch) {
                mouseXMovement = e.touches[0].pageX - mouseX;
                if (navDrawerTouch === 'open' && !this.open) {
                    mouseXMovement = mouseXMovement > 320 ? 320 : mouseXMovement;
                    UiElement.css(navDrawer, 'transform', 'translateX(' + (-320 + mouseXMovement) + 'px)');
                }
                else if (navDrawerTouch === 'close' && this.open) {
                    mouseXMovement = mouseXMovement < -330 ? -330 : mouseXMovement;
                    mouseXMovement = mouseXMovement > 0 ? 0 : mouseXMovement;
                    UiElement.css(navDrawer, 'transform', 'translateX(' + (mouseXMovement) + 'px)');
                }
            }
        };
        this.onTouchEnd = (e) => {
            if (navDrawerTouch) {
                if (navDrawerTouch === 'open' && mouseXMovement > 20) {
                    UiElement.css(navDrawer, 'transform', '');
                    this.open = true;
                    this.openChange.emit(this.open);
                    this.openNav();
                }
                else if (navDrawerTouch === 'close' && mouseXMovement < -20) {
                    UiElement.css(navDrawer, 'transform', '');
                    this.open = false;
                    this.openChange.emit(this.open);
                    this.closeNav();
                }
                else {
                    UiElement.css(navDrawer, 'transform', '');
                }
            }
            navDrawerTouch = undefined;
        };
        UiElement.on(window, 'touchstart', this.onTouchStart);
        UiElement.on(window, 'touchmove', this.onTouchMove);
        UiElement.on(window, 'touchend', this.onTouchEnd);
    }
    ngOnChanges(changes) {
        const isNavDrawerPersistent = UiCookie.get('NavDrawerPersistent') === 'true';
        if (isNavDrawerPersistent) {
            this.open = true;
            this.openNav();
        }
        if (changes.open) {
            const isOpen = changes.open.currentValue;
            this.open = isOpen;
            if (isOpen) {
                this.openNav();
            }
            else {
                this.closeNav();
            }
            const isPersistent = this.element.nativeElement.classList.contains('persistent');
            const body = UiElement.closest(this.element.nativeElement, 'body');
            if (isPersistent && isOpen) {
                if (document.body.clientWidth > 375) {
                    body.classList.add('ui-nav-drawer-persistent');
                    UiCookie.set('NavDrawerPersistent', 'true');
                }
            }
            else {
                body.classList.remove('ui-nav-drawer-persistent');
                UiCookie.set('NavDrawerPersistent', 'false');
            }
            setTimeout(() => {
                UiElement.trigger(window, 'resize');
            }, 280);
        }
    }
    ngOnDestroy() {
        UiElement.off(window, 'touchstart', this.onTouchStart);
        UiElement.off(window, 'touchmove', this.onTouchMove);
        UiElement.off(window, 'touchend', this.onTouchEnd);
        document.body.classList.add('notransition');
        document.body.classList.remove('ui-nav-drawer-persistent');
        setTimeout(() => {
            document.body.classList.remove('notransition');
        }, 1);
    }
    closeMenuOverlay() {
        if (this.open !== undefined) {
            this.open = false;
            this.openChange.emit(this.open);
        }
    }
};
UiNavDrawerComponent.ctorParameters = () => [
    { type: ElementRef }
];
__decorate([
    Input(),
    __metadata("design:type", Boolean)
], UiNavDrawerComponent.prototype, "open", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], UiNavDrawerComponent.prototype, "openChange", void 0);
UiNavDrawerComponent = __decorate([
    Component({
        selector: 'ui-nav-drawer',
        template: "<nav>\r\n    <ng-content></ng-content>\r\n</nav>\r\n<div class=\"ui-nav-drawer-overlay\" (click)=\"closeMenuOverlay()\"></div>\r\n",
        encapsulation: ViewEncapsulation.None,
        styles: ["ui-nav-drawer.right nav{right:-10px;left:auto;transform:translateX(100%)}ui-nav-drawer nav{top:0;bottom:0;max-width:320px;position:fixed;width:100%;z-index:7;box-shadow:0 16px 24px 2px rgba(0,0,0,.14),0 6px 30px 5px rgba(0,0,0,.12),0 8px 10px 0 rgba(0,0,0,.2);transition:transform 280ms cubic-bezier(0,0,.2,1);transform:translateX(-100%);-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;left:-10px}ui-nav-drawer nav .ui-nav-drawer-overflow{height:calc(100% - 64px);overflow:auto;margin-top:-1px;position:relative}ui-nav-drawer nav .ui-list{padding-bottom:0}ui-nav-drawer nav .ui-list .ui-list-item:not(.nothing){padding-left:21px}ui-nav-drawer.persistent nav{z-index:4}ui-nav-drawer.open nav{left:0;transform:translateX(0)}ui-nav-drawer.open.right nav{left:auto;right:0}ui-nav-drawer:not(.persistent) .ui-nav-drawer-overlay{position:fixed;left:0;top:0;bottom:0;right:0;opacity:0;z-index:-1;visibility:hidden}@media (max-width:375px),only screen and (min-width:376px) and (max-width:763px){ui-nav-drawer nav{width:calc(100% - 56px)}ui-nav-drawer .ui-nav-drawer-overlay{position:fixed;left:0;top:0;bottom:0;right:0;opacity:0;z-index:-1;visibility:hidden}}ui-nav-drawer.open nav+.ui-nav-drawer-overlay{-webkit-animation:280ms cubic-bezier(0,0,.2,1) openNav;animation:280ms cubic-bezier(0,0,.2,1) openNav;-webkit-animation-fill-mode:forwards;animation-fill-mode:forwards}ui-nav-drawer:not(.open) nav+.ui-nav-drawer-overlay{-webkit-animation:280ms cubic-bezier(0,0,.2,1) closeNav;animation:280ms cubic-bezier(0,0,.2,1) closeNav;-webkit-animation-fill-mode:forwards;animation-fill-mode:forwards}@-webkit-keyframes openNav{0%{opacity:0;z-index:3}100%{opacity:1;z-index:3}}@keyframes openNav{0%{opacity:0;z-index:3}100%{opacity:1;z-index:3}}@-webkit-keyframes closeNav{0%{opacity:1;z-index:3}99%{opacity:0;z-index:3}100%{opacity:0;z-index:-1}}@keyframes closeNav{0%{opacity:1;z-index:3}99%{opacity:0;z-index:3}100%{opacity:0;z-index:-1}}body{transition:margin-left 280ms cubic-bezier(0,0,.2,1)}@media only screen and (min-width:376px) and (min-width:764px){ui-nav-drawer.persistent nav{box-shadow:0 0 2px 0 rgba(0,0,0,.14),0 2px 2px 0 rgba(0,0,0,.12),0 1px 3px 0 rgba(0,0,0,.2)}body.ui-nav-drawer-persistent{margin-left:320px}}"]
    }),
    __metadata("design:paramtypes", [ElementRef])
], UiNavDrawerComponent);

let UiOptionComponent = class UiOptionComponent {
    constructor(element) {
        this.element = element;
    }
    ngAfterViewInit() {
        const input = this.element.nativeElement.querySelector('input');
        input.classList.add('ui-option');
        const optionShell = '<div class="ui-option-shell"><div class="ui-option-fill"></div><div class="ui-option-mark"></div></div>';
        input.insertAdjacentHTML('afterend', optionShell);
        this.setColor();
    }
    ngOnChanges(changes) {
        if (changes.color && !changes.color.firstChange) {
            this.setColor();
        }
    }
    setColor() {
        const optionFill = this.element.nativeElement.querySelector('.ui-option-fill');
        optionFill.style.borderColor = this.color || '';
    }
};
UiOptionComponent.ctorParameters = () => [
    { type: ElementRef }
];
__decorate([
    Input(),
    __metadata("design:type", String)
], UiOptionComponent.prototype, "color", void 0);
UiOptionComponent = __decorate([
    Component({
        selector: 'ui-option',
        template: "<label>\r\n    <ng-content></ng-content>\r\n</label>\r\n",
        encapsulation: ViewEncapsulation.None,
        styles: ["ui-option-container{display:flex;flex-wrap:wrap;min-height:32px;align-items:center;margin-bottom:8px}ui-option-container .info{color:rgba(0,0,0,.87);display:block;width:100%;margin-bottom:8px;font-size:12px;line-height:16px}ui-option-container .info .secondary{display:block;color:rgba(0,0,0,.54)}ui-option-container>ui-option{flex:0 0 auto;max-width:100%;margin-right:16px}ui-option{position:relative;display:inline-flex;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none}ui-option.no-space{margin:0}ui-option input{width:0;height:0;position:absolute;z-index:-9999;opacity:0}ui-option .ui-option-shell{position:relative;flex:0 0 auto;width:18px;height:18px;transition:.2s ease-in-out}ui-option.small{font-size:14px}ui-option.small .ui-option-shell{width:14px;height:14px}ui-option.small input[type=checkbox]:checked+.ui-option-shell .ui-option-fill{border-width:7px}ui-option .ui-option-shell:not(:last-child){margin-right:4px}ui-option input[type=checkbox]+.ui-option-shell,ui-option input[type=checkbox]+.ui-option-shell .ui-option-fill{border-radius:2px}ui-option input[type=radio]+.ui-option-shell,ui-option input[type=radio]+.ui-option-shell .ui-option-fill{border-radius:50%}ui-option .ui-option-shell::before{content:\"\";display:block;position:absolute;top:-100%;left:-100%;right:-100%;bottom:-100%;transform:scale(0);border-radius:50%;transition:.1s ease-in-out;pointer-events:none}ui-option .ui-option:focus+.ui-option-shell::before,ui-option>label:active .ui-option-shell::before{transform:scale(1)}ui-option input[type=checkbox]:not(:disabled):active+.ui-option-shell,ui-option>label:active .ui-option-shell{transform:scale(.9)}ui-option .ui-option-fill{content:\"\";display:block;position:absolute;top:-2px;left:-2px;right:-2px;bottom:-2px;margin:auto;border-radius:2px;overflow:hidden;transition:.1s ease-in-out}ui-option input[type=checkbox]+.ui-option-shell .ui-option-fill{border-width:0;border-style:solid;transition:border .2s ease-in-out}ui-option input[type=checkbox]:checked+.ui-option-shell .ui-option-fill{border-width:9px}ui-option input[type=checkbox]+.ui-option-shell .ui-option-mark{position:absolute;top:0;left:0;width:50%;height:90%;transform:rotate(45deg) translate(22%,-26%);opacity:0;transition:50ms ease-in-out}ui-option input[type=checkbox]:checked+.ui-option-shell .ui-option-mark{opacity:1}ui-option input[type=checkbox]+.ui-option-shell .ui-option-mark::after,ui-option input[type=checkbox]+.ui-option-shell .ui-option-mark::before{content:\"\";position:absolute;display:block;background-color:#fff;transition:transform .1s ease-in-out,opacity .2s ease-in-out}ui-option input[type=checkbox]+.ui-option-shell .ui-option-mark::before{top:87%;left:0;right:0;bottom:0;transform-origin:0 50%;transform:scaleX(0)}ui-option input[type=checkbox]+.ui-option-shell .ui-option-mark::after{top:10%;left:70%;right:0;bottom:0;transform-origin:50% 100%;transform:scaleY(0)}ui-option input[type=checkbox]:checked+.ui-option-shell .ui-option-mark::before{transform:scaleX(1);transition:50ms ease-in-out .2s,opacity linear}ui-option input[type=checkbox]:checked+.ui-option-shell .ui-option-mark::after{transform:scaleY(1);transition:50ms ease-in-out 250ms,opacity linear}ui-option input[type=radio]+.ui-option-shell .ui-option-fill{transition:border .1s ease-in-out .1s,transform .2s ease-in-out}ui-option input[type=radio]:checked+.ui-option-shell .ui-option-fill{border-width:9px;transform:scale(.6);transition:border .2s ease-in-out,transform .3s cubic-bezier(.42,0,.53,2) .1s}ui-option input:disabled+.ui-option-shell{opacity:.6}ui-option input:disabled+*{cursor:not-allowed;transform:scale(1)!important}ui-option input:disabled+.ui-option-shell::before{display:none}ui-option input:disabled+div+span{color:#bdbdbd}ui-option>label{display:flex;align-items:center;min-height:19px}"]
    }),
    __metadata("design:paramtypes", [ElementRef])
], UiOptionComponent);

let UiProgressRadialComponent = class UiProgressRadialComponent {
    constructor() {
    }
    ngOnInit() {
    }
};
UiProgressRadialComponent = __decorate([
    Component({
        selector: 'ui-progress-radial.indeterminate',
        template: "<svg class=\"spinner-container\" viewBox=\"0 0 44 44\">\r\n    <circle class=\"path\" cx=\"22\" cy=\"22\" r=\"20\" fill=\"none\" stroke-width=\"4\"></circle>\r\n</svg>\r\n",
        styles: [":host{width:24px;display:block}:host .spinner-container{-webkit-animation:2s linear infinite rotate;animation:2s linear infinite rotate;z-index:2}:host .spinner-container .path{stroke-dasharray:1,150;stroke-dashoffset:0;-webkit-animation:1.5s ease-in-out infinite dash;animation:1.5s ease-in-out infinite dash}:host #initial_startup .spinner-container .path,:host #startup .spinner-container .path{stroke:#acb9bf}@-webkit-keyframes rotate{100%{transform:rotate(360deg)}}@keyframes rotate{100%{transform:rotate(360deg)}}@-webkit-keyframes dash{0%{stroke-dasharray:1,150;stroke-dashoffset:0}50%{stroke-dasharray:90,150;stroke-dashoffset:-35}100%{stroke-dasharray:90,150;stroke-dashoffset:-124}}@keyframes dash{0%{stroke-dasharray:1,150;stroke-dashoffset:0}50%{stroke-dasharray:90,150;stroke-dashoffset:-35}100%{stroke-dasharray:90,150;stroke-dashoffset:-124}}:host-context(.ui-button.fab),:host-context(.ui-button.icon){position:absolute;width:100%;top:0}"]
    }),
    __metadata("design:paramtypes", [])
], UiProgressRadialComponent);

const maxRipples = 10;
let ripples = 0;
let UiRippleDirective = class UiRippleDirective {
    constructor(element) {
        this.element = element;
        this.isIE = navigator.userAgent.indexOf('Trident') > -1;
    }
    ngAfterViewInit() {
        this.elRippleContainerTemplate = document.createElement('div');
        this.elRippleContainerTemplate.classList.add('ui-ripple-container');
        this.elRippleTemplate = document.createElement('div');
        this.elRippleTemplate.classList.add('ui-ripple-wave');
        this.elRippleContainerTemplateClone = this.elRippleContainerTemplate.cloneNode(true);
    }
    onMousedown(e) {
        if (!this.isIE) {
            ripples = document.querySelectorAll('.ui-ripple-wave').length;
            if (!this.rippleDisable && !this.element.nativeElement.hasAttribute('disabled') && ripples < maxRipples) {
                const elementWidth = this.element.nativeElement.offsetWidth;
                const elementHeight = this.element.nativeElement.offsetHeight;
                const isIcon = this.element.nativeElement.classList.contains('icon');
                const isFab = this.element.nativeElement.classList.contains('fab');
                const isRounded = this.element.nativeElement.classList.contains('ripple-rounded');
                if (isIcon || isFab || isRounded) {
                    this.elRippleContainerTemplateClone.style.borderRadius = '50%';
                }
                this.elRippleContainerTemplateClone.style.width = elementWidth + 'px';
                this.elRippleContainerTemplateClone.style.height = elementHeight + 'px';
                this.element.nativeElement.appendChild(this.elRippleContainerTemplateClone);
                const elRippleTemplateClone = this.elRippleTemplate.cloneNode(true);
                const isElementHorizontal = elementWidth > elementHeight;
                let finalWidth;
                let finalHeight;
                let finalTop;
                let finalLeft;
                if (isElementHorizontal) {
                    finalWidth = elementWidth * 3;
                    finalHeight = elementWidth * 3;
                }
                else {
                    finalWidth = elementHeight * 3;
                    finalHeight = elementHeight * 3;
                }
                finalTop = -(finalWidth / 2);
                finalLeft = -(finalWidth / 2);
                elRippleTemplateClone.style.width = finalWidth + 'px';
                elRippleTemplateClone.style.height = finalHeight + 'px';
                const mousePos = this.getMousePosition(e);
                const elementPos = UiElement.position(this.element.nativeElement);
                const pos = {
                    y: mousePos.y - elementPos.top,
                    x: mousePos.x - elementPos.left
                };
                if (isIcon || isFab || isRounded) {
                    finalTop = finalTop + (elementWidth / 2);
                    finalLeft = finalLeft + (elementWidth / 2);
                }
                else {
                    finalTop = finalTop + pos.y;
                    finalLeft = finalLeft + pos.x;
                }
                elRippleTemplateClone.style.top = finalTop + 'px';
                elRippleTemplateClone.style.left = finalLeft + 'px';
                this.elRippleContainerTemplateClone.insertBefore(elRippleTemplateClone, this.elRippleContainerTemplateClone.firstChild);
                this.elRippleContainerTemplateClone.classList.add('pressed');
                UiElement.animate(this.elRippleContainerTemplateClone, 'border-spacing', 0, 1, 800, null, (tick) => {
                    elRippleTemplateClone.style.transform = `scale(${tick})`;
                });
                ripples++;
            }
        }
    }
    onMouseup() {
        if (!this.isIE) {
            debounce(() => {
                this.eraseRipples(this);
            }, 800, true)();
        }
    }
    onMouseout() {
        if (!this.isIE) {
            debounce(() => {
                this.eraseRipples(this);
            }, 2000, true)();
        }
    }
    eraseRipples(thiss) {
        thiss.elRippleContainerTemplateClone.classList.remove('pressed');
        const elRipples = thiss.elRippleContainerTemplateClone.children;
        const len = elRipples.length;
        ripples = len;
        for (let i = 0; i < len; i++) {
            const elRipple = elRipples[i];
            if (elRipple) {
                const elementOpacity = elRipple.style.opacity || '1';
                if (elementOpacity === '1') {
                    UiElement.animate(elRipple, 'opacity', 1, 0, 800, () => {
                        try {
                            elRipple.parentNode.removeChild(elRipple);
                            ripples--;
                        }
                        catch (e) {
                        }
                        if (!ripples) {
                            try {
                                thiss.elRippleContainerTemplateClone.parentNode.removeChild(thiss.elRippleContainerTemplateClone);
                            }
                            catch (e) {
                            }
                        }
                    }, null);
                }
            }
        }
    }
    getMousePosition(e) {
        const pos = {
            y: undefined,
            x: undefined
        };
        if (e.originalEvent && e.originalEvent.touches !== undefined) {
            pos.y = e.originalEvent.touches[0].pageY;
            pos.x = e.originalEvent.touches[0].pageX;
        }
        else if (e.pageX) {
            pos.y = e.pageY;
            pos.x = e.pageX;
        }
        else if (e && e.touches !== undefined) {
            pos.y = e.touches[0].pageY;
            pos.x = e.touches[0].pageX;
        }
        return pos;
    }
};
UiRippleDirective.ctorParameters = () => [
    { type: ElementRef }
];
__decorate([
    Input('ripple-disable'),
    __metadata("design:type", Object)
], UiRippleDirective.prototype, "rippleDisable", void 0);
__decorate([
    HostListener('mousedown', ['$event']),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [Object]),
    __metadata("design:returntype", void 0)
], UiRippleDirective.prototype, "onMousedown", null);
__decorate([
    HostListener('mouseup'),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", void 0)
], UiRippleDirective.prototype, "onMouseup", null);
__decorate([
    HostListener('mouseout'),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", void 0)
], UiRippleDirective.prototype, "onMouseout", null);
UiRippleDirective = __decorate([
    Directive({
        selector: '[uiRipple]'
    }),
    __metadata("design:paramtypes", [ElementRef])
], UiRippleDirective);

let UiSmartListComponent = class UiSmartListComponent {
    constructor(differs, element) {
        this.differs = differs;
        this.element = element;
        this.modelChange = new EventEmitter();
        this.differ = differs.find([]).create();
    }
    ngOnInit() {
        if (!this.defaultItem) {
            this.defaultItem = {};
        }
        this.list = [Object.assign({}, this.defaultItem)];
        if (!this.model) {
            console.error('Você precisa declarar a model no seu componente');
        }
        this.objDiffer = {};
        this.list.forEach((elt, i) => {
            this.objDiffer[i] = this.differs.find(elt).create();
        });
        this.model.forEach((item) => {
            this.list.push(item);
        });
    }
    ngDoCheck() {
        let wasChanged = false;
        this.list.forEach((elt, i) => {
            let objDiffer = this.objDiffer[i];
            if (!objDiffer) {
                objDiffer = this.objDiffer[i] = this.differs.find(elt).create();
            }
            const objChanges = objDiffer.diff(elt);
            if (objChanges) {
                wasChanged = true;
                objChanges.forEachChangedItem((elt2) => {
                    if (!elt2.currentValue && typeof elt2.currentValue !== 'number' && typeof elt2.currentValue !== 'boolean' && !elt[this.autoDeleteException]) {
                        delete elt[elt2.key];
                    }
                });
                if (elt && this.model.indexOf(elt) < 0 && (Object.keys(elt).length > Object.keys(this.defaultItem).length)) {
                    this.model.push(elt);
                }
                if (elt && (Object.keys(elt).length === Object.keys(this.defaultItem).length) && equals(elt, this.defaultItem) && this.model.length && this.model.indexOf(elt) > -1 && !elt[this.autoDeleteException]) {
                    this.model.splice(this.model.indexOf(elt), 1);
                }
            }
        });
        if (wasChanged) {
            this.newItem();
        }
    }
    newItem() {
        let found = 0;
        this.list.forEach((item) => {
            if (item && (Object.keys(item).length <= Object.keys(this.defaultItem).length) && equals(item, this.defaultItem)) {
                found++;
                const element = this.list[this.list.indexOf(item)];
                this.list.splice(this.list.indexOf(item), 1);
                this.list.splice(this.list.length, 0, element);
            }
        });
        if (!found) {
            this.list.push(Object.assign({}, this.defaultItem));
        }
        else {
            setTimeout(() => {
                this.list.splice(this.list.length - 1, 1);
                this.newItem();
            });
        }
    }
    remove(i) {
        Object.keys(this.list[i]).forEach((key) => {
            if (!Object.keys(this.defaultItem).includes(key)) {
                delete this.list[i][key];
            }
            else {
                this.list[i][key] = this.defaultItem[key];
            }
        });
        this.ngDoCheck();
    }
    ngOnChanges(changes) {
        if (changes.model && changes.model.currentValue) {
            if (changes.model.currentValue.length) {
                changes.model.currentValue.forEach((item) => {
                    if (this.list && this.list.indexOf(item) === -1) {
                        this.list.push(item);
                    }
                });
            }
            else if (changes.model.currentValue && changes.model.previousValue) {
                this.list = [Object.assign({}, this.defaultItem)];
            }
        }
    }
};
UiSmartListComponent.ctorParameters = () => [
    { type: KeyValueDiffers },
    { type: ElementRef }
];
__decorate([
    Input(),
    __metadata("design:type", Object)
], UiSmartListComponent.prototype, "model", void 0);
__decorate([
    Input('default-item'),
    __metadata("design:type", Object)
], UiSmartListComponent.prototype, "defaultItem", void 0);
__decorate([
    Input('auto-delete-exception'),
    __metadata("design:type", Object)
], UiSmartListComponent.prototype, "autoDeleteException", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], UiSmartListComponent.prototype, "modelChange", void 0);
UiSmartListComponent = __decorate([
    Component({
        selector: 'ui-smart-list',
        template: "<ng-content>\r\n</ng-content>\r\n",
        styles: [":host{display:block}:host ::ng-deep ui-smart-list-item{display:block}"]
    }),
    __metadata("design:paramtypes", [KeyValueDiffers, ElementRef])
], UiSmartListComponent);
function equals(x, y) {
    return JSON.stringify(x) === JSON.stringify(y);
}

let UiSmartListItemComponent = class UiSmartListItemComponent {
    constructor(parent, element) {
        this.parent = parent;
        this.element = element;
    }
    ngAfterViewInit() {
        const self = this;
        const inputs = this.element.nativeElement.querySelectorAll('input');
        for (let i = 0; i < inputs.length; i++) {
            const el = inputs[i];
            el.addEventListener('focus', e => {
                this.onFocus(e, self);
            });
            el.addEventListener('blur', e => {
                this.onBlur(e, self);
            });
        }
    }
    onFocus(event, self) {
        const el = event.target;
        const elItem = new UiElementRef(el).closest('ui-smart-list-item');
        const newIndex = Array.prototype.indexOf.call(self.parent.element.nativeElement.children, elItem.nativeElement);
        self.parent.currentFocusedElementIndex = newIndex > -1 ? newIndex : self.parent.currentFocusedElementIndex;
    }
    onBlur(event, self) {
        setTimeout(() => {
            const target = new UiElementRef(event.target);
            if (!target.closest('body').nativeElement) {
                setTimeout(() => {
                    self.parent.element.nativeElement.children[self.parent.currentFocusedElementIndex].querySelector('input').focus();
                }, 100);
            }
        });
    }
};
UiSmartListItemComponent.ctorParameters = () => [
    { type: UiSmartListComponent, decorators: [{ type: Inject, args: [UiSmartListComponent,] }] },
    { type: ElementRef }
];
UiSmartListItemComponent = __decorate([
    Component({
        selector: 'ui-smart-list-item',
        template: "<ng-content>\r\n</ng-content>\r\n"
    }),
    __param(0, Inject(UiSmartListComponent)),
    __metadata("design:paramtypes", [UiSmartListComponent, ElementRef])
], UiSmartListItemComponent);

let timeout;
const bars = [];
const defaults = {
    duration: 5000,
    center: false,
    actionText: null
};
let UiSnackbar = class UiSnackbar {
    constructor() {
    }
    static show(bar) {
        bar = Object.assign({}, defaults, bar);
        bars.push(bar);
        if (bars.length === 1) {
            this.timerBar(bar);
        }
        this.barsChange.emit(bars);
    }
    static hide() {
        if (bars.length) {
            const snackbar = document.querySelector('ui-snackbar-container > ui-snackbar');
            if (!snackbar) {
                return;
            }
            snackbar.classList.add('leave');
            setTimeout(() => {
                clearTimeout(timeout);
                this.finishTimeout();
            }, 280);
        }
    }
    static timerBar(bar) {
        if (bars.length) {
            this.elevateFAB();
            if (bar.duration !== Infinity) {
                timeout = setTimeout(() => {
                    const firstSnackbar = document.querySelectorAll('ui-snackbar-container > ui-snackbar')[0];
                    if (firstSnackbar) {
                        document.querySelectorAll('ui-snackbar-container > ui-snackbar')[0].classList.add('leave');
                    }
                    setTimeout(() => this.finishTimeout(), 280);
                }, bar.duration);
            }
        }
    }
    ;
    static finishTimeout() {
        bars.shift();
        this.setTranslateFAB(0, false);
        if (bars.length) {
            this.timerBar(bars[0]);
        }
        this.barsChange.emit(bars);
    }
    static elevateFAB() {
        setTimeout(() => {
            let snackHeight;
            if (window.innerWidth <= 764) {
                snackHeight = document.querySelectorAll('ui-snackbar-container > ui-snackbar')[0].clientHeight;
            }
            else {
                snackHeight = 0;
            }
            this.setTranslateFAB(snackHeight, true);
        });
    }
    static setTranslateFAB(translate, addClass) {
        let fabs;
        if (window.innerWidth <= 764) {
            fabs = document.querySelectorAll('.ui-fab-container');
        }
        else {
            fabs = document.querySelectorAll('.ui-fab-container.scrolled');
        }
        [].forEach.call(document.querySelectorAll('.ui-fab-container'), (fab) => {
            fab.classList.remove('elevating-snack');
            fab.style.transform = '';
        });
        [].forEach.call(fabs, (fab) => {
            fab.classList[addClass ? 'add' : 'remove']('elevating-snack');
            if (translate) {
                fab.style.transform = `translateY(-${translate}px)`;
            }
            else {
                fab.style.transform = '';
            }
        });
    }
};
UiSnackbar.barsChange = new EventEmitter();
UiSnackbar = __decorate([
    Injectable(),
    __metadata("design:paramtypes", [])
], UiSnackbar);

let UiSnackbarComponent = class UiSnackbarComponent {
    constructor() {
    }
    hide() {
        UiSnackbar.hide();
    }
};
__decorate([
    Input(),
    __metadata("design:type", Object)
], UiSnackbarComponent.prototype, "bar", void 0);
UiSnackbarComponent = __decorate([
    Component({
        selector: 'ui-snackbar',
        template: "<div class=\"text\" [innerHtml]=\"bar.text\"></div>\r\n<div class=\"action\" *ngIf=\"bar.action && bar.actionText\">\r\n    <button class=\"ui-button accent flat\" (click)=\"bar.action(hide)\" uiRipple>\r\n        {{bar.actionText}}\r\n    </button>\r\n</div>\r\n",
        styles: [":host{display:flex;align-items:center;justify-content:space-between;background-color:#323232;padding-left:24px;box-shadow:0 0 4px 0 rgba(0,0,0,.14),0 3px 4px 0 rgba(0,0,0,.12),0 1px 5px 0 rgba(0,0,0,.2);margin:0 auto;width:100%;flex:0 0 auto;transition:transform 280ms cubic-bezier(0,0,.2,1)}:host:first-child{-webkit-animation:280ms cubic-bezier(0,0,.2,1) enter-snackbar;animation:280ms cubic-bezier(0,0,.2,1) enter-snackbar}:host+::ng-deep ui-snackbar:not(.nothing){position:absolute;z-index:-1;transform:translateY(150%);bottom:initial}:host.leave{transform:translateY(100%)}@media only screen and (min-width:376px) and (min-width:764px){:host{min-width:288px;margin:16px;border-radius:2px;max-width:568px;width:auto}:host:not(.center){position:absolute;bottom:0}:host:not(.center).leave{transform:translateY(calc(100% + 16px))}}:host .text{color:#fff;font-size:14px;padding:14px 0;min-height:48px;display:flex;align-items:center;margin-right:24px}:host button.ui-button{min-width:0;margin-right:8px}:host.center{position:absolute;bottom:0;margin:0 auto;border-bottom-left-radius:0;border-bottom-right-radius:0;transform:translateX(-50%);left:50%}:host.center:first-child{-webkit-animation:280ms cubic-bezier(0,0,.2,1) enter-snackbar-center;animation:280ms cubic-bezier(0,0,.2,1) enter-snackbar-center}:host.center.leave{transform:translateY(100%) translateX(-50%)}:host ::ng-deep [uiRipple].ui-button:not(.success):not(.warning):not(.error):not(:disabled).flat.accent .ui-ripple-wave{background-color:rgba(255,255,255,.1)}@media only screen and (min-width:376px) and (min-width:764px){::ng-deep .ui-button.elevating-snack{transform:translateY(0)!important}}@-webkit-keyframes enter-snackbar{0%{transform:translateY(100%)}100%{transform:translateY(0)}}@keyframes enter-snackbar{0%{transform:translateY(100%)}100%{transform:translateY(0)}}@-webkit-keyframes enter-snackbar-center{0%{transform:translateY(100%) translateX(-50%)}100%{transform:translateY(0) translateX(-50%)}}@keyframes enter-snackbar-center{0%{transform:translateY(100%) translateX(-50%)}100%{transform:translateY(0) translateX(-50%)}}"]
    }),
    __metadata("design:paramtypes", [])
], UiSnackbarComponent);

let UiSnackbarContainerComponent = class UiSnackbarContainerComponent {
    constructor() {
        UiSnackbar.barsChange.subscribe((value) => {
            this.bars = value;
        });
    }
    ngAfterViewInit() {
        UiElement.on(window, 'resize', () => {
            if (this.bars && this.bars.length) {
                UiSnackbar.elevateFAB();
            }
        });
    }
};
UiSnackbarContainerComponent = __decorate([
    Component({
        selector: 'ui-snackbar-container',
        template: "<ui-snackbar *ngFor=\"let bar of bars\" [bar]=\"bar\" [ngClass]=\"{'center': bar.center}\">\r\n    {{bar.text}}\r\n</ui-snackbar>\r\n",
        styles: [":host{position:fixed;height:0;left:0;right:0;bottom:0;display:flex;flex-direction:column;justify-content:flex-end;transition:left 280ms;z-index:6}@media only screen and (min-width:376px) and (min-width:764px){:host-context(.ui-nav-drawer-persistent){left:320px}}"]
    }),
    __metadata("design:paramtypes", [])
], UiSnackbarContainerComponent);

let UiSwitchComponent = class UiSwitchComponent {
    constructor(element) {
        this.element = element;
    }
    ngAfterViewInit() {
        const input = this.element.nativeElement.querySelectorAll('input')[0];
        input.classList.add('ui-switch');
        const switchShell = '<div class="switch-cover"><div class="track"></div><div class="thumb-container"><div class="thumb"></div></div></div>';
        input.insertAdjacentHTML('afterend', switchShell);
    }
};
UiSwitchComponent.ctorParameters = () => [
    { type: ElementRef }
];
UiSwitchComponent = __decorate([
    Component({
        selector: 'ui-switch',
        template: "<label>\r\n    <ng-content></ng-content>\r\n</label>\r\n",
        encapsulation: ViewEncapsulation.None,
        styles: ["ui-switch-container{display:flex;align-items:center;justify-content:space-between;margin-bottom:18px}ui-switch-container .info{-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;cursor:default;margin-right:10px}ui-switch-container .info .secondary{display:block}ui-switch-container.no-space{margin-bottom:0}ui-switch{position:relative;width:36px;height:24px;display:inline-block}ui-switch input{position:absolute;width:0;height:0;opacity:0}ui-switch .switch-cover{width:0;height:0;margin:auto}ui-switch .track{position:absolute;top:0;left:0;right:0;bottom:0;margin:auto;width:34px;height:14px;background-color:inherit;opacity:.5;border-radius:7px;transition:.3s ease-in-out}ui-switch .thumb-container{position:absolute;top:0;right:0;bottom:0;height:0;margin:auto 0;width:20px;background-color:inherit;transition:right .3s ease-in-out}ui-switch .thumb{position:absolute;top:0;bottom:0;margin:auto 0;width:20px;height:20px;border-radius:10px;transform:translateX(0);box-shadow:0 2px 4px rgba(0,0,0,.15),0 2px 6px rgba(0,0,0,.2);background-color:inherit;transition:.3s ease-in-out}ui-switch input:not(:checked)+.switch-cover .thumb-container{right:100%}ui-switch input:not(:checked)+.switch-cover .thumb{box-shadow:0 1px 2px rgba(0,0,0,.21),0 1px 3px rgba(0,0,0,.3);transform:translateX(100%)}ui-switch input:not(:checked):not(:disabled)+.switch-cover .thumb{background-color:#fff}ui-switch .thumb-container::before{content:\"\";position:absolute;top:0;left:50%;right:0;bottom:0;width:40px;height:40px;margin:auto -20px;border-radius:50%;background-color:inherit;opacity:.2;transform:scale(0);transition:.3s ease-in-out;pointer-events:none}ui-switch input:not(:checked)+.switch-cover .thumb-container::before{opacity:.1;margin:auto 0}ui-switch input:active+.switch-cover .thumb-container::before,ui-switch input:focus+.switch-cover .thumb-container::before{transform:scale(1)}fieldset:disabled ui-switch-container .info{color:rgba(0,0,0,.42)}fieldset:disabled ui-switch-container .info .secondary{color:rgba(0,0,0,.24)}"]
    }),
    __metadata("design:paramtypes", [ElementRef])
], UiSwitchComponent);

let UiToolbarComponent = class UiToolbarComponent {
    constructor(element) {
        this.element = element;
        UiElement.on(window, 'scroll resize', (e) => {
            if (this.element.nativeElement.classList.contains('elevate-on-scroll')) {
                const header = this.element.nativeElement.querySelectorAll('header')[0];
                const scroll = (window.scrollY || window.pageYOffset) * 3.6;
                if (this.element.nativeElement.classList.contains('size-2x')) {
                    if (e.type === 'scroll' && scroll < 97) {
                        this.element.nativeElement.classList.add('notransition');
                        header.style.paddingBottom = (102 - scroll) + 'px';
                        header.style.height = (162 - (scroll)) + 'px';
                        setTimeout(() => {
                            this.element.nativeElement.classList.remove('notransition');
                        }, 500);
                    }
                    else {
                        header.style.paddingBottom = '';
                        header.style.height = '';
                    }
                    if (scroll > 97) {
                        header.style.zIndex = 3;
                        this.element.nativeElement.classList.add('scrolled');
                    }
                    else {
                        header.style.zIndex = 2;
                        this.element.nativeElement.classList.remove('scrolled');
                    }
                }
                else {
                    if ((window.scrollY || window.pageYOffset) > 1) {
                        this.element.nativeElement.classList.add('scrolled');
                    }
                    else {
                        this.element.nativeElement.classList.remove('scrolled');
                    }
                }
            }
        });
        // let form: any = document.querySelectorAll('form');
        // if (form.length) {
        //     form = <HTMLElement>form[0];
        //     const input = form.querySelectorAll('input')[0];
        //     input.addEventListener('focus', () => {
        //         form.classList.add('open');
        //     });
        //     input.addEventListener('blur', () => {
        //         form.classList.remove('open');
        //     });
        // }
    }
    ngAfterViewInit() {
    }
};
UiToolbarComponent.ctorParameters = () => [
    { type: ElementRef }
];
UiToolbarComponent = __decorate([
    Component({
        selector: 'ui-toolbar',
        template: "<header>\r\n    <ng-content></ng-content>\r\n</header>\r\n<div class=\"ui-toolbar-space\"></div>\r\n",
        // styleUrls: ['./toolbar.component.scss'],
        encapsulation: ViewEncapsulation.None
    }),
    __metadata("design:paramtypes", [ElementRef])
], UiToolbarComponent);

let mainToolbar;
let defaultBreakpoint;
const change = new EventEmitter();
const sizes = [480, 600, 840, 960, 1280, 1440, 1600];
let UiToolbarService = class UiToolbarService {
    constructor() {
        this.change = change;
    }
    get() {
        return this.sharedValue;
    }
    set(sharedValue) {
        this.sharedValue = sharedValue;
        this.change.emit(sharedValue);
    }
    registerMainToolbar(element) {
        mainToolbar = element;
        defaultBreakpoint = [];
        sizes.forEach(size => {
            if (mainToolbar.classList.contains(`elevate-on-s${size}`)) {
                defaultBreakpoint.push(size);
            }
        });
    }
    getMainToolbar() {
        if (!mainToolbar) {
            console.error('Você não registrou um toolbar principal.');
        }
        else {
            return mainToolbar;
        }
    }
    activateExtendedToolbar(breakpoint) {
        if (!mainToolbar) {
            return;
        }
        if (breakpoint) {
            if (!sizes.includes(breakpoint)) {
                console.error(`O tamanho do "breakpoint" tem que ser um dos tamanhos suportados: ${sizes.join(', ')}`);
            }
            else {
                sizes.forEach(size => this.getMainToolbar().classList.remove(`elevate-on-s${size}`));
                this.getMainToolbar().classList.add(`elevate-on-s${breakpoint}`);
            }
        }
        this.getMainToolbar().classList.add('size-2x');
        const header = this.getMainToolbar().querySelectorAll('header')[0];
        header.style.transition = 'all 280ms';
        setTimeout(() => {
            header.style.transition = '';
            UiElement.trigger(window, 'scroll');
        }, 280);
    }
    deactivateExtendedToolbar() {
        if (!mainToolbar) {
            return;
        }
        sizes.forEach(size => this.getMainToolbar().classList.remove(`elevate-on-s${size}`));
        defaultBreakpoint.forEach(size => this.getMainToolbar().classList.add(`elevate-on-s${size}`));
        this.getMainToolbar().classList.remove('size-2x');
        this.getMainToolbar().classList.remove('scrolled');
        const header = this.getMainToolbar().querySelectorAll('header')[0];
        header.style.transition = 'all 280ms';
        header.style.height = '';
        header.style.paddingBottom = '';
        setTimeout(() => {
            header.style.transition = '';
        }, 280);
        UiElement.trigger(window, 'scroll');
    }
    activateTransparentToolbar(auxiliarClass) {
        this.getMainToolbar().classList.add('transparent');
        if (auxiliarClass) {
            this.getMainToolbar().classList.add(auxiliarClass);
        }
    }
    deactivateTransparentToolbar(auxiliarClass) {
        this.getMainToolbar().classList.remove('transparent');
        if (auxiliarClass) {
            this.getMainToolbar().classList.remove(auxiliarClass);
        }
    }
    activateElevatingToolbar(auxiliarClass) {
        this.getMainToolbar().classList.add('elevate-on-scroll');
        if (auxiliarClass) {
            this.getMainToolbar().classList.add(auxiliarClass);
        }
    }
    deactivateElevatingToolbar(auxiliarClass) {
        this.getMainToolbar().classList.remove('elevate-on-scroll');
        if (auxiliarClass) {
            this.getMainToolbar().classList.remove(auxiliarClass);
        }
    }
};
UiToolbarService = __decorate([
    Injectable(),
    __metadata("design:paramtypes", [])
], UiToolbarService);

function _window() {
    // return the global native browser window object
    return window;
}
let UiWindowRef = class UiWindowRef {
    static nativeWindow() {
        return _window();
    }
};
UiWindowRef = __decorate([
    Injectable()
], UiWindowRef);

function checkDate(value) {
    value = value.replace(/[^\w\s!\/]/gi, '');
    if (!/^[\d, \/]+$/.test(value)) {
        return false;
    }
    const splittedDate = value.split('/');
    if (splittedDate.length !== 3) {
        return false;
    }
    let dayIndex;
    let monthIndex;
    let yearIndex;
    let mask = 'd/M/yy';
    mask = mask.split('/');
    for (let i = 0; i < 3; i++) {
        if (mask[i].indexOf('d') > -1) {
            dayIndex = i;
        }
        if (mask[i].indexOf('M') > -1) {
            monthIndex = i;
        }
        if (mask[i].indexOf('y') > -1) {
            yearIndex = i;
        }
    }
    if (isNaN(dayIndex) || isNaN(monthIndex) || isNaN(yearIndex)) {
        return false;
    }
    const date = splittedDate[dayIndex];
    const month = splittedDate[monthIndex];
    const year = splittedDate[yearIndex];
    if (!date || !month || !year) {
        return false;
    }
    if (month < 1 || month > 12) {
        return false;
    }
    if (year.length < 4) {
        return false;
    }
    const dateCheck = new Date(year, month, 0).getDate();
    if (date > dateCheck || date < 1) {
        return false;
    }
    return new Date(year, month - 1, date);
}

var UiMaskDateDirective_1;
let UiMaskDateDirective = UiMaskDateDirective_1 = class UiMaskDateDirective {
    constructor(elementRef, datePipe) {
        this.elementRef = elementRef;
        this.datePipe = datePipe;
        this.maxlength = 10;
        this.regex = /^\d\d\/\d\d\/\d\d\d\d$/g;
        this.regexiso = /^(-?(?:[1-9][0-9]*)?[0-9]{4})-(1[0-2]|0[1-9])-(3[01]|0[1-9]|[12][0-9])T(2[0-3]|[01][0-9]):([0-5][0-9]):([0-5][0-9])(.[0-9]+)?(Z|(((\+|\-)[0-1][0-9]):([0-5][0-9])))?$/g;
        this.symbolsPositions = [2, 5];
        this.dateFormatsList = [
            {
                format: 'dd/MM/yyyy',
                maxlength: 10,
                regex: /^(\d{2}\/){2}\d{4}$/g,
                symbolsPositions: [2, 5]
            },
            {
                format: 'dd/MM',
                maxlength: 5,
                regex: /^(\d{2})\/(\d{2})$/g,
                symbolsPositions: [2]
            },
            {
                format: 'MM/yyyy',
                maxlength: 7,
                regex: /^(\d{2})\/(\d{4})$/g,
                symbolsPositions: [2]
            },
            {
                format: 'dd/MM/yy',
                maxlength: 8,
                regex: /^(\d{2}\/){2}\d{2}$/g,
                symbolsPositions: [2, 5]
            },
            {
                format: 'MM/yy',
                maxlength: 5,
                regex: /^(\d{2})\/(\d{2})$/g,
                symbolsPositions: [2]
            }
        ];
        this.day = '01'; // Dia padrão
        this.year = (new Date().getFullYear()).toString(); // Ano Padrão
        this.ngModelChange = new EventEmitter();
    }
    ngOnInit() {
        this.validaDateFormat();
    }
    ngAfterViewInit() {
        this.minDate = this.minDate && isDate(new Date(this.minDate)) ? new Date(this.minDate) : this.minDate;
        this.maxDate = this.maxDate && isDate(new Date(this.maxDate)) ? new Date(this.maxDate) : this.maxDate;
        this.ngModel = this.ngModel && isDate(new Date(this.ngModel)) ? new Date(this.ngModel) : this.ngModel;
        setTimeout(() => {
            this.loaded = true;
        });
    }
    writeValue(rawValue) {
        if (this.control && this.loaded && rawValue) {
            this.control.markAsDirty();
        }
        if (!this.input && rawValue) {
            this.elementRef.nativeElement.value = this.format(this.datePipe.transform(this.ngModel, this.dateFormat));
        }
        this.input = false;
    }
    renderViaInput(rawValue) {
        if (rawValue) {
            this.control.markAsDirty();
        }
        this.ngModel = checkDate(this.getCorrectValue(this.format(rawValue))) || this.format(rawValue);
        this.ngModelChange.emit(this.ngModel);
        this.elementRef.nativeElement.value = this.format(this.elementRef.nativeElement.value);
    }
    registerOnChange(fn) {
        this.onChange = fn;
    }
    registerOnTouched(fn) {
        this.onTouched = fn;
    }
    format(date) {
        if (!date) {
            return '';
        }
        date = date.toString().replace(/[^0-9]+/g, '');
        if (date.length > this.symbolsPositions[0]) {
            date = date.substring(0, this.symbolsPositions[0]) + '/' + date.substring(this.symbolsPositions[0]);
        }
        if (date.length > this.symbolsPositions[1]) {
            date = date.substring(0, this.symbolsPositions[1]) + '/' + date.substring(this.symbolsPositions[1], this.maxlength - 1);
        }
        return date.substring(0, this.maxlength);
    }
    /**
     * Verifica se o formato da data é válido
     */
    validaDateFormat() {
        if (!this.dateFormat) { // Caso não seja passado nenhum parametro, coloca o default
            this.dateFormat = 'dd/MM/yyyy';
            return;
        }
        let valid = false;
        this.dateFormatsList.forEach(item => {
            if (item.format === this.dateFormat) {
                this.maxlength = item.maxlength;
                this.regex = item.regex;
                this.symbolsPositions = item.symbolsPositions;
                valid = true;
            }
        });
        if (!valid) {
            console.error('Formato de data não suportado, tente algum destes: ["dd/MM/yyyy", "dd/MM", "MM/yyyy", "dd/MM/yy", "MM/yy"]');
        }
    }
    ngOnChanges(changes) {
        if (changes.ngModel && !changes.ngModel.firstChange && (changes.ngModel.currentValue === null || changes.ngModel.currentValue === undefined)) {
            this.elementRef.nativeElement.value = '';
        }
        if (changes.minDate && !changes.minDate.firstChange) {
            this.minDate = changes.minDate.currentValue && isDate(new Date(this.minDate)) ? new Date(this.minDate) : this.minDate;
            this.control.updateValueAndValidity(this.control);
        }
        if (changes.maxDate && !changes.maxDate.firstChange) {
            this.maxDate = changes.maxDate.currentValue && isDate(new Date(this.maxDate)) ? new Date(this.maxDate) : this.maxDate;
            this.control.updateValueAndValidity(this.control);
        }
        if ((changes.minDate && !changes.minDate.firstChange) || (changes.maxDate && !changes.maxDate.firstChange)) {
            this.control.updateValueAndValidity(this.control);
        }
    }
    /**
     * Retorna o valor formatado corretamente p/ uma data válida
     * @param value { string } valor da view
     */
    getCorrectValue(value) {
        const test = this.regex.test(value);
        if (this.dateFormat === 'MM/yyyy' && test) {
            return `${this.day}/${value}`;
        }
        if (this.dateFormat === 'dd/MM' && test) {
            return `${value}/${this.year}`;
        }
        if (this.dateFormat === 'dd/MM/yy' && test) {
            const valueSplitted = value.split('/');
            return `${valueSplitted[0]}/${valueSplitted[1]}/20${valueSplitted[2]}`;
        }
        if (this.dateFormat === 'MM/yy' && test) {
            const valueSplitted = value.split('/');
            return `${this.day}/${valueSplitted[0]}/20${valueSplitted[1]}`;
        }
        return value;
    }
    validate(control) {
        this.control = control;
        const value = this.ngModel && this.regexiso.test(this.ngModel) ? new Date(this.ngModel) : this.ngModel;
        const dateControl = isDate(control.value) ? control.value : new Date(control.value);
        if (value && (!isDate(value) || !checkDate(value.toLocaleDateString('pt-BR')))) {
            return { parse: true };
        }
        if (value && (isDate(value) || checkDate(value.toLocaleDateString('pt-BR')))) {
            dateControl.setHours(0, 0, 0, 0);
            if (this.minDate && isDate(this.minDate)) {
                this.minDate.setHours(0, 0, 0, 0);
                if (dateControl.getTime() < this.minDate.getTime()) {
                    return { minDate: true };
                }
            }
            if (this.maxDate && isDate(this.maxDate)) {
                this.maxDate.setHours(0, 0, 0, 0);
                if (dateControl.getTime() > this.maxDate.getTime()) {
                    return { maxDate: true };
                }
            }
        }
        return null;
    }
    setDisabledState(isDisabled) {
        const method = isDisabled ? 'setAttribute' : 'removeAttribute';
        this.elementRef.nativeElement[method]('disabled', 'disabled');
    }
    onKeydown() {
        this.beforeSelIndex = UiElement.caretPosition.get(this.elementRef.nativeElement);
    }
    onInput($event) {
        const afterSelIndex = UiElement.caretPosition.get(this.elementRef.nativeElement);
        const rawValue = this.elementRef.nativeElement.value;
        this.input = true;
        this.renderViaInput(rawValue);
        UiElement.caretPosition.set(this.elementRef.nativeElement, this.beforeSelIndex, afterSelIndex, this.symbolsPositions);
    }
};
UiMaskDateDirective.ctorParameters = () => [
    { type: ElementRef },
    { type: DatePipe }
];
__decorate([
    Input(),
    __metadata("design:type", Date)
], UiMaskDateDirective.prototype, "minDate", void 0);
__decorate([
    Input(),
    __metadata("design:type", Date)
], UiMaskDateDirective.prototype, "maxDate", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], UiMaskDateDirective.prototype, "ngModel", void 0);
__decorate([
    Input(),
    __metadata("design:type", String)
], UiMaskDateDirective.prototype, "dateFormat", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], UiMaskDateDirective.prototype, "day", void 0);
__decorate([
    Input(),
    __metadata("design:type", String)
], UiMaskDateDirective.prototype, "year", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], UiMaskDateDirective.prototype, "ngModelChange", void 0);
__decorate([
    HostListener('keydown'),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", void 0)
], UiMaskDateDirective.prototype, "onKeydown", null);
__decorate([
    HostListener('input', ['$event']),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [Object]),
    __metadata("design:returntype", void 0)
], UiMaskDateDirective.prototype, "onInput", null);
UiMaskDateDirective = UiMaskDateDirective_1 = __decorate([
    Directive({
        selector: '[uiMaskDate][ngModel]',
        providers: [{
                provide: NG_VALUE_ACCESSOR,
                useExisting: forwardRef(() => UiMaskDateDirective_1),
                multi: true
            }, {
                provide: NG_VALIDATORS,
                useExisting: forwardRef(() => UiMaskDateDirective_1),
                multi: true
            }, DatePipe]
    }),
    __metadata("design:paramtypes", [ElementRef, DatePipe])
], UiMaskDateDirective);

let UiTimeAgoPipe = class UiTimeAgoPipe {
    constructor(ref) {
        this.isDestroyed = false;
        this.async = new AsyncPipe(ref);
    }
    transform(obj, textBefore = '', textAfter = '', isMinified, isHence) {
        this.textBefore = textBefore;
        this.textAfter = textAfter;
        this.isMinified = isMinified;
        this.isHence = isHence;
        if (obj == null) {
            return '';
        }
        if (!(obj instanceof Date)) {
            try {
                obj = new Date(obj);
            }
            catch (e) {
                throw new Error('UiTimeAgo só funciona com datas');
            }
        }
        this.value = obj;
        if (!this.timer) {
            this.timer = this.getObservable();
        }
        return this.async.transform(this.timer);
    }
    now() {
        return new Date();
    }
    ngOnDestroy() {
        this.isDestroyed = true;
    }
    getObservable() {
        return of(1).pipe(repeatWhen(notifications => {
            return notifications.pipe(flatMap((x, i) => {
                const sleep = i < 60 ? 1000 : 30000;
                return timer(sleep);
            }));
        }), takeWhile(_ => !this.isDestroyed), map((x, i) => this.elapsed()));
    }
    elapsed() {
        const now = this.now().getTime();
        let delta = (now - this.value.getTime()) / 1000;
        if (this.isHence) {
            delta = delta * -1;
        }
        if (delta < 60) {
            const realDelta = Math.floor(delta);
            let timeAgo;
            if (this.isMinified) {
                timeAgo = `${realDelta}s`;
            }
            else {
                timeAgo = `${realDelta} segundo${(realDelta !== 1) ? 's' : ''}`;
            }
            return `${this.textBefore}${timeAgo}${this.textAfter}`;
        }
        else if (delta < 3600) {
            const realDelta = Math.floor(delta / 60);
            let timeAgo;
            if (this.isMinified) {
                timeAgo = `${realDelta}m`;
            }
            else {
                timeAgo = `${realDelta} minuto${(realDelta !== 1) ? 's' : ''}`;
            }
            return `${this.textBefore}${timeAgo}${this.textAfter}`;
        }
        else if (delta < 86400) {
            const realDelta = Math.floor(delta / 3600);
            let timeAgo;
            if (this.isMinified) {
                timeAgo = `${realDelta}h`;
            }
            else {
                timeAgo = `${realDelta} hora${(realDelta !== 1) ? 's' : ''}`;
            }
            return `${this.textBefore}${timeAgo}${this.textAfter}`;
        }
        else {
            const realDelta = Math.floor(delta / 86400);
            let timeAgo;
            if (this.isMinified) {
                timeAgo = `${realDelta}d`;
            }
            else {
                timeAgo = `${realDelta} dia${(realDelta !== 1) ? 's' : ''}`;
            }
            return `${this.textBefore}${timeAgo}${this.textAfter}`;
        }
    }
};
UiTimeAgoPipe.ctorParameters = () => [
    { type: ChangeDetectorRef }
];
UiTimeAgoPipe = __decorate([
    Pipe({
        name: 'uiTimeAgo',
        pure: false
    }),
    __metadata("design:paramtypes", [ChangeDetectorRef])
], UiTimeAgoPipe);

let UiListItemDirective = class UiListItemDirective {
    constructor(element) {
        this.element = element;
    }
    ngAfterViewInit() {
        setTimeout(() => {
            const itemActive = this.uiListItem.querySelectorAll('.ui-list-item.active')[0];
            if (itemActive) {
                this.element.nativeElement.classList.toggle('expanded');
                this.uiListItem.classList.toggle('expanded');
                toggleExpand(this.uiListItem, this.element.nativeElement);
            }
        });
    }
    onClick() {
        this.element.nativeElement.classList.toggle('expanded');
        this.uiListItem.classList.toggle('expanded');
        toggleExpand(this.uiListItem, this.element.nativeElement);
    }
};
UiListItemDirective.ctorParameters = () => [
    { type: ElementRef }
];
__decorate([
    Input(),
    __metadata("design:type", Object)
], UiListItemDirective.prototype, "uiListItem", void 0);
__decorate([
    HostListener('click'),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", void 0)
], UiListItemDirective.prototype, "onClick", null);
UiListItemDirective = __decorate([
    Directive({ selector: '[uiListItem]' }),
    __metadata("design:paramtypes", [ElementRef])
], UiListItemDirective);
function toggleExpand(elementList, elementTrigger) {
    if (!elementList.style.height || elementList.style.height === '0px') {
        const height = getHeight(elementList);
        elementList.style.height = (elementList.style.maxHeight ? (height > elementList.style.maxHeight.replace('px', '') ? elementList.style.maxHeight : height + 'px') : height + 'px');
        let listItemGroup = UiElement.closest(elementList, '.ui-list-item-group');
        while (listItemGroup) {
            listItemGroup.style.height = getHeight(listItemGroup) + height + 'px';
            if (listItemGroup) {
                listItemGroup = UiElement.closest(listItemGroup, '.ui-list-item-group');
            }
        }
    }
    else {
        const backupHeight = parseInt(elementList.style.height.replace('px', ''), 10);
        elementList.style.height = '';
        let listItemGroup = UiElement.closest(elementList, '.ui-list-item-group');
        while (listItemGroup) {
            listItemGroup.style.height = getHeight(listItemGroup) - backupHeight + 'px';
            if (listItemGroup) {
                listItemGroup = UiElement.closest(listItemGroup, '.ui-list-item-group');
            }
        }
    }
    setTimeout(() => {
        const list = UiElement.closest(elementList, '.ui-list');
        if (list) {
            let overflow = list.parentNode;
            if (UiElement.is(overflow, 'ui-list')) {
                overflow = overflow.parentNode;
            }
            UiElement.animate(elementList, 'border-spacing', overflow.scrollTop, elementTrigger.offsetTop, 500, null, (tick) => {
                overflow.scrollTop = tick;
            });
        }
    }, 500);
}
function getHeight(element) {
    return Array.prototype.reduce.call(element.childNodes, (p, c) => p + (c.offsetHeight || 0), 0);
}

let UiCpfPipe = class UiCpfPipe {
    transform(value, mask) {
        if (!value) {
            return '';
        }
        value = value.toString().replace(/[^0-9]+/g, '');
        if (!mask) {
            value = value.padStart(11, '0');
        }
        if (value.length > 3) {
            value = value.substring(0, 3) + '.' + value.substring(3);
        }
        if (value.length > 7) {
            value = value.substring(0, 7) + '.' + value.substring(7);
        }
        if (value.length > 11) {
            value = value.substring(0, 11) + '-' + value.substring(11);
        }
        if (value.length > 14) {
            value = value.substring(0, 14);
        }
        return value;
    }
};
UiCpfPipe = __decorate([
    Pipe({
        name: 'uiCpf'
    })
], UiCpfPipe);

var UiMaskCpfDirective_1;
let UiMaskCpfDirective = UiMaskCpfDirective_1 = class UiMaskCpfDirective {
    constructor(elementRef, cpfPipe) {
        this.elementRef = elementRef;
        this.cpfPipe = cpfPipe;
        this.symbolsPositions = [3, 7, 11, 14];
        this.padOnPaste = true;
        this.ngModelChange = new EventEmitter();
    }
    ngOnChanges(changes) {
        if (!changes.ngModel.firstChange && (changes.ngModel.currentValue === null || changes.ngModel.currentValue === undefined)) {
            this.elementRef.nativeElement.value = '';
        }
    }
    ngAfterViewInit() {
        setTimeout(() => {
            this.loaded = true;
        });
    }
    writeValue(rawValue) {
        if (this.control && this.loaded && rawValue) {
            this.control.markAsDirty();
        }
        if (!this.input) {
            this.ngModel = this.ngModel ? this.ngModel.toString().padStart(11, '0') : '';
            this.elementRef.nativeElement.value = this.cpfPipe.transform(this.ngModel, true);
        }
        this.input = false;
    }
    renderViaInput(rawValue) {
        if (rawValue) {
            this.control.markAsDirty();
        }
        this.ngModel = this.format(rawValue);
        this.ngModelChange.emit(this.ngModel);
        this.elementRef.nativeElement.value = this.cpfPipe.transform(this.elementRef.nativeElement.value, true);
    }
    registerOnChange(fn) {
        this.onChange = fn;
    }
    registerOnTouched(fn) {
        this.onTouched = fn;
    }
    format(value) {
        value = value.toString().replace(/[^0-9]+/g, '');
        return value.substring(0, 11);
    }
    validate(control) {
        this.control = control;
        if (this.input) {
            if (control.value && this.format(control.value).length < 11) {
                return { parse: true };
            }
        }
        if (this.uiMaskCpf === true && control.value && !this.cpfIsValid(control.value)) {
            return { parse: true };
        }
        this.input = false;
        return null;
    }
    setDisabledState(isDisabled) {
        const method = isDisabled ? 'setAttribute' : 'removeAttribute';
        this.elementRef.nativeElement[method]('disabled', 'disabled');
    }
    cpfIsValid(cpf) {
        if (cpf && cpf.length === 11) {
            let sum;
            let rest;
            sum = 0;
            if (cpf === '00000000000') {
                return false;
            }
            for (let i = 1; i <= 9; i++) {
                sum = sum + parseInt(cpf.substring(i - 1, i), 10) * (11 - i);
            }
            rest = (sum * 10) % 11;
            if ((rest === 10) || (rest === 11)) {
                rest = 0;
            }
            if (rest !== parseInt(cpf.substring(9, 10), 10)) {
                return false;
            }
            sum = 0;
            for (let i = 1; i <= 10; i++) {
                sum = sum + parseInt(cpf.substring(i - 1, i), 20) * (12 - i);
            }
            rest = (sum * 10) % 11;
            if ((rest === 10) || (rest === 11)) {
                rest = 0;
            }
            return rest === parseInt(cpf.substring(10, 11), 10);
        }
    }
    onKeydown() {
        this.beforeSelIndex = UiElement.caretPosition.get(this.elementRef.nativeElement);
    }
    onInput($event) {
        const afterSelIndex = UiElement.caretPosition.get(this.elementRef.nativeElement);
        const rawValue = this.elementRef.nativeElement.value;
        this.input = this.format(rawValue) !== this.ngModel;
        this.renderViaInput(rawValue);
        UiElement.caretPosition.set(this.elementRef.nativeElement, this.beforeSelIndex, afterSelIndex, this.symbolsPositions);
    }
    padLeft(event) {
        if (this.padOnPaste) {
            event.preventDefault();
            let data;
            if (window['clipboardData']) {
                data = window['clipboardData'];
            }
            else if (event.clipboardData && event.clipboardData.getData) {
                data = event.clipboardData;
            }
            const text = data.getData('text').toString().replace(/[^0-9]+/g, '');
            this.renderViaInput(text.padStart(11, '0'));
        }
    }
};
UiMaskCpfDirective.ctorParameters = () => [
    { type: ElementRef },
    { type: UiCpfPipe }
];
__decorate([
    Input(),
    __metadata("design:type", Object)
], UiMaskCpfDirective.prototype, "ngModel", void 0);
__decorate([
    Input(),
    __metadata("design:type", Boolean)
], UiMaskCpfDirective.prototype, "padOnPaste", void 0);
__decorate([
    Input('uiMaskCpf'),
    __metadata("design:type", Object)
], UiMaskCpfDirective.prototype, "uiMaskCpf", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], UiMaskCpfDirective.prototype, "ngModelChange", void 0);
__decorate([
    HostListener('keydown'),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", void 0)
], UiMaskCpfDirective.prototype, "onKeydown", null);
__decorate([
    HostListener('input', ['$event']),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [Object]),
    __metadata("design:returntype", void 0)
], UiMaskCpfDirective.prototype, "onInput", null);
__decorate([
    HostListener('paste', ['$event']),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [Object]),
    __metadata("design:returntype", void 0)
], UiMaskCpfDirective.prototype, "padLeft", null);
UiMaskCpfDirective = UiMaskCpfDirective_1 = __decorate([
    Directive({
        selector: '[uiMaskCpf][ngModel]',
        providers: [{
                provide: NG_VALUE_ACCESSOR,
                useExisting: forwardRef(() => UiMaskCpfDirective_1),
                multi: true
            }, {
                provide: NG_VALIDATORS,
                useExisting: forwardRef(() => UiMaskCpfDirective_1),
                multi: true
            }, UiCpfPipe]
    }),
    __metadata("design:paramtypes", [ElementRef, UiCpfPipe])
], UiMaskCpfDirective);

let UiCnpjPipe = class UiCnpjPipe {
    transform(value, mask) {
        if (!value) {
            return '';
        }
        value = value.toString().replace(/[^0-9]+/g, '');
        if (!mask) {
            value = value.padStart(14, '0');
        }
        value = value.toString().replace(/[^0-9]+/g, '');
        if (value.length > 2) {
            value = value.substring(0, 2) + '.' + value.substring(2);
        }
        if (value.length > 6) {
            value = value.substring(0, 6) + '.' + value.substring(6);
        }
        if (value.length > 10) {
            value = value.substring(0, 10) + '/' + value.substring(10);
        }
        if (value.length > 15) {
            value = value.substring(0, 15) + '-' + value.substring(15);
        }
        if (value.length > 18) {
            value = value.substring(0, 18);
        }
        return value;
    }
};
UiCnpjPipe = __decorate([
    Pipe({
        name: 'uiCnpj'
    })
], UiCnpjPipe);

var UiMaskCnpjDirective_1;
let UiMaskCnpjDirective = UiMaskCnpjDirective_1 = class UiMaskCnpjDirective {
    constructor(elementRef, cnpjPipe) {
        this.elementRef = elementRef;
        this.cnpjPipe = cnpjPipe;
        this.symbolsPositions = [2, 6, 10, 15, 18];
        this.padOnPaste = true;
        this.ngModelChange = new EventEmitter();
    }
    ngOnChanges(changes) {
        if (!changes.ngModel.firstChange && (changes.ngModel.currentValue === null || changes.ngModel.currentValue === undefined)) {
            this.elementRef.nativeElement.value = '';
        }
    }
    ngAfterViewInit() {
        setTimeout(() => {
            this.loaded = true;
        });
    }
    writeValue(rawValue) {
        if (this.control && this.loaded && rawValue) {
            this.control.markAsDirty();
        }
        if (!this.input) {
            this.ngModel = this.ngModel ? this.ngModel.toString().padStart(14, '0') : '';
            this.elementRef.nativeElement.value = this.cnpjPipe.transform(this.ngModel, true);
        }
        this.input = false;
    }
    renderViaInput(rawValue) {
        if (rawValue) {
            this.control.markAsDirty();
        }
        this.ngModel = this.format(rawValue);
        this.ngModelChange.emit(this.ngModel);
        this.elementRef.nativeElement.value = this.cnpjPipe.transform(this.elementRef.nativeElement.value, true);
    }
    registerOnChange(fn) {
        this.onChange = fn;
    }
    registerOnTouched(fn) {
        this.onTouched = fn;
    }
    format(value) {
        value = value.toString().replace(/[^0-9]+/g, '');
        return value.substring(0, 14);
    }
    validate(control) {
        this.control = control;
        if (this.input) {
            if (control.value && this.format(control.value).length < 14) {
                return { parse: true };
            }
        }
        if (this.uiMaskCnpj === true && control.value && !this.cnpjIsValid(control.value)) {
            return { parse: true };
        }
        this.input = false;
        return null;
    }
    setDisabledState(isDisabled) {
        const method = isDisabled ? 'setAttribute' : 'removeAttribute';
        this.elementRef.nativeElement[method]('disabled', 'disabled');
    }
    cnpjIsValid(cnpj) {
        if (!(+cnpj) || cnpj.length !== 14) {
            return false;
        }
        let size = cnpj.length - 2;
        let numbers = cnpj.substring(0, size);
        const digits = cnpj.substring(size);
        let sum = 0;
        let pos = size - 7;
        for (let i = size; i >= 1; i--) {
            sum += numbers.charAt(size - i) * pos--;
            if (pos < 2) {
                pos = 9;
            }
        }
        let result = sum % 11 < 2 ? 0 : 11 - sum % 11;
        if (result.toString() !== digits.charAt(0)) {
            return false;
        }
        size = size + 1;
        numbers = cnpj.substring(0, size);
        sum = 0;
        pos = size - 7;
        for (let i = size; i >= 1; i--) {
            sum += numbers.charAt(size - i) * pos--;
            if (pos < 2) {
                pos = 9;
            }
        }
        result = sum % 11 < 2 ? 0 : 11 - sum % 11;
        return result.toString() === digits.charAt(1);
    }
    onKeydown() {
        this.beforeSelIndex = UiElement.caretPosition.get(this.elementRef.nativeElement);
    }
    onInput($event) {
        const afterSelIndex = UiElement.caretPosition.get(this.elementRef.nativeElement);
        const rawValue = this.elementRef.nativeElement.value;
        this.input = this.format(rawValue) !== this.ngModel;
        this.renderViaInput(rawValue);
        UiElement.caretPosition.set(this.elementRef.nativeElement, this.beforeSelIndex, afterSelIndex, this.symbolsPositions);
    }
    padLeft(event) {
        if (this.padOnPaste) {
            event.preventDefault();
            let data;
            if (window['clipboardData']) {
                data = window['clipboardData'];
            }
            else if (event.clipboardData && event.clipboardData.getData) {
                data = event.clipboardData;
            }
            const text = data.getData('text').toString().replace(/[^0-9]+/g, '');
            this.renderViaInput(text.padStart(14, '0'));
        }
    }
};
UiMaskCnpjDirective.ctorParameters = () => [
    { type: ElementRef },
    { type: UiCnpjPipe }
];
__decorate([
    Input(),
    __metadata("design:type", Object)
], UiMaskCnpjDirective.prototype, "ngModel", void 0);
__decorate([
    Input(),
    __metadata("design:type", Boolean)
], UiMaskCnpjDirective.prototype, "padOnPaste", void 0);
__decorate([
    Input('uiMaskCnpj'),
    __metadata("design:type", Object)
], UiMaskCnpjDirective.prototype, "uiMaskCnpj", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], UiMaskCnpjDirective.prototype, "ngModelChange", void 0);
__decorate([
    HostListener('keydown'),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", void 0)
], UiMaskCnpjDirective.prototype, "onKeydown", null);
__decorate([
    HostListener('input', ['$event']),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [Object]),
    __metadata("design:returntype", void 0)
], UiMaskCnpjDirective.prototype, "onInput", null);
__decorate([
    HostListener('paste', ['$event']),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [Object]),
    __metadata("design:returntype", void 0)
], UiMaskCnpjDirective.prototype, "padLeft", null);
UiMaskCnpjDirective = UiMaskCnpjDirective_1 = __decorate([
    Directive({
        selector: '[uiMaskCnpj][ngModel]',
        providers: [{
                provide: NG_VALUE_ACCESSOR,
                useExisting: forwardRef(() => UiMaskCnpjDirective_1),
                multi: true
            }, {
                provide: NG_VALIDATORS,
                useExisting: forwardRef(() => UiMaskCnpjDirective_1),
                multi: true
            }, UiCnpjPipe]
    }),
    __metadata("design:paramtypes", [ElementRef, UiCnpjPipe])
], UiMaskCnpjDirective);

let UiCepPipe = class UiCepPipe {
    transform(value, args) {
        if (!value) {
            return '';
        }
        value = value.toString().replace(/[^0-9]+/g, '');
        if (value.length > 5) {
            value = value.substring(0, 5) + '-' + value.substring(5);
        }
        if (value.length > 9) {
            value = value.substring(0, 9);
        }
        return value;
    }
};
UiCepPipe = __decorate([
    Pipe({
        name: 'uiCep'
    })
], UiCepPipe);

var UiMaskCepDirective_1;
let UiMaskCepDirective = UiMaskCepDirective_1 = class UiMaskCepDirective {
    constructor(elementRef, cepPipe) {
        this.elementRef = elementRef;
        this.cepPipe = cepPipe;
        this.symbolsPositions = [5, 9];
        this.ngModelChange = new EventEmitter();
    }
    ngOnChanges(changes) {
        if (!changes.ngModel.firstChange && (changes.ngModel.currentValue === null || changes.ngModel.currentValue === undefined)) {
            this.elementRef.nativeElement.value = '';
        }
    }
    ngAfterViewInit() {
        setTimeout(() => {
            this.loaded = true;
        });
    }
    writeValue(rawValue) {
        if (this.control && this.loaded && rawValue) {
            this.control.markAsDirty();
        }
        if (!this.input) {
            this.elementRef.nativeElement.value = this.cepPipe.transform(this.ngModel);
        }
        this.input = false;
    }
    renderViaInput(rawValue) {
        if (rawValue) {
            this.control.markAsDirty();
        }
        this.ngModel = this.format(rawValue);
        this.ngModelChange.emit(this.ngModel);
        this.elementRef.nativeElement.value = this.cepPipe.transform(this.elementRef.nativeElement.value);
    }
    registerOnChange(fn) {
        this.onChange = fn;
    }
    registerOnTouched(fn) {
        this.onTouched = fn;
    }
    format(value) {
        value = value.toString().replace(/[^0-9]+/g, '');
        return value.substring(0, 8);
    }
    validate(control) {
        this.control = control;
        if (control.value && this.format(control.value).length < 8) {
            return { parse: true };
        }
        return null;
    }
    setDisabledState(isDisabled) {
        const method = isDisabled ? 'setAttribute' : 'removeAttribute';
        this.elementRef.nativeElement[method]('disabled', 'disabled');
    }
    onKeydown() {
        this.beforeSelIndex = UiElement.caretPosition.get(this.elementRef.nativeElement);
    }
    onInput($event) {
        const afterSelIndex = UiElement.caretPosition.get(this.elementRef.nativeElement);
        const rawValue = this.elementRef.nativeElement.value;
        this.input = true;
        this.renderViaInput(rawValue);
        UiElement.caretPosition.set(this.elementRef.nativeElement, this.beforeSelIndex, afterSelIndex, this.symbolsPositions);
    }
};
UiMaskCepDirective.ctorParameters = () => [
    { type: ElementRef },
    { type: UiCepPipe }
];
__decorate([
    Input(),
    __metadata("design:type", Object)
], UiMaskCepDirective.prototype, "ngModel", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], UiMaskCepDirective.prototype, "ngModelChange", void 0);
__decorate([
    HostListener('keydown'),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", void 0)
], UiMaskCepDirective.prototype, "onKeydown", null);
__decorate([
    HostListener('input', ['$event']),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [Object]),
    __metadata("design:returntype", void 0)
], UiMaskCepDirective.prototype, "onInput", null);
UiMaskCepDirective = UiMaskCepDirective_1 = __decorate([
    Directive({
        selector: '[uiMaskCep][ngModel]',
        providers: [{
                provide: NG_VALUE_ACCESSOR,
                useExisting: forwardRef(() => UiMaskCepDirective_1),
                multi: true
            }, {
                provide: NG_VALIDATORS,
                useExisting: forwardRef(() => UiMaskCepDirective_1),
                multi: true
            }, UiCepPipe]
    }),
    __metadata("design:paramtypes", [ElementRef, UiCepPipe])
], UiMaskCepDirective);

let UiCepNovoPipe = class UiCepNovoPipe {
    transform(value, args) {
        if (!value) {
            return '';
        }
        value = value.toString().replace(/[^a-zA-Z0-9]+/g, '');
        if (value.length > 5) {
            value = value.substring(0, 5) + '-' + value.substring(5);
        }
        if (value.length > 9) {
            value = value.substring(0, 9);
        }
        return value;
    }
};
UiCepNovoPipe = __decorate([
    Pipe({
        name: 'uiCepNovo'
    })
], UiCepNovoPipe);

var UiMaskCepNovoDirective_1;
let UiMaskCepNovoDirective = UiMaskCepNovoDirective_1 = class UiMaskCepNovoDirective {
    constructor(elementRef, cepPipe) {
        this.elementRef = elementRef;
        this.cepPipe = cepPipe;
        this.symbolsPositions = [5, 9];
        this.ngModelChange = new EventEmitter();
    }
    ngOnChanges(changes) {
        if (!changes.ngModel.firstChange && (changes.ngModel.currentValue === null || changes.ngModel.currentValue === undefined)) {
            this.elementRef.nativeElement.value = '';
        }
    }
    ngAfterViewInit() {
        setTimeout(() => {
            this.loaded = true;
        });
    }
    writeValue(rawValue) {
        if (this.control && this.loaded && rawValue) {
            this.control.markAsDirty();
        }
        if (!this.input) {
            this.elementRef.nativeElement.value = this.cepPipe.transform(this.ngModel);
        }
        this.input = false;
    }
    renderViaInput(rawValue) {
        if (rawValue) {
            this.control.markAsDirty();
        }
        this.ngModel = this.format(rawValue);
        this.ngModelChange.emit(this.ngModel);
        this.elementRef.nativeElement.value = this.cepPipe.transform(this.elementRef.nativeElement.value);
    }
    registerOnChange(fn) {
        this.onChange = fn;
    }
    registerOnTouched(fn) {
        this.onTouched = fn;
    }
    format(value) {
        value = value.toString().replace(/[^a-zA-Z0-9]+/g, '');
        return value.substring(0, 8);
    }
    validate(control) {
        this.control = control;
        if (control.value && this.format(control.value).length < 8) {
            return { parse: true };
        }
        return null;
    }
    setDisabledState(isDisabled) {
        const method = isDisabled ? 'setAttribute' : 'removeAttribute';
        this.elementRef.nativeElement[method]('disabled', 'disabled');
    }
    onKeydown() {
        this.beforeSelIndex = UiElement.caretPosition.get(this.elementRef.nativeElement);
    }
    onInput($event) {
        const afterSelIndex = UiElement.caretPosition.get(this.elementRef.nativeElement);
        const rawValue = this.elementRef.nativeElement.value;
        this.input = true;
        this.renderViaInput(rawValue);
        UiElement.caretPosition.set(this.elementRef.nativeElement, this.beforeSelIndex, afterSelIndex, this.symbolsPositions);
    }
};
UiMaskCepNovoDirective.ctorParameters = () => [
    { type: ElementRef },
    { type: UiCepNovoPipe }
];
__decorate([
    Input(),
    __metadata("design:type", Object)
], UiMaskCepNovoDirective.prototype, "ngModel", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], UiMaskCepNovoDirective.prototype, "ngModelChange", void 0);
__decorate([
    HostListener('keydown'),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", void 0)
], UiMaskCepNovoDirective.prototype, "onKeydown", null);
__decorate([
    HostListener('input', ['$event']),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [Object]),
    __metadata("design:returntype", void 0)
], UiMaskCepNovoDirective.prototype, "onInput", null);
UiMaskCepNovoDirective = UiMaskCepNovoDirective_1 = __decorate([
    Directive({
        selector: '[uiMaskCepNovo][ngModel]',
        providers: [{
                provide: NG_VALUE_ACCESSOR,
                useExisting: forwardRef(() => UiMaskCepNovoDirective_1),
                multi: true
            }, {
                provide: NG_VALIDATORS,
                useExisting: forwardRef(() => UiMaskCepNovoDirective_1),
                multi: true
            }, UiCepNovoPipe]
    }),
    __metadata("design:paramtypes", [ElementRef, UiCepNovoPipe])
], UiMaskCepNovoDirective);

let UiPhonePipe = class UiPhonePipe {
    transform(value, type) {
        if (!value) {
            return '';
        }
        value = value.toString().replace(/[^0-9]+/g, '');
        if (type === 'ddi') { // MASK COM PADRAO DDI
            if (value.length > 0) {
                value = '+' + value;
            }
            if (value[1] === '1') { // US +1 (000) 000-000-0000
                if (value.length > 2) {
                    value = value.substring(0, 2) + ' (' + value.substring(2);
                }
                if (value.length > 7) {
                    value = value.substring(0, 7) + ') ' + value.substring(7);
                }
                if (value.length > 12) {
                    value = value.substring(0, 12) + '-' + value.substring(12);
                }
                if (value.length > 17) {
                    value = value.substring(0, 17);
                }
            }
            else { // BR +55 (00) 00000-0000 
                if (value.length > 3) {
                    value = value.substring(0, 3) + ' (' + value.substring(3);
                }
                if (value.length > 7) {
                    value = value.substring(0, 7) + ') ' + value.substring(7);
                }
                if (value.length > 12 && value.length < 18) {
                    value = value.substring(0, 13) + '-' + value.substring(13);
                }
                else if (value.length > 17) {
                    value = value.substring(0, 14) + '-' + value.substring(14);
                }
                if (value.length > 17) {
                    value = value.substring(0, 19);
                }
            }
        }
        else { // MASK COM PADRÃO DEFAULT (00) 00000-0000            
            if (value.length > 0) {
                value = '(' + value;
            }
            if (value.length > 3) {
                value = value.substring(0, 3) + ') ' + value.substring(3);
            }
            if (value.length > 9 && value.length < 14) {
                value = value.substring(0, 9) + '-' + value.substring(9);
            }
            else if (value.length > 13) {
                value = value.substring(0, 10) + '-' + value.substring(10);
            }
            if (value.length > 15) {
                value = value.substring(0, 15);
            }
        }
        return value;
    }
};
UiPhonePipe = __decorate([
    Pipe({
        name: 'uiPhone'
    })
], UiPhonePipe);

var UiMaskPhoneDirective_1;
let UiMaskPhoneDirective = UiMaskPhoneDirective_1 = class UiMaskPhoneDirective {
    constructor(elementRef, phonePipe) {
        this.elementRef = elementRef;
        this.phonePipe = phonePipe;
        this.ngModelChange = new EventEmitter();
    }
    ngOnInit() {
        switch (this.uiMaskPhone) {
            case 'ddi':
                this.symbolsPositions = [0, 12, 14, 17];
                break;
            default:
                this.maxLength = 11;
                this.symbolsPositions = [0, 9, 11, 14];
        }
    }
    ngOnChanges(changes) {
        if (!changes.ngModel.firstChange && (changes.ngModel.currentValue === null || changes.ngModel.currentValue === undefined)) {
            this.elementRef.nativeElement.value = '';
        }
    }
    ngAfterViewInit() {
        setTimeout(() => {
            this.loaded = true;
        });
    }
    writeValue(rawValue) {
        if (this.uiMaskPhone === 'ddi' && rawValue) {
            const firstChar = rawValue.toString().substring(0, 1);
            this.maxLength = firstChar === '1' ? 11 : 13;
        }
        if (this.control && this.loaded && rawValue) {
            this.control.markAsDirty();
        }
        this.elementRef.nativeElement.value = this.phonePipe.transform(this.ngModel, this.uiMaskPhone || '');
        this.input = false;
    }
    renderViaInput(rawValue) {
        if (rawValue) {
            this.control.markAsDirty();
        }
        this.ngModel = this.format(rawValue);
        this.ngModelChange.emit(this.ngModel);
        this.elementRef.nativeElement.value = this.phonePipe.transform(this.elementRef.nativeElement.value, this.uiMaskPhone || '');
    }
    registerOnChange(fn) {
        this.onChange = fn;
    }
    registerOnTouched(fn) {
        this.onTouched = fn;
    }
    format(value) {
        value = value.toString().replace(/[^0-9]+/g, '');
        return value.substring(0, this.maxLength);
    }
    validate(control) {
        this.control = control;
        if (control.value && this.format(control.value).length < this.maxLength - 1) {
            return { parse: true };
        }
        return null;
    }
    setDisabledState(isDisabled) {
        const method = isDisabled ? 'setAttribute' : 'removeAttribute';
        this.elementRef.nativeElement[method]('disabled', 'disabled');
    }
    onKeydown() {
        this.beforeSelIndex = UiElement.caretPosition.get(this.elementRef.nativeElement);
    }
    onInput($event) {
        let afterSelIndex = UiElement.caretPosition.get(this.elementRef.nativeElement);
        const rawValue = this.elementRef.nativeElement.value;
        this.input = true;
        this.renderViaInput(rawValue);
        if (this.uiMaskPhone === 'ddi') {
            if (this.ngModel && this.ngModel.substring(0, 1) === '1') {
                this.maxLength = 11;
                if (afterSelIndex === 3) {
                    this.beforeSelIndex = 4;
                    afterSelIndex = 5;
                }
            }
            else {
                this.maxLength = 13;
                if (afterSelIndex === 4) {
                    this.beforeSelIndex = 5;
                    afterSelIndex = 6;
                }
            }
            if (afterSelIndex === 8) {
                this.beforeSelIndex = 9;
                afterSelIndex = 10;
            }
        }
        else {
            if (afterSelIndex === 4) {
                this.beforeSelIndex = 5;
                afterSelIndex = 6;
            }
        }
        UiElement.caretPosition.set(this.elementRef.nativeElement, this.beforeSelIndex, afterSelIndex, this.symbolsPositions);
    }
};
UiMaskPhoneDirective.ctorParameters = () => [
    { type: ElementRef },
    { type: UiPhonePipe }
];
__decorate([
    Input(),
    __metadata("design:type", Object)
], UiMaskPhoneDirective.prototype, "ngModel", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], UiMaskPhoneDirective.prototype, "uiMaskPhone", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], UiMaskPhoneDirective.prototype, "ngModelChange", void 0);
__decorate([
    HostListener('keydown'),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", void 0)
], UiMaskPhoneDirective.prototype, "onKeydown", null);
__decorate([
    HostListener('input', ['$event']),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [Object]),
    __metadata("design:returntype", void 0)
], UiMaskPhoneDirective.prototype, "onInput", null);
UiMaskPhoneDirective = UiMaskPhoneDirective_1 = __decorate([
    Directive({
        selector: '[uiMaskPhone][ngModel]',
        providers: [{
                provide: NG_VALUE_ACCESSOR,
                useExisting: forwardRef(() => UiMaskPhoneDirective_1),
                multi: true
            }, {
                provide: NG_VALIDATORS,
                useExisting: forwardRef(() => UiMaskPhoneDirective_1),
                multi: true
            }, UiPhonePipe]
    }),
    __metadata("design:paramtypes", [ElementRef, UiPhonePipe])
], UiMaskPhoneDirective);

let UiListComponent = class UiListComponent {
    constructor() {
    }
    ngOnChanges() {
        if (!this.list) {
            console.error('É obrigatório fornecer a model "list"');
            return false;
        }
        if (!this.itemModel) {
            this.itemModel = {
                id: 'id',
                parentId: 'parentId',
                name: 'name',
                url: 'url',
                icon: 'icon'
            };
        }
        this.list.forEach(item => {
            Object.keys(this.itemModel).forEach((key) => {
                const old_key = this.itemModel[key];
                renameObjectKey(item, old_key, key);
            });
        });
        this.list = iteratePristineMenu(this.list);
    }
};
__decorate([
    Input(),
    __metadata("design:type", Object)
], UiListComponent.prototype, "list", void 0);
__decorate([
    Input('item-model'),
    __metadata("design:type", Object)
], UiListComponent.prototype, "itemModel", void 0);
UiListComponent = __decorate([
    Component({
        selector: 'ui-list',
        template: "<ng-container>\r\n    <div class=\"ui-list\">\r\n        <ng-content></ng-content>\r\n        <ui-list-items [items]=\"list\"></ui-list-items>\r\n    </div>\r\n</ng-container>\r\n",
        encapsulation: ViewEncapsulation.None
    }),
    __metadata("design:paramtypes", [])
], UiListComponent);
function iteratePristineMenu(allItems) {
    const remainingList = [];
    const newMenu = allItems.filter(function (item) {
        if (item.parentId !== null) {
            remainingList.push(item);
        }
        return item.parentId === null;
    });
    return iterateOptionsMenu(newMenu, remainingList)[0];
}
function iterateOptionsMenu(list, fullList) {
    let remainingList;
    for (let i = 0; i < list.length; i++) {
        remainingList = [];
        const target = list[i];
        const subMenus = fullList.filter(item => {
            if (item.parentId !== target.id) {
                remainingList.push(item);
            }
            return item.parentId === target.id;
        });
        if (subMenus.length) {
            target.childs = subMenus;
            remainingList = iterateOptionsMenu(target.childs, remainingList)[1];
        }
    }
    return [list, remainingList];
}
function renameObjectKey(obj, oldName, newName) {
    if (!obj.hasOwnProperty(oldName) || oldName === newName) {
        return false;
    }
    obj[newName] = obj[oldName];
    delete obj[oldName];
    return true;
}

let UiListItemsComponent = class UiListItemsComponent {
    constructor() {
    }
    ngOnInit() {
    }
};
__decorate([
    Input(),
    __metadata("design:type", Object)
], UiListItemsComponent.prototype, "items", void 0);
UiListItemsComponent = __decorate([
    Component({
        selector: 'ui-list-items',
        template: "<div *ngFor=\"let item of items\">\r\n    <ui-list-item [item]=\"item\"></ui-list-item>\r\n</div>\r\n"
    }),
    __metadata("design:paramtypes", [])
], UiListItemsComponent);

let UiListItemComponent = class UiListItemComponent {
    constructor() {
    }
    ngOnInit() {
    }
};
__decorate([
    Input(),
    __metadata("design:type", Object)
], UiListItemComponent.prototype, "item", void 0);
UiListItemComponent = __decorate([
    Component({
        selector: 'ui-list-item',
        template: "<div *ngIf=\"!item.childs && !item.url\" class=\"ui-list-item disabled\">\r\n    <span *ngIf=\"!!item.icon\" class=\"icon\">\r\n        <i *ngIf=\"item.icon.material\" class=\"material-icons\">{{item.icon.material}}</i>\r\n        <img *ngIf=\"!!item.icon.img\" [src]=\"item.icon.img\" style=\"width:24px;height:24px\"/>\r\n    </span>\r\n    {{item.name}}\r\n</div>\r\n<a *ngIf=\"!item.childs && item.url\" class=\"ui-list-item\" uiRipple\r\n   [routerLink]=\"item.url ? [item.url] : null\"\r\n   [routerLinkActive]=\"['active']\">\r\n    <span *ngIf=\"!!item.icon\" class=\"icon\">\r\n        <i *ngIf=\"item.icon.material\" class=\"material-icons\">{{item.icon.material}}</i>\r\n        <img *ngIf=\"!!item.icon.img\" [src]=\"item.icon.img\" style=\"width:24px;height:24px\"/>\r\n    </span>\r\n    {{item.name}}\r\n</a>\r\n<div *ngIf=\"item.childs\">\r\n    <div class=\"ui-list-item\" uiRipple [uiListItem]=\"childs\">\r\n        <span *ngIf=\"!!item.icon\" class=\"icon\">\r\n            <i *ngIf=\"item.icon.material\" class=\"material-icons\">{{item.icon.material}}</i>\r\n            <img *ngIf=\"!!item.icon.img\" [src]=\"item.icon.img\" style=\"width:24px;height:24px\"/>\r\n        </span>\r\n        {{item.name}}\r\n        <span class=\"arrow\"><i class=\"material-icons\">keyboard_arrow_down</i></span>\r\n    </div>\r\n    <div class=\"ui-list-item-group\" #childs>\r\n        <div>\r\n            <ui-list-items [items]=\"item.childs\"></ui-list-items>\r\n        </div>\r\n    </div>\r\n</div>\r\n"
    }),
    __metadata("design:paramtypes", [])
], UiListItemComponent);

let UiSliderComponent = class UiSliderComponent {
    constructor(elementRef) {
        this.elementRef = elementRef;
        this.valueChange = new EventEmitter();
        if (!this.viewFormat) {
            this.viewFormat = value => value;
        }
    }
    ngOnInit() {
        this.percentageBlock = 100 / (this.range.length - 1);
        this.value = this.value || this.range[0];
        this.valueModel = this.closestNumber(this.value).index || this.range[0];
    }
    ngOnChanges(changes) {
        if (changes.value && !changes.value.firstChange && !this.mouseDown) {
            this.valueModel = this.closestNumber(changes.value.currentValue).index;
        }
        if (changes.color && !changes.color.firstChange && !this.mouseDown) {
            this.color = changes.color.currentValue;
        }
        if (changes.textColor && !changes.textColor.firstChange && !this.mouseDown) {
            this.textColor = changes.textColor.currentValue;
        }
    }
    ngAfterViewInit() {
        this.valueElement = this.elementRef.nativeElement.querySelectorAll('.thumb-container')[0];
        this.registerEventsListeners();
    }
    registerEventsListeners() {
        UiElement.on(this.valueElement, 'mousedown touchstart', () => {
            if (this.disabled) {
                return;
            }
            this.mouseDown = true;
            this.toggleTackOn(true);
            this.toggleBalloon(true, 0);
            this.valueElement.classList.add('active');
        });
        UiElement.on(document, 'mouseup touchend', e => {
            if (this.disabled) {
                return;
            }
            this.valueElement.classList.remove('active');
            if (this.mouseDown && (e.pageX || e.originalEvent)) {
                this.change(e, true);
            }
            this.mouseDown = false;
            this.toggleBalloon();
            this.toggleTackOn();
        });
        UiElement.on(document, 'mousemove touchmove', e => {
            if (!this.mouseDown || this.disabled) {
                return;
            }
            this.change(e);
        });
    }
    change(event, mouseUp) {
        const currentPosition = event.pageX || (event.touches ? event.touches[0].pageX : null) || (event.changedTouches ? event.changedTouches[0].pageX : null);
        let position = this.getPositionInIndex(currentPosition);
        const newValue = this.closestNumber(this.range[Math.round(position)]);
        if (mouseUp) {
            position = newValue.index;
        }
        this.value = newValue.value;
        this.valueModel = position;
        this.valueChange.emit(this.value);
    }
    toggleBalloon(active, right) {
        const balloon = this.elementRef.nativeElement.querySelectorAll('.balloon-wrap')[0];
        if (balloon) {
            if (active) {
                balloon.style.right = typeof right === 'number' ? right : '';
                balloon.classList.add('active');
            }
            else {
                balloon.classList.remove('active');
            }
        }
    }
    toggleTackOn(active) {
        const trackOn = this.elementRef.nativeElement.querySelectorAll('.track.on')[0];
        const method = active ? 'add' : 'remove';
        trackOn.classList[method]('no-transition');
    }
    getPositionInIndex(position) {
        const trackOff = this.elementRef.nativeElement.querySelectorAll('.track.off')[0];
        position -= UiElement.position(trackOff).left;
        position = position / trackOff.clientWidth * 100;
        position = position > 100 ? 100 : position < 0 ? 0 : position;
        return ((this.range.length - 1) / 100) * position;
    }
    closestNumber(number) {
        let current = this.range[0];
        let difference = Math.abs(number - current);
        let itemIndex = 0;
        let newDifference;
        for (let i = 0; i < this.range.length; i++) {
            newDifference = Math.abs(number - this.range[i]);
            if (newDifference < difference) {
                difference = newDifference;
                current = this.range[i];
                itemIndex = i;
            }
        }
        return { index: itemIndex, value: current };
    }
    getPercentage() {
        return this.percentageBlock * this.valueModel;
    }
};
UiSliderComponent.ctorParameters = () => [
    { type: ElementRef }
];
__decorate([
    Input(),
    __metadata("design:type", Boolean)
], UiSliderComponent.prototype, "hideBalloon", void 0);
__decorate([
    Input(),
    __metadata("design:type", Boolean)
], UiSliderComponent.prototype, "disabled", void 0);
__decorate([
    Input(),
    __metadata("design:type", Number)
], UiSliderComponent.prototype, "begin", void 0);
__decorate([
    Input(),
    __metadata("design:type", Number)
], UiSliderComponent.prototype, "end", void 0);
__decorate([
    Input(),
    __metadata("design:type", String)
], UiSliderComponent.prototype, "direction", void 0);
__decorate([
    Input(),
    __metadata("design:type", Number)
], UiSliderComponent.prototype, "value", void 0);
__decorate([
    Input(),
    __metadata("design:type", Array)
], UiSliderComponent.prototype, "range", void 0);
__decorate([
    Input(),
    __metadata("design:type", String)
], UiSliderComponent.prototype, "color", void 0);
__decorate([
    Input('text-color'),
    __metadata("design:type", String)
], UiSliderComponent.prototype, "textColor", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], UiSliderComponent.prototype, "valueChange", void 0);
__decorate([
    Input('view-format'),
    __metadata("design:type", Function)
], UiSliderComponent.prototype, "viewFormat", void 0);
UiSliderComponent = __decorate([
    Component({
        selector: 'ui-slider[value]',
        template: "<div class=\"track off\"></div>\r\n<div class=\"points\" [ngClass]=\"{'disabled': disabled, 'show': mouseDown}\">\r\n    <div class=\"point\" *ngFor=\"let value of range\"></div>\r\n</div>\r\n<div class=\"track on\"\r\n     [ngClass]=\"{'disabled': disabled}\"\r\n     [ngStyle]=\"{'left': getPercentageLeft ? getPercentageLeft() + '%' : 0,\r\n                 'right': getPercentageRight ? getPercentageRight() + '%' : '',\r\n                 'width': getPercentage ? getPercentage() + '%': '',\r\n                 'background-color': color || ''}\">\r\n    <div class=\"balloon-wrap\" *ngIf=\"!hideBalloon\">\r\n        <svg version=\"1.1\" xmlns=\"http://www.w3.org/2000/svg\"  x=\"0px\" y=\"0px\" width=\"36px\" height=\"36px\" viewBox=\"0 0 36 36\" enable-background=\"new 0 0 36 36\" xml:space=\"preserve\">\r\n            <path [style.fill]=\"color || ''\" d=\"M31.948,13.996c-0.146-5.378-4.016-8.907-4.016-8.907C23.222,0.624,18.163,0.993,18,1.006\r\n                c-0.163-0.013-5.222-0.382-9.931,4.083c0,0-3.87,3.528-4.016,8.907c0,0-0.497,3.41,1.572,7.205c0,0,0.864,2.126,4.765,6.678\r\n                c0,0,3.406,3.846,7.595,7.089v0.024c0.005-0.004,0.01-0.008,0.015-0.012c0.005,0.004,0.01,0.008,0.015,0.012v-0.024\r\n                c4.19-3.244,7.595-7.089,7.595-7.089c3.901-4.552,4.765-6.678,4.765-6.678C32.445,17.405,31.948,13.996,31.948,13.996z\"/>\r\n        </svg>\r\n        <div class=\"value\" [style.color]=\"textColor || ''\">\r\n            {{viewFormat(multiHandle ? direction === 'begin' ? begin : end : value)}}\r\n        </div>\r\n    </div>\r\n    <div class=\"thumb-container left\" tabindex=\"1\" *ngIf=\"multiHandle\" [style.background-color]=\"color || ''\">\r\n        <div class=\"thumb\"></div>\r\n    </div>\r\n    <div class=\"thumb-container right\" tabindex=\"1\" [style.background-color]=\"color || ''\">\r\n        <div class=\"thumb\"></div>\r\n    </div>\r\n</div>\r\n",
        styles: [":host{display:block;position:relative}:host .track{height:2px}:host .track.on{position:absolute;top:0;transition:left 280ms,right 280ms,width 280ms,background 280ms}:host .track.on.no-transition{transition:none}:host .track.on.disabled{background-color:transparent}:host .track.on.disabled .thumb-container{background-color:#bdbdbd}:host .track.on.disabled .thumb-container:focus::before{transform:scale(0)}:host .track.on.disabled .thumb-container .thumb{width:8px;height:8px;background-color:inherit}:host .track.on .thumb-container{position:absolute;top:1px;border-radius:50%;transition:transform 280ms cubic-bezier(0,0,.2,1),background-color 280ms cubic-bezier(0,0,.2,1)}:host .track.on .thumb-container.left{left:0;transform:scale(1) translate(-50%,-50%)}:host .track.on .thumb-container.right{right:0;transform:scale(1) translate(50%,-50%)}:host .track.on .thumb-container .thumb{position:relative;width:12px;height:12px;border-radius:50%;transition:width 280ms cubic-bezier(0,0,.2,1),height 280ms cubic-bezier(0,0,.2,1),background 280ms cubic-bezier(0,0,.2,1),transform 280ms cubic-bezier(0,0,.2,1)}:host .track.on .thumb-container::before{content:\"\";position:absolute;width:32px;height:32px;top:-10px;left:-10px;border-radius:50%;transform:scale(0);transition:transform 280ms cubic-bezier(0,0,.2,1);background-color:inherit;opacity:.1}:host .track.on .thumb-container:focus::before{transform:scale(1)}:host .track.on .thumb-container.active::before{transform:scale(0)}:host .track.on .thumb-container.active .thumb{width:18px;height:18px}:host .track.on .balloon-wrap{position:absolute;top:-42px;transition:transform 280ms cubic-bezier(0,0,.2,1),width 280ms cubic-bezier(0,0,.2,1);z-index:1;transform:scale(0);transform-origin:bottom;cursor:default;margin-left:-18px;margin-right:-18px;width:36px}:host .track.on .balloon-wrap.active{transform:scale(1)}:host .track.on .balloon-wrap .value{position:absolute;top:0;left:0;right:0;bottom:0;display:flex;justify-content:center;font-size:10px;padding-top:9px;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none}:host .track.on .balloon-wrap~.thumb-container{transition:transform 280ms cubic-bezier(0,0,.2,1),background-color 280ms cubic-bezier(0,0,.2,1)}:host .track.on .balloon-wrap~.thumb-container::before{transition:transform 280ms cubic-bezier(0,0,.2,1) 280ms}:host .track.on .balloon-wrap~.thumb-container .thumb{transition:width 280ms cubic-bezier(0,0,.2,1),height 280ms cubic-bezier(0,0,.2,1),background 280ms cubic-bezier(0,0,.2,1),transform 280ms cubic-bezier(0,0,.2,1)}:host .track.on .balloon-wrap~.thumb-container.active{pointer-events:auto}:host .track.on .balloon-wrap~.thumb-container.active .thumb{width:0;height:0}:host .track.on .balloon-wrap~.thumb-container.active::before{transition:none}:host .points{margin-top:-2px;width:100%;display:flex;align-items:center;justify-content:space-between}:host .points .point{padding:1px;border-radius:50%;transform:scale(0)}:host .points.show .point{transform:scale(1)}:host .points.disabled .point{background-color:transparent}"]
    }),
    __metadata("design:paramtypes", [ElementRef])
], UiSliderComponent);

let UiSliderMultiHandleComponent = class UiSliderMultiHandleComponent {
    constructor(elementRef) {
        this.elementRef = elementRef;
        this.beginChange = new EventEmitter();
        this.endChange = new EventEmitter();
        if (!this.viewFormat) {
            this.viewFormat = value => value;
        }
    }
    ngOnInit() {
        this.bodyElement = document.body;
        this.htmlElement = document.documentElement;
        this.multiHandle = true;
        this.percentageBlock = 100 / (this.range.length - 1);
        this.begin = this.begin || this.range[0];
        this.end = this.end || this.range[0];
        this.beginModel = this.closestNumber(this.begin).index || this.range[0];
        this.endModel = this.closestNumber(this.end).index || this.range[0];
    }
    ngOnChanges(changes) {
        if (changes.begin && !changes.begin.firstChange && !this.mouseDown) {
            this.beginModel = this.closestNumber(this.begin).index;
        }
        if (changes.end && !changes.end.firstChange && !this.mouseDown) {
            this.endModel = this.closestNumber(this.end).index;
        }
        if (changes.color && !changes.color.firstChange && !this.mouseDown) {
            this.color = changes.color.currentValue;
        }
        if (changes.textColor && !changes.textColor.firstChange && !this.mouseDown) {
            this.textColor = changes.textColor.currentValue;
        }
    }
    ngAfterViewInit() {
        this.thumbs = this.elementRef.nativeElement.querySelectorAll('.thumb-container');
        this.beginElement = this.thumbs[0];
        this.endElement = this.thumbs[1];
        this.registerEventsListeners();
    }
    registerEventsListeners() {
        UiElement.on(this.beginElement, 'mousedown touchstart', e => {
            if (this.disabled) {
                return;
            }
            e.stopImmediatePropagation();
            this.direction = 'begin';
            this.toggleBalloon(true);
            this.beginElement.classList.add('active');
            this.endElement.classList.remove('active');
        });
        UiElement.on(this.thumbs, 'mousedown touchstart', e => {
            if (this.disabled) {
                return;
            }
            e.stopImmediatePropagation();
            this.mouseDown = true;
            this.toggleTackOn(true);
            UiElement.disableScroll();
        });
        UiElement.on(this.endElement, 'mousedown touchstart', e => {
            if (this.disabled) {
                return;
            }
            e.stopImmediatePropagation();
            this.direction = 'end';
            this.toggleBalloon(true, 0);
            this.endElement.classList.add('active');
            this.beginElement.classList.remove('active');
        });
        UiElement.on(document, 'mouseup touchend', e => {
            if (this.disabled) {
                return;
            }
            this.beginElement.classList.remove('active');
            this.endElement.classList.remove('active');
            if (this.mouseDown && (e.pageX || e.originalEvent)) {
                this.change(e, true);
            }
            this.mouseDown = false;
            this.toggleBalloon();
            this.toggleTackOn();
            UiElement.enableScroll();
        });
        UiElement.on(document, 'mousemove touchmove', e => {
            if (!this.mouseDown || this.disabled) {
                return;
            }
            this.change(e);
        });
    }
    change(event, mouseUp) {
        const currentPosition = event.pageX || (event.touches ? event.touches[0].pageX : null) || (event.changedTouches ? event.changedTouches[0].pageX : null);
        let position = this.getPositionInIndex(currentPosition);
        const newValue = this.closestNumber(this.range[Math.round(position)]);
        if (mouseUp) {
            position = newValue.index;
        }
        if (this.direction === 'begin' && this.beginModel >= this.endModel) {
            this[`${this.direction}Model`] = newValue.index;
            this.direction = 'end';
            UiElement.trigger(this.endElement, 'mousedown');
            this.endElement.focus();
        }
        else if (this.direction === 'end' && this.endModel < this.beginModel) {
            this[`${this.direction}Model`] = newValue.index;
            this.direction = 'begin';
            UiElement.trigger(this.beginElement, 'mousedown');
            this.beginElement.focus();
        }
        this[this.direction] = newValue.value;
        this[`${this.direction}Model`] = position;
        this[`${this.direction}Change`].emit(this[this.direction]);
    }
    toggleBalloon(active, right) {
        const balloon = this.elementRef.nativeElement.querySelectorAll('.balloon-wrap')[0];
        if (balloon) {
            if (active) {
                balloon.style.right = typeof right === 'number' ? right : '';
                balloon.classList.add('active');
            }
            else {
                balloon.classList.remove('active');
            }
        }
    }
    toggleTackOn(active) {
        const trackOn = this.elementRef.nativeElement.querySelectorAll('.track.on')[0];
        const method = active ? 'add' : 'remove';
        trackOn.classList[method]('no-transition');
    }
    getPositionInIndex(position) {
        const trackOff = this.elementRef.nativeElement.querySelectorAll('.track.off')[0];
        position -= UiElement.position(trackOff).left;
        position = position / trackOff.clientWidth * 100;
        position = position > 100 ? 100 : position < 0 ? 0 : position;
        return ((this.range.length - 1) / 100) * position;
    }
    closestNumber(number) {
        let current = this.range[0];
        let difference = Math.abs(number - current);
        let itemIndex = 0;
        let newDifference;
        for (let i = 0; i < this.range.length; i++) {
            newDifference = Math.abs(number - this.range[i]);
            if (newDifference < difference) {
                difference = newDifference;
                current = this.range[i];
                itemIndex = i;
            }
        }
        return { index: itemIndex, value: current };
    }
    getPercentageLeft() {
        return this.percentageBlock * this.beginModel;
    }
    getPercentageRight() {
        return this.percentageBlock * Math.abs(this.endModel - (this.range.length - 1));
    }
};
UiSliderMultiHandleComponent.ctorParameters = () => [
    { type: ElementRef }
];
__decorate([
    Input(),
    __metadata("design:type", Boolean)
], UiSliderMultiHandleComponent.prototype, "hideBalloon", void 0);
__decorate([
    Input(),
    __metadata("design:type", Boolean)
], UiSliderMultiHandleComponent.prototype, "disabled", void 0);
__decorate([
    Input(),
    __metadata("design:type", Number)
], UiSliderMultiHandleComponent.prototype, "begin", void 0);
__decorate([
    Input(),
    __metadata("design:type", Number)
], UiSliderMultiHandleComponent.prototype, "end", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], UiSliderMultiHandleComponent.prototype, "value", void 0);
__decorate([
    Input(),
    __metadata("design:type", Array)
], UiSliderMultiHandleComponent.prototype, "range", void 0);
__decorate([
    Input(),
    __metadata("design:type", String)
], UiSliderMultiHandleComponent.prototype, "color", void 0);
__decorate([
    Input('text-color'),
    __metadata("design:type", String)
], UiSliderMultiHandleComponent.prototype, "textColor", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], UiSliderMultiHandleComponent.prototype, "beginChange", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], UiSliderMultiHandleComponent.prototype, "endChange", void 0);
__decorate([
    Input('view-format'),
    __metadata("design:type", Function)
], UiSliderMultiHandleComponent.prototype, "viewFormat", void 0);
UiSliderMultiHandleComponent = __decorate([
    Component({
        selector: 'ui-slider[begin][end]',
        template: "<div class=\"track off\"></div>\r\n<div class=\"points\" [ngClass]=\"{'disabled': disabled, 'show': mouseDown}\">\r\n    <div class=\"point\" *ngFor=\"let value of range\"></div>\r\n</div>\r\n<div class=\"track on\"\r\n     [ngClass]=\"{'disabled': disabled}\"\r\n     [ngStyle]=\"{'left': getPercentageLeft ? getPercentageLeft() + '%' : 0,\r\n                 'right': getPercentageRight ? getPercentageRight() + '%' : '',\r\n                 'width': getPercentage ? getPercentage() + '%': '',\r\n                 'background-color': color || ''}\">\r\n    <div class=\"balloon-wrap\" *ngIf=\"!hideBalloon\">\r\n        <svg version=\"1.1\" xmlns=\"http://www.w3.org/2000/svg\"  x=\"0px\" y=\"0px\" width=\"36px\" height=\"36px\" viewBox=\"0 0 36 36\" enable-background=\"new 0 0 36 36\" xml:space=\"preserve\">\r\n            <path [style.fill]=\"color || ''\" d=\"M31.948,13.996c-0.146-5.378-4.016-8.907-4.016-8.907C23.222,0.624,18.163,0.993,18,1.006\r\n                c-0.163-0.013-5.222-0.382-9.931,4.083c0,0-3.87,3.528-4.016,8.907c0,0-0.497,3.41,1.572,7.205c0,0,0.864,2.126,4.765,6.678\r\n                c0,0,3.406,3.846,7.595,7.089v0.024c0.005-0.004,0.01-0.008,0.015-0.012c0.005,0.004,0.01,0.008,0.015,0.012v-0.024\r\n                c4.19-3.244,7.595-7.089,7.595-7.089c3.901-4.552,4.765-6.678,4.765-6.678C32.445,17.405,31.948,13.996,31.948,13.996z\"/>\r\n        </svg>\r\n        <div class=\"value\" [style.color]=\"textColor || ''\">\r\n            {{viewFormat(multiHandle ? direction === 'begin' ? begin : end : value)}}\r\n        </div>\r\n    </div>\r\n    <div class=\"thumb-container left\" tabindex=\"1\" *ngIf=\"multiHandle\" [style.background-color]=\"color || ''\">\r\n        <div class=\"thumb\"></div>\r\n    </div>\r\n    <div class=\"thumb-container right\" tabindex=\"1\" [style.background-color]=\"color || ''\">\r\n        <div class=\"thumb\"></div>\r\n    </div>\r\n</div>\r\n",
        styles: [":host{display:block;position:relative}:host .track{height:2px}:host .track.on{position:absolute;top:0;transition:left 280ms,right 280ms,width 280ms,background 280ms}:host .track.on.no-transition{transition:none}:host .track.on.disabled{background-color:transparent}:host .track.on.disabled .thumb-container{background-color:#bdbdbd}:host .track.on.disabled .thumb-container:focus::before{transform:scale(0)}:host .track.on.disabled .thumb-container .thumb{width:8px;height:8px;background-color:inherit}:host .track.on .thumb-container{position:absolute;top:1px;border-radius:50%;transition:transform 280ms cubic-bezier(0,0,.2,1),background-color 280ms cubic-bezier(0,0,.2,1)}:host .track.on .thumb-container.left{left:0;transform:scale(1) translate(-50%,-50%)}:host .track.on .thumb-container.right{right:0;transform:scale(1) translate(50%,-50%)}:host .track.on .thumb-container .thumb{position:relative;width:12px;height:12px;border-radius:50%;transition:width 280ms cubic-bezier(0,0,.2,1),height 280ms cubic-bezier(0,0,.2,1),background 280ms cubic-bezier(0,0,.2,1),transform 280ms cubic-bezier(0,0,.2,1)}:host .track.on .thumb-container::before{content:\"\";position:absolute;width:32px;height:32px;top:-10px;left:-10px;border-radius:50%;transform:scale(0);transition:transform 280ms cubic-bezier(0,0,.2,1);background-color:inherit;opacity:.1}:host .track.on .thumb-container:focus::before{transform:scale(1)}:host .track.on .thumb-container.active::before{transform:scale(0)}:host .track.on .thumb-container.active .thumb{width:18px;height:18px}:host .track.on .balloon-wrap{position:absolute;top:-42px;transition:transform 280ms cubic-bezier(0,0,.2,1),width 280ms cubic-bezier(0,0,.2,1);z-index:1;transform:scale(0);transform-origin:bottom;cursor:default;margin-left:-18px;margin-right:-18px;width:36px}:host .track.on .balloon-wrap.active{transform:scale(1)}:host .track.on .balloon-wrap .value{position:absolute;top:0;left:0;right:0;bottom:0;display:flex;justify-content:center;font-size:10px;padding-top:9px;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none}:host .track.on .balloon-wrap~.thumb-container{transition:transform 280ms cubic-bezier(0,0,.2,1),background-color 280ms cubic-bezier(0,0,.2,1)}:host .track.on .balloon-wrap~.thumb-container::before{transition:transform 280ms cubic-bezier(0,0,.2,1) 280ms}:host .track.on .balloon-wrap~.thumb-container .thumb{transition:width 280ms cubic-bezier(0,0,.2,1),height 280ms cubic-bezier(0,0,.2,1),background 280ms cubic-bezier(0,0,.2,1),transform 280ms cubic-bezier(0,0,.2,1)}:host .track.on .balloon-wrap~.thumb-container.active{pointer-events:auto}:host .track.on .balloon-wrap~.thumb-container.active .thumb{width:0;height:0}:host .track.on .balloon-wrap~.thumb-container.active::before{transition:none}:host .points{margin-top:-2px;width:100%;display:flex;align-items:center;justify-content:space-between}:host .points .point{padding:1px;border-radius:50%;transform:scale(0)}:host .points.show .point{transform:scale(1)}:host .points.disabled .point{background-color:transparent}"]
    }),
    __metadata("design:paramtypes", [ElementRef])
], UiSliderMultiHandleComponent);

let UiInfiniteLoadService = class UiInfiniteLoadService {
    constructor() {
    }
    register(element, func, orientation = 'vertical') {
        this.element = element;
        this.func = func;
        this.listener = () => {
            if (orientation === 'vertical') {
                const heightOffset = (this.element.scrollHeight || document.documentElement.scrollHeight) - (this.element.clientHeight || this.element.innerHeight);
                const scrollTop = this.element.scrollTop || this.element.scrollY;
                const safeZone = heightOffset * 0.1;
                if (scrollTop >= heightOffset - safeZone) {
                    func();
                }
            }
            else {
                const widthOffset = (this.element.scrollWidth || document.documentElement.scrollWidth) - (this.element.clientWidth || this.element.innerWidth);
                const scrollLeft = this.element.scrollLeft || this.element.scrollX;
                const safeZone = widthOffset * 0.1;
                if (scrollLeft >= widthOffset - safeZone) {
                    func();
                }
            }
        };
        this.element.addEventListener('scroll', this.listener);
        this.readyToCheck = true;
    }
    destroy() {
        this.element.removeEventListener('scroll', this.listener);
        this.readyToCheck = false;
    }
};
UiInfiniteLoadService = __decorate([
    Injectable(),
    __metadata("design:paramtypes", [])
], UiInfiniteLoadService);

let UiInfiniteLoadDirective = class UiInfiniteLoadDirective {
    constructor(element, infiniteLoad) {
        this.element = element;
        this.infiniteLoad = infiniteLoad;
        this.uiInfiniteLoad = new EventEmitter();
        this.orientation = 'vertical';
    }
    ngAfterViewInit() {
        this.infiniteLoad.register(this.element.nativeElement, () => {
            this.uiInfiniteLoad.emit();
        }, this.orientation);
    }
    ngDoCheck() {
        if (this.infiniteLoad.listener) {
            this.infiniteLoad.listener();
        }
    }
};
UiInfiniteLoadDirective.ctorParameters = () => [
    { type: ElementRef },
    { type: UiInfiniteLoadService }
];
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], UiInfiniteLoadDirective.prototype, "uiInfiniteLoad", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], UiInfiniteLoadDirective.prototype, "orientation", void 0);
UiInfiniteLoadDirective = __decorate([
    Directive({
        selector: '[uiInfiniteLoad]'
    }),
    __metadata("design:paramtypes", [ElementRef, UiInfiniteLoadService])
], UiInfiniteLoadDirective);

let UiAutocompleteComponent = class UiAutocompleteComponent {
    selectItem(item) {
        this.selectChange.emit(item);
    }
    loadMoreEmit() {
        setTimeout(() => this.loadMore.emit());
    }
};
UiAutocompleteComponent = __decorate([
    Component({
        selector: 'ui-autocomplete',
        template: "<ui-card class=\"suggestions\" tabindex=\"-1\" [ngClass]=\"{'has-secondary': !!secondary}\" (uiInfiniteLoad)=\"loadMoreEmit()\">\r\n    <div class=\"suggestions-wrap\">\r\n        <div class=\"ui-progress\" [ngClass]=\"{'hide': !loading, 'accent': accentClass}\" style=\"position: absolute\">\r\n            <div class=\"indeterminate\"></div>\r\n        </div>\r\n        <ul class=\"ui-list\">\r\n            <li class=\"multi-line\" uiRipple\r\n                *ngFor=\"let item of list; let index = index\"\r\n                (click)=\"selectItem(item)\"\r\n                [ngClass]=\"{'focused': index === focusedIndex, 'accent': accentClass}\"\r\n                [style.transition-delay]=\"(index > 5 ? 0: 100 + (index * 50)) + 'ms'\">\r\n                <div class=\"lines\" *ngIf=\"secondary\">\r\n                    <div class=\"primary\">{{item[primary] || item[secondary]}}</div>\r\n                    <div class=\"secondary\">{{item[primary] ? item[secondary] : null}}</div>\r\n                </div>\r\n                <span *ngIf=\"!secondary\" class=\"primary\">{{item[primary] || item}}</span>\r\n            </li>\r\n            <li *ngIf=\"!list.length && !hideNotFound\" class=\"not-found\">\r\n                <span *ngIf=\"ngModel\">Nenhum registro encontrado para \"{{ngModel}}\"</span>\r\n                <span *ngIf=\"!ngModel\">Nenhum registro encontrado</span>\r\n            </li>\r\n        </ul>\r\n    </div>\r\n</ui-card>\r\n",
        styles: [":host{display:block}:host .suggestions{box-shadow:0 8px 10px 1px rgba(0,0,0,.14),0 3px 14px 3px rgba(0,0,0,.12),0 4px 15px 0 rgba(0,0,0,.2);overflow-y:auto}:host .suggestions .suggestions-wrap .ui-list{padding:0}:host .suggestions .suggestions-wrap .ui-list .not-found,:host .suggestions .suggestions-wrap .ui-list .not-found span{overflow:hidden;text-overflow:ellipsis;white-space:nowrap}::ng-deep .wrap-autocomplete{position:absolute;z-index:2;transition:top 280ms,left 280ms}::ng-deep .wrap-autocomplete .overlay{overflow:hidden}::ng-deep .wrap-autocomplete ui-autocomplete>.suggestions:not(.nothing){transition:max-height 280ms cubic-bezier(.4,0,.6,1),opacity 280ms cubic-bezier(.4,0,.6,1);z-index:3;max-height:0}::ng-deep .wrap-autocomplete ui-autocomplete>.suggestions:not(.nothing) .ui-list li{transition:opacity 280ms cubic-bezier(.4,0,.6,1),transform 280ms cubic-bezier(.4,0,.6,1);opacity:0;transform:translateY(-8px)}::ng-deep .wrap-autocomplete.open ui-autocomplete>.suggestions:not(.nothing){max-height:240px;-webkit-animation:280ms cubic-bezier(.4,0,.6,1) hide-overflow;animation:280ms cubic-bezier(.4,0,.6,1) hide-overflow}::ng-deep .wrap-autocomplete.open ui-autocomplete>.suggestions:not(.nothing).has-secondary{max-height:370px}::ng-deep .wrap-autocomplete.open ui-autocomplete>.suggestions:not(.nothing) .ui-list li{opacity:1;transform:translateY(0)}::ng-deep .wrap-autocomplete:not(.open) ui-autocomplete>.suggestions:not(.nothing){overflow:hidden}@-webkit-keyframes hide-overflow{0%,99.99%{overflow:hidden}100%{overflow:auto}}@keyframes hide-overflow{0%,99.99%{overflow:hidden}100%{overflow:auto}}::ng-deep .wrap-dialog+.wrap-autocomplete{z-index:5}"]
    })
], UiAutocompleteComponent);

var UiAutocompleteDirective_1;
let UiAutocompleteDirective = UiAutocompleteDirective_1 = class UiAutocompleteDirective {
    constructor(componentFactoryResolver, applicationRef, injector, elementRef) {
        this.componentFactoryResolver = componentFactoryResolver;
        this.applicationRef = applicationRef;
        this.injector = injector;
        this.elementRef = elementRef;
        this.loadMore = new EventEmitter();
        this.loadMoreEmmiter = new EventEmitter();
        this.ngModelChange = new EventEmitter();
        this.modelValueChange = new EventEmitter();
        this.selectChange = new EventEmitter();
        this.requiredChange = new EventEmitter();
    }
    ngOnInit() {
        this.selectChange.subscribe(item => {
            this.ngModel = item[this.primary] || item;
            this.modelValue = this.modelProperty && item && typeof item === 'object' ? item[this.modelProperty] : item;
            this.ngModelChange.emit(this.ngModel);
            this.modelValueChange.emit(this.modelValue);
            if (this.select) {
                this.select(item);
            }
            this.elementRef.nativeElement.blur();
            this.close();
        });
    }
    ngAfterViewInit() {
        UiElement.on(window, 'click resize', e => {
            if (this.componentRef) {
                if (!(UiElement.is(e.target, '.wrap-autocomplete') || UiElement.closest(e.target, '.wrap-autocomplete') || UiElement.is(e.target, '.overlay') || e.target === this.elementRef.nativeElement)) {
                    this.close();
                }
            }
        });
    }
    ngOnChanges(changes) {
        if (changes.ngModel && !changes.ngModel.firstChange && this.componentRef) {
            this.componentRef.instance.ngModel = changes.ngModel.currentValue;
        }
        if (changes.list && !changes.list.firstChange && this.componentRef) {
            this.componentRef.instance.list = changes.list.currentValue;
            setTimeout(() => {
                const position = UiElement.position(this.elementRef.nativeElement);
                const coordinate = {
                    x: position.left,
                    y: position.top + 1
                };
                this.setPosition(coordinate, this.componentElement);
            });
        }
        if (changes.loading && !changes.loading.firstChange && this.componentRef) {
            this.componentRef.instance.loading = changes.loading.currentValue;
        }
    }
    createComponent() {
        const componentFactory = this.componentFactoryResolver.resolveComponentFactory(UiAutocompleteComponent);
        this.componentRef = componentFactory.create(this.injector);
    }
    getComponentAsElement() {
        return this.componentRef.hostView.rootNodes[0];
    }
    setInstances(component, componentRef) {
        const keysComponent = ['ngModel', 'list', 'primary', 'secondary', 'selectChange', 'loading', 'accentClass', 'loadMore', 'hideNotFound'];
        keysComponent.forEach(key => {
            componentRef.instance[key] = component[key];
        });
    }
    render(element, coordinate) {
        this.createWrapElement();
        this.wrapElement.appendChild(element);
        document.body.appendChild(this.wrapElement);
        setTimeout(() => {
            this.setPosition(coordinate, element);
            this.wrapElement.classList.add('open');
        });
    }
    createWrapElement() {
        this.wrapElement = document.createElement('div');
        this.wrapElement.classList.add('wrap-autocomplete');
        const overlay = document.createElement('div');
        overlay.classList.add('overlay');
        if (this.themeClass) {
            this.wrapElement.classList.add(this.themeClass);
        }
        UiElement.css(this.wrapElement, 'top', 0);
        UiElement.css(this.wrapElement, 'left', 0);
        UiElement.css(this.wrapElement, 'visibility', 'hidden');
        UiElement.css(this.wrapElement, 'transition', 'none');
        this.wrapElement.appendChild(overlay);
    }
    setFocusIndex(index) {
        this.componentRef.instance.focusedIndex = index;
    }
    close() {
        if (this.wrapElement) {
            this.wrapElement.classList.remove('open');
            setTimeout(() => {
                if (this.componentRef) {
                    this.applicationRef.detachView(this.componentRef.hostView);
                    this.componentRef = null;
                    this.wrapElement.remove();
                }
            }, 280);
        }
    }
    initialize() {
        this.focusedIndex = undefined;
        this.accentClass = this.elementRef.nativeElement.classList.contains('accent');
        const position = UiElement.position(this.elementRef.nativeElement);
        const coordinate = {
            x: position.left,
            y: position.top + 1
        };
        if (!this.componentRef) {
            this.createComponent();
            this.setInstances(this, this.componentRef);
            this.applicationRef.attachView(this.componentRef.hostView);
            this.componentElement = this.getComponentAsElement();
            this.render(this.componentElement, coordinate);
        }
    }
    setPosition(coordinate, element) {
        const wrap = element.querySelector('.suggestions-wrap');
        const maxHeightWrap = !!this.secondary ? 370 : 240;
        const horizontalCoveringArea = coordinate.x + wrap.clientWidth;
        const verticalCoveringArea = coordinate.y + (wrap.clientHeight > maxHeightWrap ? maxHeightWrap : wrap.clientHeight);
        const windowWidth = window.innerWidth + (document.body.scrollLeft || window.scrollX || window.pageXOffset);
        const windowHeight = window.innerHeight + (document.body.scrollTop || window.scrollY || window.pageYOffset);
        if (horizontalCoveringArea > windowWidth) {
            coordinate.x = windowWidth - (wrap.clientWidth + 8);
        }
        if (coordinate.x <= 8) {
            coordinate.x = 8;
        }
        if (verticalCoveringArea > windowHeight) {
            coordinate.y = coordinate.y - ((wrap.clientHeight > maxHeightWrap ? maxHeightWrap : wrap.clientHeight) + this.elementRef.nativeElement.clientHeight) - 14; // 14 = label focus
        }
        UiElement.css(this.wrapElement, 'top', `${coordinate.y + this.elementRef.nativeElement.clientHeight}px`);
        UiElement.css(this.wrapElement, 'left', `${coordinate.x}px`);
        UiElement.css(this.wrapElement, 'width', `${this.elementRef.nativeElement.clientWidth}px`);
        UiElement.css(this.wrapElement, 'visibility', '');
        UiElement.css(this.wrapElement, 'transition', '');
    }
    registerOnChange(fn) {
        this.onChange = fn;
    }
    registerOnTouched(fn) {
        this.onTouched = fn;
    }
    validate(control) {
        this.control = control;
        if (this.elementRef.nativeElement.hasAttribute('required') && !control.value) {
            return { required: true };
        }
        return null;
    }
    onInput() {
        if (!(this.ngModel && this.modelValue) || (this.ngModel !== this.modelValue)) {
            this.modelValue = null;
            this.modelValueChange.emit(this.modelValue);
            this.control.updateValueAndValidity();
        }
    }
    onFocus() {
        if (this.hidePanel) {
            return;
        }
        this.initialize();
    }
    onClick() {
        if (this.hidePanel) {
            return;
        }
        this.initialize();
    }
    onBlur(e) {
        if (!this.hidePanel && e.relatedTarget !== this.componentElement.querySelector('ui-card.suggestions')) {
            this.close();
        }
    }
    onKeydown(e) {
        if (!this.componentRef) {
            return;
        }
        if (typeof this.focusedIndex === 'undefined') {
            this.focusedIndex = -1;
        }
        switch (e.which) {
            case 8:
            case 37:
                this.elementRef.nativeElement.focus();
                break;
            case 38:
                this.focusedIndex = !this.list.length ? null : this.focusedIndex ? this.focusedIndex - 1 : this.list.length - 1;
                this.setFocusIndex(this.focusedIndex);
                break;
            case 40:
                this.focusedIndex = !this.list.length ? null : this.list.length - 1 === this.focusedIndex ? 0 : this.focusedIndex + 1;
                this.setFocusIndex(this.focusedIndex);
                break;
            case 13:
                if (this.list && typeof this.focusedIndex === 'number' && this.focusedIndex !== -1) {
                    this.selectChange.emit(this.list[this.focusedIndex]);
                }
                event.preventDefault();
                break;
        }
    }
};
UiAutocompleteDirective.ctorParameters = () => [
    { type: ComponentFactoryResolver },
    { type: ApplicationRef },
    { type: Injector },
    { type: ElementRef }
];
__decorate([
    Input(),
    __metadata("design:type", Array)
], UiAutocompleteDirective.prototype, "list", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], UiAutocompleteDirective.prototype, "ngModel", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], UiAutocompleteDirective.prototype, "modelValue", void 0);
__decorate([
    Input('model-property'),
    __metadata("design:type", Object)
], UiAutocompleteDirective.prototype, "modelProperty", void 0);
__decorate([
    Input(),
    __metadata("design:type", Function)
], UiAutocompleteDirective.prototype, "select", void 0);
__decorate([
    Input(),
    __metadata("design:type", String)
], UiAutocompleteDirective.prototype, "primary", void 0);
__decorate([
    Input(),
    __metadata("design:type", String)
], UiAutocompleteDirective.prototype, "secondary", void 0);
__decorate([
    Input(),
    __metadata("design:type", Boolean)
], UiAutocompleteDirective.prototype, "loading", void 0);
__decorate([
    Input('theme-class'),
    __metadata("design:type", String)
], UiAutocompleteDirective.prototype, "themeClass", void 0);
__decorate([
    Input(),
    __metadata("design:type", Boolean)
], UiAutocompleteDirective.prototype, "hideNotFound", void 0);
__decorate([
    Input(),
    __metadata("design:type", Boolean)
], UiAutocompleteDirective.prototype, "hidePanel", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], UiAutocompleteDirective.prototype, "loadMore", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], UiAutocompleteDirective.prototype, "loadMoreEmmiter", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], UiAutocompleteDirective.prototype, "ngModelChange", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], UiAutocompleteDirective.prototype, "modelValueChange", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], UiAutocompleteDirective.prototype, "selectChange", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], UiAutocompleteDirective.prototype, "requiredChange", void 0);
__decorate([
    HostListener('input'),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", void 0)
], UiAutocompleteDirective.prototype, "onInput", null);
__decorate([
    HostListener('focus'),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", void 0)
], UiAutocompleteDirective.prototype, "onFocus", null);
__decorate([
    HostListener('click'),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", void 0)
], UiAutocompleteDirective.prototype, "onClick", null);
__decorate([
    HostListener('blur', ['$event']),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [Object]),
    __metadata("design:returntype", void 0)
], UiAutocompleteDirective.prototype, "onBlur", null);
__decorate([
    HostListener('keydown', ['$event']),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [Object]),
    __metadata("design:returntype", void 0)
], UiAutocompleteDirective.prototype, "onKeydown", null);
UiAutocompleteDirective = UiAutocompleteDirective_1 = __decorate([
    Directive({
        selector: '[uiAutocomplete]',
        providers: [{
                provide: NG_VALIDATORS,
                useExisting: forwardRef(() => UiAutocompleteDirective_1),
                multi: true
            }]
    }),
    __metadata("design:paramtypes", [ComponentFactoryResolver,
        ApplicationRef,
        Injector,
        ElementRef])
], UiAutocompleteDirective);

var UiMaskIntegerDirective_1;
let UiMaskIntegerDirective = UiMaskIntegerDirective_1 = class UiMaskIntegerDirective {
    constructor(elementRef) {
        this.elementRef = elementRef;
        this.ngModelChange = new EventEmitter();
    }
    ngOnChanges(changes) {
        if (changes.ngModel && !changes.ngModel.firstChange && (changes.ngModel.currentValue === null || changes.ngModel.currentValue === undefined)) {
            this.elementRef.nativeElement.value = '';
        }
        if (typeof changes.max !== 'undefined') {
            this.max = changes.max.currentValue;
        }
        if (typeof changes.min !== 'undefined') {
            this.min = changes.min.currentValue;
        }
    }
    ngOnInit() {
        switch (this.uiMaskInteger) {
            case 'smallint':
                this.min = -32768;
                this.max = 32768;
                break;
            case 'bigint':
                this.min = -9223372036854775808;
                this.max = 9223372036854775807;
                break;
            case 'integer':
                this.min = -2147483648;
                this.max = 2147483647;
                break;
        }
    }
    ngAfterViewInit() {
        setTimeout(() => {
            this.loaded = true;
        });
    }
    writeValue(rawValue) {
        if (this.control && this.loaded && rawValue) {
            this.control.markAsDirty();
        }
        if (!this.input) {
            const valueConverted = parseInt(this.ngModel, 10);
            this.elementRef.nativeElement.value = typeof this.ngModel === 'number' ? this.ngModel : !Number.isNaN(valueConverted) ? valueConverted : '';
        }
        this.input = false;
    }
    renderViaInput(rawValue) {
        if (rawValue) {
            this.control.markAsDirty();
        }
        this.ngModel = this.format(rawValue);
        this.ngModelChange.emit(this.ngModel);
        this.elementRef.nativeElement.value = this.ngModel || '';
    }
    registerOnChange(fn) {
        this.onChange = fn;
    }
    registerOnTouched(fn) {
        this.onTouched = fn;
    }
    format(value) {
        const newValue = value.toString().replace(/[^0-9]+/g, '');
        return newValue || undefined;
    }
    validate(control) {
        this.control = control;
        if (typeof this.min !== 'undefined' && control.value && this.format(control.value) < this.min) {
            return { min: true };
        }
        if (typeof this.max !== 'undefined' && control.value && this.format(control.value) > this.max) {
            return { max: true };
        }
        return null;
    }
    setDisabledState(isDisabled) {
        const method = isDisabled ? 'setAttribute' : 'removeAttribute';
        this.elementRef.nativeElement[method]('disabled', 'disabled');
    }
    onInput($event) {
        const rawValue = this.elementRef.nativeElement.value;
        this.input = true;
        this.renderViaInput(rawValue);
    }
};
UiMaskIntegerDirective.ctorParameters = () => [
    { type: ElementRef }
];
__decorate([
    Input(),
    __metadata("design:type", Object)
], UiMaskIntegerDirective.prototype, "ngModel", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], UiMaskIntegerDirective.prototype, "ngModelChange", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], UiMaskIntegerDirective.prototype, "uiMaskInteger", void 0);
__decorate([
    Input(),
    __metadata("design:type", Number)
], UiMaskIntegerDirective.prototype, "min", void 0);
__decorate([
    Input(),
    __metadata("design:type", Number)
], UiMaskIntegerDirective.prototype, "max", void 0);
__decorate([
    HostListener('input', ['$event']),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [Object]),
    __metadata("design:returntype", void 0)
], UiMaskIntegerDirective.prototype, "onInput", null);
UiMaskIntegerDirective = UiMaskIntegerDirective_1 = __decorate([
    Directive({
        selector: '[uiMaskInteger][ngModel]',
        providers: [{
                provide: NG_VALUE_ACCESSOR,
                useExisting: forwardRef(() => UiMaskIntegerDirective_1),
                multi: true
            }, {
                provide: NG_VALIDATORS,
                useExisting: forwardRef(() => UiMaskIntegerDirective_1),
                multi: true
            }]
    }),
    __metadata("design:paramtypes", [ElementRef])
], UiMaskIntegerDirective);

let UiTabsComponent = 
/**/
class UiTabsComponent {
    constructor(element) {
        this.element = element;
        this.onScroll = () => this.tabsScroll(0);
        this.disabled = [];
    }
    ngOnInit() {
        this.internetExplorer = navigator.userAgent.includes('Trident');
    }
    ngAfterViewInit() {
        const tabs = this.element.nativeElement.querySelectorAll('.tab');
        const indicator = this.element.nativeElement.querySelector('.indicator');
        for (let i = 0; i < tabs.length; i++) {
            if (tabs[i].classList.contains('disabled')) {
                tabs[i].classList.remove('disabled');
            }
        }
        for (let i = 0; i < this.disabled.length; i++) {
            tabs[this.disabled[i]].classList.add('disabled');
        }
        const self = this;
        let timeout;
        function scrollToTab(tab, withoutAnimation) {
            for (let i = 0; i < tabs.length; i++) {
                const tab2 = tabs[i];
                if (tab2 !== tab && tab2.classList.contains('selected')) {
                    UiElement.css(indicator, 'left', UiElement.offset(tab2).left + 'px');
                    UiElement.css(indicator, 'width', tab2.offsetWidth + 'px');
                    tab2.classList.remove('selected');
                }
            }
            UiElement.css(indicator, 'left', UiElement.offset(tab).left + 'px');
            UiElement.css(indicator, 'width', tab.offsetWidth + 'px');
            clearTimeout(timeout);
            timeout = setTimeout(() => {
                tab.classList.add('selected');
                UiElement.css(indicator, 'width', '');
                UiElement.css(indicator, 'left', '');
            }, 280);
            const overflow = self.element.nativeElement.querySelector('.overflow');
            self.tabsScroll(UiElement.offset(tab).left - overflow.scrollLeft, withoutAnimation);
        }
        for (let i = 0; i < tabs.length; i++) {
            const tab = tabs[i];
            this.element.nativeElement.addEventListener('click', (e) => {
                if (e.target === tab && !e.target.classList.contains('disabled')) {
                    scrollToTab(tab);
                }
            });
        }
        const tabSelected = this.element.nativeElement.querySelector('.tab.first-selected');
        if (tabSelected) {
            scrollToTab(tabSelected, true);
            // tabSelected.nativeElement.click();
        }
        UiElement.trigger(window, 'scroll');
        UiElement.on(window, 'scroll resize', this.onScroll);
    }
    ngOnChanges(changes) {
        setTimeout(() => {
            this.ngAfterViewInit();
        });
    }
    ngOnDestroy() {
        UiElement.off(window, 'scroll resize', this.onScroll);
    }
    tabsScroll(value, withoutAnimation) {
        const overflow = this.element.nativeElement.querySelector('.overflow');
        let scrollLeft = overflow.scrollLeft;
        const maxScrollLeft = overflow.scrollWidth - overflow.clientWidth;
        const animationTiming = withoutAnimation || this.internetExplorer ? 1 : 280;
        if (typeof value !== 'undefined') {
            UiElement.animate(overflow, 'borderSpacing', scrollLeft, scrollLeft + value, animationTiming, null, (tick) => {
                overflow.scrollLeft = tick;
                scrollLeft = overflow.scrollLeft;
                this.showLeftArrow = (scrollLeft > 0);
                this.showRightArrow = (scrollLeft < maxScrollLeft);
            });
        }
        else {
            this.showLeftArrow = (scrollLeft > 0);
            this.showRightArrow = (scrollLeft < maxScrollLeft);
        }
        if (!this.showRightArrow) {
            if (this.infiniteLoad) {
                this.infiniteLoad();
            }
        }
    }
};
UiTabsComponent.ctorParameters = () => [
    { type: ElementRef }
];
__decorate([
    Input('infinite-load'),
    __metadata("design:type", Object)
], UiTabsComponent.prototype, "infiniteLoad", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], UiTabsComponent.prototype, "watch", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], UiTabsComponent.prototype, "disabled", void 0);
UiTabsComponent = __decorate([
    Component({
        selector: 'ui-tabs',
        template: "<div class=\"tabs\">\r\n    <div class=\"overflow\" (scroll)=\"tabsScroll()\">\r\n        <ng-content></ng-content>\r\n        <div class=\"indicator\"></div>\r\n    </div>\r\n    <div class=\"arrows\">\r\n        <div class=\"left\" [class.show]=\"showLeftArrow\">\r\n            <div class=\"ui-button icon flat\" uiRipple (click)=\"tabsScroll(-200)\">\r\n                <i class=\"material-icons\">keyboard_arrow_left</i>\r\n            </div>\r\n        </div>\r\n        <div class=\"right\" [class.show]=\"showRightArrow\">\r\n            <div class=\"ui-button icon flat\" uiRipple (click)=\"tabsScroll(200)\">\r\n                <i class=\"material-icons\">keyboard_arrow_right</i>\r\n            </div>\r\n        </div>\r\n    </div>\r\n</div>\r\n",
        styles: [":host{width:100%;display:block}:host .tabs{position:relative;overflow:hidden;z-index:2;width:100%;height:48px}:host .tabs .overflow{overflow-y:auto;position:relative;width:100%;height:100px;display:flex;transition:transform 280ms cubic-bezier(0,0,.2,1),padding-left 280ms cubic-bezier(0,0,.2,1)}:host .tabs .overflow ::ng-deep .tab{height:48px;display:flex;justify-content:center;align-items:center;padding:0 12px;text-transform:uppercase;cursor:default;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;font-size:14px;font-weight:500;text-align:center;transition:color 280ms cubic-bezier(0,0,.2,1),max-width 280ms cubic-bezier(0,0,.2,1)}@media (max-width:375px),only screen and (min-width:376px) and (max-width:763px){:host .tabs .overflow ::ng-deep .tab{min-width:72px}}:host:not(.scrollable) .tabs ::ng-deep .tab{width:100%}@media (min-width:763px){:host.scrollable:not(.no-padding) .tabs .overflow{padding-left:60px}}@media (max-width:1082px){:host-context(body.ui-nav-drawer-persistent).scrollable:not(.no-padding) .tabs .overflow{padding-left:0}}:host.scrollable .tabs .overflow ::ng-deep .tab{min-width:160px;max-width:264px}:host .tabs .overflow .indicator{position:absolute;height:2px;top:46px;transition:width 280ms cubic-bezier(0,0,.2,1),left 280ms cubic-bezier(0,0,.2,1)}:host .tabs .arrows{position:absolute;width:100%;top:0;left:0;right:0;height:100%;pointer-events:none;display:flex;align-items:center;cursor:default}:host .tabs .arrows .ui-button{margin:0}:host .tabs .arrows .left,:host .tabs .arrows .right{display:flex;justify-content:center;width:50px;transition:transform 280ms cubic-bezier(0,0,.2,1)}:host .tabs .arrows .left .ui-button,:host .tabs .arrows .right .ui-button{pointer-events:auto;transform:scale(0)}:host .tabs .arrows .left.show .ui-button,:host .tabs .arrows .right.show .ui-button{transform:scale(1)}:host .tabs .arrows .right{margin-left:auto}:host:not(.scrollable) .arrows{display:none!important}"]
    })
    /**/
    ,
    __metadata("design:paramtypes", [ElementRef])
], UiTabsComponent);

let UiTabsPagesComponent = class UiTabsPagesComponent {
    constructor(element) {
        this.element = element;
        this.onChangePage = new EventEmitter();
        this.currentPage = 1;
    }
    ngAfterViewInit() {
        if (this.tabs) {
            const tabs = new UiElementRef(this.tabs.element.nativeElement).querySelector('.tab');
            let touchXMovement;
            let touchXStartPosition;
            let touchYMovement;
            let touchYStartPosition;
            let firstMovementCoord;
            let currentBannerIndex;
            let newPosition;
            const elBannerContainer = this.element.nativeElement.querySelector('.page-container');
            elBannerContainer.addEventListener('touchstart', (e) => {
                currentBannerIndex = tabs.indexOf(tabs.filter(tab => tab.is('.selected'))[0]);
                touchXStartPosition = e.touches[0].pageX;
                touchYStartPosition = e.touches[0].pageY;
                elBannerContainer.classList.add('no-transition');
                if (this.enableOverflow) {
                    const pageContainer = new UiElementRef(this.element.nativeElement);
                    const pages = pageContainer.querySelector('.page-container .page');
                    for (let i = 0; i < pages.length; i++) {
                        pages[i].css('height', '');
                    }
                }
            });
            elBannerContainer.addEventListener('touchmove', (e) => {
                if (touchXStartPosition < 0 || touchXStartPosition > 40) {
                    touchXMovement = touchXStartPosition - e.touches[0].pageX;
                    touchYMovement = touchYStartPosition - e.touches[0].pageY;
                    if (!firstMovementCoord) {
                        if (touchXMovement > 20 || touchXMovement < -20) {
                            firstMovementCoord = 'X';
                        }
                        else if (touchYMovement > 20 || touchYMovement < -20) {
                            firstMovementCoord = 'Y';
                        }
                    }
                    if (touchXMovement && firstMovementCoord === 'X') {
                        UiElement.disableScroll();
                        const i = currentBannerIndex;
                        const isNegative = i > 0 ? -1 : 1;
                        const currentPosition = (i * 100) * isNegative;
                        const pages = this.element.nativeElement.querySelectorAll('.page-container .page');
                        for (let i = 0; i < pages.length; i++) {
                            const page = pages[i];
                            newPosition = currentPosition - ((100 / page.clientWidth) * touchXMovement);
                            page.style.transform = `translate(${newPosition}%)`;
                        }
                    }
                }
            });
            elBannerContainer.addEventListener('touchend', () => {
                elBannerContainer.classList.remove('no-transition');
                if (touchXMovement) {
                    const newIndex = (Math.round(newPosition / 100) * -1);
                    if (tabs[newIndex]) {
                        tabs[newIndex].trigger('click');
                    }
                    else {
                        this.pagesGoToPage();
                    }
                }
                UiElement.enableScroll();
                firstMovementCoord = undefined;
            });
        }
        this.pagesGoToPage(1);
    }
    pagesGoToPage(nextPage) {
        let tabs;
        if (this.tabs) {
            tabs = new UiElementRef(this.tabs.element.nativeElement).querySelector('.tab');
        }
        else {
            tabs = new UiElementRef(this.element.nativeElement).querySelector('.page');
        }
        if (tabs[nextPage - 1]) {
            const isNegative = (nextPage - 1) > 0 ? -1 : 1;
            const newPosition = (nextPage - 1) * 100 * isNegative;
            const pages = this.element.nativeElement.children[0].children;
            for (let i = 0; i < pages.length; i++) {
                const page = pages[i];
                page.style.transform = `translate(${newPosition}%)`;
            }
        }
        else {
            this.pagesGoToPage(tabs.indexOf(tabs.filter(tab => tab.is('.selected'))[0]) + 1);
            // TODO: Verificar se isso realmente funciona
        }
        const pageContainer = new UiElementRef(this.element.nativeElement);
        const elNextPage = new UiElementRef(this.element.nativeElement.children[0].children[nextPage - 1]);
        const pages = this.element.nativeElement.children[0].children;
        for (let i = 0; i < pages.length; i++) {
            if (nextPage - 1 === i) {
                const pageRef = new UiElementRef(pages[i]);
                pageRef.css('height', '');
            }
        }
        if (this.firstLoad) {
            const elCurrentPage = new UiElementRef(this.element.nativeElement.children[0].children[this.currentPage - 1]);
            pageContainer.css('height', elCurrentPage.nativeElement.clientHeight + 'px');
        }
        else {
            this.firstLoad = true;
        }
        if (elNextPage) {
            setTimeout(() => {
                pageContainer.css('height', elNextPage.nativeElement.clientHeight + 'px');
                clearTimeout(this.timeOutTurnBack);
                this.timeOutTurnBack = setTimeout(() => {
                    pageContainer.css('height', '');
                    for (let i = 0; i < pages.length; i++) {
                        if (nextPage - 1 !== i) {
                            const pageRef = new UiElementRef(pages[i]);
                            pageRef.css('height', 0);
                        }
                    }
                }, 280);
            });
        }
        if (typeof nextPage !== 'undefined') {
            this.currentPage = nextPage;
            if (this.onChangePage) {
                setTimeout(() => {
                    this.onChangePage.emit();
                });
            }
        }
    }
};
UiTabsPagesComponent.ctorParameters = () => [
    { type: ElementRef }
];
__decorate([
    Input(),
    __metadata("design:type", Object)
], UiTabsPagesComponent.prototype, "tabs", void 0);
__decorate([
    Input('enable-overflow'),
    __metadata("design:type", Boolean)
], UiTabsPagesComponent.prototype, "enableOverflow", void 0);
__decorate([
    Output('onchangepage'),
    __metadata("design:type", EventEmitter)
], UiTabsPagesComponent.prototype, "onChangePage", void 0);
UiTabsPagesComponent = __decorate([
    Component({
        selector: 'ui-tabs-pages',
        template: "<div class=\"page-container\">\r\n    <ng-content></ng-content>\r\n</div>\r\n",
        styles: [":host{width:100%;transition:height 280ms cubic-bezier(0,0,.2,1);overflow:hidden;display:block}:host .page-container{overflow:hidden;text-align:center;display:flex;justify-content:flex-start;max-width:100%;max-width:100vw}:host .page-container:not(.no-transition) ::ng-deep .page{transition:transform 280ms cubic-bezier(0,0,.2,1)}:host .page-container ::ng-deep .page{text-align:left;flex-shrink:0;width:100%;margin-bottom:auto}"]
    }),
    __metadata("design:paramtypes", [ElementRef])
], UiTabsPagesComponent);

let UiLazyLoadDirective = class UiLazyLoadDirective {
    constructor(element) {
        this.element = element;
        this.elementRef = new UiElementRef(element.nativeElement);
        this.elementRef.on('load', () => {
            this.elementRef.classList.add('loaded');
        });
    }
    ngDoCheck() {
        if (!this.visible && this.elementRef.isInViewport()) {
            this.visible = true;
            this.elementRef.attribute('src', this.lazySrc);
        }
    }
};
UiLazyLoadDirective.ctorParameters = () => [
    { type: ElementRef }
];
__decorate([
    Input('lazy-src'),
    __metadata("design:type", Object)
], UiLazyLoadDirective.prototype, "lazySrc", void 0);
UiLazyLoadDirective = __decorate([
    Directive({ selector: '[uiLazyLoad][lazy-src]' }),
    __metadata("design:paramtypes", [ElementRef])
], UiLazyLoadDirective);

let UiDataTableComponent = class UiDataTableComponent {
    constructor(element) {
        this.element = element;
    }
    ngOnInit() {
        const self = new UiElementRef(this.element.nativeElement);
        const tfoot = self.querySelector('tfoot');
        if (tfoot) {
            this.tableFooter.nativeElement.appendChild(tfoot.nativeElement);
        }
    }
};
UiDataTableComponent.ctorParameters = () => [
    { type: ElementRef }
];
__decorate([
    ViewChild('tableFooter', { static: true }),
    __metadata("design:type", Object)
], UiDataTableComponent.prototype, "tableFooter", void 0);
UiDataTableComponent = __decorate([
    Component({
        selector: 'ui-data-table',
        template: "<div class=\"ui-table-overflow\">\r\n    <table class=\"ui-data-table\">\r\n        <ng-content></ng-content>\r\n    </table>\r\n</div>\r\n<table class=\"ui-data-table\" #tableFooter>\r\n</table>\r\n"
    }),
    __metadata("design:paramtypes", [ElementRef])
], UiDataTableComponent);

let UiBottomSheetComponent = class UiBottomSheetComponent {
    constructor(elementRef) {
        this.elementRef = elementRef;
        this.closeChange = new EventEmitter();
    }
    close() {
        this.opened = false;
        this.closeChange.emit();
        if (this.viewRef) {
            const fabs = new UiElementRef(document).querySelector('.ui-fab-container');
            if (fabs.length) {
                fabs.classList.remove('hide');
            }
            this.viewRef.rootNodes.forEach(rootNode => {
                if (rootNode.classList) {
                    rootNode.classList.remove('open');
                }
            });
            if (this.viewRef) {
                setTimeout(() => {
                    this.viewRef.rootNodes.forEach(rootNode => {
                        if (rootNode.remove) {
                            rootNode.remove();
                        }
                        else {
                            rootNode.parentNode.removeChild(rootNode);
                        }
                    });
                    this.viewRef.destroy();
                    this.viewRef = null;
                }, 280);
            }
            document.body.style.overflowY = '';
        }
    }
    show(config) {
        if (!this.viewRef) {
            const dialog = this;
            this.close();
            config = config || {};
            if (config.clickOverlayToClose === undefined) {
                config.clickOverlayToClose = true;
            }
            else if (config.clickOverlayToClose) {
                config.clickOverlayToClose = JSON.parse(config.clickOverlayToClose);
            }
            this.viewRef = dialog.templateRef.createEmbeddedView(dialog.templateRef);
            this.viewRef.detectChanges();
            this.viewRef.rootNodes.forEach(rootNode => {
                document.body.appendChild(rootNode);
                if (rootNode.clientWidth) {
                    this.open(rootNode, config);
                }
            });
        }
    }
    open(element, config) {
        this.opened = true;
        setTimeout(() => {
            setTimeout(() => {
                const card = element.querySelector('ui-card');
                card.className += ` ${this.elementRef.nativeElement.className}`;
                if (config.themeClass) {
                    element.classList.add(config.themeClass);
                }
                if (config.transparentOverlay) {
                    element.classList.add('transparent-overlay');
                }
                if (config.cardSize) {
                    card.style.maxWidth = config.cardSize + 'px';
                }
                if (!config.transparentOverlay && config.fabs) {
                    config.fabs.classList.add('hide');
                }
                element.querySelectorAll('.overlay')[0].addEventListener('click', () => {
                    this.close();
                });
                element.style.transform = '';
                element.classList.add('open');
                // UiElement.disableScroll();
            });
        });
    }
};
UiBottomSheetComponent.ctorParameters = () => [
    { type: ElementRef }
];
__decorate([
    Input('card-size'),
    __metadata("design:type", Number)
], UiBottomSheetComponent.prototype, "cardSize", void 0);
__decorate([
    ViewChild(TemplateRef, { static: true }),
    __metadata("design:type", TemplateRef)
], UiBottomSheetComponent.prototype, "templateRef", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], UiBottomSheetComponent.prototype, "closeChange", void 0);
UiBottomSheetComponent = __decorate([
    Component({
        selector: 'ui-bottom-sheet',
        template: "<ng-template>\r\n    <div class=\"wrap-bottom-sheet\">\r\n        <div class=\"overlay\"></div>\r\n        <ui-card>\r\n            <ng-content>\r\n            </ng-content>\r\n        </ui-card>\r\n    </div>\r\n</ng-template>\r\n",
        encapsulation: ViewEncapsulation.None,
        styles: [".wrap-bottom-sheet{position:fixed;top:0;left:0;right:0;bottom:0;z-index:5;display:flex;align-items:flex-end;justify-content:center;max-height:100%;overflow:hidden}.wrap-bottom-sheet ui-card{width:100%;max-height:100%;transform:translateY(100%);box-shadow:0 16px 24px 2px rgba(0,0,0,.14),0 6px 30px 5px rgba(0,0,0,.12),0 8px 10px 0 rgba(0,0,0,.2);transition:transform 195ms cubic-bezier(.4,0,1,1);border-top-left-radius:2px;border-top-right-radius:2px;overflow-y:auto}.wrap-bottom-sheet ui-card .header{padding:0 16px;min-height:56px;display:flex;align-items:center;font-size:16px;font-weight:500}.wrap-bottom-sheet ui-card.grid ul:not(.ui-list){list-style:none;display:flex;flex-wrap:wrap}.wrap-bottom-sheet ui-card.grid ul:not(.ui-list) .ui-divider{min-width:100%;margin:0}.wrap-bottom-sheet ui-card.grid ul:not(.ui-list) li:not(.ui-divider){padding:24px;display:flex;align-items:center;justify-content:center;flex-direction:column;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;font-size:14px;cursor:default}.wrap-bottom-sheet ui-card.grid ul:not(.ui-list) li:not(.ui-divider) .icon{width:48px;height:48px;margin-bottom:8px}.wrap-bottom-sheet ui-card.grid ul:not(.ui-list) li:not(.ui-divider) .icon i{font-size:48px}.wrap-bottom-sheet ui-card.grid ul.ui-list{display:flex;flex-wrap:wrap}.wrap-bottom-sheet ui-card.grid ul.col-2 li:not(.ui-divider){min-width:50%;max-width:50%}.wrap-bottom-sheet ui-card.grid ul.col-3 li:not(.ui-divider){min-width:33.3333333333%;max-width:33.3333333333%}.wrap-bottom-sheet ui-card.grid ul.col-4 li:not(.ui-divider){min-width:25%;max-width:25%}.wrap-bottom-sheet ui-card.grid .header~ul{padding-top:0}@media (max-width:600px){.wrap-bottom-sheet ui-card{max-width:100%!important;border-radius:0}}.wrap-bottom-sheet .overlay{transition:opacity 280ms;position:absolute;top:0;left:0;right:0;bottom:0;opacity:0}.wrap-bottom-sheet.open ui-card{transition:transform 195ms cubic-bezier(0,0,.2,1);transform:translateY(0)}.wrap-bottom-sheet.open .overlay{transition:opacity 280ms cubic-bezier(0,0,.2,1);opacity:1}"]
    }),
    __metadata("design:paramtypes", [ElementRef])
], UiBottomSheetComponent);

let UiBottomSheetTriggerDirective = class UiBottomSheetTriggerDirective {
    constructor(viewContainerRef, elementRef) {
        this.viewContainerRef = viewContainerRef;
        this.elementRef = elementRef;
    }
    ngAfterViewInit() {
        this.bottomSheet.closeChange.subscribe(() => {
            this.close();
        });
        UiElement.on(this.elementRef.nativeElement, this.triggerEvents || 'click', () => {
            this.render();
        });
    }
    render() {
        this.viewRef = this.viewContainerRef.createEmbeddedView(this.bottomSheet.templateRef);
        this.viewRef.detectChanges();
        this.viewRef.rootNodes.forEach(rootNode => {
            document.body.appendChild(rootNode);
            if (rootNode.clientWidth) {
                this.open(rootNode);
            }
        });
    }
    open(element) {
        setTimeout(() => {
            const card = element.querySelector('ui-card');
            card.className += ` ${this.bottomSheet.elementRef.nativeElement.className}`;
            if (this.themeClass) {
                element.classList.add(this.themeClass);
            }
            if (this.transparentOverlay) {
                element.classList.add('transparent-overlay');
            }
            if (this.bottomSheet.cardSize) {
                card.style.maxWidth = this.bottomSheet.cardSize + 'px';
            }
            if (!this.transparentOverlay && this.fabs) {
                this.fabs.classList.add('hide');
            }
            element.querySelectorAll('.overlay')[0].addEventListener('click', () => {
                this.close();
            });
            element.style.transform = '';
            element.classList.add('open');
            // UiElement.disableScroll();
        });
    }
    close() {
        if (this.viewContainerRef.length) {
            const viewRef = this.viewRef;
            if (this.fabs) {
                this.fabs.classList.remove('hide');
            }
            viewRef.rootNodes.forEach(rootNode => {
                if (rootNode.classList) {
                    rootNode.classList.remove('open');
                }
            });
            setTimeout(() => this.viewContainerRef.remove(this.viewContainerRef.indexOf(viewRef)), 280);
            // UiElement.enableScroll();
        }
    }
};
UiBottomSheetTriggerDirective.ctorParameters = () => [
    { type: ViewContainerRef },
    { type: ElementRef }
];
__decorate([
    Input('trigger-events'),
    __metadata("design:type", String)
], UiBottomSheetTriggerDirective.prototype, "triggerEvents", void 0);
__decorate([
    Input('theme-class'),
    __metadata("design:type", String)
], UiBottomSheetTriggerDirective.prototype, "themeClass", void 0);
__decorate([
    Input('transparent-overlay'),
    __metadata("design:type", Boolean)
], UiBottomSheetTriggerDirective.prototype, "transparentOverlay", void 0);
__decorate([
    Input('uiBottomSheetTrigger'),
    __metadata("design:type", Object)
], UiBottomSheetTriggerDirective.prototype, "bottomSheet", void 0);
UiBottomSheetTriggerDirective = __decorate([
    Directive({
        selector: '[uiBottomSheetTrigger]'
    }),
    __metadata("design:paramtypes", [ViewContainerRef, ElementRef])
], UiBottomSheetTriggerDirective);

let UiInputFileDirective = class UiInputFileDirective {
    constructor(element, ngControl) {
        this.element = element;
        this.ngControl = ngControl;
        this.filesChange = new EventEmitter();
        this.modelChange = new EventEmitter();
    }
    onChange(e) {
        e.stopPropagation();
        e.preventDefault();
        this.readFiles(e.target.files);
    }
    readFiles(files) {
        this.ngControl.control.markAsDirty();
        this.ngControl.control.setErrors(null);
        this.model = [];
        const accepts = this.accept ? this.accept.split(',') : [];
        const maxSize = this.maxSize ? this.toByte(this.maxSize) : null;
        const maxFileSize = this.maxFileSize ? this.toByte(this.maxFileSize) : null;
        let sum = 0;
        for (let i = 0; i < files.length; i++) {
            const file = files[i];
            sum += file.size;
            const validMaxFileSize = this.validateMaxSize(file.size, maxFileSize);
            const validMaxSize = this.validateMaxSize(sum, maxSize);
            const fileExtension = file.name.substring(file.name.lastIndexOf('.') + 1);
            const validType = this.validateType(file, fileExtension, accepts);
            if (validMaxFileSize) {
                this.ngControl.control.setErrors(Object.assign(this.ngControl.errors || {}, { maxFileSize: true }));
            }
            if (!validType) {
                this.ngControl.control.setErrors(Object.assign(this.ngControl.errors || {}, { accept: true }));
            }
            if (this.validateMaxSize(sum, maxSize)) {
                this.ngControl.control.setErrors(Object.assign(this.ngControl.errors || {}, { maxSize: true }));
            }
            if (validType && !validMaxFileSize && !validMaxSize) {
                this.model.push({});
                this.modelChange.emit(this.model);
                this.readFile(file, this.model[i], i);
            }
            else if (this.error) {
                this.error(file, {
                    type: !validType,
                    maxSize: validMaxSize,
                    maxFileSize: validMaxFileSize
                }, i);
            }
        }
        this.files = files;
        this.filesChange.emit(this.files);
        if (this.fileChange) {
            this.fileChange(this.files, this.ngControl.control.invalid);
        }
        this.element.nativeElement.value = ''; // Resetando value para próximos arquivos
    }
    validateType(file, extension, accepts) {
        if (!accepts.length) {
            return true;
        }
        for (let j = 0; j < accepts.length; j++) {
            const accept = accepts[j].trim();
            const regex = accept.match(/^[^\*]*\*$/) ? new RegExp('^' + accept) : new RegExp('^' + accept + '$');
            if (file.type.match(regex) || extension.match(regex)) {
                return true;
            }
        }
        return false;
    }
    validateMaxSize(size, maxSize) {
        return (maxSize && size > maxSize);
    }
    toByte(sizeString) {
        sizeString = sizeString.toString();
        const unitMatch = sizeString.match(/[a-zA-Z]+/g);
        const unit = unitMatch ? unitMatch[0] : null;
        const sizeMatch = sizeString.match(/\d+/);
        const unitSize = sizeMatch ? parseInt(sizeMatch[0], 10) : null;
        let size = unitSize;
        switch (unit) {
            case 'KB':
                size = unitSize * 1024;
                break;
            case 'MB':
                size = unitSize * Math.pow(1024, 2);
                break;
            case 'GB':
                size = unitSize * Math.pow(1024, 3);
                break;
            case 'TB':
                size = unitSize * Math.pow(1024, 4);
                break;
            case 'PB':
                size = unitSize * Math.pow(1024, 5);
                break;
            case 'EB':
                size = unitSize * Math.pow(1024, 6);
                break;
            case 'ZB':
                size = unitSize * Math.pow(1024, 7);
                break;
            case 'YB':
                size = unitSize * Math.pow(1024, 8);
                break;
        }
        return size;
    }
    readFile(file, data, index) {
        if (typeof (data) !== 'object')
            return;
        const reader = new FileReader();
        data.resolved = 'false';
        reader.onload = (e) => {
            data.result = e.target.result;
            data.resolved = true;
            this.modelChange.emit(this.model);
            this.read(file, data.result, index);
        };
        reader.onerror = (e) => {
            data.error = e.target.error;
            this.modelChange.emit(this.model);
        };
        reader.onprogress = (e) => {
            data.progress = {
                loaded: e.loaded,
                total: e.total,
                percent: Math.round((e.loaded / e.total) * 100)
            };
            this.modelChange.emit(this.model);
        };
        reader.readAsDataURL(file);
    }
};
UiInputFileDirective.ctorParameters = () => [
    { type: ElementRef },
    { type: NgControl }
];
__decorate([
    Input(),
    __metadata("design:type", Object)
], UiInputFileDirective.prototype, "files", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], UiInputFileDirective.prototype, "model", void 0);
__decorate([
    Input(),
    __metadata("design:type", String)
], UiInputFileDirective.prototype, "accept", void 0);
__decorate([
    Input(),
    __metadata("design:type", Function)
], UiInputFileDirective.prototype, "read", void 0);
__decorate([
    Input(),
    __metadata("design:type", Function)
], UiInputFileDirective.prototype, "error", void 0);
__decorate([
    Input(),
    __metadata("design:type", Function)
], UiInputFileDirective.prototype, "fileChange", void 0);
__decorate([
    Input('max-size'),
    __metadata("design:type", String)
], UiInputFileDirective.prototype, "maxSize", void 0);
__decorate([
    Input('max-file-size'),
    __metadata("design:type", String)
], UiInputFileDirective.prototype, "maxFileSize", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], UiInputFileDirective.prototype, "filesChange", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], UiInputFileDirective.prototype, "modelChange", void 0);
__decorate([
    HostListener('change', ['$event']),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [Object]),
    __metadata("design:returntype", void 0)
], UiInputFileDirective.prototype, "onChange", null);
UiInputFileDirective = __decorate([
    Directive({
        selector: '[uiInputFile]',
        exportAs: 'uiInputFile'
    }),
    __metadata("design:paramtypes", [ElementRef, NgControl])
], UiInputFileDirective);

let UiEllipsisDirective = class UiEllipsisDirective {
    constructor(element) {
        this.element = element;
    }
    ngOnInit() {
        const elementRef = new UiElementRef(this.element.nativeElement);
        this.uiEllipsis = this.uiEllipsis || 1;
        this.lineHeight = this.lineHeight || 17;
        elementRef.css('-webkit-line-clamp', this.uiEllipsis);
        elementRef.css('max-height', (this.lineHeight * this.uiEllipsis) + 'px');
        elementRef.css('line-height', this.lineHeight + 'px');
        elementRef.on('mousemove', () => {
            if (elementRef.nativeElement.scrollHeight > elementRef.nativeElement.clientHeight) {
                elementRef.nativeElement.setAttribute('title', elementRef.nativeElement.innerText);
            }
            else {
                elementRef.nativeElement.removeAttribute('title');
            }
        });
    }
};
UiEllipsisDirective.ctorParameters = () => [
    { type: ElementRef }
];
__decorate([
    Input(),
    __metadata("design:type", Number)
], UiEllipsisDirective.prototype, "uiEllipsis", void 0);
__decorate([
    Output(),
    __metadata("design:type", Number)
], UiEllipsisDirective.prototype, "uiEllipsisChange", void 0);
__decorate([
    Input('line-height'),
    __metadata("design:type", Number)
], UiEllipsisDirective.prototype, "lineHeight", void 0);
UiEllipsisDirective = __decorate([
    Directive({ selector: '[uiEllipsis]' }),
    __metadata("design:paramtypes", [ElementRef])
], UiEllipsisDirective);

var UiRequiredDirective_1;
let UiRequiredDirective = UiRequiredDirective_1 = class UiRequiredDirective {
    constructor() { }
    validate(control) {
        const value = control.value;
        if (value && value.trim && !value.trim()) {
            return {
                required: true,
                uiMaxlength: false
            };
        }
        return null;
    }
};
__decorate([
    Input('required'),
    __metadata("design:type", Object)
], UiRequiredDirective.prototype, "maxLength", void 0);
UiRequiredDirective = UiRequiredDirective_1 = __decorate([
    Directive({
        selector: '[required][ngModel]',
        providers: [
            { provide: NG_VALIDATORS, useExisting: forwardRef(() => UiRequiredDirective_1), multi: true }
        ]
    }),
    __metadata("design:paramtypes", [])
], UiRequiredDirective);

const textBlack = 'rgba(0, 0, 0, .87)';
const textWhite = '#fff';
const colors = [{
        name: 'red'
    }, {
        name: 'pink'
    }, {
        name: 'purple'
    }, {
        name: 'deepPurple'
    }, {
        name: 'indigo'
    }, {
        name: 'blue'
    }, {
        name: 'lightBlue'
    }, {
        name: 'cyan'
    }, {
        name: 'teal'
    }, {
        name: 'green'
    }, {
        name: 'lightGreen'
    }, {
        name: 'lime'
    }, {
        name: 'yellow'
    }, {
        name: 'amber'
    }, {
        name: 'orange'
    }, {
        name: 'deepOrange'
    }, {
        name: 'brown'
    }, {
        name: 'grey'
    }, {
        name: 'blueGrey'
    }, {
        name: 'black',
        hideSlider: true
    }, {
        name: 'white',
        hideSlider: true,
        hasBorder: true
    }];
const palette = {
    red: {
        50: {
            color: '#ffebee',
            text: textBlack
        },
        100: {
            color: '#ffcdd2',
            text: textBlack
        },
        200: {
            color: '#ef9a9a',
            text: textBlack
        },
        300: {
            color: '#e57373',
            text: textBlack
        },
        400: {
            color: '#ef5350',
            text: textWhite
        },
        500: {
            color: '#f44336',
            text: textWhite
        },
        600: {
            color: '#e53935',
            text: textWhite
        },
        700: {
            color: '#d32f2f',
            text: textWhite
        },
        800: {
            color: '#c62828',
            text: textWhite
        },
        900: {
            color: '#b71c1c',
            text: textWhite
        }
    },
    pink: {
        50: {
            color: '#fce4ec',
            text: textBlack
        },
        100: {
            color: '#f8bbd0',
            text: textBlack
        },
        200: {
            color: '#f48fb1',
            text: textBlack
        },
        300: {
            color: '#f06292',
            text: textWhite
        },
        400: {
            color: '#ec407a',
            text: textWhite
        },
        500: {
            color: '#e91e63',
            text: textWhite
        },
        600: {
            color: '#d81b60',
            text: textWhite
        },
        700: {
            color: '#c2185b',
            text: textWhite
        },
        800: {
            color: '#ad1457',
            text: textWhite
        },
        900: {
            color: '#880e4f',
            text: textWhite
        }
    },
    purple: {
        50: {
            color: '#f3e5f5',
            text: textBlack
        },
        100: {
            color: '#e1bee7',
            text: textBlack
        },
        200: {
            color: '#ce93d8',
            text: textBlack
        },
        300: {
            color: '#ba68c8',
            text: textWhite
        },
        400: {
            color: '#ab47bc',
            text: textWhite
        },
        500: {
            color: '#9c27b0',
            text: textWhite
        },
        600: {
            color: '#8e24aa',
            text: textWhite
        },
        700: {
            color: '#7b1fa2',
            text: textWhite
        },
        800: {
            color: '#6a1b9a',
            text: textWhite
        },
        900: {
            color: '#4a148c',
            text: textWhite
        }
    },
    deepPurple: {
        50: {
            color: '#ede7f6',
            text: textBlack
        },
        100: {
            color: '#d1c4e9',
            text: textBlack
        },
        200: {
            color: '#b39ddb',
            text: textBlack
        },
        300: {
            color: '#9575cd',
            text: textWhite
        },
        400: {
            color: '#7e57c2',
            text: textWhite
        },
        500: {
            color: '#673ab7',
            text: textWhite
        },
        600: {
            color: '#5e35b1',
            text: textWhite
        },
        700: {
            color: '#512da8',
            text: textWhite
        },
        800: {
            color: '#4527a0',
            text: textWhite
        },
        900: {
            color: '#311b92',
            text: textWhite
        }
    },
    indigo: {
        50: {
            color: '#e8eaf6',
            text: textBlack
        },
        100: {
            color: '#c5cae9',
            text: textBlack
        },
        200: {
            color: '#9fa8da',
            text: textBlack
        },
        300: {
            color: '#7986cb',
            text: textWhite
        },
        400: {
            color: '#5c6bc0',
            text: textWhite
        },
        500: {
            color: '#3f51b5',
            text: textWhite
        },
        600: {
            color: '#3949ab',
            text: textWhite
        },
        700: {
            color: '#303f9f',
            text: textWhite
        },
        800: {
            color: '#283593',
            text: textWhite
        },
        900: {
            color: '#1a237e',
            text: textWhite
        }
    },
    blue: {
        50: {
            color: '#e3f2fd',
            text: textBlack
        },
        100: {
            color: '#bbdefb',
            text: textBlack
        },
        200: {
            color: '#90caf9',
            text: textBlack
        },
        300: {
            color: '#64b5f6',
            text: textBlack
        },
        400: {
            color: '#42a5f5',
            text: textBlack
        },
        500: {
            color: '#2196f3',
            text: textWhite
        },
        600: {
            color: '#1e88e5',
            text: textWhite
        },
        700: {
            color: '#1976d2',
            text: textWhite
        },
        800: {
            color: '#1565c0',
            text: textWhite
        },
        900: {
            color: '#0d47a1',
            text: textWhite
        }
    },
    lightBlue: {
        50: {
            color: '#e1f5fe',
            text: textBlack
        },
        100: {
            color: '#b3e5fc',
            text: textBlack
        },
        200: {
            color: '#81d4fa',
            text: textBlack
        },
        300: {
            color: '#4fc3f7',
            text: textBlack
        },
        400: {
            color: '#29b6f6',
            text: textBlack
        },
        500: {
            color: '#03a9f4',
            text: textBlack
        },
        600: {
            color: '#039be5',
            text: textWhite
        },
        700: {
            color: '#0288d1',
            text: textWhite
        },
        800: {
            color: '#0277bd',
            text: textWhite
        },
        900: {
            color: '#01579b',
            text: textWhite
        }
    },
    cyan: {
        50: {
            color: '#e0f7fa',
            text: textBlack
        },
        100: {
            color: '#b2ebf2',
            text: textBlack
        },
        200: {
            color: '#80deea',
            text: textBlack
        },
        300: {
            color: '#4dd0e1',
            text: textBlack
        },
        400: {
            color: '#26c6da',
            text: textBlack
        },
        500: {
            color: '#00bcd4',
            text: textBlack
        },
        600: {
            color: '#00acc1',
            text: textBlack
        },
        700: {
            color: '#0097a7',
            text: textWhite
        },
        800: {
            color: '#00838f',
            text: textWhite
        },
        900: {
            color: '#006064',
            text: textWhite
        }
    },
    teal: {
        50: {
            color: '#e0f2f1',
            text: textBlack
        },
        100: {
            color: '#b2dfdb',
            text: textBlack
        },
        200: {
            color: '#80cbc4',
            text: textBlack
        },
        300: {
            color: '#4db6ac',
            text: textBlack
        },
        400: {
            color: '#26a69a',
            text: textBlack
        },
        500: {
            color: '#009688',
            text: textWhite
        },
        600: {
            color: '#00897b',
            text: textWhite
        },
        700: {
            color: '#00796b',
            text: textWhite
        },
        800: {
            color: '#00695c',
            text: textWhite
        },
        900: {
            color: '#004d40',
            text: textWhite
        }
    },
    green: {
        50: {
            color: '#e8f5e9',
            text: textBlack
        },
        100: {
            color: '#c8e6c9',
            text: textBlack
        },
        200: {
            color: '#a5d6a7',
            text: textBlack
        },
        300: {
            color: '#81c784',
            text: textBlack
        },
        400: {
            color: '#66bb6a',
            text: textBlack
        },
        500: {
            color: '#4caf50',
            text: textBlack
        },
        600: {
            color: '#43a047',
            text: textWhite
        },
        700: {
            color: '#388e3c',
            text: textWhite
        },
        800: {
            color: '#2e7d32',
            text: textWhite
        },
        900: {
            color: '#1b5e20',
            text: textWhite
        }
    },
    lightGreen: {
        50: {
            color: '#f1f8e9',
            text: textBlack
        },
        100: {
            color: '#dcedc8',
            text: textBlack
        },
        200: {
            color: '#c5e1a5',
            text: textBlack
        },
        300: {
            color: '#aed581',
            text: textBlack
        },
        400: {
            color: '#9ccc65',
            text: textBlack
        },
        500: {
            color: '#8bc34a',
            text: textBlack
        },
        600: {
            color: '#7cb342',
            text: textBlack
        },
        700: {
            color: '#689f38',
            text: textWhite
        },
        800: {
            color: '#558b2f',
            text: textWhite
        },
        900: {
            color: '#33691e',
            text: textWhite
        }
    },
    lime: {
        50: {
            color: '#f9fbe7',
            text: textBlack
        },
        100: {
            color: '#f0f4c3',
            text: textBlack
        },
        200: {
            color: '#e6ee9c',
            text: textBlack
        },
        300: {
            color: '#dce775',
            text: textBlack
        },
        400: {
            color: '#d4e157',
            text: textBlack
        },
        500: {
            color: '#cddc39',
            text: textBlack
        },
        600: {
            color: '#c0ca33',
            text: textBlack
        },
        700: {
            color: '#afb42b',
            text: textBlack
        },
        800: {
            color: '#9e9d24',
            text: textBlack
        },
        900: {
            color: '#827717',
            text: textWhite
        }
    },
    yellow: {
        50: {
            color: '#fffde7',
            text: textBlack
        },
        100: {
            color: '#fff9c4',
            text: textBlack
        },
        200: {
            color: '#fff59d',
            text: textBlack
        },
        300: {
            color: '#fff176',
            text: textBlack
        },
        400: {
            color: '#ffee58',
            text: textBlack
        },
        500: {
            color: '#ffeb3b',
            text: textBlack
        },
        600: {
            color: '#fdd835',
            text: textBlack
        },
        700: {
            color: '#fbc02d',
            text: textBlack
        },
        800: {
            color: '#f9a825',
            text: textBlack
        },
        900: {
            color: '#f57f17',
            text: textBlack
        }
    },
    amber: {
        50: {
            color: '#fff8e1',
            text: textBlack
        },
        100: {
            color: '#ffecb3',
            text: textBlack
        },
        200: {
            color: '#ffe082',
            text: textBlack
        },
        300: {
            color: '#ffd54f',
            text: textBlack
        },
        400: {
            color: '#ffca28',
            text: textBlack
        },
        500: {
            color: '#ffc107',
            text: textBlack
        },
        600: {
            color: '#ffb300',
            text: textBlack
        },
        700: {
            color: '#ffa000',
            text: textBlack
        },
        800: {
            color: '#ff8f00',
            text: textBlack
        },
        900: {
            color: '#ff6f00',
            text: textBlack
        }
    },
    orange: {
        50: {
            color: '#fff3e0',
            text: textBlack
        },
        100: {
            color: '#ffe0b2',
            text: textBlack
        },
        200: {
            color: '#ffcc80',
            text: textBlack
        },
        300: {
            color: '#ffb74d',
            text: textBlack
        },
        400: {
            color: '#ffa726',
            text: textBlack
        },
        500: {
            color: '#ff9800',
            text: textBlack
        },
        600: {
            color: '#fb8c00',
            text: textBlack
        },
        700: {
            color: '#f57c00',
            text: textBlack
        },
        800: {
            color: '#ef6c00',
            text: textWhite
        },
        900: {
            color: '#e65100',
            text: textWhite
        }
    },
    deepOrange: {
        50: {
            color: '#fbe9e7',
            text: textBlack
        },
        100: {
            color: '#ffccbc',
            text: textBlack
        },
        200: {
            color: '#ffab91',
            text: textBlack
        },
        300: {
            color: '#ff8a65',
            text: textBlack
        },
        400: {
            color: '#ff7043',
            text: textBlack
        },
        500: {
            color: '#ff5722',
            text: textWhite
        },
        600: {
            color: '#f4511e',
            text: textWhite
        },
        700: {
            color: '#e64a19',
            text: textWhite
        },
        800: {
            color: '#d84315',
            text: textWhite
        },
        900: {
            color: '#bf360c',
            text: textWhite
        }
    },
    brown: {
        50: {
            color: '#efebe9',
            text: textBlack
        },
        100: {
            color: '#d7ccc8',
            text: textBlack
        },
        200: {
            color: '#bcaaa4',
            text: textBlack
        },
        300: {
            color: '#a1887f',
            text: textWhite
        },
        400: {
            color: '#8d6e63',
            text: textWhite
        },
        500: {
            color: '#795548',
            text: textWhite
        },
        600: {
            color: '#6d4c41',
            text: textWhite
        },
        700: {
            color: '#5d4037',
            text: textWhite
        },
        800: {
            color: '#4e342e',
            text: textWhite
        },
        900: {
            color: '#3e2723',
            text: textWhite
        }
    },
    grey: {
        50: {
            color: '#fafafa',
            text: textBlack
        },
        100: {
            color: '#f5f5f5',
            text: textBlack
        },
        200: {
            color: '#eeeeee',
            text: textBlack
        },
        300: {
            color: '#e0e0e0',
            text: textBlack
        },
        400: {
            color: '#bdbdbd',
            text: textBlack
        },
        500: {
            color: '#9e9e9e',
            text: textBlack
        },
        600: {
            color: '#757575',
            text: textWhite
        },
        700: {
            color: '#616161',
            text: textWhite
        },
        800: {
            color: '#424242',
            text: textWhite
        },
        900: {
            color: '#212121',
            text: textWhite
        }
    },
    blueGrey: {
        50: {
            color: '#eceff1',
            text: textBlack
        },
        100: {
            color: '#cfd8dc',
            text: textBlack
        },
        200: {
            color: '#b0bec5',
            text: textBlack
        },
        300: {
            color: '#90a4ae',
            text: textBlack
        },
        400: {
            color: '#78909c',
            text: textWhite
        },
        500: {
            color: '#607d8b',
            text: textWhite
        },
        600: {
            color: '#546e7a',
            text: textWhite
        },
        700: {
            color: '#455a64',
            text: textWhite
        },
        800: {
            color: '#37474f',
            text: textWhite
        },
        900: {
            color: '#263238',
            text: textWhite
        }
    },
    black: {
        500: {
            color: '#000000',
            text: textWhite
        }
    },
    white: {
        500: {
            color: '#FFFFFF',
            text: textBlack
        }
    }
};

let UiColorPickerComponent = class UiColorPickerComponent {
    constructor(ngControl) {
        this.ngControl = ngControl;
        this.valueChange = new EventEmitter();
        this.palette = palette;
        this.colors = colors;
        this.hues = Array.from({ length: 10 }, (ngModel, index) => index * 100);
        this.hues[0] = 50;
        this.value = 500;
        this.colorSelected = {};
    }
    ngAfterViewInit() {
        this.setColorSelected(this.ngModel);
        this.hueColor.valueChange.subscribe(hue => {
            this.ngModel = this.getColor(this.colorSelected.name, hue);
            this.ngModelChange.emit(this.ngModel);
        });
    }
    getColor(color, hue = 500) {
        if (!color) {
            return;
        }
        return this.palette[color][hue].color;
    }
    getColorText(color, hue = 500) {
        if (!color) {
            return;
        }
        return this.palette[color][hue].text;
    }
    selectColor(colorSelected) {
        this.ngControl.control.markAsDirty();
        this.deselectColors();
        colorSelected.selected = true;
        this.colorSelected = colorSelected;
        this.ngModel = this.getColor(this.colorSelected.name, this.value);
        this.ngModelChange.emit(this.ngModel);
    }
    deselectColors() {
        this.ngControl.control.markAsDirty();
        this.ngModel = this.getColor(null);
        this.ngModelChange.emit(this.ngModel);
        this.colorSelected = {};
        this.value = 500;
        this.colors.forEach(color => color.selected = false);
    }
    setColorSelected(color) {
        if (!color) {
            return;
        }
        Object.keys(this.palette).forEach(key => {
            Object.keys(this.palette[key]).forEach(hue => {
                if (this.palette[key][hue].color === color) {
                    this.colors.forEach(item => {
                        if (item.name === key) {
                            setTimeout(() => {
                                item.selected = true;
                                this.value = hue;
                                this.colorSelected = item;
                            });
                        }
                    });
                }
            });
        });
    }
};
UiColorPickerComponent.ctorParameters = () => [
    { type: NgControl }
];
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], UiColorPickerComponent.prototype, "valueChange", void 0);
__decorate([
    ViewChild('hueColor'),
    __metadata("design:type", Object)
], UiColorPickerComponent.prototype, "hueColor", void 0);
UiColorPickerComponent = __decorate([
    Component({
        selector: 'ui-color-picker',
        template: "<ui-card>\r\n    <div class=\"colors\">\r\n        <div class=\"color\"\r\n             *ngFor=\"let color of colors\"\r\n             tabindex=\"1\"\r\n             [class.selected]=\"color.name === colorSelected.name\"\r\n             [ngStyle]=\"{'background-color': getColor(color.name, color.name === colorSelected.name ? value : 500), 'border': color.hasBorder ? '1px solid #424242' : 'none'}\"\r\n             (click)=\"selectColor(color)\">\r\n            <i class=\"material-icons\" [style.color]=\"getColorText(color.name, color.name === colorSelected.name ? value : 500)\" *ngIf=\"color.selected\">done</i>\r\n        </div>\r\n        <div class=\"color remove\" [class.selected]=\"!colorSelected.name\" (click)=\"deselectColors()\" tabindex=\"1\">\r\n            <i class=\"material-icons secondary-text\">block</i>\r\n        </div>\r\n    </div>\r\n    <ui-card-content [hidden]=\"!colorSelected.name\" *ngIf=\"!colorSelected.hideSlider\">\r\n        <ui-slider [range]=\"hues\"\r\n                   [(value)]=\"value\"\r\n                   [hideBalloon]=\"true\"\r\n                   [color]=\"getColor(colorSelected.name, value)\"\r\n                   [text-color]=\"getColorText(colorSelected.name, value)\"\r\n                   #hueColor></ui-slider>\r\n    </ui-card-content>\r\n</ui-card>\r\n",
        styles: [":host ui-card{max-width:246px}:host ui-card ui-card-content{height:34px;overflow:hidden;padding:0 16px;transition:height 280ms cubic-bezier(0,0,.2,1)}:host ui-card ui-card-content[hidden]{height:0}:host .colors{padding:8px 16px 16px 8px;display:flex;flex-wrap:wrap}:host .colors .color{width:36px;height:36px;display:flex;align-items:center;justify-content:center;border-radius:50%;margin-left:8px;margin-top:8px;cursor:default;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;transition:background-color 280ms cubic-bezier(0,0,.2,1),box-shadow 280ms cubic-bezier(0,0,.2,1)}:host .colors .color.remove i{font-size:44px}:host .colors .color i{transition:color 280ms cubic-bezier(0,0,.2,1)}:host .colors .color.selected{box-shadow:0 0 4px 0 rgba(0,0,0,.14),0 3px 4px 0 rgba(0,0,0,.12),0 1px 5px 0 rgba(0,0,0,.2)}:host ::ng-deep ui-slider:not(.nothing){margin-top:16px}:host ::ng-deep ui-slider:not(.nothing) .track{height:4px}:host ::ng-deep ui-slider:not(.nothing) .thumb{width:16px;height:16px}:host ::ng-deep ui-slider:not(.nothing) .points{margin-top:-4px}:host ::ng-deep ui-slider:not(.nothing) .points .point:not(.nothing){padding:2px;opacity:.54}::ng-deep .wrap-color-picker{z-index:5}::ng-deep .wrap-color-picker .overlay{overflow:hidden}::ng-deep .wrap-color-picker ui-color-picker{transform-origin:top left;transition:transform 280ms cubic-bezier(.4,0,.6,1),opacity 280ms cubic-bezier(.4,0,.6,1);transform:scale(0);opacity:0;position:absolute;z-index:5}::ng-deep .wrap-color-picker.open ui-color-picker{transform:scale(1);opacity:1}@media (max-width:600px){::ng-deep .wrap-color-picker{position:fixed;top:0;left:0;right:0;bottom:0;display:flex;background-color:transparent!important}::ng-deep .wrap-color-picker .overlay{position:fixed;top:0;left:0;right:0;bottom:0;background-color:rgba(0,0,0,0);transition:background 195ms cubic-bezier(0,0,.2,1)}::ng-deep .wrap-color-picker ui-color-picker{position:relative;top:0!important;left:0!important;margin:auto;transform-origin:bottom;transition:transform 225ms cubic-bezier(.4,0,1,1),opacity 195ms cubic-bezier(.4,0,1,1);transform:scale(.8) translateY(16px)}::ng-deep .wrap-color-picker ui-color-picker ui-card{box-shadow:0 24px 38px 3px rgba(0,0,0,.14),0 9px 49px 8px rgba(0,0,0,.12),0 11px 15px 0 rgba(0,0,0,.2)}::ng-deep .wrap-color-picker.open .overlay{background-color:rgba(0,0,0,.2)}::ng-deep .wrap-color-picker.open ui-color-picker{transition:transform 225ms cubic-bezier(0,0,.2,1),opacity 195ms cubic-bezier(0,0,.2,1);transform:scale(1) translateY(0)}}"]
    }),
    __metadata("design:paramtypes", [NgControl])
], UiColorPickerComponent);

let UiColorPickerDirective = class UiColorPickerDirective {
    constructor(element, componentFactoryResolver, applicationRef, injector) {
        this.element = element;
        this.componentFactoryResolver = componentFactoryResolver;
        this.applicationRef = applicationRef;
        this.injector = injector;
        this.ngModelChange = new EventEmitter();
        this.palette = palette;
    }
    ngAfterViewInit() {
        this.generateElementColor();
        this.setColorElement(this.ngModel);
        this.element.nativeElement.classList.add('elevate');
        this.element.nativeElement.parentNode.appendChild(this.elementColor);
        this.addEvents();
        this.ngModelChange.subscribe(color => {
            this.setColorElement(color);
        });
    }
    ngOnChanges(changes) {
        if (changes.ngModel && !changes.ngModel.firstChange) {
            this.ngModel = changes.ngModel.currentValue;
            this.setColorElement(this.ngModel);
        }
    }
    generateElementColor() {
        this.elementColor = document.createElement('div');
        this.elementColor.classList.add('ui-color');
        this.elementColor.setAttribute('tabindex', '1');
    }
    setColorElement(color) {
        let icon = this.elementColor.querySelector('i');
        if (color) {
            if (icon) {
                icon.remove();
            }
            this.elementColor.setAttribute('style', `background-color: ${color}`);
        }
        else if (!icon) {
            icon = document.createElement('i');
            icon.classList.add('material-icons', 'secondary-text');
            icon.innerText = 'block';
            this.elementColor.appendChild(icon);
            this.elementColor.setAttribute('style', '');
        }
    }
    addEvents() {
        UiElement.on(this.elementColor, 'click', e => {
            const position = UiElement.position(this.elementColor);
            const coordinate = {
                x: position.left,
                y: position.top
            };
            if (!this.componentRef) {
                this.createComponent();
                this.setInstances(this, this.componentRef);
                this.applicationRef.attachView(this.componentRef.hostView);
                this.componentElement = this.getComponentAsElement();
                this.render(this.componentElement, coordinate);
                e.stopPropagation();
            }
        });
        UiElement.on(window, 'click resize scroll', (e) => {
            if (this.componentRef) {
                if ((!(UiElement.is(e.target, '.wrap-color-picker') || UiElement.closest(e.target, '.wrap-color-picker')) && !(document.body.clientWidth <= 600 && e.type === 'scroll')) || UiElement.is(e.target, '.overlay')) {
                    this.close();
                }
            }
        });
    }
    createComponent() {
        const componentFactory = this.componentFactoryResolver.resolveComponentFactory(UiColorPickerComponent);
        this.componentRef = componentFactory.create(this.injector);
    }
    getComponentAsElement() {
        return this.componentRef.hostView.rootNodes[0];
    }
    setInstances(component, componentRef) {
        const keysComponent = ['ngModel', 'ngModelChange'];
        keysComponent.forEach(key => {
            componentRef.instance[key] = component[key];
        });
    }
    render(element, coordinate) {
        this.createWrapElement();
        this.wrapElement.appendChild(element);
        document.body.appendChild(this.wrapElement);
        setTimeout(() => {
            if (this.themeClass) {
                this.wrapElement.classList.add(this.themeClass);
            }
            this.wrapElement.classList.add('open');
            this.setPosition(coordinate);
        });
    }
    createWrapElement() {
        this.wrapElement = document.createElement('div');
        this.wrapElement.classList.add('wrap-color-picker');
        const overlay = document.createElement('div');
        overlay.classList.add('overlay');
        this.wrapElement.appendChild(overlay);
    }
    setPosition(coordinate) {
        const horizontalCoveringArea = coordinate.x + this.componentElement.clientWidth;
        const verticalCoveringArea = coordinate.y + this.componentElement.clientHeight;
        const windowWidth = window.innerWidth + document.body.scrollLeft;
        const windowHeight = window.innerHeight + document.body.scrollTop;
        if (horizontalCoveringArea > windowWidth) {
            coordinate.x = windowWidth - (this.componentElement.clientWidth + 8);
        }
        if (coordinate.x <= 8) {
            coordinate.x = 8;
        }
        if (verticalCoveringArea > windowHeight) {
            coordinate.y = coordinate.y - this.componentElement.clientHeight;
        }
        this.componentElement.style.top = (coordinate.y) + 'px';
        this.componentElement.style.left = coordinate.x + 'px';
    }
    close() {
        if (this.wrapElement) {
            this.wrapElement.classList.remove('open');
            setTimeout(() => {
                if (this.componentRef) {
                    this.componentRef.instance.colors.forEach(color => color.selected = false);
                    this.applicationRef.detachView(this.componentRef.hostView);
                    this.componentRef = null;
                    this.wrapElement.remove();
                }
            }, 280);
        }
    }
};
UiColorPickerDirective.ctorParameters = () => [
    { type: ElementRef },
    { type: ComponentFactoryResolver },
    { type: ApplicationRef },
    { type: Injector }
];
__decorate([
    Input(),
    __metadata("design:type", Object)
], UiColorPickerDirective.prototype, "ngModel", void 0);
__decorate([
    Input('theme-class'),
    __metadata("design:type", Object)
], UiColorPickerDirective.prototype, "themeClass", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], UiColorPickerDirective.prototype, "ngModelChange", void 0);
UiColorPickerDirective = __decorate([
    Directive({
        selector: '[uiColorPicker]'
    }),
    __metadata("design:paramtypes", [ElementRef,
        ComponentFactoryResolver,
        ApplicationRef,
        Injector])
], UiColorPickerDirective);

const MAX_LOOKUP_RETRIES = 3;
let UiInputAutosizeDirective = class UiInputAutosizeDirective {
    constructor(element) {
        this.element = element;
        this.retries = 0;
        if (this.element.nativeElement.tagName !== 'TEXTAREA') {
            this._findNestedTextArea();
        }
        else {
            this.textAreaEl = this.element.nativeElement;
        }
    }
    onInput(textArea) {
        this.adjust();
    }
    onChange(textArea) {
        this.adjust();
    }
    // Faz com que o autosize execute quando a tela for carregada, para casos em que o campo iniciar preenchido
    ngAfterViewInit() {
        setTimeout(() => {
            this.adjust();
        });
    }
    _findNestedTextArea() {
        this.textAreaEl = this.element.nativeElement.getElementsByTagName('textarea')[0];
        if (!this.textAreaEl) {
            if (this.retries >= MAX_LOOKUP_RETRIES) {
                console.error('textarea não encontrado');
            }
            else {
                this.retries++;
                setTimeout(() => {
                    this._findNestedTextArea();
                }, 100);
            }
        }
    }
    ngDoCheck() {
        // this.adjust();
    }
    // setTimeout para aguardar a atualização da model do input
    ngOnChanges(changes) {
        setTimeout(() => {
            this.adjust();
        });
    }
    adjust() {
        if (!!this.textAreaEl) {
            this.textAreaEl.style.overflow = 'hidden';
            this.textAreaEl.style.height = '';
            this.textAreaEl.style.height = this.textAreaEl.scrollHeight + 'px';
        }
    }
};
UiInputAutosizeDirective.ctorParameters = () => [
    { type: ElementRef }
];
__decorate([
    Input(),
    __metadata("design:type", Object)
], UiInputAutosizeDirective.prototype, "ngModel", void 0);
__decorate([
    HostListener('input', ['$event.target']),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [HTMLTextAreaElement]),
    __metadata("design:returntype", void 0)
], UiInputAutosizeDirective.prototype, "onInput", null);
__decorate([
    HostListener('change', ['$event.target']),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [HTMLTextAreaElement]),
    __metadata("design:returntype", void 0)
], UiInputAutosizeDirective.prototype, "onChange", null);
UiInputAutosizeDirective = __decorate([
    Directive({
        selector: '[autosize]'
    }),
    __metadata("design:paramtypes", [ElementRef])
], UiInputAutosizeDirective);

let UiClockComponent = class UiClockComponent {
    constructor(element) {
        this.element = element;
        this.select = new EventEmitter();
        this.cancel = new EventEmitter();
        this.ngModelChange = new EventEmitter();
        this.chosen = new Subject$1();
        const beforeMidday = Array.apply(null, { length: 12 }).map(Number.call, Number);
        const afterMidday = Array.apply(null, { length: 12 }).map(Number.call, Number).map(val => val + 12);
        beforeMidday[0] = 12;
        afterMidday[0] = 0;
        this.hours = [...afterMidday, ...beforeMidday];
        this.minutes = Array.apply(null, { length: 12 }).map(Number.call, Number).map(val => val * 5);
        this.activeSelection = 'hours';
        this.pointerRotation = 0;
    }
    ngOnInit() {
        this.formatModel();
    }
    ngAfterViewInit() {
        this.element.nativeElement.tabIndex = 1;
        setTimeout(() => {
            this.element.nativeElement.focus();
        });
        UiElement.on(document, 'keydown', e => {
            if (!this.focused) {
                return;
            }
            switch (e.keyCode) {
                case 13:
                    if (this.activeSelection === 'hours') {
                        this.selectHour(this.hour);
                    }
                    else {
                        this.selectMinute(this.minute);
                    }
                    break;
                case 39:
                case 40:
                    if (this.activeSelection === 'hours') {
                        this.hour = this.hour + 1 > 23 ? 0 : this.hour + 1;
                    }
                    else {
                        this.minute = this.minute + 1 > 59 ? 0 : this.minute + 1;
                    }
                    this.getPositionPointer();
                    e.preventDefault();
                    break;
                case 37:
                case 38:
                    if (this.activeSelection === 'hours') {
                        this.hour = this.hour - 1 < 0 ? 23 : this.hour - 1;
                    }
                    else {
                        this.minute = this.minute - 1 < 0 ? 59 : this.minute - 1;
                    }
                    this.getPositionPointer();
                    e.preventDefault();
                    break;
            }
        });
        UiElement.on(document, 'click', e => {
            this.focused = (this.element.nativeElement === e.target || this.element.nativeElement === UiElement.closest(e.target, 'ui-clock')) && (UiElement.is(e.target, 'ui-clock') || UiElement.closest(e.target, 'ui-clock'));
        });
    }
    ngOnChanges(value) {
        if (value.ngModel && !value.ngModel.firstChange) {
            this.ngModel = value.ngModel.currentValue;
            this.formatModel();
        }
        if (value.confirmSelection) {
            this.confirmSelection = value.confirmSelection.currentValue;
        }
    }
    formatModel() {
        if (this.ngModel) {
            const time = this.ngModel.split(':');
            this.hour = parseInt(time[0], 10);
            this.minute = parseInt(time[1], 10);
            this.getPositionPointer();
        }
    }
    selectTime(close) {
        if (this.hasHourAndMinute()) {
            this.ngModel = `${this.formatToLpad(this.hour)}:${this.formatToLpad(this.minute)}`;
            this.ngModelChange.emit(this.ngModel);
            this.select.emit(this.ngModel);
            this.chosen.next({ value: this.ngModel, close });
        }
    }
    cancelTime() {
        this.activeSelection = 'hours';
        this.hour = null;
        this.minute = null;
        this.ngModel = null;
        this.ngModelChange.emit(this.ngModel);
        this.cancel.emit();
    }
    selectHour(hour) {
        this.activeSelection = 'minutes';
        this.hour = hour;
        this.minute = this.minute || 0;
        this.getPositionPointer();
        if (!this.confirmSelection) {
            this.selectTime();
        }
    }
    selectMinute(minute) {
        this.activeSelection = 'hours';
        this.minute = minute;
        this.getPositionPointer();
        if (!this.confirmSelection) {
            this.selectTime(true);
        }
    }
    isEmpty() {
        return !(typeof this.hour === 'number' && typeof this.minute === 'number');
    }
    formatToLpad(value) {
        if (typeof value === 'number' && value.toString().length < 2) {
            value = `0${value}`;
        }
        return value;
    }
    getPositionPointer() {
        if (!this.hasHourAndMinute()) {
            return;
        }
        let oldRotation = this.pointerRotation;
        oldRotation = oldRotation >= 360 ? oldRotation - (Math.floor(oldRotation / 360) * 360) : (oldRotation <= -360 ? oldRotation + (Math.floor(Math.abs(oldRotation) / 360) * 360) : oldRotation);
        let amountRotate;
        const actualRotate = this.activeSelection === 'hours' ? (30 * (this.hour >= 12 ? this.hour - 12 : this.hour)) : 6 * this.minute;
        if (actualRotate - oldRotation < -180) {
            amountRotate = 360 - oldRotation + actualRotate;
        }
        else if (actualRotate - oldRotation > 180) {
            amountRotate = -(360 - actualRotate + oldRotation);
        }
        else {
            amountRotate = actualRotate - oldRotation;
        }
        if (Math.abs(amountRotate) === 180) {
            amountRotate = actualRotate > oldRotation ? Math.abs(amountRotate) : -amountRotate;
        }
        this.pointerRotation += amountRotate;
    }
    getPositionTopPointer() {
        if (this.activeSelection === 'hours' && this.hour > 0 && this.hour < 13) {
            return '40px';
        }
        return '';
    }
    hasHourAndMinute() {
        return typeof this.hour === 'number' && typeof this.minute === 'number';
    }
    validate() {
        return (this.hour < 24 && this.minute < 60) || !this.hasHourAndMinute();
    }
};
UiClockComponent.ctorParameters = () => [
    { type: ElementRef }
];
__decorate([
    Input(),
    __metadata("design:type", Object)
], UiClockComponent.prototype, "ngModel", void 0);
__decorate([
    Input('hide-header'),
    __metadata("design:type", Boolean)
], UiClockComponent.prototype, "hideHeader", void 0);
__decorate([
    Input('confirm-selection'),
    __metadata("design:type", Boolean)
], UiClockComponent.prototype, "confirmSelection", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], UiClockComponent.prototype, "select", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], UiClockComponent.prototype, "cancel", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], UiClockComponent.prototype, "ngModelChange", void 0);
UiClockComponent = __decorate([
    Component({
        selector: 'ui-clock',
        template: "<header *ngIf=\"!hideHeader\" [class.time-error]=\"!validate()\">\r\n    <div>\r\n        <span class=\"time-empty\" *ngIf=\"isEmpty()\">Selecione um hor\u00E1rio</span>\r\n        <span *ngIf=\"!isEmpty() && !validate()\">Hor\u00E1rio inv\u00E1lido</span>\r\n        <div class=\"time\" *ngIf=\"!isEmpty() && validate()\" (click)=\"getPositionPointer()\">\r\n            <span (click)=\"activeSelection = 'hours'\" [class.time-focused]=\"activeSelection === 'hours'\">{{formatToLpad(hour)}}</span>:<span (click)=\"activeSelection = 'minutes'\" [class.time-focused]=\"activeSelection === 'minutes'\">{{formatToLpad(minute)}}</span>\r\n        </div>\r\n    </div>\r\n</header>\r\n<div>\r\n    <div class=\"content\">\r\n        <div class=\"clock-cover\">\r\n            <div class=\"clock-wrap\" [class.has-pointer]=\"hasHourAndMinute() && validate()\">\r\n                <div class=\"pointer\"\r\n                     *ngIf=\"hasHourAndMinute() && validate()\"\r\n                     [ngStyle]=\"{'transform': 'rotate(' + pointerRotation + 'deg)', 'top':  getPositionTopPointer()}\"\r\n                     [@fade]>\r\n                    <div class=\"ball\" [class.show-core]=\"activeSelection === 'minutes' && minute % 5 !== 0\"></div>\r\n                </div>\r\n                <div *ngIf=\"activeSelection === 'hours'\" [@explosion]>\r\n                    <div class=\"hour\"\r\n                         *ngFor=\"let hour of hours\"\r\n                         [style.transform]=\"'rotate(' + (30 * (hour >= 12 ? hour - 12 : hour )) + 'deg)'\"\r\n                         (click)=\"selectHour(hour)\">\r\n                        <button class=\"ui-button icon flat\" [style.transform]=\"'rotate(-' + (30 * (hour >= 12 ? hour - 12 : hour )) + 'deg)'\">{{hour}}</button>\r\n                    </div>\r\n                </div>\r\n                <div *ngIf=\"activeSelection === 'minutes'\" [@explosion]>\r\n                    <div class=\"minute\"\r\n                         *ngFor=\"let minute of minutes; let index = index\"\r\n                         [style.transform]=\"'rotate(' + (30 * (index >= 12 ? index - 12 : index )) + 'deg)'\"\r\n                         (click)=\"selectMinute(minute)\">\r\n                        <button class=\"ui-button icon flat\" [style.transform]=\"'rotate(-' + (30 * (index >= 12 ? index - 12 : index )) + 'deg)'\">{{minute}}</button>\r\n                    </div>\r\n                </div>\r\n            </div>\r\n        </div>\r\n    </div>\r\n    <div class=\"actions ui-button-container align-right\" *ngIf=\"confirmSelection\">\r\n        <button class=\"ui-button flat primary\" uiRipple (click)=\"cancelTime()\">Cancelar</button>\r\n        <button class=\"ui-button flat primary\" uiRipple (click)=\"selectTime(true)\" [disabled]=\"!hasHourAndMinute()\">Ok</button>\r\n    </div>\r\n</div>\r\n",
        encapsulation: ViewEncapsulation.None,
        animations: [trigger('explosion', [
                transition(':enter', [
                    style({
                        opacity: 0,
                        transform: 'scale(1.3)'
                    }),
                    animate('280ms cubic-bezier(0.0, 0.0, 0.2, 1)', style({
                        opacity: 1,
                        transform: 'scale(1)'
                    }))
                ]),
                transition(':leave', [
                    style({
                        opacity: 1,
                        transform: 'scale(1)'
                    }),
                    animate('280ms cubic-bezier(0.0, 0.0, 0.2, 1)', style({
                        opacity: 0,
                        transform: 'scale(1.3)'
                    }))
                ])
            ]), trigger('fade', [
                transition(':enter', [
                    style({
                        opacity: 0,
                    }),
                    animate('280ms cubic-bezier(0.0, 0.0, 0.2, 1)', style({
                        opacity: 1,
                    }))
                ]),
                transition(':leave', [
                    style({
                        opacity: 1,
                    }),
                    animate('280ms cubic-bezier(0.0, 0.0, 0.2, 1)', style({
                        opacity: 0,
                    }))
                ])
            ])],
        styles: ["ui-clock{display:inline-flex;flex-direction:column;overflow:hidden;border-radius:2px;position:relative;z-index:0}ui-clock header{padding:16px;min-height:72px;display:flex;justify-content:center;flex-direction:column}ui-clock header .time-empty{font-size:18px;font-weight:500}ui-clock header .time{margin-top:8px;font-size:40px;font-weight:500;text-align:center;cursor:default}ui-clock .actions{padding:0 8px 8px;text-align:right;cursor:default}ui-clock .content{position:relative}ui-clock .content .clock-cover{overflow:hidden;transition:.3s ease-in-out;margin:24px}ui-clock .content .clock-cover .clock-wrap{border-radius:50%;width:250px;height:250px;position:relative}ui-clock .content .clock-cover .clock-wrap>div:not(.pointer){position:absolute;top:0;left:0;right:0;bottom:0;z-index:1}ui-clock .content .clock-cover .clock-wrap::before{content:\"\";position:absolute;top:0;left:0;right:0;bottom:0;display:block;width:4px;height:4px;margin:auto;border-radius:50%;transition:transform 280ms cubic-bezier(0,0,.2,1);transform:scale(0)}ui-clock .content .clock-cover .clock-wrap .hour,ui-clock .content .clock-cover .clock-wrap .minute,ui-clock .content .clock-cover .clock-wrap .pointer{position:absolute;top:8px;left:0;right:0;bottom:50%;width:36px;margin:0 auto;pointer-events:none;transform-origin:bottom center}ui-clock .content .clock-cover .clock-wrap .hour .ui-button,ui-clock .content .clock-cover .clock-wrap .minute .ui-button,ui-clock .content .clock-cover .clock-wrap .pointer .ui-button{pointer-events:auto}ui-clock .content .clock-cover .clock-wrap .hour .ui-button::before,ui-clock .content .clock-cover .clock-wrap .minute .ui-button::before,ui-clock .content .clock-cover .clock-wrap .pointer .ui-button::before{transform:scale(1)}ui-clock .content .clock-cover .clock-wrap .pointer{z-index:2;transition:transform 280ms cubic-bezier(0,0,.2,1),top 280ms cubic-bezier(0,0,.2,1)}ui-clock .content .clock-cover .clock-wrap .pointer::before{content:\"\";width:2px;position:absolute;top:36px;left:0;right:0;bottom:0;margin:auto}ui-clock .content .clock-cover .clock-wrap .pointer .ball{width:36px;height:36px;margin:auto;border-radius:50%;position:absolute;top:0}ui-clock .content .clock-cover .clock-wrap .pointer .ball::before{content:\"\";width:8px;height:8px;margin:auto;display:block;border-radius:50%;position:absolute;top:0;left:0;right:0;bottom:0;transition:transform 280ms cubic-bezier(0,0,.2,1);transform:scale(0)}ui-clock .content .clock-cover .clock-wrap .pointer .ball.show-core::before{transform:scale(1)}ui-clock .content .clock-cover .clock-wrap .hour:nth-child(n+13){top:40px}ui-clock .content .clock-cover .clock-wrap.has-pointer::before{transform:scale(1)}@media (min-width:600px),(min-width:496px) and (orientation:landscape){ui-clock:not(.portrait-only){flex-direction:row}ui-clock:not(.portrait-only) header{width:168px}ui-clock:not(.portrait-only) .clock-cover{margin:8px 24px}}"]
    }),
    __metadata("design:paramtypes", [ElementRef])
], UiClockComponent);

let UiTimePickerService = class UiTimePickerService {
    constructor() {
        this.timePickers = {};
    }
    add(name, component) {
        if (this.timePickers && this.timePickers[name]) {
            return;
        }
        this.timePickers[name] = component;
    }
    get(name) {
        return this.timePickers[name];
    }
    remove(name) {
        delete this.timePickers[name];
    }
    closeAll() {
        UiElement.trigger(window, 'click');
    }
    getAll() {
        return this.timePickers;
    }
    updateModel(name, value) {
        this.timePickers[name].ngModel = value;
        this.timePickers[name].ngModelChange.emit(value);
    }
};
UiTimePickerService = __decorate([
    Injectable(),
    __metadata("design:paramtypes", [])
], UiTimePickerService);

let UiTimePickerDirective = class UiTimePickerDirective {
    constructor(timePickerService, element) {
        this.timePickerService = timePickerService;
        this.element = element;
        this.select = new EventEmitter();
        this.ngModelChange = new EventEmitter();
        this.chosen = new Subject();
    }
    ngOnInit() {
        this.timePickerService.add(this.timePicker, this);
    }
    ngAfterViewInit() {
        this.element.nativeElement.setAttribute('time-picker-name', this.timePicker);
    }
    ngOnChanges(value) {
        this.chosen.next(value);
    }
    ngOnDestroy() {
        this.timePickerService.remove(this.timePicker);
    }
};
UiTimePickerDirective.ctorParameters = () => [
    { type: UiTimePickerService },
    { type: ElementRef }
];
__decorate([
    Input(),
    __metadata("design:type", Object)
], UiTimePickerDirective.prototype, "ngModel", void 0);
__decorate([
    Input(),
    __metadata("design:type", Boolean)
], UiTimePickerDirective.prototype, "confirmSelection", void 0);
__decorate([
    Input('theme-class'),
    __metadata("design:type", String)
], UiTimePickerDirective.prototype, "themeClass", void 0);
__decorate([
    Input('uiTimePicker'),
    __metadata("design:type", String)
], UiTimePickerDirective.prototype, "timePicker", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], UiTimePickerDirective.prototype, "select", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], UiTimePickerDirective.prototype, "ngModelChange", void 0);
UiTimePickerDirective = __decorate([
    Directive({
        selector: '[uiTimePicker]'
    }),
    __metadata("design:paramtypes", [UiTimePickerService, ElementRef])
], UiTimePickerDirective);

let UiTimePickerCallerDirective = class UiTimePickerCallerDirective {
    constructor(componentFactoryResolver, applicationRef, injector, timePickerService, elementRef) {
        this.componentFactoryResolver = componentFactoryResolver;
        this.applicationRef = applicationRef;
        this.injector = injector;
        this.timePickerService = timePickerService;
        this.elementRef = elementRef;
    }
    ngAfterViewInit() {
        this.timePicker = this.timePickerService.get(this.timePickerCaller);
        UiElement.on(this.elementRef.nativeElement, this.pickerEvent || 'click', (e) => {
            this.inputElement = document.querySelector(`[time-picker-name="${this.timePickerCaller}"]`);
            this.timePickerService.closeAll();
            const position = UiElement.position(this.inputElement);
            const coordinate = {
                x: position.left,
                y: this.inputElement.offsetHeight + position.top
            };
            if (!this.pickerOpen) {
                this.renderTimePicker(this.timePicker, coordinate);
                e.stopPropagation(); // Parando propagação do evento para os eventos do window
            }
        });
        UiElement.on(window, 'click resize scroll', (e) => {
            if (this.pickerOpen) {
                if ((!(UiElement.is(e.target, '.wrap-time-picker') || UiElement.closest(e.target, '.wrap-time-picker'))
                    && !(document.body.clientWidth <= 600 && e.type === 'scroll')) || UiElement.is(e.target, '.overlay')) {
                    this.closePicker();
                }
            }
        });
    }
    getComponentAsElement(componentRef) {
        return componentRef.hostView.rootNodes[0];
    }
    setInstances(component, componentRef) {
        const keysComponent = ['ngModel', 'confirmSelection', 'select'];
        keysComponent.map(key => componentRef.instance[key] = component[key]);
        componentRef.instance.focused = true;
        component.chosen.subscribe(value => componentRef.instance.ngOnChanges(value));
        componentRef.instance.cancel.subscribe(() => this.closePicker());
        componentRef.instance.chosen.subscribe(objectValue => {
            this.timePickerService.updateModel(this.timePickerCaller, objectValue.value);
            if (this.pickerOpen && objectValue.close) {
                this.inputElement.focus();
                this.closePicker();
            }
        });
    }
    renderViewClock(element, coordinate, themeClass) {
        this.wrapTimePicker = document.createElement('div');
        this.wrapTimePicker.classList.add('wrap-time-picker');
        const overlay = document.createElement('div');
        overlay.classList.add('overlay');
        if (themeClass) {
            this.wrapTimePicker.classList.add(themeClass);
        }
        this.wrapTimePicker.style.transform = 'scale(0)';
        element.classList.add('portrait-only');
        this.wrapTimePicker.appendChild(overlay);
        this.wrapTimePicker.appendChild(element);
        document.body.appendChild(this.wrapTimePicker);
        setTimeout(() => {
            const pickerHorizontalCoveringArea = coordinate.x + element.clientWidth;
            const pickerVerticalCoveringArea = coordinate.y + element.clientHeight;
            const windowWidth = window.innerWidth + (document.body.scrollLeft || window.scrollX || window.pageXOffset);
            const windowHeight = window.innerHeight + (document.body.scrollTop || window.scrollY || window.pageYOffset);
            if (pickerHorizontalCoveringArea > windowWidth) {
                coordinate.x = windowWidth - (element.clientWidth + 8);
            }
            if (pickerVerticalCoveringArea > windowHeight) {
                coordinate.y = windowHeight - (element.clientHeight + 8);
            }
            this.wrapTimePicker.style.transform = '';
            element.style.position = 'absolute';
            element.style.top = coordinate.y + 'px';
            element.style.left = coordinate.x + 'px';
            this.wrapTimePicker.classList.add('open');
            if (document.body.clientWidth <= 600) {
                document.body.style.overflowY = 'hidden';
            }
        });
    }
    renderTimePicker(component, coordinate) {
        const componentFactory = this.componentFactoryResolver.resolveComponentFactory(UiClockComponent);
        this.componentRef = componentFactory.create(this.injector);
        this.componentElement = this.getComponentAsElement(this.componentRef);
        this.setInstances(component, this.componentRef);
        this.applicationRef.attachView(this.componentRef.hostView);
        this.renderViewClock(this.componentElement, coordinate, component.themeClass);
        this.pickerOpen = true;
    }
    closePicker() {
        this.wrapTimePicker.classList.remove('open');
        setTimeout(() => {
            this.pickerOpen = false;
            this.applicationRef.detachView(this.componentRef.hostView);
            document.body.style.overflowY = '';
            try {
                document.body.removeChild(this.wrapTimePicker);
            }
            catch (e) {
            }
        }, 280);
    }
};
UiTimePickerCallerDirective.ctorParameters = () => [
    { type: ComponentFactoryResolver },
    { type: ApplicationRef },
    { type: Injector },
    { type: UiTimePickerService },
    { type: ElementRef }
];
__decorate([
    Input(),
    __metadata("design:type", String)
], UiTimePickerCallerDirective.prototype, "pickerEvent", void 0);
__decorate([
    Input('uiTimePickerCaller'),
    __metadata("design:type", String)
], UiTimePickerCallerDirective.prototype, "timePickerCaller", void 0);
UiTimePickerCallerDirective = __decorate([
    Directive({
        selector: '[uiTimePickerCaller]'
    }),
    __metadata("design:paramtypes", [ComponentFactoryResolver,
        ApplicationRef,
        Injector,
        UiTimePickerService,
        ElementRef])
], UiTimePickerCallerDirective);

let UiTimePipe = class UiTimePipe {
    transform(value, args) {
        if (!value) {
            return '';
        }
        value = value.toString().replace(/[^0-9]+/g, '');
        if (value.length > 2) {
            value = value.substring(0, 2) + ':' + value.substring(2);
        }
        if (value.length > 5) {
            value = value.substring(0, 5);
        }
        return value;
    }
};
UiTimePipe = __decorate([
    Pipe({
        name: 'uiTime'
    })
], UiTimePipe);

var UiMaskTimeDirective_1;
let UiMaskTimeDirective = UiMaskTimeDirective_1 = class UiMaskTimeDirective {
    constructor(elementRef, timePipe) {
        this.elementRef = elementRef;
        this.timePipe = timePipe;
        this.symbolsPositions = [2];
        this.ngModelChange = new EventEmitter();
    }
    ngOnChanges(changes) {
        if (changes.ngModel && !changes.ngModel.firstChange && (changes.ngModel.currentValue === null || changes.ngModel.currentValue === undefined)) {
            this.elementRef.nativeElement.value = '';
        }
        if (changes.minTime && !changes.minTime.firstChange) {
            this.minTime = changes.minTime.currentValue;
        }
        if (changes.maxTime && !changes.maxTime.firstChange) {
            this.maxTime = changes.maxTime.currentValue;
        }
    }
    ngAfterViewInit() {
        setTimeout(() => {
            this.loaded = true;
        });
    }
    writeValue(rawValue) {
        if (this.control && this.loaded && rawValue) {
            this.control.markAsDirty();
        }
        if (!this.input) {
            this.elementRef.nativeElement.value = this.timePipe.transform(this.ngModel);
        }
        this.input = false;
    }
    renderViaInput(rawValue) {
        if (rawValue) {
            this.control.markAsDirty();
        }
        this.ngModel = this.timePipe.transform(rawValue);
        this.ngModelChange.emit(this.ngModel);
        this.elementRef.nativeElement.value = this.timePipe.transform(this.elementRef.nativeElement.value);
    }
    registerOnChange(fn) {
        this.onChange = fn;
    }
    registerOnTouched(fn) {
        this.onTouched = fn;
    }
    format(value) {
        value = value.toString().replace(/[^0-9]+/g, '');
        return value.substring(0, 4);
    }
    validate(control) {
        this.control = control;
        if (control.value && this.format(control.value).length < 4) {
            return { parse: true };
        }
        if (control.value) {
            const time = control.value.split(':');
            if (!this.customTime && time[0] > 23) {
                return { hour: true };
            }
            if (!this.customTime && time[1] > 59) {
                return { minute: true };
            }
            if (this.minTime && this.format(this.minTime).length === 4 && this.format(control.value) < this.format(this.minTime)) {
                return { minTime: true };
            }
            if (this.maxTime && this.format(this.maxTime).length === 4 && this.format(control.value) > this.format(this.maxTime)) {
                return { maxTime: true };
            }
        }
        return null;
    }
    setDisabledState(isDisabled) {
        const method = isDisabled ? 'setAttribute' : 'removeAttribute';
        this.elementRef.nativeElement[method]('disabled', 'disabled');
    }
    onKeydown() {
        this.beforeSelIndex = UiElement.caretPosition.get(this.elementRef.nativeElement);
    }
    onInput() {
        const afterSelIndex = UiElement.caretPosition.get(this.elementRef.nativeElement);
        const rawValue = this.elementRef.nativeElement.value;
        this.input = true;
        this.renderViaInput(rawValue);
        UiElement.caretPosition.set(this.elementRef.nativeElement, this.beforeSelIndex, afterSelIndex, this.symbolsPositions);
    }
};
UiMaskTimeDirective.ctorParameters = () => [
    { type: ElementRef },
    { type: UiTimePipe }
];
__decorate([
    Input(),
    __metadata("design:type", Object)
], UiMaskTimeDirective.prototype, "ngModel", void 0);
__decorate([
    Input(),
    __metadata("design:type", String)
], UiMaskTimeDirective.prototype, "minTime", void 0);
__decorate([
    Input(),
    __metadata("design:type", String)
], UiMaskTimeDirective.prototype, "maxTime", void 0);
__decorate([
    Input(),
    __metadata("design:type", Boolean)
], UiMaskTimeDirective.prototype, "customTime", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], UiMaskTimeDirective.prototype, "ngModelChange", void 0);
__decorate([
    HostListener('keydown'),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", void 0)
], UiMaskTimeDirective.prototype, "onKeydown", null);
__decorate([
    HostListener('input'),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", void 0)
], UiMaskTimeDirective.prototype, "onInput", null);
UiMaskTimeDirective = UiMaskTimeDirective_1 = __decorate([
    Directive({
        selector: '[uiMaskTime][ngModel]',
        providers: [{
                provide: NG_VALUE_ACCESSOR,
                useExisting: forwardRef(() => UiMaskTimeDirective_1),
                multi: true
            }, {
                provide: NG_VALIDATORS,
                useExisting: forwardRef(() => UiMaskTimeDirective_1),
                multi: true
            }, UiTimePipe]
    }),
    __metadata("design:paramtypes", [ElementRef, UiTimePipe])
], UiMaskTimeDirective);

let UiCurrencyPipe = class UiCurrencyPipe {
    transform(value, args) {
        if (!value && typeof value !== 'number') {
            return '';
        }
        if (typeof value === 'number') {
            value = value.toFixed(2);
        }
        const isNegative = !(value.toString().match(/[+]/) || !value.toString().match(/[-]/));
        // Verifica se há valor no model (permite remover o '0,00')
        const noValue = value.length === 3 && value.replace(',', '').split('').every(n => n === '0');
        // Removendo o que não é dígito qualquer zero adicional no começo da string
        value = value.toString().replace(/[^0-9]+/g, '').replace(/^0+/g, '');
        // Adiciona os zeros necessários à esquerda devido a formatação de dinheiro, caso haja valor na model
        if (!noValue) {
            while (value.length < 3) {
                value = '0' + value.toString();
            }
        }
        let newCurrency = '';
        value = value.split('');
        for (let i = 0; i < value.length; i++) {
            const valueChar = value[value.length - 1 - i];
            if (i === 2) {
                newCurrency = ',' + newCurrency;
            }
            else if (i > 3 && !((i - 2) % 3)) {
                newCurrency = '.' + newCurrency;
            }
            newCurrency = valueChar + newCurrency;
        }
        // ADICIONANDO O SINAL NEGATIVO
        if (args && args.noNegative) {
            return newCurrency;
        }
        return isNegative ? '-' + newCurrency : newCurrency;
    }
};
UiCurrencyPipe = __decorate([
    Pipe({
        name: 'uiCurrency'
    })
], UiCurrencyPipe);

var UiMaskCurrencyDirective_1;
let UiMaskCurrencyDirective = UiMaskCurrencyDirective_1 = class UiMaskCurrencyDirective {
    constructor(elementRef, currencyPipe) {
        this.elementRef = elementRef;
        this.currencyPipe = currencyPipe;
        this.ngModelChange = new EventEmitter();
    }
    ngOnChanges(changes) {
        if (changes.ngModel && !changes.ngModel.firstChange && (changes.ngModel.currentValue === null || changes.ngModel.currentValue === undefined)) {
            this.elementRef.nativeElement.value = '';
        }
        if (typeof changes.max !== 'undefined') {
            this.max = changes.max.currentValue;
        }
        if (typeof changes.min !== 'undefined') {
            this.min = changes.min.currentValue;
        }
    }
    ngAfterViewInit() {
        setTimeout(() => {
            this.loaded = true;
        });
    }
    writeValue(rawValue) {
        if (this.control && this.loaded && rawValue) {
            this.control.markAsDirty();
        }
        if (!this.input) {
            this.elementRef.nativeElement.value = this.formatViewValue(this.ngModel);
        }
        this.input = false;
    }
    renderViaInput(rawValue) {
        if (rawValue) {
            this.control.markAsDirty();
        }
        this.ngModel = this.format(rawValue);
        this.ngModelChange.emit(this.ngModel);
        this.elementRef.nativeElement.value = this.formatViewValue(this.elementRef.nativeElement.value);
    }
    registerOnChange(fn) {
        this.onChange = fn;
    }
    registerOnTouched(fn) {
        this.onTouched = fn;
    }
    format(value) {
        value = this.currencyPipe.transform(value, { noNegative: this.noNegative });
        const removeGroupSep = new RegExp('[^\\d\\,-]+', 'g');
        value = value.toString().replace(removeGroupSep, '');
        value = parseFloat(value.replace(',', '.'));
        return typeof value === 'number' && !isNaN(value) ? value : null;
    }
    formatViewValue(value) {
        const isDeletingZero = this.beforeViewValue === ('0,00') && value.length < this.beforeViewValue.length;
        value = isDeletingZero ? '' : value;
        return this.currencyPipe.transform(value, { noNegative: this.noNegative });
    }
    validate(control) {
        this.control = control;
        // if (control.value && this.format(control.value).length < 11) {
        //     return {parse: true};
        // }
        if (typeof this.min !== 'undefined' && control.value && this.format(control.value) < this.min) {
            return { min: true };
        }
        if (typeof this.max !== 'undefined' && control.value && this.format(control.value) > this.max) {
            return { max: true };
        }
        return null;
    }
    setDisabledState(isDisabled) {
        const method = isDisabled ? 'setAttribute' : 'removeAttribute';
        this.elementRef.nativeElement[method]('disabled', 'disabled');
    }
    onKeydown() {
        this.beforeSelIndex = UiElement.caretPosition.get(this.elementRef.nativeElement);
    }
    onInput($event) {
        // const afterSelIndex = UiElement.caretPosition.get(this.elementRef.nativeElement);
        const rawValue = this.elementRef.nativeElement.value;
        this.input = true;
        this.beforeViewValue = rawValue;
        this.renderViaInput(rawValue);
        // UiElement.caretPosition.set(this.elementRef.nativeElement, this.beforeSelIndex, afterSelIndex, this.symbolsPositions);
    }
};
UiMaskCurrencyDirective.ctorParameters = () => [
    { type: ElementRef },
    { type: UiCurrencyPipe }
];
__decorate([
    Input(),
    __metadata("design:type", Object)
], UiMaskCurrencyDirective.prototype, "ngModel", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], UiMaskCurrencyDirective.prototype, "ngModelChange", void 0);
__decorate([
    Input(),
    __metadata("design:type", Number)
], UiMaskCurrencyDirective.prototype, "min", void 0);
__decorate([
    Input(),
    __metadata("design:type", Number)
], UiMaskCurrencyDirective.prototype, "max", void 0);
__decorate([
    Input(),
    __metadata("design:type", Boolean)
], UiMaskCurrencyDirective.prototype, "noNegative", void 0);
__decorate([
    HostListener('keydown'),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", void 0)
], UiMaskCurrencyDirective.prototype, "onKeydown", null);
__decorate([
    HostListener('input', ['$event']),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [Object]),
    __metadata("design:returntype", void 0)
], UiMaskCurrencyDirective.prototype, "onInput", null);
UiMaskCurrencyDirective = UiMaskCurrencyDirective_1 = __decorate([
    Directive({
        selector: '[uiMaskCurrency][ngModel]',
        providers: [{
                provide: NG_VALUE_ACCESSOR,
                useExisting: forwardRef(() => UiMaskCurrencyDirective_1),
                multi: true
            }, {
                provide: NG_VALIDATORS,
                useExisting: forwardRef(() => UiMaskCurrencyDirective_1),
                multi: true
            }, UiCurrencyPipe]
    }),
    __metadata("design:paramtypes", [ElementRef, UiCurrencyPipe])
], UiMaskCurrencyDirective);

var UiDialog_1;
let viewRef;
let UiDialog = UiDialog_1 = class UiDialog {
    static show(dialog, config) {
        UiDialog_1.hide();
        config = config || {};
        if (config.clickOverlayToClose === undefined) {
            config.clickOverlayToClose = true;
        }
        else if (config.clickOverlayToClose) {
            config.clickOverlayToClose = JSON.parse(config.clickOverlayToClose);
        }
        viewRef = dialog.templateRef.createEmbeddedView(dialog.templateRef);
        viewRef.detectChanges();
        viewRef.rootNodes.forEach(rootNode => {
            document.body.appendChild(rootNode);
            if (rootNode.clientWidth) {
                UiDialog_1.open(rootNode, config);
            }
        });
    }
    static open(element, config) {
        setTimeout(() => {
            const fabs = new UiElementRef(document).querySelector('.ui-fab-container');
            if (config.darkClass) {
                element.classList.add(config.darkClass);
            }
            if (config.themeClass) {
                element.classList.add(config.themeClass);
            }
            if (config.transparentOverlay) {
                element.classList.add('transparent-overlay');
            }
            if (config.cardSize) {
                element.querySelector('ui-card').style.maxWidth = config.cardSize + 'px';
                element.querySelector('ui-card').style.width = '100%';
            }
            if (!config.transparentOverlay && fabs.length) {
                fabs.classList.add('hide');
            }
            if (config.clickOverlayToClose) {
                element.querySelector('.overlay').addEventListener('click', () => {
                    if (typeof config.onClose === 'function') {
                        config.onClose();
                    }
                    UiDialog_1.hide();
                });
            }
            element.style.transform = '';
            element.classList.add('open');
            document.body.style.overflowY = 'hidden';
        });
    }
    static hide() {
        if (viewRef) {
            const fabs = new UiElementRef(document).querySelector('.ui-fab-container');
            if (fabs.length) {
                fabs.classList.remove('hide');
            }
            viewRef.rootNodes.forEach(rootNode => {
                if (rootNode.classList) {
                    rootNode.classList.remove('open');
                }
            });
            setTimeout(() => {
                viewRef.rootNodes.forEach(rootNode => {
                    if (rootNode.remove) {
                        rootNode.remove();
                    }
                    else {
                        rootNode.parentNode.removeChild(rootNode);
                    }
                });
                viewRef.destroy();
                viewRef = null;
            }, 280);
            document.body.style.overflowY = '';
        }
    }
};
UiDialog = UiDialog_1 = __decorate([
    Injectable()
], UiDialog);

var UiSelectComponent_1;
let UiSelectComponent = UiSelectComponent_1 = class UiSelectComponent {
    constructor(element, viewContainerRef) {
        this.element = element;
        this.viewContainerRef = viewContainerRef;
        this.ngModelChange = new EventEmitter();
        this.isMobile = UiElement.isMobile;
        this.options = [];
        this.optionsExternal = [];
    }
    ngOnInit() {
        this.element.nativeElement.setAttribute('tabindex', 0);
        this.selectOption();
    }
    ngAfterViewInit() {
    }
    ngOnChanges(changes) {
        this.element.nativeElement.setAttribute('disabled', this.disabled);
        if (changes.options || changes.ngModel) {
            this.selectOption();
        }
        if (changes.ngModel && !changes.ngModel.firstChange) {
            this.ngModel = changes.ngModel.currentValue;
            if (changes.ngModel.currentValue) {
                this.selectOption();
            }
            else {
                this.onChangeSelect(changes.ngModel.currentValue);
            }
        }
    }
    onFocus() {
        this.close();
        const closestFieldset = UiElement.closest(this.element.nativeElement, 'fieldset:disabled');
        if (!this.disabled && !closestFieldset) {
            if (this.isMobile()) {
                this.selectNative.nativeElement.focus();
            }
            else {
                setTimeout(() => {
                    const position = UiElement.position(this.element.nativeElement);
                    const coordinate = {
                        x: position.left,
                        y: position.top
                    };
                    this.render(coordinate);
                });
            }
        }
        else {
            this.element.nativeElement.blur();
        }
    }
    onBlur(event) {
        if (!event.relatedTarget || !(UiElement.is(event.relatedTarget, 'ui-select-option') || UiElement.closest(event.relatedTarget, '.wrap-select'))) {
            this.close();
        }
    }
    render(coordinate) {
        this.viewRef = this.viewContainerRef.createEmbeddedView(this.templateRef);
        this.viewRef.detectChanges();
        this.viewRef.rootNodes.forEach(rootNode => {
            document.body.appendChild(rootNode);
            if (rootNode.clientWidth) {
                this.open(rootNode, coordinate);
            }
        });
    }
    open(element, coordinate) {
        setTimeout(() => {
            const horizontalCoveringArea = coordinate.x + element.clientWidth;
            const verticalCoveringArea = coordinate.y + element.clientHeight;
            const windowWidth = window.innerWidth + (window.scrollX || window.pageXOffset);
            const windowHeight = document.body.clientHeight + (window.scrollY || window.pageYOffset);
            if (horizontalCoveringArea > windowWidth) {
                coordinate.x = windowWidth - (element.clientWidth + 8);
            }
            if (coordinate.x <= 8) {
                coordinate.x = 8;
            }
            if (verticalCoveringArea > windowHeight) {
                coordinate.y = windowHeight - (element.clientHeight + 8);
            }
            if (coordinate.y <= 0) {
                coordinate.y = 0;
            }
            if (this.darkClass) {
                element.classList.add(this.darkClass);
            }
            element.style.transform = '';
            // element.querySelector('ui-card').style.maxHeight = window.innerHeight + 'px';
            element.style.top = coordinate.y + 'px';
            element.style.left = coordinate.x + 'px';
            element.style.left = coordinate.x + 'px';
            element.style.width = this.element.nativeElement.clientWidth + 'px';
            element.querySelector('.selected').addEventListener('blur', (event) => {
                if (!event.relatedTarget || !(UiElement.is(event.relatedTarget, 'ui-select-option') || UiElement.is(event.relatedTarget, '.input-select'))) {
                    this.close();
                }
            });
            if (this.chosen) {
                element.querySelector('.input-select').addEventListener('blur', (event) => {
                    if (!event.relatedTarget || !(UiElement.is(event.relatedTarget, 'ui-select-option') || UiElement.is(event.relatedTarget, '.selected'))) {
                        this.close();
                    }
                });
                element.querySelector('.input-select').click();
                element.scrollTo(0, 0);
            }
            else {
                element.querySelector('.selected').focus();
            }
            element.classList.add('open');
        });
    }
    close() {
        if (this.viewContainerRef.length) {
            const viewRef = this.viewRef; // Salvando a referência para achar o index deste componente
            viewRef.rootNodes.forEach(rootNode => {
                if (rootNode.classList) {
                    rootNode.classList.remove('open');
                }
            });
            setTimeout(() => this.viewContainerRef.remove(this.viewContainerRef.indexOf(viewRef)), 280);
        }
    }
    onChangeSelect(select) {
        if (select) {
            this.model = select[this.value];
            this.selected = select[this.label];
            this.ngModelChange.emit(select[this.value]);
        }
        else {
            this.search = select;
            this.model = select;
            this.selected = select;
            this.ngModelChange.emit(select);
        }
    }
    selectOption() {
        this.options.forEach(option => {
            if (option[this.value] === this.ngModel) {
                this.onChangeSelect(option);
            }
        });
    }
    writeValue() {
    }
    registerOnChange() {
    }
    registerOnTouched() {
    }
};
UiSelectComponent.ctorParameters = () => [
    { type: ElementRef },
    { type: ViewContainerRef }
];
__decorate([
    Input('dark-class'),
    __metadata("design:type", Object)
], UiSelectComponent.prototype, "darkClass", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], UiSelectComponent.prototype, "input", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], UiSelectComponent.prototype, "disabled", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], UiSelectComponent.prototype, "chosen", void 0);
__decorate([
    Output(),
    __metadata("design:type", Object)
], UiSelectComponent.prototype, "ngModelChange", void 0);
__decorate([
    ViewChild(TemplateRef),
    __metadata("design:type", TemplateRef)
], UiSelectComponent.prototype, "templateRef", void 0);
__decorate([
    ViewChild('selectNative', { static: true }),
    __metadata("design:type", Object)
], UiSelectComponent.prototype, "selectNative", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], UiSelectComponent.prototype, "value", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], UiSelectComponent.prototype, "label", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], UiSelectComponent.prototype, "options", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], UiSelectComponent.prototype, "ngModel", void 0);
__decorate([
    ViewChild(NgModel),
    __metadata("design:type", NgModel)
], UiSelectComponent.prototype, "model", void 0);
__decorate([
    HostListener('focus'),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", void 0)
], UiSelectComponent.prototype, "onFocus", null);
__decorate([
    HostListener('blur', ['$event']),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [Object]),
    __metadata("design:returntype", void 0)
], UiSelectComponent.prototype, "onBlur", null);
UiSelectComponent = UiSelectComponent_1 = __decorate([
    Component({
        selector: 'ui-select',
        template: "<div class=\"selected\">{{selected}}</div>\r\n<ng-template>\r\n    <div class=\"wrap-select\">\r\n        <div class=\"wrap-select-inner\">\r\n            <div class=\"selected\" tabindex=\"0\" (click)=\"close()\">{{selected}}</div>\r\n            <div class=\"ui-divider\"></div>\r\n            <div *ngIf=\"chosen\">\r\n                <div class=\"input-select-space\">\r\n                    <input type=\"text\" [(ngModel)]=\"search\" class=\"input-select\">\r\n                </div>\r\n                <div class=\"ui-divider\"></div>\r\n            </div>\r\n            <div class=\"options\">\r\n                <ng-content></ng-content>\r\n                <ui-select-option *ngFor=\"let item of optionsExternal\" [value]=\"value\" [label]=\"label\"\r\n                                  uiRipple></ui-select-option>\r\n                <ui-select-option *ngFor=\"let item of options | selectFilter : search : label\" [value]=\"item[value]\"\r\n                                  [label]=\"item[label]\" [internal]=\"true\"\r\n                                  uiRipple></ui-select-option>\r\n            </div>\r\n        </div>\r\n    </div>\r\n</ng-template>\r\n\r\n<div [hidden]=\"!options || !isMobile()\">\r\n    <select #selectNative\r\n            style=\"transform: scale(1); position: absolute; left: 0; top: 0; width: 100%; height: 100%; opacity: 0\"\r\n            [(ngModel)]=\"selectedNative\"\r\n            (change)=\"onChangeSelect(selectedNative)\">\r\n        <option *ngFor=\"let option of options\" [ngValue]=\"option\">\r\n            {{option ? option[label] : null}}\r\n        </option>\r\n    </select>\r\n</div>\r\n",
        providers: [{
                provide: NG_VALUE_ACCESSOR,
                useExisting: UiSelectComponent_1,
                multi: true,
            }],
        styles: [":host{border-radius:2px;height:36px;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;cursor:default;display:flex;align-items:center;padding:9px;position:relative;font-size:16px}::ng-deep .wrap-select{display:block;border-radius:2px;overflow:hidden;max-height:36px;transition:max-height 280ms cubic-bezier(0,0,.2,1),box-shadow 280ms cubic-bezier(0,0,.2,1);position:absolute;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;cursor:default;z-index:5}::ng-deep .wrap-select.open{max-height:216px;box-shadow:0 8px 10px 1px rgba(0,0,0,.14),0 3px 14px 3px rgba(0,0,0,.12),0 4px 15px 0 rgba(0,0,0,.2)}::ng-deep .wrap-select .selected{height:36px;display:flex;align-items:center;padding:9px}::ng-deep .wrap-select .ui-divider{margin:0}::ng-deep .wrap-select .options{overflow-y:auto;max-height:140px}::ng-deep .wrap-select .input-select-space{padding:3px;height:36px}::ng-deep .wrap-select .input-select-space input{border-radius:2px;height:100%;width:100%;padding:0 5px}"]
    }),
    __metadata("design:paramtypes", [ElementRef, ViewContainerRef])
], UiSelectComponent);

let UiSelectOptionComponent = class UiSelectOptionComponent {
    constructor(selectComponent, element) {
        this.selectComponent = selectComponent;
        this.element = element;
    }
    ngOnInit() {
        this.element.nativeElement.setAttribute('tabindex', 0);
        if (!this.internal) {
            this.selectComponent.optionsExternal.push({
                value: this.value,
                title: this.label
            });
        }
    }
    onClick() {
        this.selectComponent.ngModelChange.next(this.value);
        this.selectComponent.model = this.value;
        this.selectComponent.selected = this.label;
        this.element.nativeElement.blur();
    }
    onEnter(e) {
        if (e.keyCode === 13) {
            this.element.nativeElement.click();
        }
    }
    onBlur(event) {
        if (!event.relatedTarget || !(UiElement.is(event.relatedTarget, 'ui-select-option') || UiElement.is(event.relatedTarget, '.selected') || UiElement.is(event.relatedTarget, '.input-select'))) {
            this.selectComponent.close();
        }
    }
};
UiSelectOptionComponent.ctorParameters = () => [
    { type: UiSelectComponent, decorators: [{ type: Inject, args: [UiSelectComponent,] }] },
    { type: ElementRef }
];
__decorate([
    Input(),
    __metadata("design:type", Object)
], UiSelectOptionComponent.prototype, "value", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], UiSelectOptionComponent.prototype, "label", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], UiSelectOptionComponent.prototype, "internal", void 0);
__decorate([
    HostListener('click'),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", void 0)
], UiSelectOptionComponent.prototype, "onClick", null);
__decorate([
    HostListener('keydown', ['$event']),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [Object]),
    __metadata("design:returntype", void 0)
], UiSelectOptionComponent.prototype, "onEnter", null);
__decorate([
    HostListener('blur', ['$event']),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [Object]),
    __metadata("design:returntype", void 0)
], UiSelectOptionComponent.prototype, "onBlur", null);
UiSelectOptionComponent = __decorate([
    Component({
        selector: 'ui-select-option',
        template: "{{label}}\r\n",
        styles: [":host{height:36px;display:flex;align-items:center;padding:9px}:host:focus{background-color:rgba(0,0,0,.1)}"]
    }),
    __param(0, Inject(UiSelectComponent)),
    __metadata("design:paramtypes", [UiSelectComponent, ElementRef])
], UiSelectOptionComponent);

let UiSelectFilterPipe = class UiSelectFilterPipe {
    transform(value, filterBy, name) {
        filterBy = filterBy ? unaccent(filterBy.toLowerCase()) : null;
        return filterBy ? value.filter(item => unaccent(item[name].toLowerCase()).indexOf(filterBy) !== -1) : value;
    }
};
UiSelectFilterPipe = __decorate([
    Pipe({
        name: 'selectFilter',
        pure: false
    })
], UiSelectFilterPipe);

let UiFilterPipe = class UiFilterPipe {
    transform(value, filterBy, name) {
        filterBy = filterBy ? unaccent(filterBy.toLowerCase()) : null;
        return filterBy ? value.filter(item => unaccent(item[name].toLowerCase()).indexOf(filterBy) !== -1) : value;
    }
};
UiFilterPipe = __decorate([
    Pipe({
        name: 'uiFilter',
        pure: false
    })
], UiFilterPipe);

let UiAvatarComponent = class UiAvatarComponent {
    constructor(element) {
        this.element = element;
        this.nameLength = 1;
        this.initials = false;
    }
    ngOnInit() {
        this.newImage = this.image;
    }
    ngAfterViewInit() {
        this.setSize();
    }
    ngOnChanges(changes) {
        if (changes.name && !changes.name.firstChange) {
            this.name = changes.name.currentValue;
        }
        if (changes.color && !changes.color.firstChange) {
            this.color = changes.color.currentValue;
        }
        if (changes.image && !changes.image.firstChange) {
            if (!changes.image.currentValue) {
                this.showImage = false;
                this.newImage = null;
            }
            this.image = changes.image.currentValue;
        }
        if (changes.size && !changes.size.firstChange) {
            this.size = changes.size.currentValue;
            this.setSize();
        }
        if (changes.nameLength && !changes.nameLength.firstChange) {
            this.nameLength = changes.nameLength.currentValue;
        }
    }
    isBright(color) {
        return UiColor.isBright(color);
    }
    loadedImage() {
        this.showImage = true;
        this.animateImage();
    }
    animateImage() {
        this.grayscale = true;
        setTimeout(() => {
            this.grayscale = false;
            this.newImage = this.image;
        }, 1120);
    }
    setSize() {
        if (this.size) {
            const wrap = this.element.nativeElement.querySelector('.wrap');
            const empty = this.element.nativeElement.querySelector('.empty');
            if (empty) {
                UiElement.css(empty, 'font-size', `${Math.round(this.size / 100 * 36.36)}px`);
            }
            UiElement.css(wrap, 'width', `${this.size}px`);
            UiElement.css(wrap, 'height', `${this.size}px`);
        }
    }
    getFontSize() {
        return Math.round(this.size / 100 * 36.36);
    }
    getName() {
        if (this.name) {
            if (this.initials) {
                const ini = this.name.trim().split(' ').map((nome) => { return nome.charAt(0).toUpperCase(); });
                return ini[0] + ini[ini.length - 1];
            }
            else {
                return this.name.trim().substr(0, this.nameLength).toUpperCase();
            }
        }
        else {
            return '';
        }
    }
};
UiAvatarComponent.ctorParameters = () => [
    { type: ElementRef }
];
__decorate([
    Input(),
    __metadata("design:type", String)
], UiAvatarComponent.prototype, "name", void 0);
__decorate([
    Input(),
    __metadata("design:type", String)
], UiAvatarComponent.prototype, "color", void 0);
__decorate([
    Input(),
    __metadata("design:type", String)
], UiAvatarComponent.prototype, "image", void 0);
__decorate([
    Input(),
    __metadata("design:type", Number)
], UiAvatarComponent.prototype, "size", void 0);
__decorate([
    Input(),
    __metadata("design:type", Number)
], UiAvatarComponent.prototype, "nameLength", void 0);
__decorate([
    Input(),
    __metadata("design:type", Boolean)
], UiAvatarComponent.prototype, "initials", void 0);
UiAvatarComponent = __decorate([
    Component({
        selector: 'ui-avatar',
        template: "<img [src]=\"image\" (load)=\"loadedImage()\" *ngIf=\"image\">\r\n<div class=\"wrap\" [class.grayscale]=\"grayscale\">\r\n    <div class=\"empty\" [ngStyle]=\"{'background-color': color, 'color': isBright(color) ? '#000' : '#FFF', 'font-size': getFontSize() + 'px'}\" *ngIf=\"!showImage\">\r\n        {{ getName() }}\r\n    </div>\r\n    <div class=\"profile\" [style.background-image]=\"'url(' + newImage + ')'\" [@image] *ngIf=\"showImage\"></div>\r\n    <div class=\"profile\" [style.background-image]=\"'url(' + image + ')'\" [@image] *ngIf=\"grayscale\"></div>\r\n</div>\r\n",
        changeDetection: ChangeDetectionStrategy.OnPush,
        animations: [trigger('image', [
                transition(':enter', [
                    style({
                        opacity: 0,
                    }),
                    animate('280ms cubic-bezier(0.0, 0.0, 0.2, 1)', style({
                        opacity: 1
                    }))
                ]),
                transition(':leave', [
                    style({
                        opacity: 1,
                    }),
                    animate('2800ms cubic-bezier(0.0, 0.0, 0.2, 1)', style({
                        opacity: 0,
                    }))
                ])
            ]), trigger('letter', [
                transition(':leave', [
                    style({
                        opacity: 1,
                    }),
                    animate('280ms cubic-bezier(0.0, 0.0, 0.2, 1)', style({
                        opacity: 0,
                    }))
                ])
            ])],
        styles: [":host{display:block}img{display:none}.wrap{width:44px;height:44px;margin:4px;position:relative}.empty,.profile{position:absolute;top:0;left:0;right:0;bottom:0;border-radius:50%}.empty{display:flex;align-items:center;justify-content:center;font-size:16px;transition:background 280ms cubic-bezier(0,0,.2,1),color 280ms cubic-bezier(0,0,.2,1)}.profile{background-size:cover;background-position:center}.grayscale{-webkit-animation:960ms cubic-bezier(0,0,.2,1) 160ms forwards grayscale;animation:960ms cubic-bezier(0,0,.2,1) 160ms forwards grayscale;filter:grayscale(100%)}@-webkit-keyframes grayscale{100%{filter:grayscale(0)}}@keyframes grayscale{100%{filter:grayscale(0)}}"]
    }),
    __metadata("design:paramtypes", [ElementRef])
], UiAvatarComponent);

let UiFloatPipe = class UiFloatPipe {
    transform(value, decimal = null, noNegative) {
        if (!value && typeof value !== 'number') {
            return '';
        }
        if (!decimal || isNaN(decimal)) {
            const decimals = value.toString().split('.');
            decimal = decimals.length > 1 ? decimals[1].length : 0;
        }
        if (typeof value === 'number') {
            value = value.toFixed(decimal);
        }
        const isNegative = !(value.toString().match(/[+]/) || !value.toString().match(/[-]/));
        // Verifica se há valor no model (permite remover o '0,00')
        const noValue = decimal && value.length === (decimal + 1) && value.replace(',', '').split('').every(n => n === '0');
        // Removendo o que não é dígito qualquer zero adicional no começo da string
        value = value.toString().replace(/[^0-9]+/g, '').replace(/^0+/g, '');
        // Adiciona os zeros necessários à esquerda, caso haja valor na model
        if (!noValue) {
            while (value.length < (decimal + 1)) {
                value = '0' + value.toString();
            }
        }
        let newValue = '';
        value = value.split('');
        for (let i = 0; i < value.length; i++) {
            const valueChar = value[value.length - 1 - i];
            if (decimal && i === decimal) {
                newValue = ',' + newValue;
            }
            else if (i > decimal &&
                !((i - decimal) % 3)) {
                newValue = '.' + newValue;
            }
            newValue = valueChar + newValue;
        }
        // ADICIONANDO O SINAL NEGATIVO
        if (noNegative) {
            return newValue;
        }
        return isNegative ? '-' + newValue : newValue;
    }
};
UiFloatPipe = __decorate([
    Pipe({
        name: 'uiFloat'
    })
], UiFloatPipe);

var UiMaskFloatDirective_1;
let UiMaskFloatDirective = UiMaskFloatDirective_1 = class UiMaskFloatDirective {
    constructor(elementRef, floatPipe) {
        this.elementRef = elementRef;
        this.floatPipe = floatPipe;
        this.uiMaskFloat = 2;
        this.ngModelChange = new EventEmitter();
        this.decimal = this.uiMaskFloat;
    }
    ngOnChanges(changes) {
        if (changes.ngModel && !changes.ngModel.firstChange && (changes.ngModel.currentValue === null || changes.ngModel.currentValue === undefined)) {
            this.elementRef.nativeElement.value = '';
        }
        if (typeof changes.uiMaskFloat !== 'undefined') {
            this.uiMaskFloat = changes.uiMaskFloat.currentValue || 2;
            this.decimal = this.uiMaskFloat;
        }
        if (typeof changes.decimal !== 'undefined') {
            this.decimal = changes.decimal.currentValue || 2;
            this.uiMaskFloat = this.decimal;
        }
        if (typeof changes.max !== 'undefined') {
            this.max = changes.max.currentValue;
        }
        if (typeof changes.min !== 'undefined') {
            this.min = changes.min.currentValue;
        }
    }
    ngAfterViewInit() {
        setTimeout(() => {
            this.loaded = true;
        });
    }
    writeValue(rawValue) {
        if (this.control && this.loaded && rawValue) {
            this.control.markAsDirty();
        }
        if (!this.input) {
            this.elementRef.nativeElement.value = this.formatViewValue(this.ngModel);
        }
        this.input = false;
    }
    renderViaInput(rawValue) {
        if (rawValue) {
            this.control.markAsDirty();
        }
        this.ngModel = this.format(rawValue);
        this.ngModelChange.emit(this.ngModel);
        this.elementRef.nativeElement.value =
            this.formatViewValue(this.elementRef.nativeElement.value);
    }
    registerOnChange(fn) {
        this.onChange = fn;
    }
    registerOnTouched(fn) {
        this.onTouched = fn;
    }
    format(value) {
        value = this.floatPipe.transform(value, +this.decimal, this.noNegative);
        const removeGroupSep = new RegExp('[^\\d\\,-]+', 'g');
        value = value.toString().replace(removeGroupSep, '');
        value = parseFloat(value.replace(',', '.'));
        return typeof value === 'number' && !isNaN(value) ? value : null;
    }
    formatViewValue(value) {
        let standard = '0,';
        standard = standard.padEnd(+this.decimal + 2, '0');
        const isDeletingZero = this.beforeViewValue === (standard) && value.length < this.beforeViewValue.length;
        value = isDeletingZero ? '' : value;
        return this.floatPipe.transform(value, +this.decimal, this.noNegative);
    }
    validate(control) {
        this.control = control;
        if (typeof this.min !== 'undefined' && control.value && this.format(control.value) < this.min) {
            return { min: true };
        }
        if (typeof this.max !== 'undefined' && control.value && this.format(control.value) > this.max) {
            return { max: true };
        }
        return null;
    }
    setDisabledState(isDisabled) {
        const method = isDisabled ? 'setAttribute' : 'removeAttribute';
        this.elementRef.nativeElement[method]('disabled', 'disabled');
    }
    onKeydown() {
        this.beforeSelIndex = UiElement.caretPosition.get(this.elementRef.nativeElement);
    }
    onInput($event) {
        const rawValue = this.elementRef.nativeElement.value;
        this.input = true;
        this.beforeViewValue = rawValue;
        this.renderViaInput(rawValue);
    }
};
UiMaskFloatDirective.ctorParameters = () => [
    { type: ElementRef },
    { type: UiFloatPipe }
];
__decorate([
    Input(),
    __metadata("design:type", Number)
], UiMaskFloatDirective.prototype, "uiMaskFloat", void 0);
__decorate([
    Input(),
    __metadata("design:type", Number)
], UiMaskFloatDirective.prototype, "decimal", void 0);
__decorate([
    Input(),
    __metadata("design:type", Number)
], UiMaskFloatDirective.prototype, "max", void 0);
__decorate([
    Input(),
    __metadata("design:type", Number)
], UiMaskFloatDirective.prototype, "min", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], UiMaskFloatDirective.prototype, "ngModel", void 0);
__decorate([
    Input(),
    __metadata("design:type", Boolean)
], UiMaskFloatDirective.prototype, "noNegative", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], UiMaskFloatDirective.prototype, "ngModelChange", void 0);
__decorate([
    HostListener('keydown'),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", void 0)
], UiMaskFloatDirective.prototype, "onKeydown", null);
__decorate([
    HostListener('input', ['$event']),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [Object]),
    __metadata("design:returntype", void 0)
], UiMaskFloatDirective.prototype, "onInput", null);
UiMaskFloatDirective = UiMaskFloatDirective_1 = __decorate([
    Directive({
        selector: '[uiMaskFloat][ngModel]',
        providers: [{
                provide: NG_VALUE_ACCESSOR,
                useExisting: forwardRef(() => UiMaskFloatDirective_1),
                multi: true
            }, {
                provide: NG_VALIDATORS,
                useExisting: forwardRef(() => UiMaskFloatDirective_1),
                multi: true
            }, UiFloatPipe]
    }),
    __metadata("design:paramtypes", [ElementRef, UiFloatPipe])
], UiMaskFloatDirective);

/**
 * TODO: Persist tooltip.
 * */
let TooltipDirective = class TooltipDirective {
    constructor(element) {
        this.element = element;
        this.onShow = (event) => {
            this.show(event);
        };
        this.onHide = () => {
            this.hide();
        };
    }
    ngOnInit() {
        if (!this.top && !this.left && !this.right) {
            this.bottom = true;
        }
    }
    ngAfterViewInit() {
        UiElement.on(this.element.nativeElement, 'mouseenter', this.onShow);
        UiElement.on(this.element.nativeElement, 'mouseleave', this.onHide);
    }
    ngOnDestroy() {
        UiElement.off(this.element.nativeElement, 'mouseenter', this.onShow);
        UiElement.off(this.element.nativeElement, 'mouseleave', this.onHide);
        this.hide();
    }
    setClass() {
        if (this.top) {
            this.class = 'top';
        }
        if (this.left) {
            this.class = 'left';
        }
        if (this.right) {
            this.class = 'right';
        }
        if (this.bottom) {
            this.class = 'bottom';
        }
    }
    show(event) {
        if (!this.uiTooltip) {
            return;
        }
        this.setClass();
        this.wrap = document.createElement('div');
        this.wrap.classList.add('wrap-tooltip', this.class);
        this.wrap.innerText = this.uiTooltip;
        document.body.appendChild(this.wrap);
        const elementPosition = UiElement.position(this.element.nativeElement);
        let positionLeft;
        let positionTop;
        if (this.top || this.bottom) {
            positionLeft = (elementPosition.left + this.element.nativeElement.clientWidth / 2) - (this.wrap.clientWidth / 2);
            positionLeft = positionLeft > 0 ? positionLeft : 0;
            positionTop = elementPosition.top;
            const checkHeight = window.innerHeight - 32 >= this.element.nativeElement.clientHeight + positionTop;
            if (this.bottom && checkHeight) {
                positionTop += this.element.nativeElement.clientHeight;
            }
            else {
                positionTop -= this.wrap.clientHeight;
            }
        }
        if (this.left || this.right) {
            positionTop = (elementPosition.top + this.element.nativeElement.clientHeight / 2) - (this.wrap.clientHeight / 2);
            positionLeft = elementPosition.left;
            if (this.left && positionLeft >= this.wrap.clientWidth) {
                positionLeft -= this.wrap.clientWidth;
            }
            else {
                positionLeft += this.element.nativeElement.clientWidth;
            }
        }
        UiElement.css(this.wrap, 'left', `${Math.round(positionLeft)}px`);
        UiElement.css(this.wrap, 'top', `${Math.round(positionTop)}px`);
        setTimeout(() => this.wrap && this.wrap.classList.add('show'));
    }
    hide() {
        if (!this.wrap) {
            return;
        }
        this.wrap.classList.add('hide');
        const tooltips = Array.from(document.querySelectorAll('.wrap-tooltip'));
        tooltips.forEach(tooltip => tooltip.remove());
    }
};
TooltipDirective.ctorParameters = () => [
    { type: ElementRef }
];
__decorate([
    Input(),
    __metadata("design:type", String)
], TooltipDirective.prototype, "uiTooltip", void 0);
__decorate([
    Input(),
    __metadata("design:type", Boolean)
], TooltipDirective.prototype, "top", void 0);
__decorate([
    Input(),
    __metadata("design:type", Boolean)
], TooltipDirective.prototype, "left", void 0);
__decorate([
    Input(),
    __metadata("design:type", Boolean)
], TooltipDirective.prototype, "right", void 0);
__decorate([
    Input(),
    __metadata("design:type", Boolean)
], TooltipDirective.prototype, "bottom", void 0);
TooltipDirective = __decorate([
    Directive({
        selector: '[uiTooltip]'
    }),
    __metadata("design:paramtypes", [ElementRef])
], TooltipDirective);

let UiChosenOptionComponent = class UiChosenOptionComponent {
    constructor(parent) {
        this.parent = parent;
    }
    ngAfterViewInit() {
        this.parent.loadOption(this);
    }
    ngOnChanges(changes) {
        if (this.active && changes.label && !changes.label.firstChange) {
            this.label = changes.label.currentValue;
            this.parent.updateOptionLabel(this.label);
        }
    }
    onSelect() {
        if (this.disabled) {
            return;
        }
        this.parent.select(this);
    }
    setActive(active) {
        this.active = active;
    }
};
UiChosenOptionComponent.ctorParameters = () => [
    { type: undefined, decorators: [{ type: Inject, args: [forwardRef(() => UiChosenComponent),] }] }
];
__decorate([
    Input(),
    __metadata("design:type", Object)
], UiChosenOptionComponent.prototype, "label", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], UiChosenOptionComponent.prototype, "value", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], UiChosenOptionComponent.prototype, "disabled", void 0);
UiChosenOptionComponent = __decorate([
    Component({
        selector: 'ui-chosen-option',
        template: "<div class=\"option\"\r\n     uiRipple\r\n     (click)=\"onSelect()\"\r\n     [ngClass]=\"{'active': active, 'disabled': disabled}\"\r\n     *ngIf=\"!hidden\"\r\n     [title]=\"label\">\r\n    {{label}}\r\n</div>\r\n",
        styles: [":host{display:block}.option{font-size:16px;padding:14px 16px;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;cursor:default;white-space:nowrap;text-overflow:ellipsis;overflow:hidden}"]
    }),
    __param(0, Inject(forwardRef(() => UiChosenComponent))),
    __metadata("design:paramtypes", [Object])
], UiChosenOptionComponent);

let UiChosenGroupComponent = class UiChosenGroupComponent {
    constructor() {
    }
    ngOnInit() {
    }
};
__decorate([
    Input(),
    __metadata("design:type", String)
], UiChosenGroupComponent.prototype, "label", void 0);
__decorate([
    ContentChildren(UiChosenOptionComponent),
    __metadata("design:type", QueryList)
], UiChosenGroupComponent.prototype, "options", void 0);
UiChosenGroupComponent = __decorate([
    Component({
        selector: 'ui-chosen-group',
        template: "<div class=\"label\" *ngIf=\"!hidden\">{{label}}</div>\r\n<div *ngIf=\"!hidden\">\r\n    <ng-content></ng-content>\r\n</div>\r\n",
        styles: [":host{display:block}:host ::ng-deep ui-chosen-option .option{padding-left:32px}.label{font-size:16px;padding:14px 16px;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;cursor:default;white-space:nowrap;text-overflow:ellipsis;overflow:hidden;font-weight:500}"]
    }),
    __metadata("design:paramtypes", [])
], UiChosenGroupComponent);

var UiChosenComponent_1;
// TODO: Animation
// TODO: Export render, open, close
let UiChosenComponent = UiChosenComponent_1 = class UiChosenComponent {
    constructor(element, viewContainerRef, changeDetectorRef) {
        this.element = element;
        this.viewContainerRef = viewContainerRef;
        this.changeDetectorRef = changeDetectorRef;
        this.ngModelChange = new EventEmitter();
    }
    ngOnInit() { }
    ngAfterViewInit() {
        this.element.nativeElement.setAttribute('tabindex', this.element.nativeElement.getAttribute('tabindex') || '0');
        UiElement.on(window, 'resize scroll', () => {
            this.close();
        });
        if (/Mobi|Android/.test(navigator.userAgent)) {
            this.isMobile = true;
            this.element.nativeElement.classList.add('mobile');
        }
        this.changeDetectorRef.detectChanges();
    }
    ngOnChanges(changes) {
        if (!isNullOrUndefined(changes.ngModel) &&
            !changes.ngModel.firstChange) {
            this.setValue(changes.ngModel.currentValue);
        }
        if (changes.required && !changes.required.firstChange) {
            this.required = changes.required.currentValue;
        }
        if (changes.disabled) {
            this.disabled = changes.disabled.currentValue;
        }
    }
    ngAfterContentInit() {
        if (!isNullOrUndefined(this.ngModel)) {
            setTimeout(() => this.setValue(this.ngModel));
        }
    }
    writeValue() { }
    registerOnChange() { }
    registerOnTouched() { }
    validate(control) {
        this.control = control;
        if (this.required && !control.value && control.value !== 0) {
            return { required: true };
        }
        return null;
    }
    onFocus() {
        if (this.isMobile) {
            this.nativeSelect.nativeElement.focus();
            return;
        }
        if (this.focused) {
            return;
        }
        if (this.disabled) {
            this.element.nativeElement.blur();
            return;
        }
        this.clearFilter();
        if (this.search) {
            setTimeout(() => this.inputSearch.nativeElement.focus(), 100);
        }
        this.focused = true;
        const position = UiElement.position(this.element.nativeElement);
        const coordinate = {
            x: position.left,
            y: position.top + this.element.nativeElement.clientHeight
        };
        this.render(coordinate);
    }
    render(coordinate) {
        this.viewRef = this.viewContainerRef.createEmbeddedView(this.optionTemplate);
        this.viewRef.detectChanges();
        this.viewRef.rootNodes.forEach(rootNode => {
            document.body.appendChild(rootNode);
            if (rootNode.clientWidth &&
                !rootNode.classList.contains('wrap-chosen-overlay')) {
                this.open(rootNode, coordinate);
            }
        });
    }
    open(element, coordinate) {
        element.style.top = 0;
        setTimeout(() => {
            const verticalCoveringArea = UiElement.position(this.element.nativeElement, true).top +
                element.clientHeight;
            const bodyHeight = document.body.clientHeight;
            if (verticalCoveringArea + this.element.nativeElement.clientHeight > bodyHeight) {
                coordinate.y -=
                    verticalCoveringArea -
                        bodyHeight +
                        this.element.nativeElement.clientHeight;
            }
            if (coordinate.y <= 0) {
                coordinate.y = 0;
            }
            const content = element.querySelector('ui-card > .content');
            const contentHeight = content.clientHeight;
            const search = element.querySelector('ui-card > .search');
            const searchHeight = search ? search.clientHeight : 0;
            content.style.maxHeight =
                (contentHeight > bodyHeight
                    ? bodyHeight - searchHeight
                    : contentHeight) + 'px';
            element.style.transform = '';
            element.style.top = coordinate.y + 'px';
            element.style.left = coordinate.x + 'px';
            const card = element.querySelector('ui-card');
            card.style.maxHeight = window.innerHeight + 'px';
            card.style.maxWidth = window.innerWidth - 16 + 'px';
            card.style.width = this.element.nativeElement.clientWidth + 'px';
            element.classList.add('open');
        });
    }
    close() {
        this.focused = false;
        if (this.viewContainerRef.length) {
            const viewRef = this.viewRef; // Salvando a referência para achar o index deste componente
            viewRef.rootNodes.forEach(rootNode => {
                if (rootNode.classList) {
                    rootNode.classList.remove('open');
                }
            });
            setTimeout(() => this.viewContainerRef.remove(this.viewContainerRef.indexOf(viewRef)), 280);
        }
    }
    setValue(value) {
        let updated = false;
        this.options.map(option => {
            if (option.value != value) {
                // tslint:disable-line
                option.setActive(false);
                return;
            }
            updated = true;
            this.value = option.label;
            option.setActive(true);
        });
        if (!updated) {
            this.value = null;
        }
        this.element.nativeElement.value = this.value;
    }
    select(option) {
        this.control.markAsDirty();
        this.control.markAsTouched();
        this.ngModelChange.emit(option.value);
        this.close();
    }
    filterList() {
        this.options.map(option => {
            option.hidden = this.searchText
                ? !unaccent(option.label.toLowerCase()).includes(unaccent(this.searchText.toLowerCase()))
                : false;
        });
        this.optionsGroup.map(group => (group.hidden =
            group.options.filter(option => !option.hidden).length === 0));
    }
    clearFilter() {
        this.searchText = null;
        this.filterList();
    }
    changeNativeSelect() {
        setTimeout(() => {
            this.control.markAsDirty();
            this.control.markAsTouched();
            this.ngModelChange.emit(this.ngModel);
        });
    }
    trackByValue(index, option) {
        return option.value;
    }
    updateOptionLabel(label) {
        this.value = label;
    }
    loadOption(option) {
        if (!isNullOrUndefined(this.ngModel) && option.value === this.ngModel) {
            this.value = option.label;
        }
        this.changeDetectorRef.detectChanges();
    }
};
UiChosenComponent.ctorParameters = () => [
    { type: ElementRef },
    { type: ViewContainerRef },
    { type: ChangeDetectorRef }
];
__decorate([
    Input(),
    __metadata("design:type", Object)
], UiChosenComponent.prototype, "search", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], UiChosenComponent.prototype, "ngModel", void 0);
__decorate([
    Input(),
    __metadata("design:type", Boolean)
], UiChosenComponent.prototype, "required", void 0);
__decorate([
    Input(),
    __metadata("design:type", Boolean)
], UiChosenComponent.prototype, "disabled", void 0);
__decorate([
    Input(),
    __metadata("design:type", String)
], UiChosenComponent.prototype, "placeholder", void 0);
__decorate([
    Input(),
    __metadata("design:type", String)
], UiChosenComponent.prototype, "persistPlaceholder", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], UiChosenComponent.prototype, "ngModelChange", void 0);
__decorate([
    ViewChild('optionTemplate', { static: true }),
    __metadata("design:type", TemplateRef)
], UiChosenComponent.prototype, "optionTemplate", void 0);
__decorate([
    ViewChild('inputSearch'),
    __metadata("design:type", ElementRef)
], UiChosenComponent.prototype, "inputSearch", void 0);
__decorate([
    ViewChild('nativeSelect'),
    __metadata("design:type", ElementRef)
], UiChosenComponent.prototype, "nativeSelect", void 0);
__decorate([
    ContentChildren(UiChosenOptionComponent, { descendants: true }),
    __metadata("design:type", QueryList)
], UiChosenComponent.prototype, "options", void 0);
__decorate([
    ContentChildren(UiChosenOptionComponent),
    __metadata("design:type", QueryList)
], UiChosenComponent.prototype, "onlyOptions", void 0);
__decorate([
    ContentChildren(UiChosenGroupComponent, { descendants: true }),
    __metadata("design:type", QueryList)
], UiChosenComponent.prototype, "optionsGroup", void 0);
__decorate([
    HostListener('focus'),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", void 0)
], UiChosenComponent.prototype, "onFocus", null);
UiChosenComponent = UiChosenComponent_1 = __decorate([
    Component({
        selector: 'ui-chosen',
        template: "<select *ngIf=\"isMobile\"\r\n        [required]=\"required\"\r\n        [(ngModel)]=\"ngModel\"\r\n        uiInput\r\n        #nativeSelect\r\n        [disabled]=\"disabled\"\r\n        (ngModelChange)=\"changeNativeSelect()\">\r\n    <option *ngFor=\"let option of onlyOptions; trackBy: trackByValue\"\r\n            [label]=\"option.label\"\r\n            [ngValue]=\"option.value\"\r\n            [disabled]=\"option.disabled\">{{option.label}}</option>\r\n    <optgroup *ngFor=\"let group of optionsGroup; trackBy: trackByValue\" [label]=\"group.label\">\r\n        <option *ngFor=\"let option of group.options\"\r\n                [label]=\"option.label\"\r\n                [ngValue]=\"option.value\"\r\n                [disabled]=\"option.disabled\"></option>\r\n    </optgroup>\r\n</select>\r\n<div class=\"value\" *ngIf=\"!isMobile\" [class.disabled]=\"disabled\" (click)=\"onFocus()\">\r\n    <span class=\"placeholder\"\r\n         *ngIf=\"placeholder && !value && ((!persistPlaceholder && focused) || persistPlaceholder)\">\r\n        {{placeholder}}\r\n    </span>\r\n    <span *ngIf=\"value\">{{value}}</span>\r\n</div>\r\n<ng-template #optionTemplate>\r\n    <div class=\"wrap-chosen-overlay\" (click)=\"close()\"></div>\r\n    <div class=\"wrap-chosen\">\r\n        <ui-card>\r\n            <div class=\"search\" *ngIf=\"search\">\r\n                <ui-input-container class=\"no-space\">\r\n                    <input type=\"text\" uiInput [(ngModel)]=\"searchText\" (ngModelChange)=\"filterList()\" #inputSearch>\r\n                    <button type=\"button\"\r\n                            class=\"suffix ui-button flat icon\"\r\n                            uiRipple\r\n                            (click)=\"clearFilter()\"\r\n                            [disabled]=\"!searchText\"\r\n                            uiTooltip=\"Limpar busca\">\r\n                        <i class=\"material-icons\">{{searchText ? 'close' : 'search'}}</i>\r\n                    </button>\r\n                </ui-input-container>\r\n            </div>\r\n            <div class=\"content\">\r\n                <ng-content></ng-content>\r\n            </div>\r\n        </ui-card>\r\n    </div>\r\n</ng-template>\r\n",
        providers: [
            {
                provide: NG_VALUE_ACCESSOR,
                useExisting: UiChosenComponent_1,
                multi: true
            },
            {
                provide: NG_VALIDATORS,
                useExisting: forwardRef(() => UiChosenComponent_1),
                multi: true
            }
        ],
        styles: [":host.mobile.ui-control{padding:0;border-width:0}:host .value{text-overflow:ellipsis;overflow:hidden}:host .value.disabled{color:rgba(0,0,0,.54);cursor:not-allowed}:host .value span{white-space:nowrap;text-overflow:ellipsis;overflow:hidden}.wrap-chosen-overlay{position:fixed;top:0;left:0;right:0;bottom:0;z-index:7}.wrap-chosen{position:absolute;transition:transform 280ms,opacity 280ms;transform-origin:top left;transform:scale(0);opacity:0;z-index:7}.wrap-chosen.open{transition:transform 280ms cubic-bezier(0,0,.2,1),opacity 280ms cubic-bezier(0,0,.2,1);transform:scale(1);opacity:1}.wrap-chosen ui-card{box-shadow:0 2px 4px 0 rgba(0,0,0,.14),0 4px 5px 0 rgba(0,0,0,.12),0 1px 10px 0 rgba(0,0,0,.2);overflow:hidden}.wrap-chosen ui-card .search{padding:8px 16px}.wrap-chosen ui-card .search input{width:100%}.wrap-chosen ui-card .content{max-height:235px;overflow-y:auto}body.ui-nav-drawer-persistent .wrap-chosen{z-index:6}"]
    }),
    __metadata("design:paramtypes", [ElementRef,
        ViewContainerRef,
        ChangeDetectorRef])
], UiChosenComponent);

let UiCreditCardPipe = class UiCreditCardPipe {
    transform(value, args) {
        if (!value) {
            return '';
        }
        value = value.toString().replace(/[^0-9]+/g, '');
        if (value.length > 4) {
            value = `${value.substring(0, 4)} ${value.substring(4)}`;
        }
        if (value.length > 9) {
            value = `${value.substring(0, 9)} ${value.substring(9)}`;
        }
        if (value.length > 14) {
            value = `${value.substring(0, 14)} ${value.substring(14)}`;
        }
        if (value.length > 19) {
            value = value.substring(0, 19);
        }
        return value;
    }
};
UiCreditCardPipe = __decorate([
    Pipe({
        name: 'uiCreditCard'
    })
], UiCreditCardPipe);

var UiMaskCreditCard_1;
let UiMaskCreditCard = UiMaskCreditCard_1 = class UiMaskCreditCard {
    constructor(elementRef, creditCardPipe, changeDetector) {
        this.elementRef = elementRef;
        this.creditCardPipe = creditCardPipe;
        this.changeDetector = changeDetector;
        this.symbolsPositions = [4, 9, 14];
        this.ngModelChange = new EventEmitter();
    }
    ngOnChanges(changes) {
        if (!changes.ngModel.firstChange && (changes.ngModel.currentValue === null || changes.ngModel.currentValue === undefined)) {
            this.elementRef.nativeElement.value = '';
        }
    }
    ngAfterViewInit() {
        this.loaded = true;
        this.changeDetector.detectChanges();
    }
    writeValue(rawValue) {
        if (this.control && this.loaded && rawValue) {
            this.control.markAsDirty();
        }
        this.elementRef.nativeElement.value = this.creditCardPipe.transform(this.ngModel);
    }
    renderViaInput(rawValue) {
        if (rawValue) {
            this.control.markAsDirty();
        }
        this.ngModel = this.format(rawValue);
        this.ngModelChange.emit(this.ngModel);
        this.elementRef.nativeElement.value = this.creditCardPipe.transform(this.elementRef.nativeElement.value);
    }
    registerOnChange(fn) {
        this.onChange = fn;
    }
    registerOnTouched(fn) {
        this.onTouched = fn;
    }
    format(value) {
        value = value.toString().replace(/[^0-9]+/g, '');
        return value.substring(0, 16);
    }
    validate(control) {
        this.control = control;
        if (control.value && this.format(control.value).length < 16) {
            return { parse: true };
        }
        return null;
    }
    setDisabledState(isDisabled) {
        const method = isDisabled ? 'setAttribute' : 'removeAttribute';
        this.elementRef.nativeElement[method]('disabled', 'disabled');
    }
    onKeydown() {
        this.beforeSelIndex = UiElement.caretPosition.get(this.elementRef.nativeElement);
    }
    onInput($event) {
        const afterSelIndex = UiElement.caretPosition.get(this.elementRef.nativeElement);
        const rawValue = this.elementRef.nativeElement.value;
        this.renderViaInput(rawValue);
        UiElement.caretPosition.set(this.elementRef.nativeElement, this.beforeSelIndex, afterSelIndex, this.symbolsPositions);
    }
};
UiMaskCreditCard.ctorParameters = () => [
    { type: ElementRef },
    { type: UiCreditCardPipe },
    { type: ChangeDetectorRef }
];
__decorate([
    Input(),
    __metadata("design:type", Object)
], UiMaskCreditCard.prototype, "ngModel", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], UiMaskCreditCard.prototype, "UiMaskCreditCard", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], UiMaskCreditCard.prototype, "ngModelChange", void 0);
__decorate([
    HostListener('keydown'),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", void 0)
], UiMaskCreditCard.prototype, "onKeydown", null);
__decorate([
    HostListener('input', ['$event']),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [Object]),
    __metadata("design:returntype", void 0)
], UiMaskCreditCard.prototype, "onInput", null);
UiMaskCreditCard = UiMaskCreditCard_1 = __decorate([
    Directive({
        selector: '[uiMaskCreditCard][ngModel]',
        providers: [{
                provide: NG_VALUE_ACCESSOR,
                useExisting: forwardRef(() => UiMaskCreditCard_1),
                multi: true
            }, {
                provide: NG_VALIDATORS,
                useExisting: forwardRef(() => UiMaskCreditCard_1),
                multi: true
            }, UiCreditCardPipe]
    }),
    __metadata("design:paramtypes", [ElementRef, UiCreditCardPipe, ChangeDetectorRef])
], UiMaskCreditCard);

let ExpansionPanelComponent = class ExpansionPanelComponent {
    constructor() {
        this.color = 'primary';
        this.openChange = new EventEmitter();
    }
    ngOnInit() { }
    toggle() {
        if (!this.disabled) {
            this.open = !this.open;
            this.openChange.emit(this.open);
        }
    }
};
__decorate([
    Input(),
    __metadata("design:type", Boolean)
], ExpansionPanelComponent.prototype, "disabled", void 0);
__decorate([
    Input(),
    __metadata("design:type", Boolean)
], ExpansionPanelComponent.prototype, "noArrow", void 0);
__decorate([
    Input(),
    __metadata("design:type", String)
], ExpansionPanelComponent.prototype, "label", void 0);
__decorate([
    Input(),
    __metadata("design:type", String)
], ExpansionPanelComponent.prototype, "description", void 0);
__decorate([
    Input(),
    __metadata("design:type", String)
], ExpansionPanelComponent.prototype, "color", void 0);
__decorate([
    Input(),
    __metadata("design:type", Boolean)
], ExpansionPanelComponent.prototype, "open", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], ExpansionPanelComponent.prototype, "openChange", void 0);
ExpansionPanelComponent = __decorate([
    Component({
        selector: "ui-expansion-panel",
        template: "<div class=\"ui-expansion-panel-wrap\">\r\n\r\n    <div class=\"ui-expansion-panel-header\" \r\n        (click)=\"toggle()\" \r\n        [ngStyle]=\"{'opacity': disabled ? '.5' : '1'}\" \r\n        uiRipple \r\n        [ripple-disable]=\"disabled\">\r\n        <span class=\"ui-expansion-panel-title\">\r\n            <ui-subheader [class]=\"color\">\r\n                {{ label }}\r\n            </ui-subheader>\r\n        </span>\r\n        <span class=\"ui-expansion-panel-description label secondary-text\">\r\n            {{ description }}\r\n        </span>\r\n        <span>\r\n            <i [class]=\"'material-icons ui-expansion-panel-arrow ' + color\" \r\n                [ngClass]=\"{'ui-expansion-panel-collapsed': !open}\"\r\n                [ngStyle]=\"{\r\n                    'display' : disabled || noArrow ? 'none' : 'block' \r\n                }\">\r\n                keyboard_arrow_up\r\n            </i>\r\n        </span>\r\n    </div>\r\n\r\n    <div class=\"ui-expansion-panel-body\" [@expandAnimation] *ngIf=\"open\">\r\n        <ng-content selector=\"ui-expansion-panel-content\" >\r\n        </ng-content>\r\n    </div>\r\n\r\n</div>",
        animations: [
            trigger("expandAnimation", [
                transition(":enter", [
                    style({
                        height: "0"
                    }),
                    animate("280ms cubic-bezier(0.0, 0.0, 0.2, 1)", style({
                        height: "*"
                    }))
                ]),
                transition(":leave", [
                    style({
                        height: "*"
                    }),
                    animate("280ms cubic-bezier(0.0, 0.0, 0.2, 1)", style({
                        height: "0"
                    }))
                ])
            ])
        ],
        styles: [".ui-expansion-panel-header{display:flex;flex-direction:row;justify-content:space-between;padding:4px 16px;cursor:default}.ui-expansion-panel-header span{margin:auto 0;-webkit-touch-callout:none;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none}.ui-expansion-panel-header span i{transition:transform .3s cubic-bezier(.4,0,1,1)}.ui-expansion-panel-body{transition:height .3s cubic-bezier(.4,0,1,1);overflow-y:hidden}.ui-expansion-panel-description{font-size:14px;font-weight:500}.ui-expansion-panel-collapsed{transform:rotateZ(180deg)}@media screen and (max-width:480px){.ui-expansion-panel-description{display:none}}"]
    }),
    __metadata("design:paramtypes", [])
], ExpansionPanelComponent);

let UiTabContentDirective = class UiTabContentDirective {
    constructor() { }
};
__decorate([
    ContentChild(TemplateRef),
    __metadata("design:type", TemplateRef)
], UiTabContentDirective.prototype, "template", void 0);
UiTabContentDirective = __decorate([
    Directive({
        selector: '[uiTabContent]'
    }),
    __metadata("design:paramtypes", [])
], UiTabContentDirective);

let UiTabLabelDirective = class UiTabLabelDirective {
    constructor() {
    }
};
__decorate([
    ContentChild(TemplateRef),
    __metadata("design:type", TemplateRef)
], UiTabLabelDirective.prototype, "template", void 0);
UiTabLabelDirective = __decorate([
    Directive({
        selector: '[uiTabLabel]'
    }),
    __metadata("design:paramtypes", [])
], UiTabLabelDirective);

let UiTabComponent = class UiTabComponent {
    constructor(viewContainer, changeDetectorRef) {
        this.viewContainer = viewContainer;
        this.changeDetectorRef = changeDetectorRef;
        this.tabChange = new EventEmitter();
    }
    ngOnInit() {
        this.subscription = this.tabChange.subscribe(value => {
            if (value) {
                this.loaded = true;
            }
            this.isActive = value;
            this.changeDetectorRef.detectChanges();
        });
    }
    ngOnDestroy() {
        this.subscription.unsubscribe();
    }
};
UiTabComponent.ctorParameters = () => [
    { type: ViewContainerRef },
    { type: ChangeDetectorRef }
];
__decorate([
    ViewChild('tabContent', { static: true }),
    __metadata("design:type", TemplateRef)
], UiTabComponent.prototype, "tabContent", void 0);
__decorate([
    ContentChild(UiTabContentDirective),
    __metadata("design:type", UiTabContentDirective)
], UiTabComponent.prototype, "templateContent", void 0);
__decorate([
    ContentChild(UiTabLabelDirective),
    __metadata("design:type", UiTabLabelDirective)
], UiTabComponent.prototype, "templateLabel", void 0);
__decorate([
    Input(),
    __metadata("design:type", String)
], UiTabComponent.prototype, "label", void 0);
__decorate([
    Input(),
    __metadata("design:type", String)
], UiTabComponent.prototype, "icon", void 0);
__decorate([
    Input(),
    __metadata("design:type", String)
], UiTabComponent.prototype, "disabled", void 0);
UiTabComponent = __decorate([
    Component({
        selector: 'ui-tab',
        template: "<ng-template #tabContent>\r\n    <ng-content></ng-content>\r\n    <div *ngIf=\"templateContent && templateContent.template && loaded\">\r\n        <ng-container *ngTemplateOutlet=\"templateContent.template\"></ng-container>\r\n    </div>\r\n</ng-template>\r\n",
        styles: [""]
    }),
    __metadata("design:paramtypes", [ViewContainerRef, ChangeDetectorRef])
], UiTabComponent);

let UiTabHeaderComponent = class UiTabHeaderComponent {
    constructor(element, changeDetectorRef) {
        this.element = element;
        this.changeDetectorRef = changeDetectorRef;
        this.increment = 90;
    }
    ngOnInit() {
        this.tabsContainer = this.element.nativeElement.querySelector('.tabs-container');
        this.inkBar = this.element.nativeElement.querySelector('.ink-bar');
    }
    ngAfterViewInit() {
        this.inkBar.addEventListener('transitionend', () => {
            this.showInkBar = false;
        });
    }
    ngAfterViewChecked() {
        this.hasRightScroll = this.checkRightScroll();
        this.hasLeftScroll = this.checkLeftScroll();
        this.changeDetectorRef.detectChanges();
    }
    /**
     * Move o ink bar para a tab que está ativa
     **/
    moveInkBarTo(tabRef) {
        this.showInkBar = true;
        this.changeDetectorRef.detectChanges();
        setTimeout(() => {
            UiElement.css(this.inkBar, 'left', `${tabRef.offsetLeft}px`);
            UiElement.css(this.inkBar, 'width', `${tabRef.clientWidth}px`);
        });
    }
    /**
     * Retorna se o scroll left ja saiu da posição 0
     * */
    checkLeftScroll() {
        return this.tabsContainer.scrollLeft > 0;
    }
    /**
     * Retorna se deve exibir o control da direita
     * */
    checkRightScroll() {
        const widthWithScroll = this.tabsContainer.scrollLeft + this.tabsContainer.clientWidth;
        return widthWithScroll < this.tabsContainer.scrollWidth;
    }
    /**
     * Altera o valor do scroll
     **/
    updateScroll(value) {
        const scrollLeft = this.tabsContainer.scrollLeft;
        UiElement.animate(this.tabsContainer, 'borderSpacing', scrollLeft, scrollLeft + value, 280, null, (tick) => {
            this.tabsContainer.scrollLeft = tick;
        });
    }
};
UiTabHeaderComponent.ctorParameters = () => [
    { type: ElementRef },
    { type: ChangeDetectorRef }
];
__decorate([
    Input(),
    __metadata("design:type", Boolean)
], UiTabHeaderComponent.prototype, "topIcon", void 0);
UiTabHeaderComponent = __decorate([
    Component({
        selector: 'ui-tab-header',
        template: "<div class=\"navigation left\" *ngIf=\"hasLeftScroll\">\r\n    <button type=\"button\" class=\"ui-button icon flat\" (click)=\"updateScroll(-increment)\">\r\n        <i class=\"material-icons\">chevron_left</i>\r\n    </button>\r\n</div>\r\n<div class=\"tabs-container\">\r\n    <div class=\"tabs\" [class.top-icon]=\"topIcon\">\r\n        <ng-content></ng-content>\r\n    </div>\r\n    <div class=\"ink-bar\" [hidden]=\"!showInkBar\"></div>\r\n</div>\r\n<div class=\"navigation right\" *ngIf=\"hasRightScroll\">\r\n    <button type=\"button\" class=\"ui-button icon flat\" (click)=\"updateScroll(increment)\">\r\n        <i class=\"material-icons\">chevron_right</i>\r\n    </button>\r\n</div>\r\n",
        styles: [":host{display:flex;align-items:center;position:relative}@media only screen and (min-width:376px) and (min-width:764px){::ng-deep ui-tab-group.scrollable>ui-tab-header>.tabs-container,:host.scrollable>.tabs-container{padding-left:52px}}::ng-deep ui-tab-group.fixed>ui-tab-header .tab-wrap,::ng-deep ui-tab-group.fixed>ui-tab-header ::ng-deep>.tab-wrap,:host.fixed .tab-wrap,:host.fixed ::ng-deep>.tab-wrap{flex:1}.tabs-container{flex:1;position:relative;overflow:hidden}.tabs{display:flex;height:48px;align-items:center}.tabs.top-icon{height:72px}.tabs.top-icon .tab-wrap,.tabs.top-icon ::ng-deep .tab-wrap{height:72px}.tabs.top-icon .tab-wrap .tab,.tabs.top-icon ::ng-deep .tab-wrap .tab{flex-direction:column;height:72px}.tabs.top-icon .tab-wrap .tab>.icon,.tabs.top-icon ::ng-deep .tab-wrap .tab>.icon{padding-right:0;padding-bottom:4px}.tab-wrap .tab,::ng-deep .tab-wrap .tab{padding:0 16px;min-width:90px;max-width:360px;height:48px;font-size:14px;font-weight:500;text-align:center;text-decoration:none;text-transform:uppercase;white-space:nowrap;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;border-bottom:2px solid transparent;display:flex;align-items:center;justify-content:center;cursor:default;transition:color 280ms cubic-bezier(0,0,.2,1),border-color cubic-bezier(0,0,.2,1)}.tab-wrap .tab:hover,::ng-deep .tab-wrap .tab:hover{text-decoration:none}.tab-wrap .tab>.icon,::ng-deep .tab-wrap .tab>.icon{padding-right:4px}.tab-wrap.active .tab,::ng-deep .tab-wrap.active .tab{transition:color 280ms cubic-bezier(0,0,.2,1),border-color cubic-bezier(0,0,.2,1) 280ms}.ink-bar{left:0;width:0;height:2px;position:absolute;bottom:0;transition:width 280ms cubic-bezier(0,0,.2,1),left 280ms cubic-bezier(0,0,.2,1)}.navigation{margin:0 8px;position:absolute;z-index:1}.navigation.left{left:0}.navigation.right{right:0}"]
    }),
    __metadata("design:paramtypes", [ElementRef, ChangeDetectorRef])
], UiTabHeaderComponent);

const timing = 280;
const tabFakeAnimation = trigger('tabFakeAnimation', [
    transition(':enter', animate(`${timing}ms cubic-bezier(0.0, 0.0, 0.2, 1)`)),
    transition(':leave', animate(`${timing}ms cubic-bezier(0.0, 0.0, 0.2, 1)`)),
]);
const tabTransform = trigger('tabTransform', [
    state('left', style({
        transform: 'translateX(-100%)',
        position: 'absolute'
    })),
    state('right', style({
        transform: 'translateX(100%)',
        position: 'absolute'
    })),
    state('active', style({
        transform: 'translateX(0)',
        position: 'relative'
    })),
    transition('left <=> right', animate(timing)),
    transition('active <=> right', animate(timing)),
    transition('left <=> active', animate(timing)),
]);

let UiTabGroupComponent = class UiTabGroupComponent {
    constructor(changeDetectorRef, element) {
        this.changeDetectorRef = changeDetectorRef;
        this.element = element;
    }
    ngAfterViewInit() {
        // Transformando a QueryList em um array de component(UiTabComponent)
        this.tabs = this.tabsQueryList.toArray();
        this.changeDetectorRef.detectChanges();
        this.generateIndexes();
        // Ativa uma tab através do index passado com Input ou a primeira tab
        const tab = this.getFirstTab(this.active);
        this.activateTab(tab, this.getTabRef(tab));
        this.animation = true;
        this.changeDetectorRef.detectChanges();
        this.tabsQueryList.changes.subscribe(newTabs => {
            this.tabs = newTabs.toArray();
            this.generateIndexes();
            // Verificando se a tab selecionada foi removida da lista
            if (!this.tabs.includes(this.activatedTab)) {
                // Ativando a tab que ficou no mesmo index da última tab ativa
                // TODO: Procurar uma tab que não esteja desabilitada
                const newTab = this.tabs[this.activatedTab.index] || this.tabs[this.tabs.length - 1];
                this.activateTab(newTab, this.getTabRef(newTab));
            }
        });
    }
    /**
     * Atribuí os index para as tabs
     **/
    generateIndexes() {
        this.tabs.map((tab, index) => tab.index = index);
    }
    /**
     * Retorna a primeira tab que não está desabilitada
    **/
    getFirstTab(tabIndex) {
        if (typeof tabIndex === 'number' && !this.tabs[tabIndex].disabled) {
            return this.tabs[tabIndex];
        }
        for (let i = 0; i < this.tabs.length; i++) {
            const tab = this.tabs[i];
            if (!tab.disabled) {
                return tab;
            }
        }
    }
    /**
     * Retorna a refencia da tab em HTML
    **/
    getTabRef(tab) {
        const tabsRef = this.element.nativeElement.querySelectorAll('.tab');
        return tabsRef ? tabsRef[tab.index] : null;
    }
    /**
     * Ativa uma tab
     * */
    activateTab(tab, tabRef) {
        if (tab.disabled || tab === this.activatedTab) {
            return;
        }
        if (this.activatedTab) {
            this.activatedTab.tabChange.emit(false);
        }
        this.tabsContentElement.nativeElement.style.height = this.tabsContentElement.nativeElement.clientHeight + 'px';
        tab.tabChange.emit(true);
        this.changeDetectorRef.detectChanges();
        this.activatedTab = tab;
        this.tabHeader.moveInkBarTo(tabRef);
        this.updateActivatedTab();
    }
    /**
     * Altera em todos components(UiTabComponent) o index da nova tab ativada
     **/
    updateActivatedTab() {
        this.tabs.map(tab => tab.indexActivatedTab = this.activatedTab.index);
    }
    /**
     * Callback para quando a animação do conteúdo da tab iniciar
     * */
    startTranslateAnimation(event) {
        if (event.toState === 'active') {
            this.tabsContentElement.nativeElement.style.height = event.element.scrollHeight + 'px';
        }
    }
    /**
     * Callback para quando a animação do conteúdo da tab terminar
     * */
    doneTranslateAnimation(event) {
        this.tabsContentElement.nativeElement.style.height = '';
    }
};
UiTabGroupComponent.ctorParameters = () => [
    { type: ChangeDetectorRef },
    { type: ElementRef }
];
__decorate([
    ContentChildren(UiTabComponent),
    __metadata("design:type", QueryList)
], UiTabGroupComponent.prototype, "tabsQueryList", void 0);
__decorate([
    ViewChild(UiTabHeaderComponent, { static: true }),
    __metadata("design:type", UiTabHeaderComponent)
], UiTabGroupComponent.prototype, "tabHeader", void 0);
__decorate([
    ViewChild('tabsContentElement', { static: true }),
    __metadata("design:type", ElementRef)
], UiTabGroupComponent.prototype, "tabsContentElement", void 0);
__decorate([
    Input(),
    __metadata("design:type", Number)
], UiTabGroupComponent.prototype, "active", void 0);
__decorate([
    Input(),
    __metadata("design:type", Boolean)
], UiTabGroupComponent.prototype, "fillBackground", void 0);
__decorate([
    Input(),
    __metadata("design:type", Boolean)
], UiTabGroupComponent.prototype, "themeInkBar", void 0);
__decorate([
    Input(),
    __metadata("design:type", Boolean)
], UiTabGroupComponent.prototype, "accent", void 0);
__decorate([
    Input(),
    __metadata("design:type", Boolean)
], UiTabGroupComponent.prototype, "topIcon", void 0);
__decorate([
    Input(),
    __metadata("design:type", Boolean)
], UiTabGroupComponent.prototype, "lazyLoad", void 0);
UiTabGroupComponent = __decorate([
    Component({
        selector: 'ui-tab-group',
        template: "<ui-tab-header [ngClass]=\"{\r\n                'fill-background': fillBackground,\r\n                'accent': accent,\r\n                'theme-ink-bar': themeInkBar}\"\r\n               [topIcon]=\"topIcon\">\r\n    <div class=\"tab-wrap\"\r\n         *ngFor=\"let tab of tabs\"\r\n         [ngClass]=\"{'active': tab.isActive, 'disabled': tab.disabled}\"\r\n         (click)=\"activateTab(tab, tabRef)\"\r\n         #tabRef>\r\n        <div *ngIf=\"!tab.templateLabel\" class=\"tab\" uiRipple=\"!tab.disabled\">\r\n            <i class=\"material-icons icon\" *ngIf=\"tab.icon\">{{tab.icon}}</i>\r\n            {{tab.label}}\r\n        </div>\r\n        <div *ngIf=\"tab.templateLabel\">\r\n            <ng-container *ngTemplateOutlet=\"tab.templateLabel.template\"></ng-container>\r\n        </div>\r\n    </div>\r\n</ui-tab-header>\r\n<div class=\"wrap-content\" #tabsContentElement>\r\n    <div *ngFor=\"let tab of tabs\"\r\n         [@tabTransform]=\"animation ? (tab.index < activatedTab?.index ? 'left' : tab.index > activatedTab?.index ? 'right' : 'active') : ''\"\r\n         class=\"tab-content\"\r\n         (@tabTransform.start)=\"startTranslateAnimation($event)\"\r\n         (@tabTransform.done)=\"doneTranslateAnimation($event)\">\r\n        <div *ngIf=\"tab.isActive || !lazyLoad\" [@tabFakeAnimation]>\r\n            <ng-container [ngTemplateOutlet]=\"tab.tabContent\"></ng-container>\r\n        </div>\r\n    </div>\r\n</div>\r\n",
        animations: [tabFakeAnimation, tabTransform],
        styles: [":host{overflow:hidden;position:relative;display:block}:host .wrap-content{position:relative;transition:280ms cubic-bezier(0,0,.2,1)}:host .tab-content{left:0;right:0;top:0}"]
    }),
    __metadata("design:paramtypes", [ChangeDetectorRef, ElementRef])
], UiTabGroupComponent);

let UiLabelContentComponent = class UiLabelContentComponent {
};
__decorate([
    Input(),
    __metadata("design:type", String)
], UiLabelContentComponent.prototype, "label", void 0);
__decorate([
    Input(),
    __metadata("design:type", String)
], UiLabelContentComponent.prototype, "content", void 0);
UiLabelContentComponent = __decorate([
    Component({
        selector: 'ui-label-content',
        template: "<div class=\"label secondary-text\">{{label}}</div>\r\n<div class=\"content primary-text\">{{content}}</div>\r\n",
        styles: [":host{display:block}.label{font-size:12px}.content{font-size:14px}"]
    })
], UiLabelContentComponent);

let Upload = class Upload {
    readFile(file, base64) {
        if (!this.multiple) {
            this.max = 1;
        }
        if (this.max && this.ngModel.length === this.max) {
            return;
        }
        if (this.maxLength && file.name.length > this.maxLength) {
            UiSnackbar.show({
                text: `Arquivo "${file.name}" não pode ultrapassar ${this.maxLength} caracteres.`
            });
            return;
        }
        const modelFile = {};
        let isDuplicated = false;
        modelFile[this.modelConfig.name] = file.name;
        modelFile[this.modelConfig.base64] = base64;
        this.ngModel.forEach((file) => {
            if (modelFile.name === file.name) {
                isDuplicated = true;
                UiSnackbar.show({
                    text: `Já existe o arquivo "${file.name}".`,
                    duration: 4000
                });
                return;
            }
        });
        if (isDuplicated) {
            return;
        }
        this.ngModel.push(modelFile);
        this.ngModelChange.emit(this.ngModel);
    }
    errorFile(file, error) {
        if (error.type) {
            const accept = this.accept.toUpperCase().split(',');
            UiSnackbar.hide();
            UiSnackbar.show({
                text: 'Você pode selecionar apenas arquivo' + (accept.length == 1
                    ? ` do tipo ${accept[0]}`
                    : `s dos tipos ${accept.join(', ')}`) + '.'
            });
        }
        if (error.maxFileSize) {
            UiSnackbar.hide();
            UiSnackbar.show({
                text: `Use arquivos menores que ${this.maxFileSize}.`
            });
        }
    }
    removeFile(file, index) {
        this.ngModel.splice(index, 1);
        this.ngModelChange.emit(this.ngModel);
        this.remove.emit({ file, index });
    }
    filesChange(files) {
        if (this.max && (this.ngModel.length + files.length) > this.max) {
            UiSnackbar.hide();
            UiSnackbar.show({
                text: `Você pode selecionar apenas ${this.max} arquivo${this.max > 1 ? 's' : ''}.`
            });
        }
    }
    getFileName(file) {
        return file[this.modelConfig.name];
    }
};
__decorate([
    Input(),
    __metadata("design:type", String)
], Upload.prototype, "accept", void 0);
__decorate([
    Input(),
    __metadata("design:type", Boolean)
], Upload.prototype, "multiple", void 0);
__decorate([
    Input(),
    __metadata("design:type", Boolean)
], Upload.prototype, "disabled", void 0);
__decorate([
    Input(),
    __metadata("design:type", Number)
], Upload.prototype, "max", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], Upload.prototype, "ngModelChange", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], Upload.prototype, "remove", void 0);
Upload = __decorate([
    Directive()
], Upload);

const enterLeaveViewAnimation = trigger('enterLeaveViewAnimation', 
// Default é 280ms de transição.
[
    transition(':enter', [
        style({
            height: '0',
            transform: 'scale(0.8) translateY(-16px)',
            opacity: 0
        }),
        animate('550ms cubic-bezier(0.0, 0.0, 0.2, 1)', style({
            height: '*',
            transform: 'scale(1) translateY(0)',
            opacity: 1
        }))
    ]),
    transition(':leave', [
        style({
            height: '*',
            transform: 'scale(1) translateY(0)',
            opacity: 1
        }),
        animate('550ms cubic-bezier(0.0, 0.0, 0.2, 1)', style({
            height: '0',
            transform: 'scale(0.8) translateY(-16px)',
            opacity: 0
        }))
    ])
]);

var UiUploadComponent_1;
let UiUploadComponent = UiUploadComponent_1 = class UiUploadComponent extends Upload {
    constructor() {
        super();
        this.ngModelChange = new EventEmitter();
        this.remove = new EventEmitter();
        this.readFile = this.readFile.bind(this);
        this.errorFile = this.errorFile.bind(this);
    }
    ngOnInit() {
        this.modelConfig = Object.assign({ name: 'name', base64: 'base64' }, this.modelConfig);
    }
    ngOnChanges(changes) {
        if (changes.ngModel) {
            this.ngModel = changes.ngModel.currentValue && Array.isArray(changes.ngModel.currentValue) ? changes.ngModel.currentValue : [];
        }
        if (changes.modelConfig) {
            this.modelConfig = Object.assign({ name: 'name', base64: 'base64' }, changes.modelConfig.currentValue);
        }
    }
    writeValue(rawValue) {
    }
    renderViaInput(rawValue) {
    }
    registerOnChange(fn) {
    }
    registerOnTouched(fn) {
    }
    onDragEnter(event) {
        event.stopPropagation();
        event.preventDefault();
        this.isDragging = true;
    }
    onDragOver(event) {
        event.stopPropagation();
        event.preventDefault();
        this.isDragging = true;
        event.dataTransfer.dropEffect = 'copy';
    }
    onDragLeave(event) {
        event.stopPropagation();
        event.preventDefault();
        this.isDragging = false;
    }
    onDrop(event) {
        if (this.disabled) {
            event.preventDefault();
            return;
        }
        event.preventDefault();
        event.stopPropagation();
        this.isDragging = false;
        const { files } = event.dataTransfer;
        this.inputFileRef.readFiles(files);
    }
};
__decorate([
    ViewChild('inputFileRef'),
    __metadata("design:type", Object)
], UiUploadComponent.prototype, "inputFileRef", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], UiUploadComponent.prototype, "ngModel", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], UiUploadComponent.prototype, "modelConfig", void 0);
__decorate([
    Input(),
    __metadata("design:type", String)
], UiUploadComponent.prototype, "message", void 0);
__decorate([
    Input(),
    __metadata("design:type", Number)
], UiUploadComponent.prototype, "max", void 0);
__decorate([
    Input(),
    __metadata("design:type", Number)
], UiUploadComponent.prototype, "maxLength", void 0);
__decorate([
    Input(),
    __metadata("design:type", String)
], UiUploadComponent.prototype, "maxSize", void 0);
__decorate([
    Input(),
    __metadata("design:type", String)
], UiUploadComponent.prototype, "maxFileSize", void 0);
__decorate([
    Input(),
    __metadata("design:type", Boolean)
], UiUploadComponent.prototype, "multiple", void 0);
__decorate([
    Input(),
    __metadata("design:type", Boolean)
], UiUploadComponent.prototype, "disabled", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], UiUploadComponent.prototype, "ngModelChange", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], UiUploadComponent.prototype, "remove", void 0);
__decorate([
    HostListener('dragenter', ['$event']),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [Object]),
    __metadata("design:returntype", void 0)
], UiUploadComponent.prototype, "onDragEnter", null);
__decorate([
    HostListener('dragover', ['$event']),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [Object]),
    __metadata("design:returntype", void 0)
], UiUploadComponent.prototype, "onDragOver", null);
__decorate([
    HostListener('dragleave', ['$event']),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [Object]),
    __metadata("design:returntype", void 0)
], UiUploadComponent.prototype, "onDragLeave", null);
__decorate([
    HostListener('drop', ['$event']),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [Object]),
    __metadata("design:returntype", void 0)
], UiUploadComponent.prototype, "onDrop", null);
UiUploadComponent = UiUploadComponent_1 = __decorate([
    Component({
        selector: 'ui-upload',
        template: "<fieldset [disabled]=\"disabled\">\r\n    <input type=\"file\"\r\n           name=\"input\"\r\n           uiInputFile\r\n           [(ngModel)]=\"model\"\r\n           [read]=\"readFile\"\r\n           [error]=\"errorFile\"\r\n           #inputFile\r\n           [multiple]=\"multiple\"\r\n           #inputFileRef=\"uiInputFile\"\r\n           #fieldNovaImagem=\"ngModel\"\r\n           (filesChange)=\"filesChange($event)\"\r\n           [accept]=\"accept\"\r\n           [max-size]=\"maxSize\"\r\n           [max]=\"max\"\r\n           [max-file-size]=\"maxFileSize\"\r\n           class=\"ui-input-file-hidden\"/>\r\n    <div class=\"border\" [class.dragging]=\"isDragging\" [ngClass]=\"disabled ? 'fade' : ''\">\r\n        <div [@enterLeaveViewAnimation]=\"ngModel.length === 1\" *ngIf=\"ngModel && ngModel.length\">\r\n            <div [@enterLeaveViewAnimation] *ngFor=\"let file of ngModel; let i = index\">\r\n                <header>\r\n                    <div class=\"file-name\">\r\n                        {{getFileName(ngModel[i])}}\r\n                    </div>\r\n                    <button class=\"ui-button icon error flat\" type=\"button\" (click)=\"removeFile(ngModel[i], i)\"\r\n                            uiRipple>\r\n                        <i class=\"material-icons\">delete</i>\r\n                    </button>\r\n                </header>\r\n                <div class=\"ui-divider\" *ngIf=\"multiple\"></div>\r\n            </div>\r\n        </div>\r\n        <section uiRipple (click)=\"inputFile.click()\" [ripple-disable]=\"disabled\">\r\n            <i class=\"material-icons theme\">cloud_upload</i>\r\n            <div class=\"message text-area\">\r\n                Arraste e solte seu arquivo aqui <br> ou <span class=theme>encontre na sua galeria</span>\r\n            </div>\r\n        </section>\r\n    </div>\r\n</fieldset>\r\n",
        providers: [{
                provide: NG_VALUE_ACCESSOR,
                useExisting: forwardRef(() => UiUploadComponent_1),
                multi: true
            }],
        animations: [enterLeaveViewAnimation],
        styles: [":host.space{margin:8px 0;display:block}fieldset:disabled{cursor:not-allowed}fieldset:disabled i{color:#afafaf}fieldset:disabled .fade{color:#afafaf;border-color:#afafaf}fieldset:disabled .fade span{color:#afafaf}.border{border-radius:4px;position:relative;transition:border 280ms cubic-bezier(0,0,.2,1);-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none}.border .file-name,.border .message{font-weight:500}.border .file-name{font-size:16px;word-break:break-all;cursor:pointer}.border .message{text-align:center;font-size:14px}.border header{display:flex;align-items:center;padding:8px 8px 8px 16px;justify-content:space-between}.border header button{cursor:pointer}.border .ui-divider{margin:0}.border section{display:flex;justify-content:center;padding:32px;align-items:center}.border section i{font-size:55px}.border section .text-area{color:#afafaf;padding:8px}"]
    }),
    __metadata("design:paramtypes", [])
], UiUploadComponent);

const lib = [
    UiAddCalendarDirective,
    UiCalendarComponent,
    UiCalendarContentComponent,
    UiCapitalizePipe,
    UiDataTableOrderByDirective,
    UiDatePickerCallerDirective,
    UiDatePickerDirective,
    UiDialogComponent,
    UiDialogTriggerDirective,
    UiInputContainerComponent,
    UiInputDirective,
    UiMaxlengthDirective,
    UiMenuComponent,
    UiMenuTriggerDirective,
    UiNavDrawerComponent,
    UiOptionComponent,
    UiProgressRadialComponent,
    UiRippleDirective,
    UiSmartListComponent,
    UiSmartListItemComponent,
    UiSnackbarComponent,
    UiSnackbarComponent,
    UiSnackbarContainerComponent,
    UiSwitchComponent,
    UiToolbarComponent,
    UiMenuComponent,
    UiMenuTriggerDirective,
    UiProgressRadialComponent,
    UiMaskDateDirective,
    UiTimeAgoPipe,
    UiListItemDirective,
    UiMaskCpfDirective,
    UiCpfPipe,
    UiMaskCnpjDirective,
    UiCnpjPipe,
    UiMaskCepDirective,
    UiCepPipe,
    UiMaskCepNovoDirective,
    UiCepNovoPipe,
    UiMaskPhoneDirective,
    UiPhonePipe,
    UiListComponent,
    UiListItemsComponent,
    UiListItemComponent,
    UiPhonePipe,
    UiSliderComponent,
    UiSliderMultiHandleComponent,
    UiInfiniteLoadDirective,
    UiAutocompleteDirective,
    UiAutocompleteComponent,
    UiMaskIntegerDirective,
    UiTabsComponent,
    UiTabsPagesComponent,
    UiLazyLoadDirective,
    UiDataTableComponent,
    UiLazyLoadDirective,
    UiBottomSheetComponent,
    UiBottomSheetTriggerDirective,
    UiInputFileDirective,
    UiEllipsisDirective,
    UiRequiredDirective,
    UiColorPickerComponent,
    UiColorPickerDirective,
    UiInputAutosizeDirective,
    UiColorPickerDirective,
    UiClockComponent,
    UiTimePickerDirective,
    UiTimePickerCallerDirective,
    UiTimePipe,
    UiMaskTimeDirective,
    UiMaskCurrencyDirective,
    UiCurrencyPipe,
    UiSelectComponent,
    UiSelectOptionComponent,
    UiSelectFilterPipe,
    UiFilterPipe,
    UiAvatarComponent,
    UiMaskFloatDirective,
    TooltipDirective,
    UiChosenComponent,
    UiChosenOptionComponent,
    UiChosenGroupComponent,
    UiCreditCardPipe,
    UiMaskCreditCard,
    ExpansionPanelComponent,
    UiFloatPipe,
    UiTabComponent,
    UiTabGroupComponent,
    UiTabContentDirective,
    UiTabLabelDirective,
    UiTabHeaderComponent,
    UiLabelContentComponent,
    UiUploadComponent
];
let SMNUIModule = class SMNUIModule {
};
SMNUIModule = __decorate([
    NgModule({
        imports: [
            CommonModule,
            FormsModule,
            RouterModule
        ],
        schemas: [CUSTOM_ELEMENTS_SCHEMA],
        declarations: [...lib],
        exports: [...lib],
        providers: [
            UiColor,
            UiDatetimeService,
            UiElement,
            UiReferencesService,
            UiSnackbar,
            UiWindowRef,
            UiInfiniteLoadService,
            UiTimePickerService,
            UiDialog,
        ],
        entryComponents: [
            UiCalendarComponent,
            UiCalendarContentComponent,
            UiAutocompleteComponent,
            UiColorPickerComponent,
            UiClockComponent
        ]
    })
], SMNUIModule);

/*
 * Public API Surface of smn-ui
 */

/**
 * Generated bundle index. Do not edit.
 */

export { SMNUIModule, UiCepNovoPipe, UiCepPipe, UiCnpjPipe, UiColor, UiCookie, UiCpfPipe, UiCreditCardPipe, UiCurrencyPipe, UiDatetimeService, UiDialog, UiElement, UiElementRef, UiFilterPipe, UiFloatPipe, UiInfiniteLoadService, UiMaskCreditCard, UiMaskPhoneDirective, UiPhonePipe, UiSnackbar, UiTimePipe, UiToolbarService, UiWindowRef, debounce, unaccent, _isBright as ɵa, _hexToRgb as ɵb, UiSwitchComponent as ɵba, UiToolbarComponent as ɵbb, UiMaskDateDirective as ɵbc, UiTimeAgoPipe as ɵbd, UiListItemDirective as ɵbe, UiMaskCpfDirective as ɵbf, UiMaskCnpjDirective as ɵbg, UiMaskCepDirective as ɵbh, UiMaskCepNovoDirective as ɵbi, UiListComponent as ɵbj, UiListItemsComponent as ɵbk, UiListItemComponent as ɵbl, UiSliderComponent as ɵbm, UiSliderMultiHandleComponent as ɵbn, UiInfiniteLoadDirective as ɵbo, UiAutocompleteDirective as ɵbp, UiAutocompleteComponent as ɵbq, UiMaskIntegerDirective as ɵbr, UiTabsComponent as ɵbs, UiTabsPagesComponent as ɵbt, UiLazyLoadDirective as ɵbu, UiDataTableComponent as ɵbv, UiBottomSheetComponent as ɵbw, UiBottomSheetTriggerDirective as ɵbx, UiInputFileDirective as ɵby, UiEllipsisDirective as ɵbz, _window as ɵc, UiRequiredDirective as ɵca, UiColorPickerComponent as ɵcb, UiColorPickerDirective as ɵcc, UiInputAutosizeDirective as ɵcd, UiClockComponent as ɵce, UiTimePickerDirective as ɵcf, UiTimePickerService as ɵcg, UiTimePickerCallerDirective as ɵch, UiMaskTimeDirective as ɵci, UiMaskCurrencyDirective as ɵcj, UiSelectComponent as ɵck, UiSelectOptionComponent as ɵcl, UiSelectFilterPipe as ɵcm, UiAvatarComponent as ɵcn, UiMaskFloatDirective as ɵco, TooltipDirective as ɵcp, UiChosenComponent as ɵcq, UiChosenOptionComponent as ɵcr, UiChosenGroupComponent as ɵcs, ExpansionPanelComponent as ɵct, UiTabComponent as ɵcu, UiTabContentDirective as ɵcv, UiTabLabelDirective as ɵcw, UiTabGroupComponent as ɵcx, tabFakeAnimation as ɵcy, tabTransform as ɵcz, UiAddCalendarDirective as ɵd, UiTabHeaderComponent as ɵda, UiLabelContentComponent as ɵdb, UiUploadComponent as ɵdc, Upload as ɵdd, enterLeaveViewAnimation as ɵde, UiCalendarComponent as ɵe, UiCalendarContentComponent as ɵf, UiCapitalizePipe as ɵg, UiDataTableOrderByDirective as ɵh, UiDatePickerCallerDirective as ɵi, UiReferencesService as ɵj, UiDatePickerDirective as ɵk, UiDialogComponent as ɵl, UiDialogTriggerDirective as ɵm, UiInputContainerComponent as ɵn, UiInputDirective as ɵo, UiMaxlengthDirective as ɵp, UiMenuComponent as ɵq, UiMenuTriggerDirective as ɵr, UiNavDrawerComponent as ɵs, UiOptionComponent as ɵt, UiProgressRadialComponent as ɵu, UiRippleDirective as ɵv, UiSmartListComponent as ɵw, UiSmartListItemComponent as ɵx, UiSnackbarComponent as ɵy, UiSnackbarContainerComponent as ɵz };
//# sourceMappingURL=ng-smn-ui.js.map
